mapping =\
{
    "ARTEFACT_WEAPON_DESC": "Piece of an ancient and powerful weapon. Can be used to craft {0} of the same tier, or salvaged into {1}s.",
    "DECORATIVE_EQUIPMENT_DESC": "Decorative Equipment Item",
    "FISH_FRESHWATER_ALL_COMMON_DESC": "A common Albion freshwater fish.",
    "FISH_FRESHWATER_AVALON_RARE": "A rare freshwater creature found in the Roads of Avalon",
    "FISH_FRESHWATER_FOREST_RARE": "A rare freshwater creature found in Albion's forest waters.",
    "FISH_FRESHWATER_HIGHLANDS_RARE": "A rare freshwater creature found in Albion's highland waters.",
    "FISH_FRESHWATER_MOUNTAIN_RARE": "A rare freshwater creature found in Albion's mountain waters.",
    "FISH_FRESHWATER_STEPPE_RARE": "A rare freshwater creature found in Albion's steppe waters.",
    "FISH_FRESHWATER_SWAMP_RARE": "A rare freshwater creature found in Albion's swamp waters.",
    "FISH_SALTWATER_ALL_COMMON_DESC": "A common Albion ocean fish.",
    "FISH_SALTWATER_ALL_RARE": "A rare saltwater creature found in Albion's ocean waters.",
    "FISHINGBAIT_DESC": "Consumable Item. Use to attract fish more quickly!",
    "FISHSAUCE_DESC": "While cooking, add this sauce to any meal for greatly enhanced flavor!",
    "FURNITUREITEM_BED_CHARGESREADY": "The bed is freshly made and ready to rest in.",
    "FURNITUREITEM_BED_NEXTCHARGEREADY": "The bed was recently used. It can be used again in {0}.",
    "FURNITUREITEM_BED_USEBUTTON": "Sleep",
    "FURNITUREITEM_PLAYERISLAND_DESC": "Decorative item for your Island or Hideout.",
    "FURNITUREITEM_TABLE_CHARGESREADY": "Meals ready: {0} of {1}",
    "FURNITUREITEM_TABLE_NEXTCHARGEREADY": "Next meal ready in {0}",
    "FURNITUREITEM_TABLE_USEBUTTON": "Eat",
    "FURNITUREITEM_TROPHY_FIBER_DESC": "This trophy adds a respectable amount of happiness to all Cropper Laborers.",
    "FURNITUREITEM_TROPHY_FISH_DESC": "This trophy adds a respectable amount of happiness to all Fisherman Laborers.",
    "FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all types of Laborers.",
    "FURNITUREITEM_TROPHY_HARVESTER_HEART_CHARGESREADY": "Inspirations available: {0} of {1}",
    "FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to Gamekeeper Laborers.",
    "FURNITUREITEM_TROPHY_MAGICALARMOR_CHARGESREADY": "A magic glow surrounds the trophy. Touching it will increase your Magic Resist.",
    "FURNITUREITEM_TROPHY_MAGICALDAMAGE_CHARGESREADY": "A magic glow surrounds the trophy. Touching it will increase your Magical damage.",
    "FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to Mercenary Laborers.",
    "FURNITUREITEM_TROPHY_MOB_CHARGESREADY": "What a nice trophy!",
    "FURNITUREITEM_TROPHY_NEXTCHARGEREADY": "Trophy ready in {0}",
    "FURNITUREITEM_TROPHY_ORE_DESC": "This trophy adds a respectable amount of happiness to all Prospector Laborers.",
    "FURNITUREITEM_TROPHY_PHYSICALARMOR_CHARGESREADY": "A magic glow surrounds the trophy. Touching it will increase your Armor.",
    "FURNITUREITEM_TROPHY_PHYSICALDAMAGE_CHARGESREADY": "A magic glow surrounds the trophy. Touching it will increase your Physical damage.",
    "FURNITUREITEM_TROPHY_ROCK_DESC": "This trophy adds a respectable amount of happiness to all Stonecutter Laborers.",
    "FURNITUREITEM_TROPHY_USEBUTTON": "Touch",
    "FURNITUREITEM_TROPHY_WOOD_DESC": "This trophy adds a respectable amount of happiness to all Lumberjack Laborers.",
    "GENERAL_BAG_INSIGHT_DESC": "Equipment Item\nThis bag enables you to increase the Combat Fame you can gain by a certain percentage but it consumes Silver.",
    "GENERAL_EQUIPMENT_ITEM_DESC": "Equipment Item",
    "MEAL_OMELETTE_FISH_DESC": "Meal that reduces cooldowns, casting times and energy costs for a long period.",
    "MEAL_PIE_FISH_DESC": "Meal that increases maximum load, gathering yield and crowd control resistance for a long period.",
    "MEAL_ROAST_FISH_DESC": "A savory meal that heals you based on the damage you deal and raises your max health for a long period.",
    "MEAL_SALAD_FISH_DESC": "Snack that increases crafting speed and quality for a short period.",
    "MEAL_SANDWICH_FISH_DESC": "Meal that increases maximum health and healing received for a long period.",
    "MEAL_SOUP_FISH_DESC": "Meal that increases health regeneration outside of combat (and general energy regeneration) for a long period.",
    "MEAL_STEW_FISH_DESC": "Meal that increases combat damage and reduces cooldowns for a long period.",
    "PLAYERISLAND_FURNITUREITEM_FARM_DECO_B": "Haystack",
    "PLAYERISLAND_FURNITUREITEM_FARM_DECO_C": "Haystack and cart",
    "PLAYERISLAND_FURNITUREITEM_FARM_DECO_D": "Tree stump with pumpkins",
    "PLAYERISLAND_FURNITUREITEM_STONE_FIREBOWL_A": "Fire bowl",
    "PLAYERISLAND_FURNITUREITEM_STONE_FIREBOWL_B": "Fire bowl with pedestal",
    "PLAYERISLAND_FURNITUREITEM_STONE_MAGIC_EMBLEM_GROUND_A": "Small arcane stone sigil",
    "PLAYERISLAND_FURNITUREITEM_STONE_MAGIC_EMBLEM_GROUND_B": "Arcane stone sigil",
    "PLAYERISLAND_FURNITUREITEM_STONE_NATURE_EMBLEM_GROUND_A": "Small nature stone sigil",
    "PLAYERISLAND_FURNITUREITEM_STONE_NATURE_EMBLEM_GROUND_B": "Nature stone sigil",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_A": "Scholar statue",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_A_BROKEN": "Broken scholar statue",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_HUNTER_A": "Hunting sculpture",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_HUNTER_B": "Hunter statue",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_MAGE_A": "Book sculpture",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_MAGE_B": "Magician statue",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_SWORD_A": "Small sword sculpture",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_SWORD_B": "Sword sculpture",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_WARRIOR_A": "Sword and shield sculpture",
    "PLAYERISLAND_FURNITUREITEM_STONE_STATUE_WARRIOR_B": "Warrior statue",
    "PLAYERISLAND_FURNITUREITEM_STONE_VALOR_EMBLEM_GROUND_A": "Small valorous stone sigil",
    "PLAYERISLAND_FURNITUREITEM_STONE_VALOR_EMBLEM_GROUND_B": "Valorous stone sigil",
    "PLAYERISLAND_FURNITUREITEM_STONE_WELL_A": "Stone well",
    "PLAYERISLAND_FURNITUREITEM_VEGETATION_FLOWER_A": "Flower vase",
    "PLAYERISLAND_FURNITUREITEM_VEGETATION_TREE_DECO_A": "Autumn tree",
    "PLAYERISLAND_FURNITUREITEM_VEGETATION_TREE_DECO_B": "Summer tree",
    "PLAYERISLAND_FURNITUREITEM_VEGETATION_TREE_DECO_C": "Spring tree",
    "PLAYERISLAND_FURNITUREITEM_VEGETATION_TREE_DOMESTIC_A": "Small fruit tree",
    "PLAYERISLAND_FURNITUREITEM_VEGETATION_TREE_DOMESTIC_B": "Fruit tree",
    "PLAYERISLAND_FURNITUREITEM_WOOD_BARREL_A": "Barrel with candle",
    "PLAYERISLAND_FURNITUREITEM_WOOD_BUNTING_A": "Bunting portal",
    "PLAYERISLAND_FURNITUREITEM_WOOD_CANDELABRA_A": "Candelabra",
    "PLAYERISLAND_FURNITUREITEM_WOOD_FENCE_WATCHTOWER_A": "Wooden watchtower",
    "PLAYERISLAND_FURNITUREITEM_WOOD_FISH_A": "Fish line",
    "PLAYERISLAND_FURNITUREITEM_WOOD_FLOOR_SIGN_A": "Wooden sign",
    "PLAYERISLAND_FURNITUREITEM_WOOD_GATE_A": "Wooden entrance",
    "PLAYERISLAND_FURNITUREITEM_WOOD_GATE_BIG_B": "Wooden gate",
    "PLAYERISLAND_FURNITUREITEM_WOOD_LANTERN_A": "Simple lantern",
    "PLAYERISLAND_FURNITUREITEM_WOOD_LANTERN_CORNER_A": "Corner lantern",
    "PLAYERISLAND_FURNITUREITEM_WOOD_LAUNDRY_A": "Clothes line",
    "QUESTITEM_HEAVY_BARREL": "Delivery: Barrels",
    "QUESTITEM_HEAVY_BARREL_DESC": "Big wooden barrels, mainly for the shipment of liquids, grains and the like.",
    "QUESTITEM_HEAVY_CRATE": "Delivery: Crates",
    "QUESTITEM_HEAVY_CRATE_DESC": "Big wooden boxes, mainly for the shipment of solid goods.",
    "QUESTITEM_HEAVY_FARMTOOLS": "Delivery: Farmyard Tools",
    "QUESTITEM_HEAVY_FARMTOOLS_DESC": "Tools suitable both for shoeing hooves and preparing delicious cheese-based dishes.",
    "QUESTITEM_HEAVY_FIREBARREL": "Delivery: Sensitive Barrels",
    "QUESTITEM_HEAVY_FIREBARREL_DESC": "The warnings plastered all over the outside make it abundantly clear that these barrels do not contain anything mundane. The cumulative effect of all the instructions is that they should not be touched, moved or looked at, ever.",
    "QUESTITEM_HEAVY_MANURE": "Delivery: Pile of Manure",
    "QUESTITEM_HEAVY_MANURE_DESC": "Smell confirms: definitely manure.",
    "QUESTITEM_HEAVY_MEDICAL": "Delivery: Medical Supplies",
    "QUESTITEM_HEAVY_MEDICAL_DESC": "A large quantity of military-issue medical supplies. Somebody is expecting trouble...",
    "QUESTITEM_HEAVY_MOONSHINE": "Delivery: Geoff the Brigand's All-Natural Enriched Moonshine",
    "QUESTITEM_HEAVY_MOONSHINE_DESC": "\"Guaranteed free of unnatural flavourings, colourings or preservatives\", according to the label.",
    "QUESTITEM_HEAVY_MORTAR": "Delivery: Mortar",
    "QUESTITEM_HEAVY_MORTAR_DESC": "The kind you build walls with. It's pretty heavy.",
    "QUESTITEM_LIGHT_ASSASSINATION": "Delivery: Assassination Order",
    "QUESTITEM_LIGHT_ASSASSINATION_DESC": "Order for the assassination of a key enemy figure. Comes with the Royal stamp.",
    "QUESTITEM_LIGHT_BEES": "Delivery: Beehives",
    "QUESTITEM_LIGHT_BEES_DESC": "Warning: contains bees.",
    "QUESTITEM_LIGHT_BLUEPRINTS": "Delivery: Blueprints",
    "QUESTITEM_LIGHT_BLUEPRINTS_DESC": "Explains how to construct sensible buildings.",
    "QUESTITEM_LIGHT_BOOK": "Annabelle's Diary",
    "QUESTITEM_LIGHT_BOOK_DESC": "An old book bound in rich leather.",
    "QUESTITEM_LIGHT_CASUALTIES": "Delivery: Casualty Report",
    "QUESTITEM_LIGHT_CASUALTIES_DESC": "Lists all the casualties experienced by a unit in the past week. There's quite a lot...",
    "QUESTITEM_LIGHT_FUR": "Delivery: Heavy Fur",
    "QUESTITEM_LIGHT_FUR_DESC": "Useful for keeping warm. Stinks to high heaven.",
    "QUESTITEM_LIGHT_GROCERIES": "Grocery bags",
    "QUESTITEM_LIGHT_GROCERIES_DESC": "You have no idea how so few bags can be this heavy. But it's nothing you can't do in one trip!",
    "QUESTITEM_LIGHT_JEWLERY": "An old ring",
    "QUESTITEM_LIGHT_JEWLERY_DESC": "A beautifully crafted ring, like something straight out of fairy tales.",
    "QUESTITEM_LIGHT_KITTENS": "Delivery: Sack of Kittens",
    "QUESTITEM_LIGHT_KITTENS_DESC": "Someone has stitched \"NOT TOO B THRON IN RIVAR\" on the side.",
    "QUESTITEM_LIGHT_MANUSCRIPTS": "Delivery: Artistic Manuscripts",
    "QUESTITEM_LIGHT_MANUSCRIPTS_DESC": "The topmost manuscript is titled: 'Our Glorious King Who is Bold and Not That Racist' by John Quillmaster.",
    "QUESTITEM_LIGHT_OLDCLOTHES": "Delivery: Old Clothes",
    "QUESTITEM_LIGHT_OLDCLOTHES_DESC": "A big pile of old clothes, barely used. Probably fashionable once upon a time.",
    "QUESTITEM_LIGHT_PATROLROUTE": "Delivery: Patrol Route",
    "QUESTITEM_LIGHT_PATROLROUTE_DESC": "Orders for fresh patrol routes around the King's various territories.",
    "QUESTITEM_LIGHT_PIE": "Leftovers of a pie",
    "QUESTITEM_LIGHT_PIE_DESC": "The pie was real after all. What a shame it was eaten and buried.",
    "QUESTITEM_LIGHT_PRINTS": "Footprints",
    "QUESTITEM_LIGHT_PRINTS_DESC": "Petite footprints of a fashionable boot.",
    "QUESTITEM_LIGHT_RINGS": "Delivery: Regimental Rings",
    "QUESTITEM_LIGHT_RINGS_DESC": "Rings used to identify military leaders who otherwise could not be identified after battle.",
    "QUESTITEM_LIGHT_SURVEYS": "Delivery: Geomantic Surveys",
    "QUESTITEM_LIGHT_SURVEYS_DESC": "You leaf through the stack of papers. You realize you don't find rocks particularly interesting. You put the papers down...",
    "QUESTITEM_LIGHT_THEPACKAGE": "Delivery: \"The Package\"",
    "QUESTITEM_LIGHT_THEPACKAGE_DESC": "Definitely not a bird.",
    "QUESTITEM_LIGHT_WINE": "A bottle of booze",
    "QUESTITEM_LIGHT_WINE_DESC": "Looks like booze, smells like juice, tastes like juice... Not good for parties.",
    "QUESTITEM_TOKEN_ADC_FRAME": "Adventurer Token",
    "QUESTITEM_TOKEN_ADC_FRAME_DESC": "This token is achieved by salvaging an Adventurer's Challenge Avatar Ring. It can be exchanged for special rewards at the Vanity Merchant.",
    "QUESTITEM_TOKEN_ARENA_UNRANKED": "Arena Sigil",
    "QUESTITEM_TOKEN_ARENA_UNRANKED_DESC": "A Sigil for defeating your opponent in the Arena. You can buy Arena specific-rewards from the Arena Master with these Sigils.",
    "QUESTITEM_TOKEN_AVALON": "Avalonian Energy",
    "QUESTITEM_TOKEN_AVALON_DESC": "A flask emanating immense power. Can be used to craft a variety of items.",
    "QUESTITEM_TOKEN_EVENT_EASTER_2018": "Fool's Golden Egg",
    "QUESTITEM_TOKEN_EVENT_EASTER_2018_DESC": "An egg-shaped chunk of pyrite. Normally found deep underground, these eggs surface once per year all over Albion, making them highly valuable to certain collectors. \nTrade them in at the Vanity Merchant!",
    "QUESTITEM_TOKEN_EVENT_HALLOWEEN_2017": "Pumpkin Pip",
    "QUESTITEM_TOKEN_EVENT_HALLOWEEN_2017_DESC": "Ritually carved seeds of the Samhain Pumpkin quickly become engorged with eldritch power, making them highly valuable to certain collectors.",
    "QUESTITEM_TOKEN_KEEPER": "Keeper Totem",
    "QUESTITEM_TOKEN_KEEPER_DESC": "Demonstrates the bearer's service to the land.",
    "QUESTITEM_TOKEN_MORGANA": "Morgana's Favor",
    "QUESTITEM_TOKEN_MORGANA_DESC": "Enumerates the bearer's level of support amongst the Disciples.",
    "QUESTITEM_TOKEN_ROYAL": "Royal Sigil",
    "QUESTITEM_TOKEN_ROYAL_DESC": "Certifies that the bearer has completed valuable work for the King.",
    "QUESTITEM_TOKEN_ROYAL_HORSE": "Royal Horse Token",
    "QUESTITEM_TOKEN_ROYAL_HORSE_DESC": "A token that can be traded in for a powerful \"steed\". Can only be used once per person! Get your steed today!",
    "QUESTITEM_TOKEN_ROYAL_T4": "Adept's Royal Sigil",
    "QUESTITEM_TOKEN_ROYAL_T4_DESC": "Certifies that the bearer has completed valuable work for the King.",
    "QUESTITEM_TOKEN_ROYAL_T5": "Expert's Royal Sigil",
    "QUESTITEM_TOKEN_ROYAL_T5_DESC": "Certifies that the bearer has completed invaluable work for the King.",
    "QUESTITEM_TOKEN_ROYAL_T6": "Master's Royal Sigil",
    "QUESTITEM_TOKEN_ROYAL_T6_DESC": "Certifies that the bearer has completed essential work for the King.",
    "QUESTITEM_TOKEN_ROYAL_T7": "Grandmaster's Royal Sigil",
    "QUESTITEM_TOKEN_ROYAL_T7_DESC": "Certifies that the bearer has completed critical work for the King.",
    "QUESTITEM_TOKEN_ROYAL_T8": "Elder's Royal Sigil",
    "QUESTITEM_TOKEN_ROYAL_T8_DESC": "Certifies that the bearer has completed unspoken work for the King.",
    "QUESTITEM_TOKEN_UNDEAD": "Undead Knucklebone",
    "QUESTITEM_TOKEN_UNDEAD_DESC": "Recognizes the bearer's generosity to the fallen.",
    "QUESTITEM_TRANSFER_LETTER": "Letter of Transfer",
    "QUESTITEM_TRANSFER_LETTER_DESC": "Recommends you for further service at a higher level.",
    "RANDOM_DUNGEON_ELITE_TOKEN_DESC": "Use to reveal a Hidden Elite Dungeon Entrance. The map is consumed in the process.\nThis map can only be used successfully in the Outlands within range of the corresponding tier zone.",
    "RANDOM_DUNGEON_TOKEN_DESC": "Use to reveal a Hidden Entrance. The map is consumed in the process.\nThe search might fail if you're too far from a zone of the same tier as this map.",
    "SHARD_AVALONIAN_DESC": "Shard of a forgotten kingdom, used to meld artifacts.",
    "SKIN_ARMORED_HORSE_ARENA": "Arena Veteran's Armored Horse",
    "SKIN_ARMORED_HORSE_KNIGHT": "Knight Adventurer's Armored Horse",
    "SKIN_ARMORED_HORSE_KNIGHT_GUILD_COLORED": "Knight Adventurer's Guild Armored Horse",
    "SKIN_ARMORED_HORSE_MORGANA": "Morgana Mare",
    "SKIN_ARMORED_HORSE_PONY_NATIVE_CLIENT": "Armored Pony",
    "SKIN_ARMORED_HORSE_ROGUE": "Rogue Adventurer's Armored Horse",
    "SKIN_ARMORED_HORSE_ROGUE_GUILD_COLORED": "Rogue Adventurer's Guild Armored Horse",
    "SKIN_ARMORED_HORSE_T5_MOUNT_GUILD": "Expert's Guild Warhorse",
    "SKIN_ARMORED_HORSE_T6_MOUNT_GUILD": "Master's Guild Warhorse",
    "SKIN_ARMORED_HORSE_T7_MOUNT_GUILD": "Grandmaster's Guild Warhorse",
    "SKIN_ARMORED_HORSE_T8_MOUNT_GUILD": "Elder's Guild Warhorse",
    "SKIN_ARMORED_HORSE_UNDEAD": "Armored Bonehorse",
    "SKIN_COUGAR_ARENA": "Arena Veteran's Armored Sabertooth",
    "SKIN_COUGAR_ARMORED_GREY": "Steelplate Cougar",
    "SKIN_COUGAR_OCCULT": "Occult Cougar",
    "SKIN_COUGAR_TIGER_TELLAFRIEND": "Recruiter's Tiger",
    "SKIN_COUGAR_TIGER_WHITE_TELLAFRIEND": "Recruiter's White Tiger",
    "SKIN_COUGAR_TOURNAMENT": "Sabertooth Rex",
    "SKIN_DIREBEAR_PANDA_TELLAFRIEND": "Panda",
    "SKIN_DIREBOAR_HOUSEPIG": "Domesticated Hog",
    "SKIN_DIREBOAR_PIG_TELLAFRIEND": "Recruiter's Pig",
    "SKIN_DIREBOAR_WHITE_TELLAFRIEND": "White Direboar",
    "SKIN_DIREWOLF_BERNARD_TELLAFRIEND": "Recruiter's Saint Bernard",
    "SKIN_DIREWOLF_BLOODHOUND_TELLAFRIEND": "Recruiter's Rottweiler",
    "SKIN_DIREWOLF_BOBTAIL": "Sheepdog",
    "SKIN_DIREWOLF_DIREFOX_TELLAFRIEND": "Recruiter's Dire Fox",
    "SKIN_DIREWOLF_GREY_TELLAFRIEND": "Recruiter's Grey Wolf",
    "SKIN_DIREWOLF_HUSKYSLEIGH_TELLAFRIEND": "Recruiter's Husky Sled",
    "SKIN_DIREWOLF_HYENA_TELLAFRIEND": "Ironjaw Hyena",
    "SKIN_DIREWOLF_SPECTER": "Specter Wolf",
    "SKIN_DIREWOLF_WHITE": "Ghostwolf",
    "SKIN_DONKEY_HALLOWEEN": "Jack o' Donkey",
    "SKIN_DONKEY_UNIQUE_TELLAFRIEND": "Recruiter's Donkey",
    "SKIN_GIANTSTAG_ALPACA": "Stag Skin: Alpaca",
    "SKIN_GIANTSTAG_DIVINE": "Divine Stag",
    "SKIN_GIANTSTAG_IMPALA_TELLAFRIEND": "Recruiter's Impala",
    "SKIN_GIANTSTAG_TELLAFRIEND": "Recruiter's Giant Stag",
    "SKIN_GIANTSTAG_WHITE": "Master's Giant Stag",
    "SKIN_GIANTSTAG_XMAS": "Yule Stag",
    "SKIN_HORSE_BROWN": "Brown Mare",
    "SKIN_HORSE_FOUNDER_LEGENDARY": "Legendary Explorer's Horse",
    "SKIN_HORSE_GUILDBANNER": "Jousting Horse",
    "SKIN_HORSE_KEEPER": "Keeper Horse",
    "SKIN_HORSE_PONY_TELLAFRIEND": "Recruiter's Pony",
    "SKIN_HORSE_STARTERPACK": "Legendary Adventurer's Horse",
    "SKIN_HORSE_TELLAFRIEND": "Recruiter's Horse",
    "SKIN_HORSE_UNDEAD": "Bonehorse",
    "SKIN_HORSE_UNDEAD_HALLOWEEN": "Horse Macabre",
    "SKIN_HORSE_UNICORN": "Nightshade Unicorn",
    "SKIN_HORSE_UNICORN_WHITE_TELLAFRIEND": "Unicorn",
    "SKIN_LIZARD_SAND_SALAMANDER_TELLAFRIEND": "Recruiter's Sand Salamander",
    "SKIN_OX_BISON_AH": "Auction House Ox",
    "SKIN_OX_BISON_ROYAL": "Royal Ox",
    "SKIN_OX_BLACKMARKET": "Black Market Ox",
    "SKIN_OX_CART_HERETIC": "Heretic Cart",
    "SKIN_OX_CART_STARTERPACK": "Legendary Adventurer's Cart",
    "SKIN_OX_FOUNDER_LEGENDARY": "Legendary Explorer's Ox",
    "SKIN_OX_TRANSPORT_RAM_TELLAFRIEND": "Recruiter's Bighorn Ram",
    "SKIN_OX_YAK_TELLAFRIEND": "Recruiter's Yak",
    "T1_2H_TOOL_AXE": "Beginner's Axe",
    "T1_2H_TOOL_AXE_DESC": "Equipment Item",
    "T1_2H_TOOL_HAMMER": "Beginner's Stone Hammer",
    "T1_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T1_2H_TOOL_KNIFE": "Beginner's Skinning Knife",
    "T1_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T1_2H_TOOL_PICK": "Beginner's Pickaxe",
    "T1_2H_TOOL_PICK_DESC": "Equipment Item",
    "T1_2H_TOOL_SICKLE": "Beginner's Sickle",
    "T1_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T1_ARMOR_LEATHER_SET1": "Beginner's Mercenary Jacket",
    "T1_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T1_CARROT": "Carrots",
    "T1_CARROT_DESC": "Carrots are used in a variety of meals.",
    "T1_FACTION_FOREST_TOKEN_1": "Treeheart",
    "T1_FACTION_FOREST_TOKEN_1_DESC": "A local resource which can be bought in Lymhurst for Faction Points",
    "T1_FACTION_HIGHLAND_TOKEN_1": "Rockheart",
    "T1_FACTION_HIGHLAND_TOKEN_1_DESC": "A local resource which can be bought in Martlock for Faction Points",
    "T1_FACTION_MOUNTAIN_TOKEN_1": "Mountainheart",
    "T1_FACTION_MOUNTAIN_TOKEN_1_DESC": "A local resource which can be bought in Fort Sterling for Faction Points",
    "T1_FACTION_STEPPE_TOKEN_1": "Beastheart",
    "T1_FACTION_STEPPE_TOKEN_1_DESC": "A local resource which can be bought in Bridgewatch for Faction Points",
    "T1_FACTION_SWAMP_TOKEN_1": "Vineheart",
    "T1_FACTION_SWAMP_TOKEN_1_DESC": "A local resource which can be bought in Thetford for Faction Points",
    "T1_FARM_CARROT_SEED": "Carrot Seeds",
    "T1_FARM_CARROT_SEED_DESC": "Carrot Seeds are used to plant a patch of Carrots.",
    "T1_FISH_FRESHWATER_ALL_COMMON": "Common Rudd",
    "T1_FISH_SALTWATER_ALL_COMMON": "Common Herring",
    "T1_FISHCHOPS": "Chopped Fish",
    "T1_FISHCHOPS_DESC": "The primary ingredient in all Fish Sauce",
    "T1_FISHINGBAIT": "Simple Fish Bait",
    "T1_FISHSAUCE_LEVEL1": "Basic Fish Sauce",
    "T1_FISHSAUCE_LEVEL2": "Fancy Fish Sauce",
    "T1_FISHSAUCE_LEVEL3": "Special Fish Sauce",
    "T1_HEAD_LEATHER_SET1": "Beginner's Mercenary Hood",
    "T1_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T1_HIDE": "Scraps of Hide",
    "T1_HIDE_DESC": "Low-quality hide used for crafting. It is too weak to be transmuted.",
    "T1_MAIN_SWORD": "Beginner's Broadsword",
    "T1_MAIN_SWORD_DESC": "Equipment Item",
    "T1_MEAL_GRILLEDFISH": "Grilled Fish",
    "T1_MEAL_GRILLEDFISH_DESC": "Consumable Item",
    "T1_MEAL_SEAWEEDSALAD": "Seaweed Salad",
    "T1_MEAL_SEAWEEDSALAD_DESC": "Simple meal that increases fishing speed.",
    "T1_MEAL_SOUP": "Carrot Soup",
    "T1_MEAL_SOUP_DESC": "Simple meal that increases health regeneration outside of combat for a long period.",
    "T1_MEAL_SOUP_FISH": "Greenmoor Clam Soup",
    "T1_OFF_SHIELD": "Beginner's Shield",
    "T1_OFF_SHIELD_DESC": "Equipment Item",
    "T1_ROCK": "Rough Stone",
    "T1_ROCK_DESC": "Common low-quality stone used for crafting. It is too weak to be refined.",
    "T1_SEAWEED": "Seaweed",
    "T1_SEAWEED_DESC": "Cooking ingredient, used in various recipes.",
    "T1_SHOES_LEATHER_SET1": "Beginner's Mercenary Shoes",
    "T1_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T1_SILVERBAG_NONTRADABLE": "Beginner's Bag of Silver",
    "T1_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T1_SKILLBOOK_NONTRADABLE": "Beginner's Tome of Insight",
    "T1_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 1,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T1_TRASH": "Trash",
    "T1_TRASH_DESC": "A destroyed T1 item. Cannot be repaired or salvaged.",
    "T1_WOOD": "Rough Logs",
    "T1_WOOD_DESC": "Common low-quality wood used for crafting. It is too weak to be refined.",
    "T1_WORM": "Earthworm",
    "T1_WORM_DESC": "Can be used to craft fish bait",
    "T2_2H_BOW": "Novice's Bow",
    "T2_2H_BOW_DESC": "Equipment Item",
    "T2_2H_TOOL_AXE": "Novice's Axe",
    "T2_2H_TOOL_AXE_DESC": "Equipment Item",
    "T2_2H_TOOL_HAMMER": "Novice's Stone Hammer",
    "T2_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T2_2H_TOOL_KNIFE": "Novice's Skinning Knife",
    "T2_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T2_2H_TOOL_PICK": "Novice's Pickaxe",
    "T2_2H_TOOL_PICK_DESC": "Equipment Item",
    "T2_2H_TOOL_SICKLE": "Novice's Sickle",
    "T2_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T2_2H_TOOL_SIEGEHAMMER": "Novice's Demolition Hammer",
    "T2_2H_TOOL_SIEGEHAMMER_DESC": "A powerful hammer designed for destroying buildings and furniture.",
    "T2_AGARIC": "Arcane Agaric",
    "T2_AGARIC_DESC": "Arcane Agaric is used in various alchemical decoctions.",
    "T2_ARMOR_CLOTH_KEEPER": "Novice's Druid Robe",
    "T2_ARMOR_CLOTH_KEEPER_DESC": "Equipment Item",
    "T2_ARMOR_CLOTH_SET1": "Novice's Scholar Robe",
    "T2_ARMOR_CLOTH_SET1_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T2_ARMOR_LEATHER_SET1": "Novice's Mercenary Jacket",
    "T2_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T2_ARMOR_PLATE_SET1": "Novice's Soldier Armor",
    "T2_ARMOR_PLATE_SET1_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T2_BAG": "Novice's Bag",
    "T2_BAG_DESC": "Equipment Item",
    "T2_BEAN": "Beans",
    "T2_BEAN_DESC": "Beans are used in a variety of meals.",
    "T2_CAPE": "Novice's Cape",
    "T2_CAPE_DESC": "Equipment Item",
    "T2_CLOTH": "Simple Cloth",
    "T2_CLOTH_DESC": "Advanced material used in crafting, created by refining fiber.",
    "T2_FARM_AGARIC_SEED": "Arcane Agaric Seeds",
    "T2_FARM_AGARIC_SEED_DESC": "Arcane Agaric Seeds are used to plant a patch of Arcane Agaric.",
    "T2_FARM_BEAN_SEED": "Bean Seeds",
    "T2_FARM_BEAN_SEED_DESC": "Bean Seeds are used to plant a patch of Beans.",
    "T2_FIBER": "Cotton",
    "T2_FIBER_DESC": "Fiber used for crafting. Can be refined into cloth or transmuted into higher-level material.",
    "T2_FISH_FRESHWATER_ALL_COMMON": "Striped Carp",
    "T2_FISH_SALTWATER_ALL_COMMON": "Striped Mackerel",
    "T2_FURNITUREITEM_BATTLEVAULT": "Novice's Battlevault",
    "T2_FURNITUREITEM_BATTLEVAULT_DESC": "A 32-slot battlevault with a 338 kg limit. Must be placed indoors.",
    "T2_FURNITUREITEM_BED": "Novice's Bed",
    "T2_FURNITUREITEM_BED_DESC": "Increases maximum residents in the house by 1 and contributes to Laborer happiness. Item can only be placed indoors.",
    "T2_FURNITUREITEM_CHEST": "Novice's Chest",
    "T2_FURNITUREITEM_CHEST_DESC": "A 64-slot inventory with a 7353 kg limit. Must be placed indoors.",
    "T2_FURNITUREITEM_GUILDBANNER_FABRIC": "Guild Banner on Fabric",
    "T2_FURNITUREITEM_GUILDBANNER_FABRIC_DESC": "Guild Banner. Can only be placed outdoors.",
    "T2_FURNITUREITEM_GUILDBANNER_SHIELD": "Guild Banner on Shield",
    "T2_FURNITUREITEM_GUILDBANNER_SHIELD_DESC": "Guild Banner. Can only be placed outdoors.",
    "T2_FURNITUREITEM_TABLE": "Novice's Table",
    "T2_FURNITUREITEM_TABLE_DESC": "Contributes to Laborer happiness. Item can only be placed indoors.",
    "T2_FURNITUREITEM_TROPHY_FIBER": "Comfy Cotton Trophy",
    "T2_FURNITUREITEM_TROPHY_FISH": "Carp Trophy",
    "T2_FURNITUREITEM_TROPHY_GENERAL": "Adventurer's Handbook",
    "T2_FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all Laborers.",
    "T2_FURNITUREITEM_TROPHY_HIDE": "Stuffed Fox Head",
    "T2_FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to all Gamekeeper Laborers.",
    "T2_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK": "Trophy: Mage's Book",
    "T2_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK_DESC": "Increases Magic Resist. Must be placed in a player house.",
    "T2_FURNITUREITEM_TROPHY_MAGICWEAPON": "Trophy: Lesser Staff",
    "T2_FURNITUREITEM_TROPHY_MAGICWEAPON_DESC": "Increases Magical Auto-Attack damage. Must be placed in a player house.",
    "T2_FURNITUREITEM_TROPHY_MERCENARY": "Novice Mercenary's Trophy",
    "T2_FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to all Mercenary Laborers.",
    "T2_FURNITUREITEM_TROPHY_MOB": "Trophy: Fox Head",
    "T2_FURNITUREITEM_TROPHY_MOB_DESC": "Increases maximum carrying capacity. Must be placed in a player house.",
    "T2_FURNITUREITEM_TROPHY_ORE": "Copper Ore Sample",
    "T2_FURNITUREITEM_TROPHY_PHYSICALARMOR": "Trophy: Heretic's Shield",
    "T2_FURNITUREITEM_TROPHY_PHYSICALARMOR_DESC": "Increases Armor. Must be placed in a player house.",
    "T2_FURNITUREITEM_TROPHY_PHYSICALWEAPON": "Trophy: Scoundrel's Knife",
    "T2_FURNITUREITEM_TROPHY_PHYSICALWEAPON_DESC": "Increases your Physical Auto-Attack damage. Must be placed in a player house.",
    "T2_FURNITUREITEM_TROPHY_ROCK": "Limestone Fragment",
    "T2_FURNITUREITEM_TROPHY_WOOD": "Birch Bonsai",
    "T2_HEAD_CLOTH_KEEPER": "Novice's Druid Cowl",
    "T2_HEAD_CLOTH_KEEPER_DESC": "Equipment Item",
    "T2_HEAD_CLOTH_SET1": "Novice's Scholar Cowl",
    "T2_HEAD_CLOTH_SET1_DESC": "Equipment Item",
    "T2_HEAD_LEATHER_SET1": "Novice's Mercenary Hood",
    "T2_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T2_HEAD_PLATE_SET1": "Novice's Soldier Helmet",
    "T2_HEAD_PLATE_SET1_DESC": "Equipment Item",
    "T2_HIDE": "Rugged Hide",
    "T2_HIDE_DESC": "Hide used for crafting. Can be refined into leather or transmuted into higher-level material.",
    "T2_JOURNAL_FIBER": "Novice Cropper's Journal (Partially Full)",
    "T2_JOURNAL_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_FIBER_EMPTY": "Novice Cropper's Journal (Empty)",
    "T2_JOURNAL_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_FIBER_FULL": "Novice Cropper's Journal (Full)",
    "T2_JOURNAL_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_FISHING": "Novice Fisherman's Journal (Partially Full)",
    "T2_JOURNAL_FISHING_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_FISHING_EMPTY": "Novice Fisherman's Journal (Empty)",
    "T2_JOURNAL_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_FISHING_FULL": "Novice Fisherman's Journal (Full)",
    "T2_JOURNAL_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_HIDE": "Novice Gamekeeper's Journal (Partially Full)",
    "T2_JOURNAL_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_HIDE_EMPTY": "Novice Gamekeeper's Journal (Empty)",
    "T2_JOURNAL_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_HIDE_FULL": "Novice Gamekeeper's Journal (Full)",
    "T2_JOURNAL_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_HUNTER": "Novice Fletcher's Journal (Partially Full)",
    "T2_JOURNAL_HUNTER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_HUNTER_EMPTY": "Novice Fletcher's Journal (Empty)",
    "T2_JOURNAL_HUNTER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_HUNTER_FULL": "Novice Fletcher's Journal (Full)",
    "T2_JOURNAL_HUNTER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_MAGE": "Novice Imbuer's Journal (Partially Full)",
    "T2_JOURNAL_MAGE_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_MAGE_EMPTY": "Novice Imbuer's Journal (Empty)",
    "T2_JOURNAL_MAGE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_MAGE_FULL": "Novice Imbuer's Journal (Full)",
    "T2_JOURNAL_MAGE_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_MERCENARY": "Novice Mercenary's Journal (Partially Full)",
    "T2_JOURNAL_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_MERCENARY_EMPTY": "Novice Mercenary's Journal (Empty)",
    "T2_JOURNAL_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_MERCENARY_FULL": "Novice Mercenary's Journal (Full)",
    "T2_JOURNAL_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_ORE": "Novice Prospector's Journal (Partially Full)",
    "T2_JOURNAL_ORE_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_ORE_EMPTY": "Novice Prospector's Journal (Empty)",
    "T2_JOURNAL_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_ORE_FULL": "Novice Prospector's Journal (Full)",
    "T2_JOURNAL_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_STONE": "Novice Stonecutter's Journal (Partially Full)",
    "T2_JOURNAL_STONE_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_STONE_EMPTY": "Novice Stonecutter's Journal (Empty)",
    "T2_JOURNAL_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_STONE_FULL": "Novice Stonecutter's Journal (Full)",
    "T2_JOURNAL_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TOOLMAKER": "Novice Tinker's Journal (Partially Full)",
    "T2_JOURNAL_TOOLMAKER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TOOLMAKER_EMPTY": "Novice Tinker's Journal (Empty)",
    "T2_JOURNAL_TOOLMAKER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TOOLMAKER_FULL": "Novice Tinker's Journal (Full)",
    "T2_JOURNAL_TOOLMAKER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_FIBER": "Novice Cropper's Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_FIBER_EMPTY": "Novice Cropper's Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_FIBER_FULL": "Novice Cropper's Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_FISHING": "Novice Fisherman's Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_FISHING_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_FISHING_EMPTY": "Novice Fisherman's Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_FISHING_FULL": "Novice Fisherman's Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_GENERAL": "Novice's Generalist Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_GENERAL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_GENERAL_EMPTY": "Novice's Generalist Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_GENERAL_EMPTY_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_GENERAL_FULL": "Novice's Generalist Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_GENERAL_FULL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_HIDE": "Novice Gamekeeper's Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_HIDE_EMPTY": "Novice Gamekeeper's Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_HIDE_FULL": "Novice Gamekeeper's Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_MERCENARY": "Novice Mercenary's Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_MERCENARY_EMPTY": "Novice Mercenary's Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_MERCENARY_FULL": "Novice Mercenary's Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_ORE": "Novice Prospector's Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_ORE_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_ORE_EMPTY": "Novice Prospector's Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_ORE_FULL": "Novice Prospector's Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_STONE": "Novice Stonecutter's Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_STONE_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_STONE_EMPTY": "Novice Stonecutter's Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_STONE_FULL": "Novice Stonecutter's Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_WOOD": "Novice Lumberjack's Trophy Journal (Partially Full)",
    "T2_JOURNAL_TROPHY_WOOD_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_WOOD_EMPTY": "Novice Lumberjack's Trophy Journal (Empty)",
    "T2_JOURNAL_TROPHY_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_TROPHY_WOOD_FULL": "Novice Lumberjack's Trophy Journal (Full)",
    "T2_JOURNAL_TROPHY_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_WARRIOR": "Novice Blacksmith's Journal (Partially Full)",
    "T2_JOURNAL_WARRIOR_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_WARRIOR_EMPTY": "Novice Blacksmith's Journal (Empty)",
    "T2_JOURNAL_WARRIOR_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_WARRIOR_FULL": "Novice Blacksmith's Journal (Full)",
    "T2_JOURNAL_WARRIOR_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_WOOD": "Novice Lumberjack's Journal (Partially Full)",
    "T2_JOURNAL_WOOD_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_WOOD_EMPTY": "Novice Lumberjack's Journal (Empty)",
    "T2_JOURNAL_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_JOURNAL_WOOD_FULL": "Novice Lumberjack's Journal (Full)",
    "T2_JOURNAL_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T2_LABOURER_CONTRACT_FIBER": "Novice Cropper Contract",
    "T2_LABOURER_CONTRACT_FIBER_DESC": "Croppers require filled Cropper's Journals and gather fiber.",
    "T2_LABOURER_CONTRACT_FISHERMAN": "Novice Fisherman Contract",
    "T2_LABOURER_CONTRACT_FISHERMAN_DESC": "Fishermen require filled Fisherman's Journals and catch fish.",
    "T2_LABOURER_CONTRACT_HIDE": "Novice Gamekeeper Contract",
    "T2_LABOURER_CONTRACT_HIDE_DESC": "Gamekeepers require filled Gamekeeper's Journals and gather hide.",
    "T2_LABOURER_CONTRACT_HUNTER": "Novice Fletcher Contract",
    "T2_LABOURER_CONTRACT_HUNTER_DESC": "Fletchers require filled Fletcher's Journals and gather various refined materials.",
    "T2_LABOURER_CONTRACT_MAGE": "Novice Imbuer Contract",
    "T2_LABOURER_CONTRACT_MAGE_DESC": "Imbuers require filled Imbuer's Journals and gather various refined materials.",
    "T2_LABOURER_CONTRACT_MERCENARY": "Novice Mercenary Contract",
    "T2_LABOURER_CONTRACT_MERCENARY_DESC": "Mercenaries require filled Mercenary's Journals' and gather Silver.",
    "T2_LABOURER_CONTRACT_ORE": "Novice Prospector Contract",
    "T2_LABOURER_CONTRACT_ORE_DESC": "Prospectors require filled Prospector's Journals and gather ore.",
    "T2_LABOURER_CONTRACT_STONE": "Novice Stonecutter Contract",
    "T2_LABOURER_CONTRACT_STONE_DESC": "Stonecutters require filled Stonecutter's Journals and gather stone.",
    "T2_LABOURER_CONTRACT_TOOLMAKER": "Novice Tinker Contract",
    "T2_LABOURER_CONTRACT_TOOLMAKER_DESC": "Tinkers require filled Tinker's Journals and gather various refined materials.",
    "T2_LABOURER_CONTRACT_WARRIOR": "Novice Blacksmith Contract",
    "T2_LABOURER_CONTRACT_WARRIOR_DESC": "Blacksmiths require filled Blacksmith's Journals and gather various refined materials.",
    "T2_LABOURER_CONTRACT_WOOD": "Novice Lumberjack Contract",
    "T2_LABOURER_CONTRACT_WOOD_DESC": "Lumberjacks require filled Lumberjack's Journals and gather wood.",
    "T2_LEATHER": "Stiff Leather",
    "T2_LEATHER_DESC": "Advanced material used in crafting, created by refining hide.",
    "T2_MAIN_FIRESTAFF": "Novice's Fire Staff",
    "T2_MAIN_FIRESTAFF_DESC": "Equipment Item",
    "T2_MAIN_SWORD": "Novice's Broadsword",
    "T2_MAIN_SWORD_DESC": "Equipment Item",
    "T2_MEAL_SALAD": "Bean Salad",
    "T2_MEAL_SALAD_DESC": "Simple snack that increases crafting speed and quality for a short period.",
    "T2_MEAL_SALAD_FISH": "Shallowshore Squid Salad",
    "T2_METALBAR": "Copper Bar",
    "T2_METALBAR_DESC": "Advanced material used in crafting, created by refining ore.",
    "T2_MOBDROP_BOOK": "Pages from a Mage's book",
    "T2_MOBDROP_BOOK_DESC": "Use to craft a trophy you can place in your house.",
    "T2_MOBDROP_DAGGER": "Scoundrel's Broken Knife",
    "T2_MOBDROP_DAGGER_DESC": "Use to craft a trophy you can place in your house.",
    "T2_MOBDROP_FOX_HEAD": "A Fox's Head",
    "T2_MOBDROP_FOX_HEAD_DESC": "Use to craft a trophy you can place in your house.",
    "T2_MOBDROP_SHIELD": "Heretic Shield Fragment",
    "T2_MOBDROP_SHIELD_DESC": "Use to craft a trophy you can place in your house.",
    "T2_MOBDROP_STAFF": "Lesser Staff Fragment",
    "T2_MOBDROP_STAFF_DESC": "Use to craft a trophy you can place in your house.",
    "T2_MOUNT_MULE": "Novice's Mule",
    "T2_MOUNT_MULE_DESC": "Simple mount, given to new arrivals to the lands of Albion.",
    "T2_OFF_BOOK": "Novice's Tome of Spells",
    "T2_OFF_BOOK_DESC": "Equipment Item",
    "T2_OFF_SHIELD": "Novice's Shield",
    "T2_OFF_SHIELD_DESC": "Equipment Item",
    "T2_ORE": "Copper Ore",
    "T2_ORE_DESC": "Ore used for crafting. Can be refined into metal bars or transmuted into higher-level material.",
    "T2_PLANKS": "Birch Planks",
    "T2_PLANKS_DESC": "Advanced material used in crafting, created by refining logs.",
    "T2_POTION_ENERGY": "Minor Energy Potion",
    "T2_POTION_ENERGY_DESC": "Fizzing potion. Instantly restores some energy.",
    "T2_POTION_HEAL": "Minor Healing Potion",
    "T2_POTION_HEAL_DESC": "Glowing potion. Restores some health over time.",
    "T2_ROCK": "Limestone",
    "T2_ROCK_DESC": "Stone used for crafting. Can be refined into stone blocks or transmuted into higher-level material.",
    "T2_SHOES_CLOTH_KEEPER": "Novice's Druid Sandals",
    "T2_SHOES_CLOTH_KEEPER_DESC": "Equipment Item",
    "T2_SHOES_CLOTH_SET1": "Novice's Scholar Sandals",
    "T2_SHOES_CLOTH_SET1_DESC": "Equipment Item",
    "T2_SHOES_LEATHER_SET1": "Novice's Mercenary Shoes",
    "T2_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T2_SHOES_PLATE_SET1": "Novice's Soldier Boots",
    "T2_SHOES_PLATE_SET1_DESC": "Equipment Item",
    "T2_SILVERBAG_NONTRADABLE": "Novice's Bag of Silver",
    "T2_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T2_SKILLBOOK_NONTRADABLE": "Novice's Tome of Insight",
    "T2_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 2,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T2_STONEBLOCK": "Limestone Block",
    "T2_STONEBLOCK_DESC": "Advanced material used in crafting, created by refining stone.",
    "T2_TRASH": "Trash",
    "T2_TRASH_DESC": "A destroyed T2 item. Cannot be repaired or salvaged.",
    "T2_WOOD": "Birch Logs",
    "T2_WOOD_DESC": "Logs used for crafting. Can be refined into planks or transmuted into higher-level material.",
    "T3_2H_BOW": "Journeyman's Bow",
    "T3_2H_BOW_DESC": "Equipment Item",
    "T3_2H_CROSSBOW": "Journeyman's Crossbow",
    "T3_2H_CROSSBOW_DESC": "Equipment Item",
    "T3_2H_QUARTERSTAFF": "Journeyman's Quarterstaff",
    "T3_2H_QUARTERSTAFF_DESC": "Equipment Item",
    "T3_2H_TOOL_AXE": "Journeyman's Axe",
    "T3_2H_TOOL_AXE_DESC": "Equipment Item",
    "T3_2H_TOOL_FISHINGROD": "Journeyman's Fishing Rod",
    "T3_2H_TOOL_FISHINGROD_DESC": "Equipment Item",
    "T3_2H_TOOL_HAMMER": "Journeyman's Stone Hammer",
    "T3_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T3_2H_TOOL_KNIFE": "Journeyman's Skinning Knife",
    "T3_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T3_2H_TOOL_PICK": "Journeyman's Pickaxe",
    "T3_2H_TOOL_PICK_DESC": "Equipment Item",
    "T3_2H_TOOL_SICKLE": "Journeyman's Sickle",
    "T3_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T3_2H_TOOL_SIEGEHAMMER": "Journeyman's Demolition Hammer",
    "T3_2H_TOOL_SIEGEHAMMER_DESC": "A powerful hammer designed for destroying buildings and furniture.",
    "T3_ARMOR_CLOTH_KEEPER": "Journeyman's Druid Robe",
    "T3_ARMOR_CLOTH_KEEPER_DESC": "Equipment Item",
    "T3_ARMOR_CLOTH_SET1": "Journeyman's Scholar Robe",
    "T3_ARMOR_CLOTH_SET1_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T3_ARMOR_LEATHER_SET1": "Journeyman's Mercenary Jacket",
    "T3_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T3_ARMOR_PLATE_SET1": "Journeyman's Soldier Armor",
    "T3_ARMOR_PLATE_SET1_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T3_BAG": "Journeyman's Bag",
    "T3_BAG_DESC": "Equipment Item",
    "T3_CAPE": "Journeyman's Cape",
    "T3_CAPE_DESC": "Equipment Item",
    "T3_CLOTH": "Neat Cloth",
    "T3_CLOTH_DESC": "Advanced material used in crafting, created by refining fiber.",
    "T3_COMFREY": "Brightleaf Comfrey",
    "T3_COMFREY_DESC": "Brightleaf Comfrey is used in various alchemical decoctions.",
    "T3_EGG": "Hen Eggs",
    "T3_EGG_DESC": "Hen Eggs are used in several cooking recipes and potions.",
    "T3_FARM_CHICKEN_BABY": "Baby Chickens",
    "T3_FARM_CHICKEN_BABY_DESC": "You can place Baby Chickens in your pasture to grow them into Chickens.",
    "T3_FARM_CHICKEN_GROWN": "Chicken",
    "T3_FARM_CHICKEN_GROWN_DESC": "Chickens can be slaughtered to produce Raw Chicken, or left alive to produce Hen Eggs.",
    "T3_FARM_COMFREY_SEED": "Brightleaf Comfrey Seeds",
    "T3_FARM_COMFREY_SEED_DESC": "Brightleaf Comfrey Seeds are used to plant a patch of Brightleaf Comfrey.",
    "T3_FARM_HORSE_BABY": "Journeyman's Foal",
    "T3_FARM_HORSE_BABY_DESC": "Grows into a Journeyman's Horse, which can be used to craft a Journeyman's Riding Horse.",
    "T3_FARM_HORSE_GROWN": "Journeyman's Horse",
    "T3_FARM_HORSE_GROWN_DESC": "Can be used to craft a Journeyman's Riding Horse.",
    "T3_FARM_OX_BABY": "Journeyman's Ox Calf",
    "T3_FARM_OX_BABY_DESC": "Grows into a Journeyman's Ox, which can be used to craft a Journeyman's Transport Ox.",
    "T3_FARM_OX_GROWN": "Journeyman's Ox",
    "T3_FARM_OX_GROWN_DESC": "Can be used to craft a Journeyman's Transport Ox.",
    "T3_FARM_WHEAT_SEED": "Wheat Seeds",
    "T3_FARM_WHEAT_SEED_DESC": "Wheat Seeds are used to plant a patch of Wheat.",
    "T3_FIBER": "Flax",
    "T3_FIBER_DESC": "Fiber used for crafting. Can be refined into cloth or transmuted into higher-level material.",
    "T3_FISH_FRESHWATER_ALL_COMMON": "Albion Perch",
    "T3_FISH_FRESHWATER_AVALON_RARE": "Whitefog Snapper",
    "T3_FISH_FRESHWATER_FOREST_RARE": "Greenriver Eel",
    "T3_FISH_FRESHWATER_HIGHLANDS_RARE": "Stonestream Lurcher",
    "T3_FISH_FRESHWATER_MOUNTAIN_RARE": "Upland Coldeye",
    "T3_FISH_FRESHWATER_STEPPE_RARE": "Lowriver Crab",
    "T3_FISH_FRESHWATER_SWAMP_RARE": "Greenmoor Clam",
    "T3_FISH_SALTWATER_ALL_COMMON": "Flatshore Plaice",
    "T3_FISH_SALTWATER_ALL_RARE": "Shallowshore Squid",
    "T3_FISHINGBAIT": "Fancy Fish Bait",
    "T3_FLOUR": "Flour",
    "T3_FLOUR_DESC": "Used to make Bread",
    "T3_FRAGMENT_BLUE_F1": "Journeyman's Scrap of Magic",
    "T3_FRAGMENT_BLUE_F1_DESC": "Can be transmuted into a higher-tier version, which can be used for melding.",
    "T3_FRAGMENT_GREEN_F1": "Journeyman's Scrap of Nature",
    "T3_FRAGMENT_GREEN_F1_DESC": "Can be transmuted into a higher-tier version, which can be used for melding.",
    "T3_FRAGMENT_RED_F1": "Journeyman's Scrap of Valor",
    "T3_FRAGMENT_RED_F1_DESC": "Can be transmuted into a higher-tier version, which can be used for melding.",
    "T3_FURNITUREITEM_ANNIVERSARYBANNER": "Anniversary Banner - White",
    "T3_FURNITUREITEM_ANNIVERSARYBANNER_2020": "Anniversary Banner - Red",
    "T3_FURNITUREITEM_ANNIVERSARYBANNER_2020_DESC": "A decorative banner created as part of Albion's third anniversary celebrations.",
    "T3_FURNITUREITEM_ANNIVERSARYBANNER_DESC": "A decorative banner created as part of Albion's second anniversary celebrations.",
    "T3_FURNITUREITEM_BATTLEVAULT": "Journeyman's Battlevault",
    "T3_FURNITUREITEM_BATTLEVAULT_DESC": "A 32-slot battlevault with a 439 kg limit. Can only be placed indoors.",
    "T3_FURNITUREITEM_BED": "Journeyman's Bed",
    "T3_FURNITUREITEM_BED_DESC": "Increases maximum residents in the house by 1 and contributes to Laborer happiness. Item can only be placed indoors.",
    "T3_FURNITUREITEM_CHEST": "Journeyman's Chest",
    "T3_FURNITUREITEM_CHEST_DESC": "A 64-slot inventory with a 10869 kg limit. Can only be placed indoors.",
    "T3_FURNITUREITEM_GUILDBANNER_FABRIC": "Guild Banner on Fabric",
    "T3_FURNITUREITEM_GUILDBANNER_FABRIC_DESC": "Guild Banner. Can only be placed outdoors.",
    "T3_FURNITUREITEM_GUILDBANNER_SHIELD": "Guild Banner on Shield",
    "T3_FURNITUREITEM_GUILDBANNER_SHIELD_DESC": "Guild Banner. Can only be placed outdoors.",
    "T3_FURNITUREITEM_TABLE": "Journeyman's Table",
    "T3_FURNITUREITEM_TABLE_DESC": "Contributes to Laborer happiness. Item can only be placed indoors.",
    "T3_FURNITUREITEM_TROPHY_FIBER": "Fine Flax Trophy",
    "T3_FURNITUREITEM_TROPHY_FISH": "Perch Trophy",
    "T3_FURNITUREITEM_TROPHY_GENERAL": "Magical Tome",
    "T3_FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all Laborers.",
    "T3_FURNITUREITEM_TROPHY_HIDE": "Stuffed Wolf Head",
    "T3_FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to all Gamekeeper Laborers.",
    "T3_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK": "Trophy: Magical Tome",
    "T3_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK_DESC": "Increases Magic Resist. Must be placed in a player house.",
    "T3_FURNITUREITEM_TROPHY_MAGICWEAPON": "Trophy: Greater Staff",
    "T3_FURNITUREITEM_TROPHY_MAGICWEAPON_DESC": "Increases Magical Auto-Attack damage. Must be placed in a player house.",
    "T3_FURNITUREITEM_TROPHY_MERCENARY": "Journeyman Mercenary's Trophy",
    "T3_FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to all Mercenary Laborers.",
    "T3_FURNITUREITEM_TROPHY_MOB": "Trophy: Wolf's Head",
    "T3_FURNITUREITEM_TROPHY_MOB_DESC": "Increases maximum carrying capacity. Must be placed in a player house.",
    "T3_FURNITUREITEM_TROPHY_ORE": "Tin Ore Sample",
    "T3_FURNITUREITEM_TROPHY_PHYSICALARMOR": "Trophy: Light Armor",
    "T3_FURNITUREITEM_TROPHY_PHYSICALARMOR_DESC": "Increases Armor. Must be placed in a player house.",
    "T3_FURNITUREITEM_TROPHY_PHYSICALWEAPON": "Trophy: Light Weapon",
    "T3_FURNITUREITEM_TROPHY_PHYSICALWEAPON_DESC": "Increases your Physical Auto-Attack damage. Must be placed in a player house.",
    "T3_FURNITUREITEM_TROPHY_ROCK": "Sandstone Fragment",
    "T3_FURNITUREITEM_TROPHY_WOOD": "Chestnut Bonsai",
    "T3_HEAD_CLOTH_KEEPER": "Journeyman's Druid Cowl",
    "T3_HEAD_CLOTH_KEEPER_DESC": "Equipment Item",
    "T3_HEAD_CLOTH_SET1": "Journeyman's Scholar Cowl",
    "T3_HEAD_CLOTH_SET1_DESC": "Equipment Item",
    "T3_HEAD_LEATHER_SET1": "Journeyman's Mercenary Hood",
    "T3_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T3_HEAD_PLATE_SET1": "Journeyman's Soldier Helmet",
    "T3_HEAD_PLATE_SET1_DESC": "Equipment Item",
    "T3_HIDE": "Thin Hide",
    "T3_HIDE_DESC": "Hide used for crafting. Can be refined into leather or transmuted into higher-level material.",
    "T3_JOURNAL_FIBER": "Journeyman Cropper's Journal (Partially Full)",
    "T3_JOURNAL_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_FIBER_EMPTY": "Journeyman Cropper's Journal (Empty)",
    "T3_JOURNAL_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_FIBER_FULL": "Journeyman Cropper's Journal (Full)",
    "T3_JOURNAL_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_FISHING": "Journeyman Fisherman's Journal (Partially Full)",
    "T3_JOURNAL_FISHING_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_FISHING_EMPTY": "Journeyman Fisherman's Journal (Empty)",
    "T3_JOURNAL_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_FISHING_FULL": "Journeyman Fisherman's Journal (Full)",
    "T3_JOURNAL_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_HIDE": "Journeyman Gamekeeper's Journal (Partially Full)",
    "T3_JOURNAL_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_HIDE_EMPTY": "Journeyman Gamekeeper's Journal (Empty)",
    "T3_JOURNAL_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_HIDE_FULL": "Journeyman Gamekeeper's Journal (Full)",
    "T3_JOURNAL_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_HUNTER": "Journeyman Fletcher's Journal (Partially Full)",
    "T3_JOURNAL_HUNTER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_HUNTER_EMPTY": "Journeyman Fletcher's Journal (Empty)",
    "T3_JOURNAL_HUNTER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_HUNTER_FULL": "Journeyman Fletcher's Journal (Full)",
    "T3_JOURNAL_HUNTER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_MAGE": "Journeyman Imbuer's Journal (Partially Full)",
    "T3_JOURNAL_MAGE_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_MAGE_EMPTY": "Journeyman Imbuer's Journal (Empty)",
    "T3_JOURNAL_MAGE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_MAGE_FULL": "Journeyman Imbuer's Journal (Full)",
    "T3_JOURNAL_MAGE_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_MERCENARY": "Journeyman Mercenary's Journal (Partially Full)",
    "T3_JOURNAL_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_MERCENARY_EMPTY": "Journeyman Mercenary's Journal (Empty)",
    "T3_JOURNAL_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_MERCENARY_FULL": "Journeyman Mercenary's Journal (Full)",
    "T3_JOURNAL_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_ORE": "Journeyman Prospector's Journal (Partially Full)",
    "T3_JOURNAL_ORE_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_ORE_EMPTY": "Journeyman Prospector's Journal (Empty)",
    "T3_JOURNAL_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_ORE_FULL": "Journeyman Prospector's Journal (Full)",
    "T3_JOURNAL_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_STONE": "Journeyman Stonecutter's Journal (Partially Full)",
    "T3_JOURNAL_STONE_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_STONE_EMPTY": "Journeyman Stonecutter's Journal (Empty)",
    "T3_JOURNAL_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_STONE_FULL": "Journeyman Stonecutter's Journal (Full)",
    "T3_JOURNAL_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TOOLMAKER": "Journeyman Tinker's Journal (Partially Full)",
    "T3_JOURNAL_TOOLMAKER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TOOLMAKER_EMPTY": "Journeyman Tinker's Journal (Empty)",
    "T3_JOURNAL_TOOLMAKER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TOOLMAKER_FULL": "Journeyman Tinker's Journal (Full)",
    "T3_JOURNAL_TOOLMAKER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_FIBER": "Journeyman Cropper's Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_FIBER_EMPTY": "Journeyman Cropper's Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_FIBER_FULL": "Journeyman Cropper's Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_FISHING": "Journeyman Fisherman's Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_FISHING_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_FISHING_EMPTY": "Journeyman Fisherman's Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_FISHING_FULL": "Journeyman Fisherman's Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_GENERAL": "Journeyman's Generalist Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_GENERAL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_GENERAL_EMPTY": "Journeyman's Generalist Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_GENERAL_EMPTY_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_GENERAL_FULL": "Journeyman's Generalist Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_GENERAL_FULL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_HIDE": "Journeyman Gamekeeper's Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_HIDE_EMPTY": "Journeyman Gamekeeper's Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_HIDE_FULL": "Journeyman Gamekeeper's Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_MERCENARY": "Journeyman Mercenary's Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_MERCENARY_EMPTY": "Journeyman Mercenary's Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_MERCENARY_FULL": "Journeyman Mercenary's Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_ORE": "Journeyman Prospector's Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_ORE_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_ORE_EMPTY": "Journeyman Prospector's Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_ORE_FULL": "Journeyman Prospector's Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_STONE": "Journeyman Stonecutter's Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_STONE_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_STONE_EMPTY": "Journeyman Stonecutter's Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_STONE_FULL": "Journeyman Stonecutter's Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_WOOD": "Journeyman Lumberjack's Trophy Journal (Partially Full)",
    "T3_JOURNAL_TROPHY_WOOD_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_WOOD_EMPTY": "Journeyman Lumberjack's Trophy Journal (Empty)",
    "T3_JOURNAL_TROPHY_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_TROPHY_WOOD_FULL": "Journeyman Lumberjack's Trophy Journal (Full)",
    "T3_JOURNAL_TROPHY_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_WARRIOR": "Journeyman Blacksmith's Journal (Partially Full)",
    "T3_JOURNAL_WARRIOR_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_WARRIOR_EMPTY": "Journeyman Blacksmith's Journal (Empty)",
    "T3_JOURNAL_WARRIOR_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_WARRIOR_FULL": "Journeyman Blacksmith's Journal (Full)",
    "T3_JOURNAL_WARRIOR_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_WOOD": "Journeyman Lumberjack's Journal (Partially Full)",
    "T3_JOURNAL_WOOD_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_WOOD_EMPTY": "Journeyman Lumberjack's Journal (Empty)",
    "T3_JOURNAL_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_JOURNAL_WOOD_FULL": "Journeyman Lumberjack's Journal (Full)",
    "T3_JOURNAL_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T3_LABOURER_CONTRACT_FIBER": "Journeyman Cropper Contract",
    "T3_LABOURER_CONTRACT_FIBER_DESC": "Croppers require filled Cropper's Journals and gather fiber.",
    "T3_LABOURER_CONTRACT_FISHERMAN": "Journeyman Fisherman Contract",
    "T3_LABOURER_CONTRACT_FISHERMAN_DESC": "Fishermen require filled Fisherman's Journals and catch fish.",
    "T3_LABOURER_CONTRACT_HIDE": "Journeyman Gamekeeper Contract",
    "T3_LABOURER_CONTRACT_HIDE_DESC": "Gamekeepers require filled Gamekeeper's Journals and gather hide.",
    "T3_LABOURER_CONTRACT_HUNTER": "Journeyman Fletcher Contract",
    "T3_LABOURER_CONTRACT_HUNTER_DESC": "Fletchers require filled Fletcher's Journals and gather various refined materials.",
    "T3_LABOURER_CONTRACT_MAGE": "Journeyman Imbuer Contract",
    "T3_LABOURER_CONTRACT_MAGE_DESC": "Imbuers require filled Imbuer's Journals and gather various refined materials.",
    "T3_LABOURER_CONTRACT_MERCENARY": "Journeyman Mercenary Contract",
    "T3_LABOURER_CONTRACT_MERCENARY_DESC": "Mercenaries require filled Mercenary's Journals' and gather Silver.",
    "T3_LABOURER_CONTRACT_ORE": "Journeyman Prospector Contract",
    "T3_LABOURER_CONTRACT_ORE_DESC": "Prospectors require filled Prospector's Journals and gather ore.",
    "T3_LABOURER_CONTRACT_STONE": "Journeyman Stonecutter Contract",
    "T3_LABOURER_CONTRACT_STONE_DESC": "Stonecutters require filled Stonecutter's Journals and gather stone.",
    "T3_LABOURER_CONTRACT_TOOLMAKER": "Journeyman Tinker Contract",
    "T3_LABOURER_CONTRACT_TOOLMAKER_DESC": "Tinkers require filled Tinker's Journals and gather various refined materials.",
    "T3_LABOURER_CONTRACT_WARRIOR": "Journeyman Blacksmith Contract",
    "T3_LABOURER_CONTRACT_WARRIOR_DESC": "Blacksmiths require filled Blacksmith's Journals and gather various refined materials.",
    "T3_LABOURER_CONTRACT_WOOD": "Journeyman Lumberjack Contract",
    "T3_LABOURER_CONTRACT_WOOD_DESC": "Lumberjacks require filled Lumberjack's Journals and gather wood.",
    "T3_LEATHER": "Thick Leather",
    "T3_LEATHER_DESC": "Advanced material used in crafting, created by refining hide.",
    "T3_MAIN_ARCANESTAFF": "Journeyman's Arcane Staff",
    "T3_MAIN_ARCANESTAFF_DESC": "Equipment Item",
    "T3_MAIN_AXE": "Journeyman's Battleaxe",
    "T3_MAIN_AXE_DESC": "Equipment Item",
    "T3_MAIN_CURSEDSTAFF": "Journeyman's Cursed Staff",
    "T3_MAIN_CURSEDSTAFF_DESC": "Equipment Item",
    "T3_MAIN_DAGGER": "Journeyman's Dagger",
    "T3_MAIN_DAGGER_DESC": "Equipment Item",
    "T3_MAIN_FIRESTAFF": "Journeyman's Fire Staff",
    "T3_MAIN_FIRESTAFF_DESC": "Equipment Item",
    "T3_MAIN_FROSTSTAFF": "Journeyman's Frost Staff",
    "T3_MAIN_FROSTSTAFF_DESC": "Equipment Item",
    "T3_MAIN_HAMMER": "Journeyman's Hammer",
    "T3_MAIN_HAMMER_DESC": "Equipment Item",
    "T3_MAIN_HOLYSTAFF": "Journeyman's Holy Staff",
    "T3_MAIN_HOLYSTAFF_DESC": "Equipment Item",
    "T3_MAIN_MACE": "Journeyman's Mace",
    "T3_MAIN_MACE_DESC": "Equipment Item",
    "T3_MAIN_NATURESTAFF": "Journeyman's Nature Staff",
    "T3_MAIN_NATURESTAFF_DESC": "Equipment Item",
    "T3_MAIN_SPEAR": "Journeyman's Spear",
    "T3_MAIN_SPEAR_DESC": "Equipment Item",
    "T3_MAIN_SWORD": "Journeyman's Broadsword",
    "T3_MAIN_SWORD_DESC": "Equipment Item",
    "T3_MEAL_OMELETTE": "Chicken Omelette",
    "T3_MEAL_OMELETTE_AVALON": "Avalonian Chicken Omelette",
    "T3_MEAL_OMELETTE_AVALON_DESC": "Avalonian meal that reduces cooldown periods and casting times, while also increasing your defense for a long period.",
    "T3_MEAL_OMELETTE_DESC": "Solid meal that reduces cooldown periods and casting times for a long period.",
    "T3_MEAL_OMELETTE_FISH": "Lowriver Crab Omelette",
    "T3_MEAL_PIE": "Chicken Pie",
    "T3_MEAL_PIE_DESC": "Solid meal that increases maximum load and gathering yield for a long period.",
    "T3_MEAL_PIE_FISH": "Upland Coldeye Pie",
    "T3_MEAL_ROAST": "Roast Chicken",
    "T3_MEAL_ROAST_DESC": "A savory meal that heals you based on the damage you deal for a long period.",
    "T3_MEAL_ROAST_FISH": "Roasted Whitefog Snapper",
    "T3_MEAL_SOUP": "Wheat Soup",
    "T3_MEAL_SOUP_DESC": "Simple meal that increases health regeneration outside of combat for a long period.",
    "T3_MEAL_SOUP_FISH": "Murkwater Clam Soup",
    "T3_MEAT": "Raw Chicken",
    "T3_MEAT_DESC": "Cooking ingredient, used in various recipes.",
    "T3_METALBAR": "Bronze Bar",
    "T3_METALBAR_DESC": "Advanced material used in crafting, created by refining ore.",
    "T3_MOBDROP_BOOK": "Pages from a Magical Tome",
    "T3_MOBDROP_BOOK_DESC": "Use to craft a trophy you can place in your house.",
    "T3_MOBDROP_DAGGER": "Small Weapon Fragment",
    "T3_MOBDROP_DAGGER_DESC": "Use to craft a trophy you can place in your house.",
    "T3_MOBDROP_SHIELD": "Light Armor Fragment",
    "T3_MOBDROP_SHIELD_DESC": "Use to craft a trophy you can place in your house.",
    "T3_MOBDROP_STAFF": "Greater Staff Fragment",
    "T3_MOBDROP_STAFF_DESC": "Use to craft a trophy you can place in your house.",
    "T3_MOBDROP_WOLF_HEAD": "Wolf's Head",
    "T3_MOBDROP_WOLF_HEAD_DESC": "Use to craft a trophy you can place in your house.",
    "T3_MOUNT_HORSE": "Journeyman's Riding Horse",
    "T3_MOUNT_HORSE_DESC": "Horses are commonly used for travel throughout Albion, and provide the fastest means of getting around.",
    "T3_MOUNT_OX": "Journeyman's Transport Ox",
    "T3_MOUNT_OX_DESC": "Albion oxen are tough, and sturdy enough to carry large quantities of goods, but cannot match the pace of the continent's horses.",
    "T3_OFF_BOOK": "Journeyman's Tome of Spells",
    "T3_OFF_BOOK_DESC": "Equipment Item",
    "T3_OFF_SHIELD": "Journeyman's Shield",
    "T3_OFF_SHIELD_DESC": "Equipment Item",
    "T3_OFF_TORCH": "Journeyman's Torch",
    "T3_OFF_TORCH_DESC": "Equipment Item",
    "T3_ORE": "Tin Ore",
    "T3_ORE_DESC": "Ore used for crafting. Can be refined into metal bars or transmuted into higher-level material.",
    "T3_PLANKS": "Chestnut Planks",
    "T3_PLANKS_DESC": "Advanced material used in crafting, created by refining logs.",
    "T3_POTION_REVIVE": "Minor Gigantify Potion",
    "T3_POTION_REVIVE_DESC": "Mystical Potion. Temporarily increases your max load and max health.",
    "T3_POTION_SLOWFIELD": "Minor Sticky Potion",
    "T3_POTION_SLOWFIELD_DESC": "A viscous potion. Throw it on a ground location to create an area that slows enemies and reduces their damage.",
    "T3_POTION_STONESKIN": "Minor Resistance Potion",
    "T3_POTION_STONESKIN_DESC": "Sluggish potion. Increases defenses substantially for a short period.",
    "T3_PREMIUMITEM_3_NONTRADABLE": "Three Days of Premium",
    "T3_PREMIUMITEM_3_NONTRADABLE_DESC": "A non-tradable item that grants you three days of Premium. The Premium time is applied to the active character.",
    "T3_PREMIUMITEM_5_NONTRADABLE": "Five Days of Premium",
    "T3_PREMIUMITEM_5_NONTRADABLE_DESC": "A non-tradable item that grants you five days of Premium. The Premium time is applied to the active character.",
    "T3_ROCK": "Sandstone",
    "T3_ROCK_DESC": "Stone used for crafting. Can be refined into stone blocks or transmuted into higher-level material.",
    "T3_SHOES_CLOTH_KEEPER": "Journeyman's Druid Sandals",
    "T3_SHOES_CLOTH_KEEPER_DESC": "Equipment Item",
    "T3_SHOES_CLOTH_SET1": "Journeyman's Scholar Sandals",
    "T3_SHOES_CLOTH_SET1_DESC": "Equipment Item",
    "T3_SHOES_LEATHER_SET1": "Journeyman's Mercenary Shoes",
    "T3_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T3_SHOES_PLATE_SET1": "Journeyman's Soldier Boots",
    "T3_SHOES_PLATE_SET1_DESC": "Equipment Item",
    "T3_SILVERBAG_NONTRADABLE": "Journeyman's Bag of Silver",
    "T3_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T3_SKILLBOOK_NONTRADABLE": "Journeyman's Tome of Insight",
    "T3_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 5,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T3_STONEBLOCK": "Sandstone Block",
    "T3_STONEBLOCK_DESC": "Advanced material used in crafting, created by refining stone.",
    "T3_TRASH": "Trash",
    "T3_TRASH_DESC": "A destroyed T3 item. Cannot be repaired or salvaged.",
    "T3_VANITY_CONSUMABLE_FIREWORKS_BLUE": "Royal Blue Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_BLUE_DESC": "Vanity Item",
    "T3_VANITY_CONSUMABLE_FIREWORKS_BLUE_NONTRADABLE": "Royal Blue Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_BLUE_NONTRADABLE_DESC": "Vanity Item",
    "T3_VANITY_CONSUMABLE_FIREWORKS_GREEN": "Royal Green Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_GREEN_DESC": "Vanity Item",
    "T3_VANITY_CONSUMABLE_FIREWORKS_GREEN_NONTRADABLE": "Royal Green Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_GREEN_NONTRADABLE_DESC": "Vanity Item",
    "T3_VANITY_CONSUMABLE_FIREWORKS_RED": "Royal Red Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_RED_DESC": "Vanity Item",
    "T3_VANITY_CONSUMABLE_FIREWORKS_RED_NONTRADABLE": "Royal Red Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_RED_NONTRADABLE_DESC": "Vanity Item",
    "T3_VANITY_CONSUMABLE_FIREWORKS_YELLOW": "Royal Yellow Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_YELLOW_DESC": "Vanity Item",
    "T3_VANITY_CONSUMABLE_FIREWORKS_YELLOW_NONTRADABLE": "Royal Yellow Fireworks",
    "T3_VANITY_CONSUMABLE_FIREWORKS_YELLOW_NONTRADABLE_DESC": "Vanity Item",
    "T3_WHEAT": "Sheaf of Wheat",
    "T3_WHEAT_DESC": "You can grind Wheat into Flour at a Mill, or use it to create meals.",
    "T3_WOOD": "Chestnut Logs",
    "T3_WOOD_DESC": "Logs used for crafting. Can be refined into planks or transmuted into higher-level material.",
    "T4_2H_ARCANE_RINGPAIR_AVALON": "Adept's Evensong",
    "T4_2H_ARCANE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T4_2H_ARCANESTAFF": "Adept's Great Arcane Staff",
    "T4_2H_ARCANESTAFF_DESC": "Equipment Item",
    "T4_2H_ARCANESTAFF_HELL": "Adept's Occult Staff",
    "T4_2H_ARCANESTAFF_HELL_DESC": "Equipment Item",
    "T4_2H_AXE": "Adept's Greataxe",
    "T4_2H_AXE_AVALON": "Adept's Realmbreaker",
    "T4_2H_AXE_AVALON_DESC": "Equipment Item",
    "T4_2H_AXE_DESC": "Equipment Item",
    "T4_2H_BOW": "Adept's Bow",
    "T4_2H_BOW_AVALON": "Adept's Mistpiercer",
    "T4_2H_BOW_AVALON_DESC": "Equipment Item",
    "T4_2H_BOW_DESC": "Equipment Item",
    "T4_2H_BOW_HELL": "Adept's Wailing Bow",
    "T4_2H_BOW_HELL_DESC": "Equipment Item",
    "T4_2H_BOW_KEEPER": "Adept's Bow of Badon",
    "T4_2H_BOW_KEEPER_DESC": "Equipment Item",
    "T4_2H_CLAWPAIR": "Adept's Claws",
    "T4_2H_CLAWPAIR_DESC": "Equipment Item",
    "T4_2H_CLAYMORE": "Adept's Claymore",
    "T4_2H_CLAYMORE_AVALON": "Adept's Kingmaker",
    "T4_2H_CLAYMORE_AVALON_DESC": "Equipment Item",
    "T4_2H_CLAYMORE_DESC": "Equipment Item",
    "T4_2H_CLEAVER_HELL": "Adept's Carving Sword",
    "T4_2H_CLEAVER_HELL_DESC": "Equipment Item",
    "T4_2H_COMBATSTAFF_MORGANA": "Adept's Black Monk Stave",
    "T4_2H_COMBATSTAFF_MORGANA_DESC": "Equipment Item",
    "T4_2H_CROSSBOW": "Adept's Crossbow",
    "T4_2H_CROSSBOW_CANNON_AVALON": "Adept's Energy Shaper",
    "T4_2H_CROSSBOW_CANNON_AVALON_DESC": "Equipment Item",
    "T4_2H_CROSSBOW_DESC": "Equipment Item",
    "T4_2H_CROSSBOWLARGE": "Adept's Heavy Crossbow",
    "T4_2H_CROSSBOWLARGE_DESC": "Equipment Item",
    "T4_2H_CROSSBOWLARGE_MORGANA": "Adept's Siegebow",
    "T4_2H_CROSSBOWLARGE_MORGANA_DESC": "Equipment Item",
    "T4_2H_CURSEDSTAFF": "Adept's Great Cursed Staff",
    "T4_2H_CURSEDSTAFF_DESC": "Equipment Item",
    "T4_2H_CURSEDSTAFF_MORGANA": "Adept's Damnation Staff",
    "T4_2H_CURSEDSTAFF_MORGANA_DESC": "Equipment Item",
    "T4_2H_DAGGER_KATAR_AVALON": "Adept's Bridled Fury",
    "T4_2H_DAGGER_KATAR_AVALON_DESC": "Equipment Item",
    "T4_2H_DAGGERPAIR": "Adept's Dagger Pair",
    "T4_2H_DAGGERPAIR_DESC": "Equipment Item",
    "T4_2H_DEMONICSTAFF": "Adept's Demonic Staff",
    "T4_2H_DEMONICSTAFF_DESC": "Equipment Item",
    "T4_2H_DIVINESTAFF": "Adept's Divine Staff",
    "T4_2H_DIVINESTAFF_DESC": "Equipment Item",
    "T4_2H_DOUBLEBLADEDSTAFF": "Adept's Double Bladed Staff",
    "T4_2H_DOUBLEBLADEDSTAFF_DESC": "Equipment Item",
    "T4_2H_DUALAXE_KEEPER": "Adept's Bear Paws",
    "T4_2H_DUALAXE_KEEPER_DESC": "Equipment Item",
    "T4_2H_DUALCROSSBOW_HELL": "Adept's Boltcasters",
    "T4_2H_DUALCROSSBOW_HELL_DESC": "Equipment Item",
    "T4_2H_DUALHAMMER_HELL": "Adept's Forge Hammers",
    "T4_2H_DUALHAMMER_HELL_DESC": "Equipment Item",
    "T4_2H_DUALMACE_AVALON": "Adept's Oathkeepers",
    "T4_2H_DUALMACE_AVALON_DESC": "Equipment Item",
    "T4_2H_DUALSCIMITAR_UNDEAD": "Adept's Galatine Pair",
    "T4_2H_DUALSCIMITAR_UNDEAD_DESC": "Equipment Item",
    "T4_2H_DUALSICKLE_UNDEAD": "Adept's Deathgivers",
    "T4_2H_DUALSICKLE_UNDEAD_DESC": "Equipment Item",
    "T4_2H_DUALSWORD": "Adept's Dual Swords",
    "T4_2H_DUALSWORD_DESC": "Equipment Item",
    "T4_2H_ENIGMATICORB_MORGANA": "Adept's Malevolent Locus",
    "T4_2H_ENIGMATICORB_MORGANA_DESC": "Equipment Item",
    "T4_2H_ENIGMATICSTAFF": "Adept's Enigmatic Staff",
    "T4_2H_ENIGMATICSTAFF_DESC": "Equipment Item",
    "T4_2H_FIRE_RINGPAIR_AVALON": "Adept's Dawnsong",
    "T4_2H_FIRE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T4_2H_FIRESTAFF": "Adept's Great Fire Staff",
    "T4_2H_FIRESTAFF_DESC": "Equipment Item",
    "T4_2H_FIRESTAFF_HELL": "Adept's Brimstone Staff",
    "T4_2H_FIRESTAFF_HELL_DESC": "Equipment Item",
    "T4_2H_FLAIL": "Adept's Morning Star",
    "T4_2H_FLAIL_DESC": "Equipment Item",
    "T4_2H_FROSTSTAFF": "Adept's Great Frost Staff",
    "T4_2H_FROSTSTAFF_DESC": "Equipment Item",
    "T4_2H_GLACIALSTAFF": "Adept's Glacial Staff",
    "T4_2H_GLACIALSTAFF_DESC": "Equipment Item",
    "T4_2H_GLAIVE": "Adept's Glaive",
    "T4_2H_GLAIVE_DESC": "Equipment Item",
    "T4_2H_HALBERD": "Adept's Halberd",
    "T4_2H_HALBERD_DESC": "Equipment Item",
    "T4_2H_HALBERD_MORGANA": "Adept's Carrioncaller",
    "T4_2H_HALBERD_MORGANA_DESC": "Equipment Item",
    "T4_2H_HAMMER": "Adept's Great Hammer",
    "T4_2H_HAMMER_AVALON": "Adept's Hand of Justice",
    "T4_2H_HAMMER_AVALON_DESC": "Equipment Item",
    "T4_2H_HAMMER_DESC": "Equipment Item",
    "T4_2H_HAMMER_UNDEAD": "Adept's Tombhammer",
    "T4_2H_HAMMER_UNDEAD_DESC": "Equipment Item",
    "T4_2H_HARPOON_HELL": "Adept's Spirithunter",
    "T4_2H_HARPOON_HELL_DESC": "Equipment Item",
    "T4_2H_HOLYSTAFF": "Adept's Great Holy Staff",
    "T4_2H_HOLYSTAFF_DESC": "Equipment Item",
    "T4_2H_HOLYSTAFF_HELL": "Adept's Fallen Staff",
    "T4_2H_HOLYSTAFF_HELL_DESC": "Equipment Item",
    "T4_2H_HOLYSTAFF_UNDEAD": "Adept's Redemption Staff",
    "T4_2H_HOLYSTAFF_UNDEAD_DESC": "Equipment Item",
    "T4_2H_ICECRYSTAL_UNDEAD": "Adept's Permafrost Prism",
    "T4_2H_ICECRYSTAL_UNDEAD_DESC": "Equipment Item",
    "T4_2H_ICEGAUNTLETS_HELL": "Adept's Icicle Staff",
    "T4_2H_ICEGAUNTLETS_HELL_DESC": "Equipment Item",
    "T4_2H_INFERNOSTAFF": "Adept's Infernal Staff",
    "T4_2H_INFERNOSTAFF_DESC": "Equipment Item",
    "T4_2H_INFERNOSTAFF_MORGANA": "Adept's Blazing Staff",
    "T4_2H_INFERNOSTAFF_MORGANA_DESC": "Equipment Item",
    "T4_2H_IRONCLADEDSTAFF": "Adept's Iron-clad Staff",
    "T4_2H_IRONCLADEDSTAFF_DESC": "Equipment Item",
    "T4_2H_IRONGAUNTLETS_HELL": "Adept's Black Hands",
    "T4_2H_IRONGAUNTLETS_HELL_DESC": "Equipment Item",
    "T4_2H_LONGBOW": "Adept's Longbow",
    "T4_2H_LONGBOW_DESC": "Equipment Item",
    "T4_2H_LONGBOW_ROYAL": "Royal Longbow",
    "T4_2H_LONGBOW_ROYAL_DESC": "Equipment Item",
    "T4_2H_LONGBOW_UNDEAD": "Adept's Whispering Bow",
    "T4_2H_LONGBOW_UNDEAD_DESC": "Equipment Item",
    "T4_2H_MACE": "Adept's Heavy Mace",
    "T4_2H_MACE_DESC": "Equipment Item",
    "T4_2H_MACE_MORGANA": "Adept's Camlann Mace",
    "T4_2H_MACE_MORGANA_DESC": "Equipment Item",
    "T4_2H_NATURESTAFF": "Adept's Great Nature Staff",
    "T4_2H_NATURESTAFF_DESC": "Equipment Item",
    "T4_2H_NATURESTAFF_HELL": "Adept's Blight Staff",
    "T4_2H_NATURESTAFF_HELL_DESC": "Equipment Item",
    "T4_2H_NATURESTAFF_KEEPER": "Adept's Rampant Staff",
    "T4_2H_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T4_2H_POLEHAMMER": "Adept's Polehammer",
    "T4_2H_POLEHAMMER_DESC": "Equipment Item",
    "T4_2H_QUARTERSTAFF": "Adept's Quarterstaff",
    "T4_2H_QUARTERSTAFF_AVALON": "Adept's Grailseeker",
    "T4_2H_QUARTERSTAFF_AVALON_DESC": "Equipment Item",
    "T4_2H_QUARTERSTAFF_DESC": "Equipment Item",
    "T4_2H_RAM_KEEPER": "Adept's Grovekeeper",
    "T4_2H_RAM_KEEPER_DESC": "Equipment Item",
    "T4_2H_REPEATINGCROSSBOW_UNDEAD": "Adept's Weeping Repeater",
    "T4_2H_REPEATINGCROSSBOW_UNDEAD_DESC": "Equipment Item",
    "T4_2H_ROCKSTAFF_KEEPER": "Adept's Staff of Balance",
    "T4_2H_ROCKSTAFF_KEEPER_DESC": "Equipment Item",
    "T4_2H_SCYTHE": "Adept's Scythe",
    "T4_2H_SCYTHE_DESC": "Equipment Item",
    "T4_2H_SCYTHE_HELL": "Adept's Infernal Scythe",
    "T4_2H_SCYTHE_HELL_DESC": "Equipment Item",
    "T4_2H_SKULLORB_HELL": "Adept's Cursed Skull",
    "T4_2H_SKULLORB_HELL_DESC": "Equipment Item",
    "T4_2H_SPEAR": "Adept's Pike",
    "T4_2H_SPEAR_DESC": "Equipment Item",
    "T4_2H_TOOL_AXE": "Adept's Axe",
    "T4_2H_TOOL_AXE_AVALON": "Adept's Avalonian Axe",
    "T4_2H_TOOL_AXE_DESC": "Equipment Item",
    "T4_2H_TOOL_FISHINGROD": "Adept's Fishing Rod",
    "T4_2H_TOOL_FISHINGROD_AVALON": "Adept's Avalonian Fishing Rod",
    "T4_2H_TOOL_FISHINGROD_DESC": "Equipment Item",
    "T4_2H_TOOL_HAMMER": "Adept's Stone Hammer",
    "T4_2H_TOOL_HAMMER_AVALON": "Adept's Avalonian Stone Hammer",
    "T4_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T4_2H_TOOL_KNIFE": "Adept's Skinning Knife",
    "T4_2H_TOOL_KNIFE_AVALON": "Adept's Avalonian Skinning Knife",
    "T4_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T4_2H_TOOL_PICK": "Adept's Pickaxe",
    "T4_2H_TOOL_PICK_AVALON": "Adept's Avalonian Pickaxe",
    "T4_2H_TOOL_PICK_DESC": "Equipment Item",
    "T4_2H_TOOL_SICKLE": "Adept's Sickle",
    "T4_2H_TOOL_SICKLE_AVALON": "Adept's Avalonian Sickle",
    "T4_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T4_2H_TOOL_SIEGEHAMMER": "Adept's Demolition Hammer",
    "T4_2H_TOOL_SIEGEHAMMER_AVALON": "Adept's Avalonian Demolition Hammer",
    "T4_2H_TOOL_SIEGEHAMMER_DESC": "A powerful hammer designed for destroying buildings and furniture.",
    "T4_2H_TRIDENT_UNDEAD": "Adept's Trinity Spear",
    "T4_2H_TRIDENT_UNDEAD_DESC": "Equipment Item",
    "T4_2H_TWINSCYTHE_HELL": "Adept's Soulscythe",
    "T4_2H_TWINSCYTHE_HELL_DESC": "Equipment Item",
    "T4_2H_WARBOW": "Adept's Warbow",
    "T4_2H_WARBOW_DESC": "Equipment Item",
    "T4_2H_WILDSTAFF": "Adept's Wild Staff",
    "T4_2H_WILDSTAFF_DESC": "Equipment Item",
    "T4_ARMOR_CLOTH_AVALON": "Adept's Robe of Purity",
    "T4_ARMOR_CLOTH_HELL": "Adept's Fiend Robe",
    "T4_ARMOR_CLOTH_HELL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T4_ARMOR_CLOTH_KEEPER": "Adept's Druid Robe",
    "T4_ARMOR_CLOTH_KEEPER_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T4_ARMOR_CLOTH_MORGANA": "Adept's Cultist Robe",
    "T4_ARMOR_CLOTH_MORGANA_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T4_ARMOR_CLOTH_ROYAL": "Adept's Royal Robe",
    "T4_ARMOR_CLOTH_ROYAL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T4_ARMOR_CLOTH_SET1": "Adept's Scholar Robe",
    "T4_ARMOR_CLOTH_SET1_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T4_ARMOR_CLOTH_SET2": "Adept's Cleric Robe",
    "T4_ARMOR_CLOTH_SET2_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T4_ARMOR_CLOTH_SET3": "Adept's Mage Robe",
    "T4_ARMOR_CLOTH_SET3_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T4_ARMOR_GATHERER_FIBER": "Adept's Harvester Garb",
    "T4_ARMOR_GATHERER_FIBER_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T4_ARMOR_GATHERER_FISH": "Adept's Fisherman Garb",
    "T4_ARMOR_GATHERER_FISH_DESC": "Equipment Item\nGatherer Gear helps you gather more of its resource type",
    "T4_ARMOR_GATHERER_HIDE": "Adept's Skinner Garb",
    "T4_ARMOR_GATHERER_HIDE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T4_ARMOR_GATHERER_ORE": "Adept's Miner Garb",
    "T4_ARMOR_GATHERER_ORE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T4_ARMOR_GATHERER_ROCK": "Adept's Quarrier Garb",
    "T4_ARMOR_GATHERER_ROCK_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T4_ARMOR_GATHERER_WOOD": "Adept's Lumberjack Garb",
    "T4_ARMOR_GATHERER_WOOD_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T4_ARMOR_LEATHER_AVALON": "Adept's Jacket of Tenacity",
    "T4_ARMOR_LEATHER_HELL": "Adept's Hellion Jacket",
    "T4_ARMOR_LEATHER_HELL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T4_ARMOR_LEATHER_MORGANA": "Adept's Stalker Jacket",
    "T4_ARMOR_LEATHER_MORGANA_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T4_ARMOR_LEATHER_ROYAL": "Adept's Royal Jacket",
    "T4_ARMOR_LEATHER_ROYAL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T4_ARMOR_LEATHER_SET1": "Adept's Mercenary Jacket",
    "T4_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T4_ARMOR_LEATHER_SET2": "Adept's Hunter Jacket",
    "T4_ARMOR_LEATHER_SET2_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T4_ARMOR_LEATHER_SET3": "Adept's Assassin Jacket",
    "T4_ARMOR_LEATHER_SET3_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T4_ARMOR_LEATHER_UNDEAD": "Adept's Specter Jacket",
    "T4_ARMOR_LEATHER_UNDEAD_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T4_ARMOR_PLATE_AVALON": "Adept's Armor of Valor",
    "T4_ARMOR_PLATE_HELL": "Adept's Demon Armor",
    "T4_ARMOR_PLATE_HELL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T4_ARMOR_PLATE_KEEPER": "Adept's Judicator Armor",
    "T4_ARMOR_PLATE_KEEPER_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T4_ARMOR_PLATE_ROYAL": "Adept's Royal Armor",
    "T4_ARMOR_PLATE_ROYAL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T4_ARMOR_PLATE_SET1": "Adept's Soldier Armor",
    "T4_ARMOR_PLATE_SET1_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T4_ARMOR_PLATE_SET2": "Adept's Knight Armor",
    "T4_ARMOR_PLATE_SET2_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T4_ARMOR_PLATE_SET3": "Adept's Guardian Armor",
    "T4_ARMOR_PLATE_SET3_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T4_ARMOR_PLATE_UNDEAD": "Adept's Graveguard Armor",
    "T4_ARMOR_PLATE_UNDEAD_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T4_ARTEFACT_2H_ARCANE_RINGPAIR_AVALON": "Adept's Hypnotic Harmonic Ring",
    "T4_ARTEFACT_2H_ARCANESTAFF_HELL": "Adept's Occult Orb",
    "T4_ARTEFACT_2H_AXE_AVALON": "Adept's Avalonian Battle Memoir",
    "T4_ARTEFACT_2H_BOW_AVALON": "Adept's Immaculately Crafted Riser",
    "T4_ARTEFACT_2H_BOW_HELL": "Adept's Demonic Arrowheads",
    "T4_ARTEFACT_2H_BOW_KEEPER": "Adept's Carved bone",
    "T4_ARTEFACT_2H_CLAYMORE_AVALON": "Adept's Remnants of the Old King",
    "T4_ARTEFACT_2H_CLEAVER_HELL": "Adept's Demonic Blade",
    "T4_ARTEFACT_2H_COMBATSTAFF_MORGANA": "Adept's Reinforced Morgana Pole",
    "T4_ARTEFACT_2H_CROSSBOW_CANNON_AVALON": "Adept's Humming Avalonian Whirligig",
    "T4_ARTEFACT_2H_CROSSBOWLARGE_MORGANA": "Adept's Alluring Bolts",
    "T4_ARTEFACT_2H_CURSEDSTAFF_MORGANA": "Adept's Bloodforged Catalyst",
    "T4_ARTEFACT_2H_DAGGER_KATAR_AVALON": "Adept's Bloodstained Antiquities",
    "T4_ARTEFACT_2H_DUALAXE_KEEPER": "Adept's Keeper Axeheads",
    "T4_ARTEFACT_2H_DUALCROSSBOW_HELL": "Adept's Hellish Bolts",
    "T4_ARTEFACT_2H_DUALHAMMER_HELL": "Adept's Hellish Hammer Heads",
    "T4_ARTEFACT_2H_DUALMACE_AVALON": "Adept's Broken Oaths",
    "T4_ARTEFACT_2H_DUALSCIMITAR_UNDEAD": "Adept's Cursed Blades",
    "T4_ARTEFACT_2H_DUALSICKLE_UNDEAD": "Adept's Ghastly Blades",
    "T4_ARTEFACT_2H_ENIGMATICORB_MORGANA": "Adept's Possessed Catalyst",
    "T4_ARTEFACT_2H_FIRE_RINGPAIR_AVALON": "Adept's Glowing Harmonic Ring",
    "T4_ARTEFACT_2H_FIRESTAFF_HELL": "Adept's Burning Orb",
    "T4_ARTEFACT_2H_HALBERD_MORGANA": "Adept's Morgana Halberd Head",
    "T4_ARTEFACT_2H_HAMMER_AVALON": "Adept's Massive Metallic Hand",
    "T4_ARTEFACT_2H_HAMMER_UNDEAD": "Adept's Ancient Hammer Head",
    "T4_ARTEFACT_2H_HARPOON_HELL": "Adept's Infernal Harpoon Tip",
    "T4_ARTEFACT_2H_HOLYSTAFF_HELL": "Adept's Infernal Scroll",
    "T4_ARTEFACT_2H_HOLYSTAFF_UNDEAD": "Adept's Ghastly Scroll",
    "T4_ARTEFACT_2H_ICECRYSTAL_UNDEAD": "Adept's Cursed Frozen Crystal",
    "T4_ARTEFACT_2H_ICEGAUNTLETS_HELL": "Adept's Icicle Orb",
    "T4_ARTEFACT_2H_INFERNOSTAFF_MORGANA": "Adept's Unholy Scroll",
    "T4_ARTEFACT_2H_IRONGAUNTLETS_HELL": "Adept's Black Leather",
    "T4_ARTEFACT_2H_LONGBOW_UNDEAD": "Adept's Ghastly Arrows",
    "T4_ARTEFACT_2H_MACE_MORGANA": "Adept's Imbued Mace Head",
    "T4_ARTEFACT_2H_NATURESTAFF_HELL": "Adept's Symbol of Blight",
    "T4_ARTEFACT_2H_NATURESTAFF_KEEPER": "Adept's Preserved Log",
    "T4_ARTEFACT_2H_QUARTERSTAFF_AVALON": "Adept's Timeworn Walking Staff",
    "T4_ARTEFACT_2H_RAM_KEEPER": "Adept's Engraved Log",
    "T4_ARTEFACT_2H_REPEATINGCROSSBOW_UNDEAD": "Adept's Lost Crossbow Mechanism",
    "T4_ARTEFACT_2H_ROCKSTAFF_KEEPER": "Adept's Preserved Rocks",
    "T4_ARTEFACT_2H_SCYTHE_HELL": "Adept's Hellish Sicklehead",
    "T4_ARTEFACT_2H_SKULLORB_HELL": "Adept's Cursed Jawbone",
    "T4_ARTEFACT_2H_TRIDENT_UNDEAD": "Adept's Cursed Barbs",
    "T4_ARTEFACT_2H_TWINSCYTHE_HELL": "Adept's Hellish Sicklehead Pair",
    "T4_ARTEFACT_ARMOR_CLOTH_AVALON": "Adept's Sanctified Belt",
    "T4_ARTEFACT_ARMOR_CLOTH_HELL": "Adept's Infernal Cloth Folds",
    "T4_ARTEFACT_ARMOR_CLOTH_KEEPER": "Adept's Druidic Feathers",
    "T4_ARTEFACT_ARMOR_CLOTH_MORGANA": "Adept's Alluring Amulet",
    "T4_ARTEFACT_ARMOR_LEATHER_AVALON": "Adept's Augured Sash",
    "T4_ARTEFACT_ARMOR_LEATHER_HELL": "Adept's Demonhide Leather",
    "T4_ARTEFACT_ARMOR_LEATHER_MORGANA": "Adept's Imbued Leather Folds",
    "T4_ARTEFACT_ARMOR_LEATHER_UNDEAD": "Adept's Ghastly Leather",
    "T4_ARTEFACT_ARMOR_PLATE_AVALON": "Adept's Exalted Plating",
    "T4_ARTEFACT_ARMOR_PLATE_HELL": "Adept's Demonic Plates",
    "T4_ARTEFACT_ARMOR_PLATE_KEEPER": "Adept's Preserved Animal Fur",
    "T4_ARTEFACT_ARMOR_PLATE_UNDEAD": "Adept's Ancient Chain Rings",
    "T4_ARTEFACT_HEAD_CLOTH_AVALON": "Adept's Sanctified Mask",
    "T4_ARTEFACT_HEAD_CLOTH_HELL": "Adept's Infernal Cloth Visor",
    "T4_ARTEFACT_HEAD_CLOTH_KEEPER": "Adept's Druidic Preserved Beak",
    "T4_ARTEFACT_HEAD_CLOTH_MORGANA": "Adept's Alluring Padding",
    "T4_ARTEFACT_HEAD_LEATHER_AVALON": "Adept's Augured Padding",
    "T4_ARTEFACT_HEAD_LEATHER_HELL": "Adept's Demonhide Padding",
    "T4_ARTEFACT_HEAD_LEATHER_MORGANA": "Adept's Imbued Visor",
    "T4_ARTEFACT_HEAD_LEATHER_UNDEAD": "Adept's Ghastly Visor",
    "T4_ARTEFACT_HEAD_PLATE_AVALON": "Adept's Exalted Visor",
    "T4_ARTEFACT_HEAD_PLATE_HELL": "Adept's Demonic Scraps",
    "T4_ARTEFACT_HEAD_PLATE_KEEPER": "Adept's Carved Skull Padding",
    "T4_ARTEFACT_HEAD_PLATE_UNDEAD": "Adept's Ancient Padding",
    "T4_ARTEFACT_MAIN_ARCANESTAFF_UNDEAD": "Adept's Lost Arcane Crystal",
    "T4_ARTEFACT_MAIN_CURSEDSTAFF_AVALON": "Adept's Fractured Opaque Orb",
    "T4_ARTEFACT_MAIN_CURSEDSTAFF_UNDEAD": "Adept's Lost Cursed Crystal",
    "T4_ARTEFACT_MAIN_FIRESTAFF_KEEPER": "Adept's Wildfire Orb",
    "T4_ARTEFACT_MAIN_FROSTSTAFF_AVALON": "Adept's Chilled Crystaline Shard",
    "T4_ARTEFACT_MAIN_FROSTSTAFF_KEEPER": "Adept's Hoarfrost Orb",
    "T4_ARTEFACT_MAIN_HOLYSTAFF_AVALON": "Adept's Messianic Curio",
    "T4_ARTEFACT_MAIN_HOLYSTAFF_MORGANA": "Adept's Possessed Scroll",
    "T4_ARTEFACT_MAIN_MACE_HELL": "Adept's Infernal Mace Head",
    "T4_ARTEFACT_MAIN_NATURESTAFF_AVALON": "Adept's Uprooted Perennial Sapling",
    "T4_ARTEFACT_MAIN_NATURESTAFF_KEEPER": "Adept's Druidic Inscriptions",
    "T4_ARTEFACT_MAIN_RAPIER_MORGANA": "Adept's Hardened Debole",
    "T4_ARTEFACT_MAIN_ROCKMACE_KEEPER": "Adept's Runed Rock",
    "T4_ARTEFACT_MAIN_SCIMITAR_MORGANA": "Adept's Bloodforged Blade",
    "T4_ARTEFACT_MAIN_SPEAR_KEEPER": "Adept's Keeper Spearhead",
    "T4_ARTEFACT_MAIN_SPEAR_LANCE_AVALON": "Adept's Ruined Ancestral Vamplate",
    "T4_ARTEFACT_OFF_CENSER_AVALON": "Adept's Severed Celestial Keepsake",
    "T4_ARTEFACT_OFF_DEMONSKULL_HELL": "Adept's Demonic Jawbone",
    "T4_ARTEFACT_OFF_HORN_KEEPER": "Adept's Runed Horn",
    "T4_ARTEFACT_OFF_JESTERCANE_HELL": "Adept's Hellish Handle",
    "T4_ARTEFACT_OFF_LAMP_UNDEAD": "Adept's Ghastly Candle",
    "T4_ARTEFACT_OFF_ORB_MORGANA": "Adept's Alluring Crystal",
    "T4_ARTEFACT_OFF_SHIELD_AVALON": "Adept's Crushed Avalonian Heirloom",
    "T4_ARTEFACT_OFF_SHIELD_HELL": "Adept's Infernal Shield Core",
    "T4_ARTEFACT_OFF_SPIKEDSHIELD_MORGANA": "Adept's Bloodforged Spikes",
    "T4_ARTEFACT_OFF_TALISMAN_AVALON": "Adept's Shattered Avalonian Memento",
    "T4_ARTEFACT_OFF_TOTEM_KEEPER": "Adept's Inscribed Stone",
    "T4_ARTEFACT_OFF_TOWERSHIELD_UNDEAD": "Adept's Ancient Shield Core",
    "T4_ARTEFACT_SHOES_CLOTH_AVALON": "Adept's Sanctified Bindings",
    "T4_ARTEFACT_SHOES_CLOTH_HELL": "Adept's Infernal Cloth Bindings",
    "T4_ARTEFACT_SHOES_CLOTH_KEEPER": "Adept's Druidic Bindings",
    "T4_ARTEFACT_SHOES_CLOTH_MORGANA": "Adept's Alluring Bindings",
    "T4_ARTEFACT_SHOES_LEATHER_AVALON": "Adept's Augured Fasteners",
    "T4_ARTEFACT_SHOES_LEATHER_HELL": "Adept's Demonhide Bindings",
    "T4_ARTEFACT_SHOES_LEATHER_MORGANA": "Adept's Imbued Soles",
    "T4_ARTEFACT_SHOES_LEATHER_UNDEAD": "Adept's Ghastly Bindings",
    "T4_ARTEFACT_SHOES_PLATE_AVALON": "Adept's Exalted Greave",
    "T4_ARTEFACT_SHOES_PLATE_HELL": "Adept's Demonic Filling",
    "T4_ARTEFACT_SHOES_PLATE_KEEPER": "Adept's Inscribed Bindings",
    "T4_ARTEFACT_SHOES_PLATE_UNDEAD": "Adept's Ancient Bindings",
    "T4_BACKPACK_GATHERER_FIBER": "Adept's Harvester Backpack",
    "T4_BACKPACK_GATHERER_FIBER_DESC": "Equipment Item",
    "T4_BACKPACK_GATHERER_FISH": "Adept's Fisherman Backpack",
    "T4_BACKPACK_GATHERER_FISH_DESC": "Equipment Item",
    "T4_BACKPACK_GATHERER_HIDE": "Adept's Skinner Backpack",
    "T4_BACKPACK_GATHERER_HIDE_DESC": "Equipment Item",
    "T4_BACKPACK_GATHERER_ORE": "Adept's Miner Backpack",
    "T4_BACKPACK_GATHERER_ORE_DESC": "Equipment Item",
    "T4_BACKPACK_GATHERER_ROCK": "Adept's Quarrier Backpack",
    "T4_BACKPACK_GATHERER_ROCK_DESC": "Equipment Item",
    "T4_BACKPACK_GATHERER_WOOD": "Adept's Lumberjack Backpack",
    "T4_BACKPACK_GATHERER_WOOD_DESC": "Equipment Item",
    "T4_BAG": "Adept's Bag",
    "T4_BAG_DESC": "Equipment Item",
    "T4_BAG_FW_BONUS_FAME": "Adept's Faction Fame Bag",
    "T4_BAG_FW_BONUS_FAME_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T4_BAG_FW_BONUS_SILVER": "Adept's Faction Silver Bag",
    "T4_BAG_FW_BONUS_SILVER_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T4_BAG_FW_BONUS_YIELD": "Adept's Faction Yield Bag",
    "T4_BAG_FW_BONUS_YIELD_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T4_BAG_FW_FAME_BP": "Adept's Faction Fame Bag Pattern",
    "T4_BAG_FW_FAME_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T4_BAG_FW_SILVER_BP": "Adept's Faction Silver Bag Pattern",
    "T4_BAG_FW_SILVER_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T4_BAG_FW_YIELD_BP": "Adept's Faction Yield Bag Pattern",
    "T4_BAG_FW_YIELD_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T4_BAG_INSIGHT": "Adept's Satchel of Insight",
    "T4_BREAD": "Bread",
    "T4_BREAD_DESC": "An adequate source of nutrition. Made from flour.",
    "T4_BURDOCK": "Crenellated Burdock",
    "T4_BURDOCK_DESC": "Crenellated Burdock is used in various alchemical decoctions.",
    "T4_BUTTER": "Goat's Butter",
    "T4_BUTTER_DESC": "Goat's Butter is used to make Sandwiches.",
    "T4_CAPE": "Adept's Cape",
    "T4_CAPE_ARENA_BANNER": "Arena Veteran's Small Banner",
    "T4_CAPE_ARENA_BANNER_DESC": "Equipment Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils",
    "T4_CAPE_CLOTH_ROYAL": "Royal Cloth Cape",
    "T4_CAPE_CLOTH_ROYAL_DESC": "Equipment Item",
    "T4_CAPE_DESC": "Equipment Item",
    "T4_CAPE_LEATHER_ROYAL": "Royal Leather Cape",
    "T4_CAPE_LEATHER_ROYAL_DESC": "Equipment Item",
    "T4_CAPE_PLATE_ROYAL": "Royal Platemail Cape",
    "T4_CAPE_PLATE_ROYAL_DESC": "Equipment Item",
    "T4_CAPEITEM_DEMON": "Adept's Demon Cape",
    "T4_CAPEITEM_DEMON_BP": "Adept's Demon Crest",
    "T4_CAPEITEM_DEMON_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_DEMON_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_FW_BRIDGEWATCH": "Adept's Bridgewatch Cape",
    "T4_CAPEITEM_FW_BRIDGEWATCH_BP": "Adept's Bridgewatch Crest",
    "T4_CAPEITEM_FW_BRIDGEWATCH_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_FW_BRIDGEWATCH_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_FW_FORTSTERLING": "Adept's Fort Sterling Cape",
    "T4_CAPEITEM_FW_FORTSTERLING_BP": "Adept's Fort Sterling Crest",
    "T4_CAPEITEM_FW_FORTSTERLING_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_FW_FORTSTERLING_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_FW_LYMHURST": "Adept's Lymhurst Cape",
    "T4_CAPEITEM_FW_LYMHURST_BP": "Adept's Lymhurst Crest",
    "T4_CAPEITEM_FW_LYMHURST_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_FW_LYMHURST_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_FW_MARTLOCK": "Adept's Martlock Cape",
    "T4_CAPEITEM_FW_MARTLOCK_BP": "Adept's Martlock Crest",
    "T4_CAPEITEM_FW_MARTLOCK_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_FW_MARTLOCK_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_FW_THETFORD": "Adept's Thetford Cape",
    "T4_CAPEITEM_FW_THETFORD_BP": "Adept's Thetford Crest",
    "T4_CAPEITEM_FW_THETFORD_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_FW_THETFORD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_HERETIC": "Adept's Heretic Cape",
    "T4_CAPEITEM_HERETIC_BP": "Adept's Heretic Crest",
    "T4_CAPEITEM_HERETIC_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_HERETIC_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_KEEPER": "Adept's Keeper Cape",
    "T4_CAPEITEM_KEEPER_BP": "Adept's Keeper Crest",
    "T4_CAPEITEM_KEEPER_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_KEEPER_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_MORGANA": "Adept's Morgana Cape",
    "T4_CAPEITEM_MORGANA_BP": "Adept's Morgana Crest",
    "T4_CAPEITEM_MORGANA_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_MORGANA_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CAPEITEM_UNDEAD": "Adept's Undead Cape",
    "T4_CAPEITEM_UNDEAD_BP": "Adept's Undead Crest",
    "T4_CAPEITEM_UNDEAD_BP_DESC": "Can be used to upgrade a cape",
    "T4_CAPEITEM_UNDEAD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T4_CLOTH": "Fine Cloth",
    "T4_CLOTH_DESC": "Advanced material used in crafting, created by refining fiber.",
    "T4_CLOTH_LEVEL1": "Uncommon Fine Cloth",
    "T4_CLOTH_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_CLOTH_LEVEL2": "Rare Fine Cloth",
    "T4_CLOTH_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_CLOTH_LEVEL3": "Exceptional Fine Cloth",
    "T4_CLOTH_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T4_ESSENCE": "Adept's Faded Essence",
    "T4_ESSENCE_DESC": "This essence has passed its use-by date. It can be combined with others like it at an Artifact Foundry.",
    "T4_ESSENCE_POTION": "Adept's Arcane Essence",
    "T4_ESSENCE_POTION_DESC": "A magical essence, used to enchant potions",
    "T4_FARM_BURDOCK_SEED": "Crenellated Burdock Seeds",
    "T4_FARM_BURDOCK_SEED_DESC": "Crenellated Burdock Seeds are used to plant a patch of Crenellated Burdock.",
    "T4_FARM_GIANTSTAG_BABY": "Adept's Fawn",
    "T4_FARM_GIANTSTAG_BABY_DESC": "A fawn placed in a Pasture will grow into a Tame Giant Stag, which can be trained into a mount.",
    "T4_FARM_GIANTSTAG_GROWN": "Adept's Tame Giant Stag",
    "T4_FARM_GIANTSTAG_GROWN_DESC": "Can be used to craft a Giant Stag mount.",
    "T4_FARM_GOAT_BABY": "Kid",
    "T4_FARM_GOAT_BABY_DESC": "Kids placed in a pasture will grow into Goats.",
    "T4_FARM_GOAT_GROWN": "Goat",
    "T4_FARM_GOAT_GROWN_DESC": "Goats can be slaughtered to produce Raw Goat, or kept alive to produce Goat's Milk.",
    "T4_FARM_HORSE_BABY": "Adept's Foal",
    "T4_FARM_HORSE_BABY_DESC": "Grows into an Adept's Horse, which can be used to craft an Adept's Riding Horse.",
    "T4_FARM_HORSE_GROWN": "Adept's Horse",
    "T4_FARM_HORSE_GROWN_DESC": "Can be used to craft an Adept's Riding Horse.",
    "T4_FARM_OX_BABY": "Adept's Ox Calf",
    "T4_FARM_OX_BABY_DESC": "Grows into an Adept's Ox, which can be used to craft an Adept's Transport Ox.",
    "T4_FARM_OX_GROWN": "Adept's Ox",
    "T4_FARM_OX_GROWN_DESC": "Can be used to craft an Adept's Transport Ox.",
    "T4_FARM_TURNIP_SEED": "Turnip Seeds",
    "T4_FARM_TURNIP_SEED_DESC": "Turnip Seeds are used to plant a patch of Turnips.",
    "T4_FIBER": "Hemp",
    "T4_FIBER_DESC": "Fiber used for crafting. Can be refined into cloth or transmuted into higher-level material.",
    "T4_FIBER_LEVEL1": "Uncommon Hemp",
    "T4_FIBER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_FIBER_LEVEL2": "Rare Hemp",
    "T4_FIBER_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_FIBER_LEVEL3": "Exceptional Hemp",
    "T4_FIBER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T4_FISH_FRESHWATER_ALL_COMMON": "Bluescale Pike",
    "T4_FISH_SALTWATER_ALL_COMMON": "Bluescale Cod",
    "T4_FRAGMENT_BLUE_F1": "Adept's Scrap of Magic",
    "T4_FRAGMENT_BLUE_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_BLUE_F2": "Adept's Fragment of Magic",
    "T4_FRAGMENT_BLUE_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_BLUE_F3": "Adept's Shard of Magic",
    "T4_FRAGMENT_BLUE_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_GREEN_F1": "Adept's Scrap of Nature",
    "T4_FRAGMENT_GREEN_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_GREEN_F2": "Adept's Fragment of Nature",
    "T4_FRAGMENT_GREEN_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_GREEN_F3": "Adept's Shard of Nature",
    "T4_FRAGMENT_GREEN_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_RED_F1": "Adept's Scrap of Valor",
    "T4_FRAGMENT_RED_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_RED_F2": "Adept's Fragment of Valor",
    "T4_FRAGMENT_RED_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FRAGMENT_RED_F3": "Adept's Shard of Valor",
    "T4_FRAGMENT_RED_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T4_FURNITUREITEM_BATTLEVAULT": "Adept's Battlevault",
    "T4_FURNITUREITEM_BATTLEVAULT_DESC": "A 32-slot battlevault with a 571 kg limit. Must be placed inside.",
    "T4_FURNITUREITEM_BED": "Adept's Bed",
    "T4_FURNITUREITEM_BED_DESC": "Increases maximum residents in the house by 1, and contributes to Laborer happiness. Item can only be placed indoors.",
    "T4_FURNITUREITEM_CHEST": "Adept's Chest",
    "T4_FURNITUREITEM_CHEST_DESC": "A 64-slot inventory with a 16304 kg limit. Must be placed indoors.",
    "T4_FURNITUREITEM_GUILDBANNER_FABRIC": "Guild Banner on Fabric",
    "T4_FURNITUREITEM_GUILDBANNER_FABRIC_DESC": "Guild Banner. Can only be placed outdoors.",
    "T4_FURNITUREITEM_GUILDBANNER_SHIELD": "Guild Banner on Shield",
    "T4_FURNITUREITEM_GUILDBANNER_SHIELD_DESC": "Guild Banner. Can only be placed outdoors.",
    "T4_FURNITUREITEM_REPAIRKIT": "Adept's Repair Kit",
    "T4_FURNITUREITEM_REPAIRKIT_DESC": "Repair kits are used to repair gear in the wild, however the repair fee is twice as high.",
    "T4_FURNITUREITEM_TABLE": "Adept's Table",
    "T4_FURNITUREITEM_TABLE_DESC": "Contributes to Laborer happiness. Item can only be placed indoors.",
    "T4_FURNITUREITEM_TROPHY_FIBER": "Exquisite Hemp Trophy",
    "T4_FURNITUREITEM_TROPHY_FISH": "Pike Trophy",
    "T4_FURNITUREITEM_TROPHY_GENERAL": "Ancient Scripture",
    "T4_FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all Laborers.",
    "T4_FURNITUREITEM_TROPHY_HIDE": "Stuffed Boar Head",
    "T4_FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to all Gamekeeper Laborers.",
    "T4_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK": "Trophy: Magical Scripture",
    "T4_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK_DESC": "Increases Magic Resist. Must be placed indoors.",
    "T4_FURNITUREITEM_TROPHY_MAGICWEAPON": "Trophy: Lesser Demon's Hand Fragment",
    "T4_FURNITUREITEM_TROPHY_MAGICWEAPON_DESC": "Provides an increase in Magical Auto-Attack damage. Must be placed in a player house.",
    "T4_FURNITUREITEM_TROPHY_MERCENARY": "Adept Mercenary's Trophy",
    "T4_FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to Mercenary Laborers.",
    "T4_FURNITUREITEM_TROPHY_MOB": "Trophy: Boar's Head",
    "T4_FURNITUREITEM_TROPHY_MOB_DESC": "Provides an increase in maximum carrying capacity. Must be placed in a player house.",
    "T4_FURNITUREITEM_TROPHY_MORGANA_HEART": "Trophy: Morgana Champion's Heart",
    "T4_FURNITUREITEM_TROPHY_MORGANA_HEART_DESC": "Provides an increase in move speed and CC Resist. Must be placed in a player house.",
    "T4_FURNITUREITEM_TROPHY_ORE": "Iron Ore Sample",
    "T4_FURNITUREITEM_TROPHY_PHYSICALARMOR": "Trophy: Medium Armor",
    "T4_FURNITUREITEM_TROPHY_PHYSICALARMOR_DESC": "Provides an increase to Armor. Must be placed in a player house.",
    "T4_FURNITUREITEM_TROPHY_PHYSICALWEAPON": "Trophy: Medium Weapon",
    "T4_FURNITUREITEM_TROPHY_PHYSICALWEAPON_DESC": "Provides an increase to Physical Auto-Attack damage. Must be placed in a player house.",
    "T4_FURNITUREITEM_TROPHY_ROCK": "Travertine Fragment",
    "T4_FURNITUREITEM_TROPHY_WOOD": "Pine Bonsai",
    "T4_GEM_EMERALD": "Flawed Emerald",
    "T4_GEM_EMERALD_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T4_GEM_RUBY": "Flawed Ruby",
    "T4_GEM_RUBY_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T4_GEM_SAPPHIRE": "Flawed Sapphire",
    "T4_GEM_SAPPHIRE_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T4_GVGSEASONREWARD_FAMEBUFF": "Adept's Knight Vow",
    "T4_GVGSEASONREWARD_FAMEBUFF_DESC": "Increases Fame from defeating creatures and gathering resources by 1% for 90 days",
    "T4_HEAD_CLOTH_AVALON": "Adept's Cowl of Purity",
    "T4_HEAD_CLOTH_HELL": "Adept's Fiend Cowl",
    "T4_HEAD_CLOTH_HELL_DESC": "Equipment Item",
    "T4_HEAD_CLOTH_KEEPER": "Adept's Druid Cowl",
    "T4_HEAD_CLOTH_KEEPER_DESC": "Equipment Item",
    "T4_HEAD_CLOTH_MORGANA": "Adept's Cultist Cowl",
    "T4_HEAD_CLOTH_MORGANA_DESC": "Equipment Item",
    "T4_HEAD_CLOTH_ROYAL": "Adept's Royal Cowl",
    "T4_HEAD_CLOTH_ROYAL_DESC": "Equipment Item",
    "T4_HEAD_CLOTH_SET1": "Adept's Scholar Cowl",
    "T4_HEAD_CLOTH_SET1_DESC": "Equipment Item",
    "T4_HEAD_CLOTH_SET2": "Adept's Cleric Cowl",
    "T4_HEAD_CLOTH_SET2_DESC": "Equipment Item",
    "T4_HEAD_CLOTH_SET3": "Adept's Mage Cowl",
    "T4_HEAD_CLOTH_SET3_DESC": "Equipment Item",
    "T4_HEAD_GATHERER_FIBER": "Adept's Harvester Cap",
    "T4_HEAD_GATHERER_FIBER_DESC": "Equipment Item",
    "T4_HEAD_GATHERER_FISH": "Adept's Fisherman Cap",
    "T4_HEAD_GATHERER_FISH_DESC": "Equipment Item",
    "T4_HEAD_GATHERER_HIDE": "Adept's Skinner Cap",
    "T4_HEAD_GATHERER_HIDE_DESC": "Equipment Item",
    "T4_HEAD_GATHERER_ORE": "Adept's Miner Cap",
    "T4_HEAD_GATHERER_ORE_DESC": "Equipment Item",
    "T4_HEAD_GATHERER_ROCK": "Adept's Quarrier Cap",
    "T4_HEAD_GATHERER_ROCK_DESC": "Equipment Item",
    "T4_HEAD_GATHERER_WOOD": "Adept's Lumberjack Cap",
    "T4_HEAD_GATHERER_WOOD_DESC": "Equipment Item",
    "T4_HEAD_LEATHER_AVALON": "Adept's Hood of Tenacity",
    "T4_HEAD_LEATHER_HELL": "Adept's Hellion Hood",
    "T4_HEAD_LEATHER_HELL_DESC": "Equipment Item",
    "T4_HEAD_LEATHER_MORGANA": "Adept's Stalker Hood",
    "T4_HEAD_LEATHER_MORGANA_DESC": "Equipment Item",
    "T4_HEAD_LEATHER_ROYAL": "Adept's Royal Hood",
    "T4_HEAD_LEATHER_ROYAL_DESC": "Equipment Item",
    "T4_HEAD_LEATHER_SET1": "Adept's Mercenary Hood",
    "T4_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T4_HEAD_LEATHER_SET2": "Adept's Hunter Hood",
    "T4_HEAD_LEATHER_SET2_DESC": "Equipment Item",
    "T4_HEAD_LEATHER_SET3": "Adept's Assassin Hood",
    "T4_HEAD_LEATHER_SET3_DESC": "Equipment Item",
    "T4_HEAD_LEATHER_UNDEAD": "Adept's Specter Hood",
    "T4_HEAD_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T4_HEAD_PLATE_AVALON": "Adept's Helmet of Valor",
    "T4_HEAD_PLATE_HELL": "Adept's Demon Helmet",
    "T4_HEAD_PLATE_HELL_DESC": "Equipment Item",
    "T4_HEAD_PLATE_KEEPER": "Adept's Judicator Helmet",
    "T4_HEAD_PLATE_KEEPER_DESC": "Equipment Item",
    "T4_HEAD_PLATE_ROYAL": "Adept's Royal Helmet",
    "T4_HEAD_PLATE_ROYAL_DESC": "Equipment Item",
    "T4_HEAD_PLATE_SET1": "Adept's Soldier Helmet",
    "T4_HEAD_PLATE_SET1_DESC": "Equipment Item",
    "T4_HEAD_PLATE_SET2": "Adept's Knight Helmet",
    "T4_HEAD_PLATE_SET2_DESC": "Equipment Item",
    "T4_HEAD_PLATE_SET3": "Adept's Guardian Helmet",
    "T4_HEAD_PLATE_SET3_DESC": "Equipment Item",
    "T4_HEAD_PLATE_UNDEAD": "Adept's Graveguard Helmet",
    "T4_HEAD_PLATE_UNDEAD_DESC": "Equipment Item",
    "T4_HIDE": "Medium Hide",
    "T4_HIDE_DESC": "Hide used for crafting. Can be refined into leather or transmuted into higher-level material.",
    "T4_HIDE_LEVEL1": "Uncommon Medium Hide",
    "T4_HIDE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_HIDE_LEVEL2": "Rare Medium Hide",
    "T4_HIDE_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_HIDE_LEVEL3": "Exceptional Medium Hide",
    "T4_HIDE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T4_JOURNAL_FIBER": "Adept Cropper's Journal (Partially Full)",
    "T4_JOURNAL_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_FIBER_EMPTY": "Adept Cropper's Journal (Empty)",
    "T4_JOURNAL_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_FIBER_FULL": "Adept Cropper's Journal (Full)",
    "T4_JOURNAL_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_FISHING": "Adept Fisherman's Journal (Partially Full)",
    "T4_JOURNAL_FISHING_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_FISHING_EMPTY": "Adept Fisherman's Journal (Empty)",
    "T4_JOURNAL_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_FISHING_FULL": "Adept Fisherman's Journal (Full)",
    "T4_JOURNAL_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_HIDE": "Adept Gamekeeper's Journal (Partially Full)",
    "T4_JOURNAL_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_HIDE_EMPTY": "Adept Gamekeeper's Journal (Empty)",
    "T4_JOURNAL_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_HIDE_FULL": "Adept Gamekeeper's Journal (Full)",
    "T4_JOURNAL_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_HUNTER": "Adept Fletcher's Journal (Partially Full)",
    "T4_JOURNAL_HUNTER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_HUNTER_EMPTY": "Adept Fletcher's Journal (Empty)",
    "T4_JOURNAL_HUNTER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_HUNTER_FULL": "Adept Fletcher's Journal (Full)",
    "T4_JOURNAL_HUNTER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_MAGE": "Adept Imbuer's Journal (Partially Full)",
    "T4_JOURNAL_MAGE_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_MAGE_EMPTY": "Adept Imbuer's Journal (Empty)",
    "T4_JOURNAL_MAGE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_MAGE_FULL": "Adept Imbuer's Journal (Full)",
    "T4_JOURNAL_MAGE_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_MERCENARY": "Adept Mercenary's Journal (Partially Full)",
    "T4_JOURNAL_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_MERCENARY_EMPTY": "Adept Mercenary's Journal (Empty)",
    "T4_JOURNAL_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_MERCENARY_FULL": "Adept Mercenary's Journal (Full)",
    "T4_JOURNAL_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_ORE": "Adept Prospector's Journal (Partially Full)",
    "T4_JOURNAL_ORE_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_ORE_EMPTY": "Adept Prospector's Journal (Empty)",
    "T4_JOURNAL_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_ORE_FULL": "Adept Prospector's Journal (Full)",
    "T4_JOURNAL_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_STONE": "Adept Stonecutter's Journal (Partially Full)",
    "T4_JOURNAL_STONE_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_STONE_EMPTY": "Adept Stonecutter's Journal (Empty)",
    "T4_JOURNAL_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_STONE_FULL": "Adept Stonecutter's Journal (Full)",
    "T4_JOURNAL_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TOOLMAKER": "Adept Tinker's Journal (Partially Full)",
    "T4_JOURNAL_TOOLMAKER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TOOLMAKER_EMPTY": "Adept Tinker's Journal (Empty)",
    "T4_JOURNAL_TOOLMAKER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TOOLMAKER_FULL": "Adept Tinker's Journal (Full)",
    "T4_JOURNAL_TOOLMAKER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_FIBER": "Adept Cropper's Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_FIBER_EMPTY": "Adept Cropper's Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_FIBER_FULL": "Adept Cropper's Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_FISHING": "Adept Fisherman's Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_FISHING_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_FISHING_EMPTY": "Adept Fisherman's Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_FISHING_FULL": "Adept Fisherman's Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_GENERAL": "Adept's Generalist Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_GENERAL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_GENERAL_EMPTY": "Adept's Generalist Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_GENERAL_EMPTY_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_GENERAL_FULL": "Adept's Generalist Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_GENERAL_FULL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_HIDE": "Adept Gamekeeper's Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_HIDE_EMPTY": "Adept Gamekeeper's Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_HIDE_FULL": "Adept Gamekeeper's Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_MERCENARY": "Adept Mercenary's Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_MERCENARY_EMPTY": "Adept Mercenary's Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_MERCENARY_FULL": "Adept Mercenary's Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_ORE": "Adept Prospector's Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_ORE_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_ORE_EMPTY": "Adept Prospector's Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_ORE_FULL": "Adept Prospector's Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_STONE": "Adept Stonecutter's Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_STONE_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_STONE_EMPTY": "Adept Stonecutter's Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_STONE_FULL": "Adept Stonecutter's Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_WOOD": "Adept Lumberjack's Trophy Journal (Partially Full)",
    "T4_JOURNAL_TROPHY_WOOD_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_WOOD_EMPTY": "Adept Lumberjack's Trophy Journal (Empty)",
    "T4_JOURNAL_TROPHY_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_TROPHY_WOOD_FULL": "Adept Lumberjack's Trophy Journal (Full)",
    "T4_JOURNAL_TROPHY_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_WARRIOR": "Adept Blacksmith's Journal (Partially Full)",
    "T4_JOURNAL_WARRIOR_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_WARRIOR_EMPTY": "Adept Blacksmith's Journal (Empty)",
    "T4_JOURNAL_WARRIOR_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_WARRIOR_FULL": "Adept Blacksmith's Journal (Full)",
    "T4_JOURNAL_WARRIOR_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_WOOD": "Adept Lumberjack's Journal (Partially Full)",
    "T4_JOURNAL_WOOD_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_WOOD_EMPTY": "Adept Lumberjack's Journal (Empty)",
    "T4_JOURNAL_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_JOURNAL_WOOD_FULL": "Adept Lumberjack's Journal (Full)",
    "T4_JOURNAL_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T4_LABOURER_CONTRACT_FIBER": "Adept Cropper Contract",
    "T4_LABOURER_CONTRACT_FIBER_DESC": "Croppers require filled Cropper's Journals and gather fiber.",
    "T4_LABOURER_CONTRACT_FISHERMAN": "Adept Fisherman Contract",
    "T4_LABOURER_CONTRACT_FISHERMAN_DESC": "Fishermen require filled Fisherman's Journals and catch fish.",
    "T4_LABOURER_CONTRACT_HIDE": "Adept Gamekeeper Contract",
    "T4_LABOURER_CONTRACT_HIDE_DESC": "Gamekeepers require filled Gamekeeper's Journals and gather hide.",
    "T4_LABOURER_CONTRACT_HUNTER": "Adept Fletcher Contract",
    "T4_LABOURER_CONTRACT_HUNTER_DESC": "Fletchers require filled Fletcher's Journals and gather various refined materials.",
    "T4_LABOURER_CONTRACT_MAGE": "Adept Imbuer Contract",
    "T4_LABOURER_CONTRACT_MAGE_DESC": "Imbuers require filled Imbuer's Journals and gather various refined materials.",
    "T4_LABOURER_CONTRACT_MERCENARY": "Adept Mercenary Contract",
    "T4_LABOURER_CONTRACT_MERCENARY_DESC": "Mercenaries require filled Mercenary's Journals' and gather Silver.",
    "T4_LABOURER_CONTRACT_ORE": "Adept Prospector Contract",
    "T4_LABOURER_CONTRACT_ORE_DESC": "Prospectors require filled Prospector's Journals and gather ore.",
    "T4_LABOURER_CONTRACT_STONE": "Adept Stonecutter Contract",
    "T4_LABOURER_CONTRACT_STONE_DESC": "Stonecutters require filled Stonecutter's Journals and gather stone.",
    "T4_LABOURER_CONTRACT_TOOLMAKER": "Adept Tinker Contract",
    "T4_LABOURER_CONTRACT_TOOLMAKER_DESC": "Tinkers require filled Tinker's Journals and gather various refined materials.",
    "T4_LABOURER_CONTRACT_WARRIOR": "Adept Blacksmith Contract",
    "T4_LABOURER_CONTRACT_WARRIOR_DESC": "Blacksmiths require filled Blacksmith's Journals and gather various refined materials.",
    "T4_LABOURER_CONTRACT_WOOD": "Adept Lumberjack Contract",
    "T4_LABOURER_CONTRACT_WOOD_DESC": "Lumberjacks require filled Lumberjack's Journals and gather wood.",
    "T4_LEATHER": "Worked Leather",
    "T4_LEATHER_DESC": "Advanced material used in crafting, created by refining hide.",
    "T4_LEATHER_LEVEL1": "Uncommon Worked Leather",
    "T4_LEATHER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_LEATHER_LEVEL2": "Rare Worked Leather",
    "T4_LEATHER_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_LEATHER_LEVEL3": "Exceptional Worked Leather",
    "T4_LEATHER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T4_LOOTCHEST_CRYSTAL_LEAGUE": "Adept's Crystal League Chest",
    "T4_MAIN_1HCROSSBOW": "Adept's Light Crossbow",
    "T4_MAIN_1HCROSSBOW_DESC": "Equipment Item",
    "T4_MAIN_ARCANESTAFF": "Adept's Arcane Staff",
    "T4_MAIN_ARCANESTAFF_DESC": "Equipment Item",
    "T4_MAIN_ARCANESTAFF_UNDEAD": "Adept's Witchwork Staff",
    "T4_MAIN_ARCANESTAFF_UNDEAD_DESC": "Equipment Item",
    "T4_MAIN_AXE": "Adept's Battleaxe",
    "T4_MAIN_AXE_DESC": "Equipment Item",
    "T4_MAIN_CURSEDSTAFF": "Adept's Cursed Staff",
    "T4_MAIN_CURSEDSTAFF_AVALON": "Adept's Shadowcaller",
    "T4_MAIN_CURSEDSTAFF_AVALON_DESC": "Equipment Item",
    "T4_MAIN_CURSEDSTAFF_DESC": "Equipment Item",
    "T4_MAIN_CURSEDSTAFF_UNDEAD": "Adept's Lifecurse Staff",
    "T4_MAIN_CURSEDSTAFF_UNDEAD_DESC": "Equipment Item",
    "T4_MAIN_DAGGER": "Adept's Dagger",
    "T4_MAIN_DAGGER_DESC": "Equipment Item",
    "T4_MAIN_FIRESTAFF": "Adept's Fire Staff",
    "T4_MAIN_FIRESTAFF_DESC": "Equipment Item",
    "T4_MAIN_FIRESTAFF_KEEPER": "Adept's Wildfire Staff",
    "T4_MAIN_FIRESTAFF_KEEPER_DESC": "Equipment Item",
    "T4_MAIN_FROSTSTAFF": "Adept's Frost Staff",
    "T4_MAIN_FROSTSTAFF_AVALON": "Adept's Chillhowl",
    "T4_MAIN_FROSTSTAFF_AVALON_DESC": "Equipment Item",
    "T4_MAIN_FROSTSTAFF_DESC": "Equipment Item",
    "T4_MAIN_FROSTSTAFF_KEEPER": "Adept's Hoarfrost Staff",
    "T4_MAIN_FROSTSTAFF_KEEPER_DESC": "Equipment Item",
    "T4_MAIN_HAMMER": "Adept's Hammer",
    "T4_MAIN_HAMMER_DESC": "Equipment Item",
    "T4_MAIN_HOLYSTAFF": "Adept's Holy Staff",
    "T4_MAIN_HOLYSTAFF_AVALON": "Adept's Hallowfall",
    "T4_MAIN_HOLYSTAFF_AVALON_DESC": "Equipment Item",
    "T4_MAIN_HOLYSTAFF_DESC": "Equipment Item",
    "T4_MAIN_HOLYSTAFF_MORGANA": "Adept's Lifetouch Staff",
    "T4_MAIN_HOLYSTAFF_MORGANA_DESC": "Equipment Item",
    "T4_MAIN_MACE": "Adept's Mace",
    "T4_MAIN_MACE_DESC": "Equipment Item",
    "T4_MAIN_MACE_HELL": "Adept's Incubus Mace",
    "T4_MAIN_MACE_HELL_DESC": "Equipment Item",
    "T4_MAIN_NATURESTAFF": "Adept's Nature Staff",
    "T4_MAIN_NATURESTAFF_AVALON": "Adept's Ironroot Staff",
    "T4_MAIN_NATURESTAFF_AVALON_DESC": "Equipment Item",
    "T4_MAIN_NATURESTAFF_DESC": "Equipment Item",
    "T4_MAIN_NATURESTAFF_KEEPER": "Adept's Druidic Staff",
    "T4_MAIN_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T4_MAIN_RAPIER_MORGANA": "Adept's Bloodletter",
    "T4_MAIN_RAPIER_MORGANA_DESC": "Equipment Item",
    "T4_MAIN_REPEATINGCROSSBOW": "Adept's Repeating Crossbow",
    "T4_MAIN_REPEATINGCROSSBOW_DESC": "Equipment Item",
    "T4_MAIN_ROCKMACE_KEEPER": "Adept's Bedrock Mace",
    "T4_MAIN_ROCKMACE_KEEPER_DESC": "Equipment Item",
    "T4_MAIN_SCIMITAR_MORGANA": "Adept's Clarent Blade",
    "T4_MAIN_SCIMITAR_MORGANA_DESC": "Equipment Item",
    "T4_MAIN_SPEAR": "Adept's Spear",
    "T4_MAIN_SPEAR_DESC": "Equipment Item",
    "T4_MAIN_SPEAR_KEEPER": "Adept's Heron Spear",
    "T4_MAIN_SPEAR_KEEPER_DESC": "Equipment Item",
    "T4_MAIN_SPEAR_LANCE_AVALON": "Adept's Daybreaker",
    "T4_MAIN_SPEAR_LANCE_AVALON_DESC": "Equipment Item",
    "T4_MAIN_SWORD": "Adept's Broadsword",
    "T4_MAIN_SWORD_DESC": "Equipment Item",
    "T4_MAIN_SWORD_ROYAL": "Royal Broadsword",
    "T4_MAIN_SWORD_ROYAL_DESC": "Equipment Item",
    "T4_MEAL_SALAD": "Turnip Salad",
    "T4_MEAL_SALAD_DESC": "Simple snack that increases crafting speed and quality for a short period.",
    "T4_MEAL_SALAD_FISH": "Midwater Octopus Salad",
    "T4_MEAL_SANDWICH": "Goat Sandwich",
    "T4_MEAL_SANDWICH_AVALON": "Avalonian Goat Sandwich",
    "T4_MEAL_SANDWICH_AVALON_DESC": "Avalonian meal that increases maximum health and CC Duration for a long period.",
    "T4_MEAL_SANDWICH_DESC": "Sophisticated meal that increases maximum health for a long period.",
    "T4_MEAL_SANDWICH_FISH": "Stonestream Lurcher Sandwich",
    "T4_MEAL_STEW": "Goat Stew",
    "T4_MEAL_STEW_AVALON": "Avalonian Goat Stew",
    "T4_MEAL_STEW_AVALON_DESC": "Avalonian meal that increases combat damage and health regeneration for a long period.",
    "T4_MEAL_STEW_DESC": "Sophisticated meal that increases combat damage for a long period.",
    "T4_MEAL_STEW_FISH": "Greenriver Eel Stew",
    "T4_MEAT": "Raw Goat",
    "T4_MEAT_DESC": "Cooking ingredient, used in various recipes.",
    "T4_METALBAR": "Steel Bar",
    "T4_METALBAR_DESC": "Advanced material used in crafting, created by refining ore.",
    "T4_METALBAR_LEVEL1": "Uncommon Steel Bar",
    "T4_METALBAR_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_METALBAR_LEVEL2": "Rare Steel Bar",
    "T4_METALBAR_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_METALBAR_LEVEL3": "Exceptional Steel Bar",
    "T4_METALBAR_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T4_MILK": "Goat's Milk",
    "T4_MILK_DESC": "Goat's Milk is used in various meals and potions, and can be turned into Goat's Butter.",
    "T4_MOBDROP_ARMOR": "Medium Armor Fragment",
    "T4_MOBDROP_ARMOR_DESC": "Use to craft a trophy you can place in your house.",
    "T4_MOBDROP_AXE": "Medium Weapon Fragment",
    "T4_MOBDROP_AXE_DESC": "Use to craft a trophy you can place in your house.",
    "T4_MOBDROP_BOAR_HEAD": "Boar's Head",
    "T4_MOBDROP_BOAR_HEAD_DESC": "Use to craft a trophy you can place in your house.",
    "T4_MOBDROP_BOOK": "Pages from a Magical Scripture",
    "T4_MOBDROP_BOOK_DESC": "Use to craft a trophy you can place in your house.",
    "T4_MOBDROP_CHAMPION_HEART": "Morgana Champion's Heart",
    "T4_MOBDROP_CHAMPION_HEART_DESC": "Use to craft a trophy you can place in your house.",
    "T4_MOBDROP_SHADE_HAND": "Lesser Demon's Hand Fragment",
    "T4_MOBDROP_SHADE_HAND_DESC": "Lesser Demon's hand fragment. Use to craft a trophy you can place in your house.",
    "T4_MOUNT_GIANTSTAG": "Adept's Giant Stag",
    "T4_MOUNT_GIANTSTAG_DESC": "Stags are fast and strong, making them favored mounts of gatherers and couriers.",
    "T4_MOUNT_HORSE": "Adept's Riding Horse",
    "T4_MOUNT_HORSE_DESC": "Lean and agile, Albion horses can carry their riders quickly across the continent, but have little strength to bear heavy items.",
    "T4_MOUNT_OX": "Adept's Transport Ox",
    "T4_MOUNT_OX_DESC": "Albion oxen are tough, and sturdy enough to carry large quantities of goods, but cannot match the pace of the continent's horses.",
    "T4_OFF_BOOK": "Adept's Tome of Spells",
    "T4_OFF_BOOK_DESC": "Equipment Item",
    "T4_OFF_CENSER_AVALON": "Adept's Celestial Censer",
    "T4_OFF_CENSER_AVALON_DESC": "Equipment Item",
    "T4_OFF_DEMONSKULL_HELL": "Adept's Muisak",
    "T4_OFF_DEMONSKULL_HELL_DESC": "Equipment Item",
    "T4_OFF_HORN_KEEPER": "Adept's Mistcaller",
    "T4_OFF_HORN_KEEPER_DESC": "Equipment Item",
    "T4_OFF_JESTERCANE_HELL": "Adept's Leering Cane",
    "T4_OFF_JESTERCANE_HELL_DESC": "Equipment Item",
    "T4_OFF_LAMP_UNDEAD": "Adept's Cryptcandle",
    "T4_OFF_LAMP_UNDEAD_DESC": "Equipment Item",
    "T4_OFF_ORB_MORGANA": "Adept's Eye of Secrets",
    "T4_OFF_ORB_MORGANA_DESC": "Equipment Item",
    "T4_OFF_SHIELD": "Adept's Shield",
    "T4_OFF_SHIELD_AVALON": "Adept's Astral Aegis",
    "T4_OFF_SHIELD_AVALON_DESC": "Equipment Item",
    "T4_OFF_SHIELD_DESC": "Equipment Item",
    "T4_OFF_SHIELD_HELL": "Adept's Caitiff Shield",
    "T4_OFF_SHIELD_HELL_DESC": "Equipment Item",
    "T4_OFF_SHIELD_ROYAL": "Royal Shield",
    "T4_OFF_SHIELD_ROYAL_DESC": "Equipment Item",
    "T4_OFF_SPIKEDSHIELD_MORGANA": "Adept's Facebreaker",
    "T4_OFF_SPIKEDSHIELD_MORGANA_DESC": "Equipment Item",
    "T4_OFF_TALISMAN_AVALON": "Adept's Sacred Scepter",
    "T4_OFF_TALISMAN_AVALON_DESC": "Equipment Item",
    "T4_OFF_TORCH": "Adept's Torch",
    "T4_OFF_TORCH_DESC": "Equipment Item",
    "T4_OFF_TOTEM_KEEPER": "Adept's Taproot",
    "T4_OFF_TOTEM_KEEPER_DESC": "Equipment Item",
    "T4_OFF_TOWERSHIELD_UNDEAD": "Adept's Sarcophagus",
    "T4_OFF_TOWERSHIELD_UNDEAD_DESC": "Equipment Item",
    "T4_ORE": "Iron Ore",
    "T4_ORE_DESC": "Ore used for crafting. Can be refined into metal bars or transmuted into higher-level material.",
    "T4_ORE_LEVEL1": "Uncommon Iron Ore",
    "T4_ORE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_ORE_LEVEL2": "Rare Iron Ore",
    "T4_ORE_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_ORE_LEVEL3": "Exceptional Iron Ore",
    "T4_ORE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T4_PLANKS": "Pine Planks",
    "T4_PLANKS_DESC": "Advanced material used in crafting, created by refining logs.",
    "T4_PLANKS_LEVEL1": "Uncommon Pine Planks",
    "T4_PLANKS_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_PLANKS_LEVEL2": "Rare Pine Planks",
    "T4_PLANKS_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_PLANKS_LEVEL3": "Exceptional Pine Planks",
    "T4_PLANKS_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T4_POTION_COOLDOWN": "Minor Poison Potion",
    "T4_POTION_COOLDOWN_DESC": "Poisonous potion. Can be thrown at enemies to poison them.",
    "T4_POTION_ENERGY": "Energy Potion",
    "T4_POTION_ENERGY_DESC": "Fizzing potion. Instantly restores some energy.",
    "T4_POTION_HEAL": "Healing Potion",
    "T4_POTION_HEAL_DESC": "Glowing potion. Restores some health over time.",
    "T4_RANDOM_DUNGEON_SOLO_TOKEN_1": "Adept's Dungeon Map (Solo)",
    "T4_RANDOM_DUNGEON_SOLO_TOKEN_2": "Uncommon Adept's Dungeon Map (Solo)",
    "T4_RANDOM_DUNGEON_SOLO_TOKEN_3": "Rare Adept's Dungeon Map (Solo)",
    "T4_RANDOM_DUNGEON_SOLO_TOKEN_4": "Exceptional Adept's Dungeon Map (Solo)",
    "T4_RANDOM_DUNGEON_TOKEN_1": "Adept's Dungeon Map (Group)",
    "T4_RANDOM_DUNGEON_TOKEN_2": "Uncommon Adept's Dungeon Map (Group)",
    "T4_RANDOM_DUNGEON_TOKEN_3": "Rare Adept's Dungeon Map (Group)",
    "T4_RANDOM_DUNGEON_TOKEN_4": "Exceptional Adept's Dungeon Map (Group)",
    "T4_RELIC": "Adept's Relic",
    "T4_RELIC_DESC": "An ancient relic, used to meld artifacts and enchant equipment.",
    "T4_ROCK": "Travertine",
    "T4_ROCK_DESC": "Stone used for crafting. Can be refined into stone blocks or transmuted into higher-level material.",
    "T4_ROCK_LEVEL1": "Uncommon Travertine",
    "T4_ROCK_LEVEL1_DESC": "Uncommon stone, more efficient in refining.",
    "T4_ROCK_LEVEL2": "Rare Travertine",
    "T4_ROCK_LEVEL2_DESC": "Rare stone, more efficient in refining.",
    "T4_ROCK_LEVEL3": "Exceptional Travertine",
    "T4_ROCK_LEVEL3_DESC": "Exceptional stone, more efficient in refining.",
    "T4_RUNE": "Adept's Rune",
    "T4_RUNE_DESC": "A pulsing rune, used to meld artifacts and enchant equipment.",
    "T4_RUNE_DESTRUCTION": "Minor Rune of Destruction",
    "T4_RUNE_DESTRUCTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T4_RUNE_MANIPULATION": "Minor Rune of Manipulation",
    "T4_RUNE_MANIPULATION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T4_RUNE_PROTECTION": "Minor Rune of Protection",
    "T4_RUNE_PROTECTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T4_SHARD_AVALONIAN": "Adept's Avalonian Shard",
    "T4_SHOES_CLOTH_AVALON": "Adept's Sandals of Purity",
    "T4_SHOES_CLOTH_HELL": "Adept's Fiend Sandals",
    "T4_SHOES_CLOTH_HELL_DESC": "Equipment Item",
    "T4_SHOES_CLOTH_KEEPER": "Adept's Druid Sandals",
    "T4_SHOES_CLOTH_KEEPER_DESC": "Equipment Item",
    "T4_SHOES_CLOTH_MORGANA": "Adept's Cultist Sandals",
    "T4_SHOES_CLOTH_MORGANA_DESC": "Equipment Item",
    "T4_SHOES_CLOTH_ROYAL": "Adept's Royal Sandals",
    "T4_SHOES_CLOTH_ROYAL_DESC": "Equipment Item",
    "T4_SHOES_CLOTH_SET1": "Adept's Scholar Sandals",
    "T4_SHOES_CLOTH_SET1_DESC": "Equipment Item",
    "T4_SHOES_CLOTH_SET2": "Adept's Cleric Sandals",
    "T4_SHOES_CLOTH_SET2_DESC": "Equipment Item",
    "T4_SHOES_CLOTH_SET3": "Adept's Mage Sandals",
    "T4_SHOES_CLOTH_SET3_DESC": "Equipment Item",
    "T4_SHOES_GATHERER_FIBER": "Adept's Harvester Workboots",
    "T4_SHOES_GATHERER_FIBER_DESC": "Equipment Item",
    "T4_SHOES_GATHERER_FISH": "Adept's Fisherman Workboots",
    "T4_SHOES_GATHERER_FISH_DESC": "Equipment Item",
    "T4_SHOES_GATHERER_HIDE": "Adept's Skinner Workboots",
    "T4_SHOES_GATHERER_HIDE_DESC": "Equipment Item",
    "T4_SHOES_GATHERER_ORE": "Adept's Miner Workboots",
    "T4_SHOES_GATHERER_ORE_DESC": "Equipment Item",
    "T4_SHOES_GATHERER_ROCK": "Adept's Quarrier Workboots",
    "T4_SHOES_GATHERER_ROCK_DESC": "Equipment Item",
    "T4_SHOES_GATHERER_WOOD": "Adept's Lumberjack Workboots",
    "T4_SHOES_GATHERER_WOOD_DESC": "Equipment Item",
    "T4_SHOES_LEATHER_AVALON": "Adept's Shoes of Tenacity",
    "T4_SHOES_LEATHER_HELL": "Adept's Hellion Shoes",
    "T4_SHOES_LEATHER_HELL_DESC": "Equipment Item",
    "T4_SHOES_LEATHER_MORGANA": "Adept's Stalker Shoes",
    "T4_SHOES_LEATHER_MORGANA_DESC": "Equipment Item",
    "T4_SHOES_LEATHER_ROYAL": "Adept's Royal Shoes",
    "T4_SHOES_LEATHER_ROYAL_DESC": "Equipment Item",
    "T4_SHOES_LEATHER_SET1": "Adept's Mercenary Shoes",
    "T4_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T4_SHOES_LEATHER_SET2": "Adept's Hunter Shoes",
    "T4_SHOES_LEATHER_SET2_DESC": "Equipment Item",
    "T4_SHOES_LEATHER_SET3": "Adept's Assassin Shoes",
    "T4_SHOES_LEATHER_SET3_DESC": "Equipment Item",
    "T4_SHOES_LEATHER_UNDEAD": "Adept's Specter Shoes",
    "T4_SHOES_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T4_SHOES_PLATE_AVALON": "Adept's Boots of Valor",
    "T4_SHOES_PLATE_HELL": "Adept's Demon Boots",
    "T4_SHOES_PLATE_HELL_DESC": "Equipment Item",
    "T4_SHOES_PLATE_KEEPER": "Adept's Judicator Boots",
    "T4_SHOES_PLATE_KEEPER_DESC": "Equipment Item",
    "T4_SHOES_PLATE_ROYAL": "Adept's Royal Boots",
    "T4_SHOES_PLATE_ROYAL_DESC": "Equipment Item",
    "T4_SHOES_PLATE_SET1": "Adept's Soldier Boots",
    "T4_SHOES_PLATE_SET1_DESC": "Equipment Item",
    "T4_SHOES_PLATE_SET2": "Adept's Knight Boots",
    "T4_SHOES_PLATE_SET2_DESC": "Equipment Item",
    "T4_SHOES_PLATE_SET3": "Adept's Guardian Boots",
    "T4_SHOES_PLATE_SET3_DESC": "Equipment Item",
    "T4_SHOES_PLATE_UNDEAD": "Adept's Graveguard Boots",
    "T4_SHOES_PLATE_UNDEAD_DESC": "Equipment Item",
    "T4_SILVERBAG_NONTRADABLE": "Adept's Bag of Silver",
    "T4_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T4_SKILLBOOK_NONTRADABLE": "Adept's Tome of Insight",
    "T4_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 10,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T4_SKILLBOOK_STANDARD": "Adept's Tome of Insight",
    "T4_SKILLBOOK_STANDARD_DESC": "A crystallization of ancient wisdom. Instantly rewards 10,000 Combat Fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T4_SOUL": "Adept's Soul",
    "T4_SOUL_DESC": "A tortured soul, used to meld artifacts and enchant equipment.",
    "T4_STONEBLOCK": "Travertine Block",
    "T4_STONEBLOCK_DESC": "Advanced material used in crafting, created by refining stone.",
    "T4_TRASH": "Trash",
    "T4_TRASH_DESC": "A destroyed T4 item. Cannot be repaired or salvaged.",
    "T4_TURNIP": "Turnips",
    "T4_TURNIP_DESC": "Turnips are used in a variety of meals.",
    "T4_WOOD": "Pine Logs",
    "T4_WOOD_DESC": "Logs used for crafting. Can be refined into planks or transmuted into higher-level material.",
    "T4_WOOD_LEVEL1": "Uncommon Pine Logs",
    "T4_WOOD_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T4_WOOD_LEVEL2": "Rare Pine Logs",
    "T4_WOOD_LEVEL2_DESC": "Rare material used for crafting.",
    "T4_WOOD_LEVEL3": "Exceptional Pine Logs",
    "T4_WOOD_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_2H_ARCANE_RINGPAIR_AVALON": "Expert's Evensong",
    "T5_2H_ARCANE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T5_2H_ARCANESTAFF": "Expert's Great Arcane Staff",
    "T5_2H_ARCANESTAFF_DESC": "Equipment Item",
    "T5_2H_ARCANESTAFF_ENCHANTED": "Expert's Enchanted Great Arcane Staff",
    "T5_2H_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_ARCANESTAFF_HELL": "Expert's Occult Staff",
    "T5_2H_ARCANESTAFF_HELL_DESC": "Equipment Item",
    "T5_2H_AXE": "Expert's Greataxe",
    "T5_2H_AXE_AVALON": "Expert's Realmbreaker",
    "T5_2H_AXE_AVALON_DESC": "Equipment Item",
    "T5_2H_AXE_DESC": "Equipment Item",
    "T5_2H_AXE_ENCHANTED": "Expert's Enchanted Greataxe",
    "T5_2H_AXE_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_BOW": "Expert's Bow",
    "T5_2H_BOW_AVALON": "Expert's Mistpiercer",
    "T5_2H_BOW_AVALON_DESC": "Equipment Item",
    "T5_2H_BOW_DESC": "Equipment Item",
    "T5_2H_BOW_ENCHANTED": "Expert's Enchanted Bow",
    "T5_2H_BOW_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_BOW_HELL": "Expert's Wailing Bow",
    "T5_2H_BOW_HELL_DESC": "Equipment Item",
    "T5_2H_BOW_KEEPER": "Expert's Bow of Badon",
    "T5_2H_BOW_KEEPER_DESC": "Equipment Item",
    "T5_2H_CLAWPAIR": "Expert's Claws",
    "T5_2H_CLAWPAIR_DESC": "Equipment Item",
    "T5_2H_CLAYMORE": "Expert's Claymore",
    "T5_2H_CLAYMORE_AVALON": "Expert's Kingmaker",
    "T5_2H_CLAYMORE_AVALON_DESC": "Equipment Item",
    "T5_2H_CLAYMORE_DESC": "Equipment Item",
    "T5_2H_CLAYMORE_ENCHANTED": "Expert's Enchanted Claymore",
    "T5_2H_CLAYMORE_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_CLEAVER_HELL": "Expert's Carving Sword",
    "T5_2H_CLEAVER_HELL_DESC": "Equipment Item",
    "T5_2H_COMBATSTAFF_MORGANA": "Expert's Black Monk Stave",
    "T5_2H_COMBATSTAFF_MORGANA_DESC": "Equipment Item",
    "T5_2H_CROSSBOW": "Expert's Crossbow",
    "T5_2H_CROSSBOW_CANNON_AVALON": "Expert's Energy Shaper",
    "T5_2H_CROSSBOW_CANNON_AVALON_DESC": "Equipment Item",
    "T5_2H_CROSSBOW_DESC": "Equipment Item",
    "T5_2H_CROSSBOWLARGE": "Expert's Heavy Crossbow",
    "T5_2H_CROSSBOWLARGE_DESC": "Equipment Item",
    "T5_2H_CROSSBOWLARGE_ENCHANTED": "Expert's Enchanted Heavy Crossbow",
    "T5_2H_CROSSBOWLARGE_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_CROSSBOWLARGE_MORGANA": "Expert's Siegebow",
    "T5_2H_CROSSBOWLARGE_MORGANA_DESC": "Equipment Item",
    "T5_2H_CURSEDSTAFF": "Expert's Great Cursed Staff",
    "T5_2H_CURSEDSTAFF_DESC": "Equipment Item",
    "T5_2H_CURSEDSTAFF_ENCHANTED": "Expert's Enchanted Great Cursed Staff",
    "T5_2H_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_CURSEDSTAFF_MORGANA": "Expert's Damnation Staff",
    "T5_2H_CURSEDSTAFF_MORGANA_DESC": "Equipment Item",
    "T5_2H_DAGGER_KATAR_AVALON": "Expert's Bridled Fury",
    "T5_2H_DAGGER_KATAR_AVALON_DESC": "Equipment Item",
    "T5_2H_DAGGERPAIR": "Expert's Dagger Pair",
    "T5_2H_DAGGERPAIR_DESC": "Equipment Item",
    "T5_2H_DAGGERPAIR_ENCHANTED": "Expert's Enchanted Dagger Pair",
    "T5_2H_DAGGERPAIR_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_DEMONICSTAFF": "Expert's Demonic Staff",
    "T5_2H_DEMONICSTAFF_DESC": "Equipment Item",
    "T5_2H_DIVINESTAFF": "Expert's Divine Staff",
    "T5_2H_DIVINESTAFF_DESC": "Equipment Item",
    "T5_2H_DOUBLEBLADEDSTAFF": "Expert's Double Bladed Staff",
    "T5_2H_DOUBLEBLADEDSTAFF_DESC": "Equipment Item",
    "T5_2H_DUALAXE_KEEPER": "Expert's Bear Paws",
    "T5_2H_DUALAXE_KEEPER_DESC": "Equipment Item",
    "T5_2H_DUALCROSSBOW_HELL": "Expert's Boltcasters",
    "T5_2H_DUALCROSSBOW_HELL_DESC": "Equipment Item",
    "T5_2H_DUALHAMMER_HELL": "Expert's Forge Hammers",
    "T5_2H_DUALHAMMER_HELL_DESC": "Equipment Item",
    "T5_2H_DUALMACE_AVALON": "Expert's Oathkeepers",
    "T5_2H_DUALMACE_AVALON_DESC": "Equipment Item",
    "T5_2H_DUALSCIMITAR_UNDEAD": "Expert's Galatine Pair",
    "T5_2H_DUALSCIMITAR_UNDEAD_DESC": "Equipment Item",
    "T5_2H_DUALSICKLE_UNDEAD": "Expert's Deathgivers",
    "T5_2H_DUALSICKLE_UNDEAD_DESC": "Equipment Item",
    "T5_2H_DUALSWORD": "Expert's Dual Swords",
    "T5_2H_DUALSWORD_DESC": "Equipment Item",
    "T5_2H_ENIGMATICORB_MORGANA": "Expert's Malevolent Locus",
    "T5_2H_ENIGMATICORB_MORGANA_DESC": "Equipment Item",
    "T5_2H_ENIGMATICSTAFF": "Expert's Enigmatic Staff",
    "T5_2H_ENIGMATICSTAFF_DESC": "Equipment Item",
    "T5_2H_FIRE_RINGPAIR_AVALON": "Expert's Dawnsong",
    "T5_2H_FIRE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T5_2H_FIRESTAFF": "Expert's Great Fire Staff",
    "T5_2H_FIRESTAFF_DESC": "Equipment Item",
    "T5_2H_FIRESTAFF_ENCHANTED": "Expert's Enchanted Great Fire Staff",
    "T5_2H_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_FIRESTAFF_HELL": "Expert's Brimstone Staff",
    "T5_2H_FIRESTAFF_HELL_DESC": "Equipment Item",
    "T5_2H_FLAIL": "Expert's Morning Star",
    "T5_2H_FLAIL_DESC": "Equipment Item",
    "T5_2H_FROSTSTAFF": "Expert's Great Frost Staff",
    "T5_2H_FROSTSTAFF_DESC": "Equipment Item",
    "T5_2H_FROSTSTAFF_ENCHANTED": "Expert's Enchanted Great Frost Staff",
    "T5_2H_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_GLACIALSTAFF": "Expert's Glacial Staff",
    "T5_2H_GLACIALSTAFF_DESC": "Equipment Item",
    "T5_2H_GLAIVE": "Expert's Glaive",
    "T5_2H_GLAIVE_DESC": "Equipment Item",
    "T5_2H_HALBERD": "Expert's Halberd",
    "T5_2H_HALBERD_DESC": "Equipment Item",
    "T5_2H_HALBERD_MORGANA": "Expert's Carrioncaller",
    "T5_2H_HALBERD_MORGANA_DESC": "Equipment Item",
    "T5_2H_HAMMER": "Expert's Great Hammer",
    "T5_2H_HAMMER_AVALON": "Expert's Hand of Justice",
    "T5_2H_HAMMER_AVALON_DESC": "Equipment Item",
    "T5_2H_HAMMER_DESC": "Equipment Item",
    "T5_2H_HAMMER_UNDEAD": "Expert's Tombhammer",
    "T5_2H_HAMMER_UNDEAD_DESC": "Equipment Item",
    "T5_2H_HARPOON_HELL": "Expert's Spirithunter",
    "T5_2H_HARPOON_HELL_DESC": "Equipment Item",
    "T5_2H_HOLYSTAFF": "Expert's Great Holy Staff",
    "T5_2H_HOLYSTAFF_DESC": "Equipment Item",
    "T5_2H_HOLYSTAFF_ENCHANTED": "Expert's Enchanted Great Holy Staff",
    "T5_2H_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_HOLYSTAFF_HELL": "Expert's Fallen Staff",
    "T5_2H_HOLYSTAFF_HELL_DESC": "Equipment Item",
    "T5_2H_HOLYSTAFF_UNDEAD": "Expert's Redemption Staff",
    "T5_2H_HOLYSTAFF_UNDEAD_DESC": "Equipment Item",
    "T5_2H_ICECRYSTAL_UNDEAD": "Expert's Permafrost Prism",
    "T5_2H_ICECRYSTAL_UNDEAD_DESC": "Equipment Item",
    "T5_2H_ICEGAUNTLETS_HELL": "Expert's Icicle Staff",
    "T5_2H_ICEGAUNTLETS_HELL_DESC": "Equipment Item",
    "T5_2H_INFERNOSTAFF": "Expert's Infernal Staff",
    "T5_2H_INFERNOSTAFF_DESC": "Equipment Item",
    "T5_2H_INFERNOSTAFF_MORGANA": "Expert's Blazing Staff",
    "T5_2H_INFERNOSTAFF_MORGANA_DESC": "Equipment Item",
    "T5_2H_IRONCLADEDSTAFF": "Expert's Iron-clad Staff",
    "T5_2H_IRONCLADEDSTAFF_DESC": "Equipment Item",
    "T5_2H_IRONCLADEDSTAFF_ENCHANTED": "Expert's Enchanted Iron-clad Staff",
    "T5_2H_IRONCLADEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_IRONGAUNTLETS_HELL": "Expert's Black Hands",
    "T5_2H_IRONGAUNTLETS_HELL_DESC": "Equipment Item",
    "T5_2H_LONGBOW": "Expert's Longbow",
    "T5_2H_LONGBOW_DESC": "Equipment Item",
    "T5_2H_LONGBOW_UNDEAD": "Expert's Whispering Bow",
    "T5_2H_LONGBOW_UNDEAD_DESC": "Equipment Item",
    "T5_2H_MACE": "Expert's Heavy Mace",
    "T5_2H_MACE_DESC": "Equipment Item",
    "T5_2H_MACE_ENCHANTED": "Expert's Enchanted Heavy Mace",
    "T5_2H_MACE_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_MACE_MORGANA": "Expert's Camlann Mace",
    "T5_2H_MACE_MORGANA_DESC": "Equipment Item",
    "T5_2H_NATURESTAFF": "Expert's Great Nature Staff",
    "T5_2H_NATURESTAFF_DESC": "Equipment Item",
    "T5_2H_NATURESTAFF_ENCHANTED": "Expert's Enchanted Great Nature Staff",
    "T5_2H_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_NATURESTAFF_HELL": "Expert's Blight Staff",
    "T5_2H_NATURESTAFF_HELL_DESC": "Equipment Item",
    "T5_2H_NATURESTAFF_KEEPER": "Expert's Rampant Staff",
    "T5_2H_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T5_2H_POLEHAMMER": "Expert's Polehammer",
    "T5_2H_POLEHAMMER_DESC": "Equipment Item",
    "T5_2H_POLEHAMMER_ENCHANTED": "Expert's Enchanted Polehammer",
    "T5_2H_POLEHAMMER_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_QUARTERSTAFF": "Expert's Quarterstaff",
    "T5_2H_QUARTERSTAFF_AVALON": "Expert's Grailseeker",
    "T5_2H_QUARTERSTAFF_AVALON_DESC": "Equipment Item",
    "T5_2H_QUARTERSTAFF_DESC": "Equipment Item",
    "T5_2H_QUARTERSTAFF_ENCHANTED": "Expert's Enchanted Quarterstaff",
    "T5_2H_QUARTERSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_RAM_KEEPER": "Expert's Grovekeeper",
    "T5_2H_RAM_KEEPER_DESC": "Equipment Item",
    "T5_2H_REPEATINGCROSSBOW_UNDEAD": "Expert's Weeping Repeater",
    "T5_2H_REPEATINGCROSSBOW_UNDEAD_DESC": "Equipment Item",
    "T5_2H_ROCKSTAFF_KEEPER": "Expert's Staff of Balance",
    "T5_2H_ROCKSTAFF_KEEPER_DESC": "Equipment Item",
    "T5_2H_SCYTHE": "Expert's Scythe",
    "T5_2H_SCYTHE_DESC": "Equipment Item",
    "T5_2H_SCYTHE_HELL": "Expert's Infernal Scythe",
    "T5_2H_SCYTHE_HELL_DESC": "Equipment Item",
    "T5_2H_SKULLORB_HELL": "Expert's Cursed Skull",
    "T5_2H_SKULLORB_HELL_DESC": "Equipment Item",
    "T5_2H_SPEAR": "Expert's Pike",
    "T5_2H_SPEAR_DESC": "Equipment Item",
    "T5_2H_SPEAR_ENCHANTED": "Expert's Enchanted Pike",
    "T5_2H_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_TOOL_AXE": "Expert's Axe",
    "T5_2H_TOOL_AXE_AVALON": "Expert's Avalonian Axe",
    "T5_2H_TOOL_AXE_DESC": "Equipment Item",
    "T5_2H_TOOL_FISHINGROD": "Expert's Fishing Rod",
    "T5_2H_TOOL_FISHINGROD_AVALON": "Expert's Avalonian Fishing Rod",
    "T5_2H_TOOL_FISHINGROD_DESC": "Equipment Item",
    "T5_2H_TOOL_HAMMER": "Expert's Stone Hammer",
    "T5_2H_TOOL_HAMMER_AVALON": "Expert's Avalonian Stone Hammer",
    "T5_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T5_2H_TOOL_KNIFE": "Expert's Skinning Knife",
    "T5_2H_TOOL_KNIFE_AVALON": "Expert's Avalonian Skinning Knife",
    "T5_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T5_2H_TOOL_PICK": "Expert's Pickaxe",
    "T5_2H_TOOL_PICK_AVALON": "Expert's Avalonian Pickaxe",
    "T5_2H_TOOL_PICK_DESC": "Equipment Item",
    "T5_2H_TOOL_SICKLE": "Expert's Sickle",
    "T5_2H_TOOL_SICKLE_AVALON": "Expert's Avalonian Sickle",
    "T5_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T5_2H_TOOL_SIEGEHAMMER": "Expert's Demolition Hammer",
    "T5_2H_TOOL_SIEGEHAMMER_AVALON": "Expert's Avalonian Demolition Hammer",
    "T5_2H_TOOL_SIEGEHAMMER_DESC": "A powerful hammer designed for destroying buildings and furniture.",
    "T5_2H_TRIDENT_UNDEAD": "Expert's Trinity Spear",
    "T5_2H_TRIDENT_UNDEAD_DESC": "Equipment Item",
    "T5_2H_TWINSCYTHE_HELL": "Expert's Soulscythe",
    "T5_2H_TWINSCYTHE_HELL_DESC": "Equipment Item",
    "T5_2H_WARBOW": "Expert's Warbow",
    "T5_2H_WARBOW_DESC": "Equipment Item",
    "T5_2H_WARBOW_ENCHANTED": "Expert's Enchanted Warbow",
    "T5_2H_WARBOW_ENCHANTED_DESC": "Equipment Item",
    "T5_2H_WILDSTAFF": "Expert's Wild Staff",
    "T5_2H_WILDSTAFF_DESC": "Equipment Item",
    "T5_ARMOR_CLOTH_AVALON": "Expert's Robe of Purity",
    "T5_ARMOR_CLOTH_HELL": "Expert's Fiend Robe",
    "T5_ARMOR_CLOTH_HELL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_KEEPER": "Expert's Druid Robe",
    "T5_ARMOR_CLOTH_KEEPER_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_MORGANA": "Expert's Cultist Robe",
    "T5_ARMOR_CLOTH_MORGANA_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_ROYAL": "Expert's Royal Robe",
    "T5_ARMOR_CLOTH_ROYAL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_SET1": "Expert's Scholar Robe",
    "T5_ARMOR_CLOTH_SET1_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_SET1_ENCHANTED": "Enchanted Expert's Scholar Robe",
    "T5_ARMOR_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_SET2": "Expert's Cleric Robe",
    "T5_ARMOR_CLOTH_SET2_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_SET2_ENCHANTED": "Enchanted Expert's Cleric Robe",
    "T5_ARMOR_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_CLOTH_SET3": "Expert's Mage Robe",
    "T5_ARMOR_CLOTH_SET3_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T5_ARMOR_GATHERER_FIBER": "Expert's Harvester Garb",
    "T5_ARMOR_GATHERER_FIBER_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T5_ARMOR_GATHERER_FISH": "Expert's Fisherman Garb",
    "T5_ARMOR_GATHERER_FISH_DESC": "Equipment Item\nGatherer Gear helps you gather more of its resource type",
    "T5_ARMOR_GATHERER_HIDE": "Expert's Skinner Garb",
    "T5_ARMOR_GATHERER_HIDE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T5_ARMOR_GATHERER_ORE": "Expert's Miner Garb",
    "T5_ARMOR_GATHERER_ORE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T5_ARMOR_GATHERER_ROCK": "Expert's Quarrier Garb",
    "T5_ARMOR_GATHERER_ROCK_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T5_ARMOR_GATHERER_WOOD": "Expert's Lumberjack Garb",
    "T5_ARMOR_GATHERER_WOOD_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T5_ARMOR_LEATHER_AVALON": "Expert's Jacket of Tenacity",
    "T5_ARMOR_LEATHER_HELL": "Expert's Hellion Jacket",
    "T5_ARMOR_LEATHER_HELL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_MORGANA": "Expert's Stalker Jacket",
    "T5_ARMOR_LEATHER_MORGANA_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_ROYAL": "Expert's Royal Jacket",
    "T5_ARMOR_LEATHER_ROYAL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_SET1": "Expert's Mercenary Jacket",
    "T5_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_SET1_ENCHANTED": "Enchanted Expert's Mercenary Jacket",
    "T5_ARMOR_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_SET2": "Expert's Hunter Jacket",
    "T5_ARMOR_LEATHER_SET2_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_SET2_ENCHANTED": "Enchanted Expert's Hunter Jacket",
    "T5_ARMOR_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_SET3": "Expert's Assassin Jacket",
    "T5_ARMOR_LEATHER_SET3_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_LEATHER_UNDEAD": "Expert's Specter Jacket",
    "T5_ARMOR_LEATHER_UNDEAD_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T5_ARMOR_PLATE_AVALON": "Expert's Armor of Valor",
    "T5_ARMOR_PLATE_HELL": "Expert's Demon Armor",
    "T5_ARMOR_PLATE_HELL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_KEEPER": "Expert's Judicator Armor",
    "T5_ARMOR_PLATE_KEEPER_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_ROYAL": "Expert's Royal Armor",
    "T5_ARMOR_PLATE_ROYAL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_SET1": "Expert's Soldier Armor",
    "T5_ARMOR_PLATE_SET1_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_SET1_ENCHANTED": "Enchanted Expert's Soldier Armor",
    "T5_ARMOR_PLATE_SET1_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_SET2": "Expert's Knight Armor",
    "T5_ARMOR_PLATE_SET2_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_SET2_ENCHANTED": "Enchanted Expert's Knight Armor",
    "T5_ARMOR_PLATE_SET2_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_SET3": "Expert's Guardian Armor",
    "T5_ARMOR_PLATE_SET3_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARMOR_PLATE_UNDEAD": "Expert's Graveguard Armor",
    "T5_ARMOR_PLATE_UNDEAD_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T5_ARTEFACT_2H_ARCANE_RINGPAIR_AVALON": "Expert's Hypnotic Harmonic Ring",
    "T5_ARTEFACT_2H_ARCANESTAFF_HELL": "Expert's Occult Orb",
    "T5_ARTEFACT_2H_AXE_AVALON": "Expert's Avalonian Battle Memoir",
    "T5_ARTEFACT_2H_BOW_AVALON": "Expert's Immaculately Crafted Riser",
    "T5_ARTEFACT_2H_BOW_HELL": "Expert's Demonic Arrowheads",
    "T5_ARTEFACT_2H_BOW_KEEPER": "Expert's Carved bone",
    "T5_ARTEFACT_2H_CLAYMORE_AVALON": "Expert's Remnants of the Old King",
    "T5_ARTEFACT_2H_CLEAVER_HELL": "Expert's Demonic Blade",
    "T5_ARTEFACT_2H_COMBATSTAFF_MORGANA": "Expert's Reinforced Morgana Pole",
    "T5_ARTEFACT_2H_CROSSBOW_CANNON_AVALON": "Expert's Humming Avalonian Whirligig",
    "T5_ARTEFACT_2H_CROSSBOWLARGE_MORGANA": "Expert's Alluring Bolts",
    "T5_ARTEFACT_2H_CURSEDSTAFF_MORGANA": "Expert's Bloodforged Catalyst",
    "T5_ARTEFACT_2H_DAGGER_KATAR_AVALON": "Expert's Bloodstained Antiquities",
    "T5_ARTEFACT_2H_DUALAXE_KEEPER": "Expert's Keeper Axeheads",
    "T5_ARTEFACT_2H_DUALCROSSBOW_HELL": "Expert's Hellish Bolts",
    "T5_ARTEFACT_2H_DUALHAMMER_HELL": "Expert's Hellish Hammer Heads",
    "T5_ARTEFACT_2H_DUALMACE_AVALON": "Expert's Broken Oaths",
    "T5_ARTEFACT_2H_DUALSCIMITAR_UNDEAD": "Expert's Cursed Blades",
    "T5_ARTEFACT_2H_DUALSICKLE_UNDEAD": "Expert's Ghastly Blades",
    "T5_ARTEFACT_2H_ENIGMATICORB_MORGANA": "Expert's Possessed Catalyst",
    "T5_ARTEFACT_2H_FIRE_RINGPAIR_AVALON": "Expert's Glowing Harmonic Ring",
    "T5_ARTEFACT_2H_FIRESTAFF_HELL": "Expert's Burning Orb",
    "T5_ARTEFACT_2H_HALBERD_MORGANA": "Expert's Morgana Halberd Head",
    "T5_ARTEFACT_2H_HAMMER_AVALON": "Expert's Massive Metallic Hand",
    "T5_ARTEFACT_2H_HAMMER_UNDEAD": "Expert's Ancient Hammer Head",
    "T5_ARTEFACT_2H_HARPOON_HELL": "Expert's Infernal Harpoon Tip",
    "T5_ARTEFACT_2H_HOLYSTAFF_HELL": "Expert's Infernal Scroll",
    "T5_ARTEFACT_2H_HOLYSTAFF_UNDEAD": "Expert's Ghastly Scroll",
    "T5_ARTEFACT_2H_ICECRYSTAL_UNDEAD": "Expert's Cursed Frozen Crystal",
    "T5_ARTEFACT_2H_ICEGAUNTLETS_HELL": "Expert's Icicle Orb",
    "T5_ARTEFACT_2H_INFERNOSTAFF_MORGANA": "Expert's Unholy Scroll",
    "T5_ARTEFACT_2H_IRONGAUNTLETS_HELL": "Expert's Black Leather",
    "T5_ARTEFACT_2H_LONGBOW_UNDEAD": "Expert's Ghastly Arrows",
    "T5_ARTEFACT_2H_MACE_MORGANA": "Expert's Imbued Mace Head",
    "T5_ARTEFACT_2H_NATURESTAFF_HELL": "Expert's Symbol of Blight",
    "T5_ARTEFACT_2H_NATURESTAFF_KEEPER": "Expert's Preserved Log",
    "T5_ARTEFACT_2H_QUARTERSTAFF_AVALON": "Expert's Timeworn Walking Staff",
    "T5_ARTEFACT_2H_RAM_KEEPER": "Expert's Engraved Log",
    "T5_ARTEFACT_2H_REPEATINGCROSSBOW_UNDEAD": "Expert's Lost Crossbow Mechanism",
    "T5_ARTEFACT_2H_ROCKSTAFF_KEEPER": "Expert's Preserved Rocks",
    "T5_ARTEFACT_2H_SCYTHE_HELL": "Expert's Hellish Sicklehead",
    "T5_ARTEFACT_2H_SKULLORB_HELL": "Expert's Cursed Jawbone",
    "T5_ARTEFACT_2H_TRIDENT_UNDEAD": "Expert's Cursed Barbs",
    "T5_ARTEFACT_2H_TWINSCYTHE_HELL": "Expert's Hellish Sicklehead Pair",
    "T5_ARTEFACT_ARMOR_CLOTH_AVALON": "Expert's Sanctified Belt",
    "T5_ARTEFACT_ARMOR_CLOTH_HELL": "Expert's Infernal Cloth Folds",
    "T5_ARTEFACT_ARMOR_CLOTH_KEEPER": "Expert's Druidic Feathers",
    "T5_ARTEFACT_ARMOR_CLOTH_MORGANA": "Expert's Alluring Amulet",
    "T5_ARTEFACT_ARMOR_LEATHER_AVALON": "Expert's Augured Sash",
    "T5_ARTEFACT_ARMOR_LEATHER_HELL": "Expert's Demonhide Leather",
    "T5_ARTEFACT_ARMOR_LEATHER_MORGANA": "Expert's Imbued Leather Folds",
    "T5_ARTEFACT_ARMOR_LEATHER_UNDEAD": "Expert's Ghastly Leather",
    "T5_ARTEFACT_ARMOR_PLATE_AVALON": "Expert's Exalted Plating",
    "T5_ARTEFACT_ARMOR_PLATE_HELL": "Expert's Demonic Plates",
    "T5_ARTEFACT_ARMOR_PLATE_KEEPER": "Expert's Preserved Animal Fur",
    "T5_ARTEFACT_ARMOR_PLATE_UNDEAD": "Expert's Ancient Chain Rings",
    "T5_ARTEFACT_HEAD_CLOTH_AVALON": "Expert's Sanctified Mask",
    "T5_ARTEFACT_HEAD_CLOTH_HELL": "Expert's Infernal Cloth Visor",
    "T5_ARTEFACT_HEAD_CLOTH_KEEPER": "Expert's Druidic Preserved Beak",
    "T5_ARTEFACT_HEAD_CLOTH_MORGANA": "Expert's Alluring Padding",
    "T5_ARTEFACT_HEAD_LEATHER_AVALON": "Expert's Augured Padding",
    "T5_ARTEFACT_HEAD_LEATHER_HELL": "Expert's Demonhide Padding",
    "T5_ARTEFACT_HEAD_LEATHER_MORGANA": "Expert's Imbued Visor",
    "T5_ARTEFACT_HEAD_LEATHER_UNDEAD": "Expert's Ghastly Visor",
    "T5_ARTEFACT_HEAD_PLATE_AVALON": "Expert's Exalted Visor",
    "T5_ARTEFACT_HEAD_PLATE_HELL": "Expert's Demonic Scraps",
    "T5_ARTEFACT_HEAD_PLATE_KEEPER": "Expert's Carved Skull Padding",
    "T5_ARTEFACT_HEAD_PLATE_UNDEAD": "Expert's Ancient Padding",
    "T5_ARTEFACT_MAIN_ARCANESTAFF_UNDEAD": "Expert's Lost Arcane Crystal",
    "T5_ARTEFACT_MAIN_CURSEDSTAFF_AVALON": "Expert's Fractured Opaque Orb",
    "T5_ARTEFACT_MAIN_CURSEDSTAFF_UNDEAD": "Expert's Lost Cursed Crystal",
    "T5_ARTEFACT_MAIN_FIRESTAFF_KEEPER": "Expert's Wildfire Orb",
    "T5_ARTEFACT_MAIN_FROSTSTAFF_AVALON": "Expert's Chilled Crystaline Shard",
    "T5_ARTEFACT_MAIN_FROSTSTAFF_KEEPER": "Expert's Hoarfrost Orb",
    "T5_ARTEFACT_MAIN_HOLYSTAFF_AVALON": "Expert's Messianic Curio",
    "T5_ARTEFACT_MAIN_HOLYSTAFF_MORGANA": "Expert's Possessed Scroll",
    "T5_ARTEFACT_MAIN_MACE_HELL": "Expert's Infernal Mace Head",
    "T5_ARTEFACT_MAIN_NATURESTAFF_AVALON": "Expert's Uprooted Perennial Sapling",
    "T5_ARTEFACT_MAIN_NATURESTAFF_KEEPER": "Expert's Druidic Inscriptions",
    "T5_ARTEFACT_MAIN_RAPIER_MORGANA": "Expert's Hardened Debole",
    "T5_ARTEFACT_MAIN_ROCKMACE_KEEPER": "Expert's Runed Rock",
    "T5_ARTEFACT_MAIN_SCIMITAR_MORGANA": "Expert's Bloodforged Blade",
    "T5_ARTEFACT_MAIN_SPEAR_KEEPER": "Expert's Keeper Spearhead",
    "T5_ARTEFACT_MAIN_SPEAR_LANCE_AVALON": "Expert's Ruined Ancestral Vamplate",
    "T5_ARTEFACT_OFF_CENSER_AVALON": "Expert's Severed Celestial Keepsake",
    "T5_ARTEFACT_OFF_DEMONSKULL_HELL": "Expert's Demonic Jawbone",
    "T5_ARTEFACT_OFF_HORN_KEEPER": "Expert's Runed Horn",
    "T5_ARTEFACT_OFF_JESTERCANE_HELL": "Expert's Hellish Handle",
    "T5_ARTEFACT_OFF_LAMP_UNDEAD": "Expert's Ghastly Candle",
    "T5_ARTEFACT_OFF_ORB_MORGANA": "Expert's Alluring Crystal",
    "T5_ARTEFACT_OFF_SHIELD_AVALON": "Expert's Crushed Avalonian Heirloom",
    "T5_ARTEFACT_OFF_SHIELD_HELL": "Expert's Infernal Shield Core",
    "T5_ARTEFACT_OFF_SPIKEDSHIELD_MORGANA": "Expert's Bloodforged Spikes",
    "T5_ARTEFACT_OFF_TALISMAN_AVALON": "Expert's Shattered Avalonian Memento",
    "T5_ARTEFACT_OFF_TOTEM_KEEPER": "Expert's Inscribed Stone",
    "T5_ARTEFACT_OFF_TOWERSHIELD_UNDEAD": "Expert's Ancient Shield Core",
    "T5_ARTEFACT_SHOES_CLOTH_AVALON": "Expert's Sanctified Bindings",
    "T5_ARTEFACT_SHOES_CLOTH_HELL": "Expert's Infernal Cloth Bindings",
    "T5_ARTEFACT_SHOES_CLOTH_KEEPER": "Expert's Druidic Bindings",
    "T5_ARTEFACT_SHOES_CLOTH_MORGANA": "Expert's Alluring Bindings",
    "T5_ARTEFACT_SHOES_LEATHER_AVALON": "Expert's Augured Fasteners",
    "T5_ARTEFACT_SHOES_LEATHER_HELL": "Expert's Demonhide Bindings",
    "T5_ARTEFACT_SHOES_LEATHER_MORGANA": "Expert's Imbued Soles",
    "T5_ARTEFACT_SHOES_LEATHER_UNDEAD": "Expert's Ghastly Bindings",
    "T5_ARTEFACT_SHOES_PLATE_AVALON": "Expert's Exalted Greave",
    "T5_ARTEFACT_SHOES_PLATE_HELL": "Expert's Demonic Filling",
    "T5_ARTEFACT_SHOES_PLATE_KEEPER": "Expert's Inscribed Bindings",
    "T5_ARTEFACT_SHOES_PLATE_UNDEAD": "Expert's Ancient Bindings",
    "T5_BACKPACK_GATHERER_FIBER": "Expert's Harvester Backpack",
    "T5_BACKPACK_GATHERER_FIBER_DESC": "Equipment Item",
    "T5_BACKPACK_GATHERER_FISH": "Expert's Fisherman Backpack",
    "T5_BACKPACK_GATHERER_FISH_DESC": "Equipment Item",
    "T5_BACKPACK_GATHERER_HIDE": "Expert's Skinner Backpack",
    "T5_BACKPACK_GATHERER_HIDE_DESC": "Equipment Item",
    "T5_BACKPACK_GATHERER_ORE": "Expert's Miner Backpack",
    "T5_BACKPACK_GATHERER_ORE_DESC": "Equipment Item",
    "T5_BACKPACK_GATHERER_ROCK": "Expert's Quarrier Backpack",
    "T5_BACKPACK_GATHERER_ROCK_DESC": "Equipment Item",
    "T5_BACKPACK_GATHERER_WOOD": "Expert's Lumberjack Backpack",
    "T5_BACKPACK_GATHERER_WOOD_DESC": "Equipment Item",
    "T5_BAG": "Expert's Bag",
    "T5_BAG_DESC": "Equipment Item",
    "T5_BAG_FW_BONUS_FAME": "Expert's Faction Fame Bag",
    "T5_BAG_FW_BONUS_FAME_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T5_BAG_FW_BONUS_SILVER": "Expert's Faction Silver Bag",
    "T5_BAG_FW_BONUS_SILVER_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T5_BAG_FW_BONUS_YIELD": "Expert's Faction Yield Bag",
    "T5_BAG_FW_BONUS_YIELD_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T5_BAG_FW_FAME_BP": "Expert's Faction Fame Bag Pattern",
    "T5_BAG_FW_FAME_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T5_BAG_FW_SILVER_BP": "Expert's Faction Silver Bag Pattern",
    "T5_BAG_FW_SILVER_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T5_BAG_FW_YIELD_BP": "Expert's Faction Yield Bag Pattern",
    "T5_BAG_FW_YIELD_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T5_BAG_INSIGHT": "Expert's Satchel of Insight",
    "T5_CABBAGE": "Cabbage",
    "T5_CABBAGE_DESC": "Cabbage is used in a variety of meals.",
    "T5_CAPE": "Expert's Cape",
    "T5_CAPE_DESC": "Equipment Item",
    "T5_CAPEITEM_DEMON": "Expert's Demon Cape",
    "T5_CAPEITEM_DEMON_BP": "Expert's Demon Crest",
    "T5_CAPEITEM_DEMON_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_DEMON_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_FW_BRIDGEWATCH": "Expert's Bridgewatch Cape",
    "T5_CAPEITEM_FW_BRIDGEWATCH_BP": "Expert's Bridgewatch Crest",
    "T5_CAPEITEM_FW_BRIDGEWATCH_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_FW_BRIDGEWATCH_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_FW_FORTSTERLING": "Expert's Fort Sterling Cape",
    "T5_CAPEITEM_FW_FORTSTERLING_BP": "Expert's Fort Sterling Crest",
    "T5_CAPEITEM_FW_FORTSTERLING_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_FW_FORTSTERLING_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_FW_LYMHURST": "Expert's Lymhurst Cape",
    "T5_CAPEITEM_FW_LYMHURST_BP": "Expert's Lymhurst Crest",
    "T5_CAPEITEM_FW_LYMHURST_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_FW_LYMHURST_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_FW_MARTLOCK": "Expert's Martlock Cape",
    "T5_CAPEITEM_FW_MARTLOCK_BP": "Expert's Martlock Crest",
    "T5_CAPEITEM_FW_MARTLOCK_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_FW_MARTLOCK_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_FW_THETFORD": "Expert's Thetford Cape",
    "T5_CAPEITEM_FW_THETFORD_BP": "Expert's Thetford Crest",
    "T5_CAPEITEM_FW_THETFORD_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_FW_THETFORD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_HERETIC": "Expert's Heretic Cape",
    "T5_CAPEITEM_HERETIC_BP": "Expert's Heretic Crest",
    "T5_CAPEITEM_HERETIC_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_HERETIC_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_KEEPER": "Expert's Keeper Cape",
    "T5_CAPEITEM_KEEPER_BP": "Expert's Keeper Crest",
    "T5_CAPEITEM_KEEPER_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_KEEPER_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_MORGANA": "Expert's Morgana Cape",
    "T5_CAPEITEM_MORGANA_BP": "Expert's Morgana Crest",
    "T5_CAPEITEM_MORGANA_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_MORGANA_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CAPEITEM_UNDEAD": "Expert's Undead Cape",
    "T5_CAPEITEM_UNDEAD_BP": "Expert's Undead Crest",
    "T5_CAPEITEM_UNDEAD_BP_DESC": "Can be used to upgrade a cape",
    "T5_CAPEITEM_UNDEAD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T5_CLOTH": "Ornate Cloth",
    "T5_CLOTH_DESC": "Advanced material used in crafting, created by refining fiber.",
    "T5_CLOTH_LEVEL1": "Uncommon Ornate Cloth",
    "T5_CLOTH_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_CLOTH_LEVEL2": "Rare Ornate Cloth",
    "T5_CLOTH_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_CLOTH_LEVEL3": "Exceptional Ornate Cloth",
    "T5_CLOTH_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_CLOTH_LEVEL4": "Legendary Ornate Cloth",
    "T5_CLOTH_LEVEL4_DESC": "Legendary material used for crafting.",
    "T5_EGG": "Goose Eggs",
    "T5_EGG_DESC": "Goose Eggs are used in several cooking recipes and potions.",
    "T5_ESSENCE": "Expert's Faded Essence",
    "T5_ESSENCE_DESC": "This essence has passed its use-by date. It can be combined with others like it at an Artifact Foundry.",
    "T5_ESSENCE_HUNTER": "Mystical Essence of the Hunter",
    "T5_ESSENCE_HUNTER_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T5_ESSENCE_MAGE": "Mystical Essence of the Mage",
    "T5_ESSENCE_MAGE_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T5_ESSENCE_POTION": "Expert's Arcane Essence",
    "T5_ESSENCE_POTION_DESC": "A magical essence, used to enchant potions.",
    "T5_ESSENCE_WARRIOR": "Mystical Essence of the Warrior",
    "T5_ESSENCE_WARRIOR_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T5_FARM_CABBAGE_SEED": "Cabbage Seeds",
    "T5_FARM_CABBAGE_SEED_DESC": "Cabbage Seeds are used to plant a patch of Cabbages.",
    "T5_FARM_COUGAR_BABY": "Swiftclaw Cub",
    "T5_FARM_COUGAR_BABY_DESC": "A Swiftclaw Cub placed in a Kennel will grow into a Tame Swiftclaw, which can be trained into a Swiftclaw mount.",
    "T5_FARM_COUGAR_GROWN": "Tame Swiftclaw",
    "T5_FARM_COUGAR_GROWN_DESC": "Can be used to craft a Swiftclaw mount.",
    "T5_FARM_DIREBEAR_FW_FORTSTERLING_BABY": "Winter Bear Cub",
    "T5_FARM_DIREBEAR_FW_FORTSTERLING_BABY_DESC": "A Winter Bear Cub placed in a kennel will grow into a Tame Winter Bear, which can be trained into a mount.",
    "T5_FARM_DIREBEAR_FW_FORTSTERLING_GROWN": "Tame Winter Bear",
    "T5_FARM_DIREBEAR_FW_FORTSTERLING_GROWN_DESC": "Can be used to craft a Saddled Winter Bear mount.",
    "T5_FARM_DIREBOAR_FW_LYMHURST_BABY": "Wild Boarlet",
    "T5_FARM_DIREBOAR_FW_LYMHURST_BABY_DESC": "A Wild Boarlet placed in a kennel will grow into a Tame Wild Boar, which can be trained into a mount.",
    "T5_FARM_DIREBOAR_FW_LYMHURST_GROWN": "Tame Wild Boar",
    "T5_FARM_DIREBOAR_FW_LYMHURST_GROWN_DESC": "Can be used to craft a Saddled Wild Boar mount.",
    "T5_FARM_GOOSE_BABY": "Gosling",
    "T5_FARM_GOOSE_BABY_DESC": "You can place Goslings in a pasture to grow them into Geese.",
    "T5_FARM_GOOSE_GROWN": "Goose",
    "T5_FARM_GOOSE_GROWN_DESC": "Geese can be slaughtered to produce Raw Goose, or left alive to produce Goose Eggs.",
    "T5_FARM_HORSE_BABY": "Expert's Foal",
    "T5_FARM_HORSE_BABY_DESC": "Grows into an Expert's Horse, which can be used to craft an Expert's Riding Horse or an Expert's Armored Horse.",
    "T5_FARM_HORSE_GROWN": "Expert's Horse",
    "T5_FARM_HORSE_GROWN_DESC": "Can be used to craft an Expert's Riding Horse or an Expert's Armored Horse.",
    "T5_FARM_MOABIRD_FW_BRIDGEWATCH_BABY": "Baby Moabird",
    "T5_FARM_MOABIRD_FW_BRIDGEWATCH_BABY_DESC": "A Baby Moabird placed in a kennel will grow into a Tame Moabird, which can be trained into a mount.",
    "T5_FARM_MOABIRD_FW_BRIDGEWATCH_GROWN": "Tame Moabird",
    "T5_FARM_MOABIRD_FW_BRIDGEWATCH_GROWN_DESC": "Can be used to craft a Saddled Moabird mount.",
    "T5_FARM_OX_BABY": "Expert's Ox Calf",
    "T5_FARM_OX_BABY_DESC": "Grows into an Expert's Ox, which can be used to craft an Expert's Transport Ox.",
    "T5_FARM_OX_GROWN": "Expert's Ox",
    "T5_FARM_OX_GROWN_DESC": "Can be used to craft an Expert's Transport Ox.",
    "T5_FARM_RAM_FW_MARTLOCK_BABY": "Bighorn Ram Lamb",
    "T5_FARM_RAM_FW_MARTLOCK_BABY_DESC": "A Bighorn Ram Lamb placed in a kennel will grow into a Tame Bighorn Ram, which can be trained into a mount.",
    "T5_FARM_RAM_FW_MARTLOCK_GROWN": "Tame Bighorn Ram",
    "T5_FARM_RAM_FW_MARTLOCK_GROWN_DESC": "Can be used to craft a Saddled Bighorn Ram mount.",
    "T5_FARM_SWAMPDRAGON_FW_THETFORD_BABY": "Baby Swamp Salamander",
    "T5_FARM_SWAMPDRAGON_FW_THETFORD_BABY_DESC": "A Baby Swamp Salamander placed in a kennel will grow into a Tame Swamp Salamander, which can be trained into a mount.",
    "T5_FARM_SWAMPDRAGON_FW_THETFORD_GROWN": "Tame Swamp Salamander",
    "T5_FARM_SWAMPDRAGON_FW_THETFORD_GROWN_DESC": "Can be used to craft a Saddled Swamp Salamander mount.",
    "T5_FARM_TEASEL_SEED": "Dragon Teasel Seeds",
    "T5_FARM_TEASEL_SEED_DESC": "Dragon Teasel Seeds are used to plant a patch of Dragon Teasel.",
    "T5_FIBER": "Skyflower",
    "T5_FIBER_DESC": "Fiber used for crafting. Can be refined into cloth or transmuted into higher-level material.",
    "T5_FIBER_LEVEL1": "Uncommon Skyflower",
    "T5_FIBER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_FIBER_LEVEL2": "Rare Skyflower",
    "T5_FIBER_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_FIBER_LEVEL3": "Exceptional Skyflower",
    "T5_FIBER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_FIBER_LEVEL4": "Legendary Skyflower",
    "T5_FIBER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T5_FISH_FRESHWATER_ALL_COMMON": "Spotted Trout",
    "T5_FISH_FRESHWATER_AVALON_RARE": "Clearhaze Snapper",
    "T5_FISH_FRESHWATER_FOREST_RARE": "Redspring Eel",
    "T5_FISH_FRESHWATER_HIGHLANDS_RARE": "Rushwater Lurcher",
    "T5_FISH_FRESHWATER_MOUNTAIN_RARE": "Mountain Blindeye",
    "T5_FISH_FRESHWATER_STEPPE_RARE": "Drybrook Crab",
    "T5_FISH_FRESHWATER_SWAMP_RARE": "Murkwater Clam",
    "T5_FISH_SALTWATER_ALL_COMMON": "Spotted Wolffish",
    "T5_FISH_SALTWATER_ALL_RARE": "Midwater Octopus",
    "T5_FISHINGBAIT": "Special Fish Bait",
    "T5_FRAGMENT_BLUE_F1": "Expert's Scrap of Magic",
    "T5_FRAGMENT_BLUE_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_BLUE_F2": "Expert's Fragment of Magic",
    "T5_FRAGMENT_BLUE_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_BLUE_F3": "Expert's Shard of Magic",
    "T5_FRAGMENT_BLUE_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_GREEN_F1": "Expert's Scrap of Nature",
    "T5_FRAGMENT_GREEN_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_GREEN_F2": "Expert's Fragment of Nature",
    "T5_FRAGMENT_GREEN_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_GREEN_F3": "Expert's Shard of Nature",
    "T5_FRAGMENT_GREEN_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_RED_F1": "Expert's Scrap of Valor",
    "T5_FRAGMENT_RED_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_RED_F2": "Expert's Fragment of Valor",
    "T5_FRAGMENT_RED_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FRAGMENT_RED_F3": "Expert's Shard of Valor",
    "T5_FRAGMENT_RED_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T5_FURNITUREITEM_BATTLEVAULT": "Expert's Battlevault",
    "T5_FURNITUREITEM_BATTLEVAULT_DESC": "A 32-slot battlevault with a 743 kg limit. Must be placed indoors.",
    "T5_FURNITUREITEM_BED": "Expert's Bed",
    "T5_FURNITUREITEM_BED_DESC": "Increases maximum residents in the house by 1, and contributes to Laborer happiness. Item can only be placed indoors.",
    "T5_FURNITUREITEM_CHEST": "Expert's Chest",
    "T5_FURNITUREITEM_CHEST_DESC": "A 64-slot inventory with a 24296 kg limit. Must be placed indoors.",
    "T5_FURNITUREITEM_GUILDBANNER_FABRIC": "Guild Banner on Fabric",
    "T5_FURNITUREITEM_GUILDBANNER_FABRIC_DESC": "Guild Banner. Can only be placed outdoors.",
    "T5_FURNITUREITEM_GUILDBANNER_SHIELD": "Guild Banner on Shield",
    "T5_FURNITUREITEM_GUILDBANNER_SHIELD_DESC": "Guild Banner. Can only be placed outdoors.",
    "T5_FURNITUREITEM_REPAIRKIT": "Expert's Repair Kit",
    "T5_FURNITUREITEM_REPAIRKIT_DESC": "Repair kits are used to repair gear in the wild, however the repair fee is twice as high.",
    "T5_FURNITUREITEM_TABLE": "Expert's Table",
    "T5_FURNITUREITEM_TABLE_DESC": "Contributes to Laborer happiness. Item can only be placed indoors.",
    "T5_FURNITUREITEM_TROPHY_FIBER": "Soft Skyflower Trophy",
    "T5_FURNITUREITEM_TROPHY_FISH": "Trout Trophy",
    "T5_FURNITUREITEM_TROPHY_GENERAL": "Tome of Knowledge",
    "T5_FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all Laborers.",
    "T5_FURNITUREITEM_TROPHY_HARVESTER_HEART": "Trophy: Harvester's Heart",
    "T5_FURNITUREITEM_TROPHY_HARVESTER_HEART_DESC": "Provides an increase to Auto-Attack damage and move speed. Must be placed indoors.",
    "T5_FURNITUREITEM_TROPHY_HIDE": "Stuffed Bear Head",
    "T5_FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to all Gamekeeper Laborers.",
    "T5_FURNITUREITEM_TROPHY_MERCENARY": "Expert Mercenary's Trophy",
    "T5_FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to all Mercenary Laborers.",
    "T5_FURNITUREITEM_TROPHY_MOB": "Trophy: Bear's Head",
    "T5_FURNITUREITEM_TROPHY_MOB_DESC": "Provides an increase to maximum carrying capacity. Must be placed indoors.",
    "T5_FURNITUREITEM_TROPHY_ORE": "Titanium Ore Sample",
    "T5_FURNITUREITEM_TROPHY_ROCK": "Granite Fragment",
    "T5_FURNITUREITEM_TROPHY_WOOD": "Cedar Bonsai",
    "T5_GEM_EMERALD": "Ordinary Emerald",
    "T5_GEM_EMERALD_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T5_GEM_RUBY": "Ordinary Ruby",
    "T5_GEM_RUBY_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T5_GEM_SAPPHIRE": "Ordinary Sapphire",
    "T5_GEM_SAPPHIRE_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T5_GVGSEASONREWARD_FAMEBUFF": "Expert's Knight Vow",
    "T5_GVGSEASONREWARD_FAMEBUFF_DESC": "Increases Fame from defeating creatures and gathering resources by 2% for 90 days",
    "T5_HEAD_CLOTH_AVALON": "Expert's Cowl of Purity",
    "T5_HEAD_CLOTH_HELL": "Expert's Fiend Cowl",
    "T5_HEAD_CLOTH_HELL_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_KEEPER": "Expert's Druid Cowl",
    "T5_HEAD_CLOTH_KEEPER_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_MORGANA": "Expert's Cultist Cowl",
    "T5_HEAD_CLOTH_MORGANA_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_ROYAL": "Expert's Royal Cowl",
    "T5_HEAD_CLOTH_ROYAL_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_SET1": "Expert's Scholar Cowl",
    "T5_HEAD_CLOTH_SET1_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_SET1_ENCHANTED": "Enchanted Expert's Scholar Cowl",
    "T5_HEAD_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_SET2": "Expert's Cleric Cowl",
    "T5_HEAD_CLOTH_SET2_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_SET2_ENCHANTED": "Enchanted Expert's Cleric Cowl",
    "T5_HEAD_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T5_HEAD_CLOTH_SET3": "Expert's Mage Cowl",
    "T5_HEAD_CLOTH_SET3_DESC": "Equipment Item",
    "T5_HEAD_GATHERER_FIBER": "Expert's Harvester Cap",
    "T5_HEAD_GATHERER_FIBER_DESC": "Equipment Item",
    "T5_HEAD_GATHERER_FISH": "Expert's Fisherman Cap",
    "T5_HEAD_GATHERER_FISH_DESC": "Equipment Item",
    "T5_HEAD_GATHERER_HIDE": "Expert's Skinner Cap",
    "T5_HEAD_GATHERER_HIDE_DESC": "Equipment Item",
    "T5_HEAD_GATHERER_ORE": "Expert's Miner Cap",
    "T5_HEAD_GATHERER_ORE_DESC": "Equipment Item",
    "T5_HEAD_GATHERER_ROCK": "Expert's Quarrier Cap",
    "T5_HEAD_GATHERER_ROCK_DESC": "Equipment Item",
    "T5_HEAD_GATHERER_WOOD": "Expert's Lumberjack Cap",
    "T5_HEAD_GATHERER_WOOD_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_AVALON": "Expert's Hood of Tenacity",
    "T5_HEAD_LEATHER_HELL": "Expert's Hellion Hood",
    "T5_HEAD_LEATHER_HELL_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_MORGANA": "Expert's Stalker Hood",
    "T5_HEAD_LEATHER_MORGANA_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_ROYAL": "Expert's Royal Hood",
    "T5_HEAD_LEATHER_ROYAL_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_SET1": "Expert's Mercenary Hood",
    "T5_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_SET1_ENCHANTED": "Enchanted Expert's Mercenary Hood",
    "T5_HEAD_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_SET2": "Expert's Hunter Hood",
    "T5_HEAD_LEATHER_SET2_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_SET2_ENCHANTED": "Enchanted Expert's Hunter Hood",
    "T5_HEAD_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_SET3": "Expert's Assassin Hood",
    "T5_HEAD_LEATHER_SET3_DESC": "Equipment Item",
    "T5_HEAD_LEATHER_UNDEAD": "Expert's Specter Hood",
    "T5_HEAD_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T5_HEAD_PLATE_AVALON": "Expert's Helmet of Valor",
    "T5_HEAD_PLATE_HELL": "Expert's Demon Helmet",
    "T5_HEAD_PLATE_HELL_DESC": "Equipment Item",
    "T5_HEAD_PLATE_KEEPER": "Expert's Judicator Helmet",
    "T5_HEAD_PLATE_KEEPER_DESC": "Equipment Item",
    "T5_HEAD_PLATE_ROYAL": "Expert's Royal Helmet",
    "T5_HEAD_PLATE_ROYAL_DESC": "Equipment Item",
    "T5_HEAD_PLATE_SET1": "Expert's Soldier Helmet",
    "T5_HEAD_PLATE_SET1_DESC": "Equipment Item",
    "T5_HEAD_PLATE_SET1_ENCHANTED": "Enchanted Expert's Soldier Helmet",
    "T5_HEAD_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T5_HEAD_PLATE_SET2": "Expert's Knight Helmet",
    "T5_HEAD_PLATE_SET2_DESC": "Equipment Item",
    "T5_HEAD_PLATE_SET2_ENCHANTED": "Enchanted Expert's Knight Helmet",
    "T5_HEAD_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T5_HEAD_PLATE_SET3": "Expert's Guardian Helmet",
    "T5_HEAD_PLATE_SET3_DESC": "Equipment Item",
    "T5_HEAD_PLATE_UNDEAD": "Expert's Graveguard Helmet",
    "T5_HEAD_PLATE_UNDEAD_DESC": "Equipment Item",
    "T5_HIDE": "Heavy Hide",
    "T5_HIDE_DESC": "Hide used for crafting. Can be refined into leather or transmuted into higher-level material.",
    "T5_HIDE_LEVEL1": "Uncommon Heavy Hide",
    "T5_HIDE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_HIDE_LEVEL2": "Rare Heavy Hide",
    "T5_HIDE_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_HIDE_LEVEL3": "Exceptional Heavy Hide",
    "T5_HIDE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_HIDE_LEVEL4": "Legendary Heavy Hide",
    "T5_HIDE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T5_JOURNAL_FIBER": "Expert Cropper's Journal (Partially Full)",
    "T5_JOURNAL_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_FIBER_EMPTY": "Expert Cropper's Journal (Empty)",
    "T5_JOURNAL_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_FIBER_FULL": "Expert Cropper's Journal (Full)",
    "T5_JOURNAL_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_FISHING": "Expert Fisherman's Journal (Partially Full)",
    "T5_JOURNAL_FISHING_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_FISHING_EMPTY": "Expert Fisherman's Journal (Empty)",
    "T5_JOURNAL_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_FISHING_FULL": "Expert Fisherman's Journal (Full)",
    "T5_JOURNAL_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_HIDE": "Expert Gamekeeper's Journal (Partially Full)",
    "T5_JOURNAL_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_HIDE_EMPTY": "Expert Gamekeeper's Journal (Empty)",
    "T5_JOURNAL_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_HIDE_FULL": "Expert Gamekeeper's Journal (Full)",
    "T5_JOURNAL_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_HUNTER": "Expert Fletcher's Journal (Partially Full)",
    "T5_JOURNAL_HUNTER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_HUNTER_EMPTY": "Expert Fletcher's Journal (Empty)",
    "T5_JOURNAL_HUNTER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_HUNTER_FULL": "Expert Fletcher's Journal (Full)",
    "T5_JOURNAL_HUNTER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_MAGE": "Expert Imbuer's Journal (Partially Full)",
    "T5_JOURNAL_MAGE_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_MAGE_EMPTY": "Expert Imbuer's Journal (Empty)",
    "T5_JOURNAL_MAGE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_MAGE_FULL": "Expert Imbuer's Journal (Full)",
    "T5_JOURNAL_MAGE_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_MERCENARY": "Expert Mercenary's Journal (Partially Full)",
    "T5_JOURNAL_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_MERCENARY_EMPTY": "Expert Mercenary's Journal (Empty)",
    "T5_JOURNAL_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_MERCENARY_FULL": "Expert Mercenary's Journal (Full)",
    "T5_JOURNAL_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_ORE": "Expert Prospector's Journal (Partially Full)",
    "T5_JOURNAL_ORE_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_ORE_EMPTY": "Expert Prospector's Journal (Empty)",
    "T5_JOURNAL_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_ORE_FULL": "Expert Prospector's Journal (Full)",
    "T5_JOURNAL_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_STONE": "Expert Stonecutter's Journal (Partially Full)",
    "T5_JOURNAL_STONE_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_STONE_EMPTY": "Expert Stonecutter's Journal (Empty)",
    "T5_JOURNAL_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_STONE_FULL": "Expert Stonecutter's Journal (Full)",
    "T5_JOURNAL_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TOOLMAKER": "Expert Tinker's Journal (Partially Full)",
    "T5_JOURNAL_TOOLMAKER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TOOLMAKER_EMPTY": "Expert Tinker's Journal (Empty)",
    "T5_JOURNAL_TOOLMAKER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TOOLMAKER_FULL": "Expert Tinker's Journal (Full)",
    "T5_JOURNAL_TOOLMAKER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_FIBER": "Expert Cropper's Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_FIBER_EMPTY": "Expert Cropper's Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_FIBER_FULL": "Expert Cropper's Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_FISHING": "Expert Fisherman's Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_FISHING_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_FISHING_EMPTY": "Expert Fisherman's Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_FISHING_FULL": "Expert Fisherman's Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_GENERAL": "Expert's Generalist Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_GENERAL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_GENERAL_EMPTY": "Expert's Generalist Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_GENERAL_EMPTY_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_GENERAL_FULL": "Expert's Generalist Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_GENERAL_FULL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_HIDE": "Expert Gamekeeper's Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_HIDE_EMPTY": "Expert Gamekeeper's Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_HIDE_FULL": "Expert Gamekeeper's Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_MERCENARY": "Expert Mercenary's Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_MERCENARY_EMPTY": "Expert Mercenary's Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_MERCENARY_FULL": "Expert Mercenary's Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_ORE": "Expert Prospector's Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_ORE_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_ORE_EMPTY": "Expert Prospector's Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_ORE_FULL": "Expert Prospector's Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_STONE": "Expert Stonecutter's Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_STONE_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_STONE_EMPTY": "Expert Stonecutter's Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_STONE_FULL": "Expert Stonecutter's Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_WOOD": "Expert Lumberjack's Trophy Journal (Partially Full)",
    "T5_JOURNAL_TROPHY_WOOD_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_WOOD_EMPTY": "Expert Lumberjack's Trophy Journal (Empty)",
    "T5_JOURNAL_TROPHY_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_TROPHY_WOOD_FULL": "Expert Lumberjack's Trophy Journal (Full)",
    "T5_JOURNAL_TROPHY_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_WARRIOR": "Expert Blacksmith's Journal (Partially Full)",
    "T5_JOURNAL_WARRIOR_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_WARRIOR_EMPTY": "Expert Blacksmith's Journal (Empty)",
    "T5_JOURNAL_WARRIOR_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_WARRIOR_FULL": "Expert Blacksmith's Journal (Full)",
    "T5_JOURNAL_WARRIOR_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_WOOD": "Expert Lumberjack's Journal (Partially Full)",
    "T5_JOURNAL_WOOD_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_WOOD_EMPTY": "Expert Lumberjack's Journal (Empty)",
    "T5_JOURNAL_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_JOURNAL_WOOD_FULL": "Expert Lumberjack's Journal (Full)",
    "T5_JOURNAL_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T5_LABOURER_CONTRACT_FIBER": "Expert Cropper Contract",
    "T5_LABOURER_CONTRACT_FIBER_DESC": "Croppers require filled Cropper's Journals and gather fiber.",
    "T5_LABOURER_CONTRACT_FISHERMAN": "Expert Fisherman Contract",
    "T5_LABOURER_CONTRACT_FISHERMAN_DESC": "Fishermen require filled Fisherman's Journals and catch fish.",
    "T5_LABOURER_CONTRACT_HIDE": "Expert Gamekeeper Contract",
    "T5_LABOURER_CONTRACT_HIDE_DESC": "Gamekeepers require filled Gamekeeper's Journals and gather hide.",
    "T5_LABOURER_CONTRACT_HUNTER": "Expert Fletcher Contract",
    "T5_LABOURER_CONTRACT_HUNTER_DESC": "Fletchers require filled Fletcher's Journals and gather various refined materials.",
    "T5_LABOURER_CONTRACT_MAGE": "Expert Imbuer Contract",
    "T5_LABOURER_CONTRACT_MAGE_DESC": "Imbuers require filled Imbuer's Journals and gather various refined materials.",
    "T5_LABOURER_CONTRACT_MERCENARY": "Expert Mercenary Contract",
    "T5_LABOURER_CONTRACT_MERCENARY_DESC": "Mercenaries require filled Mercenary's Journals' and gather Silver.",
    "T5_LABOURER_CONTRACT_ORE": "Expert Prospector Contract",
    "T5_LABOURER_CONTRACT_ORE_DESC": "Prospectors require filled Prospector's Journals and gather ore.",
    "T5_LABOURER_CONTRACT_STONE": "Expert Stonecutter Contract",
    "T5_LABOURER_CONTRACT_STONE_DESC": "Stonecutters require filled Stonecutter's Journals and gather stone.",
    "T5_LABOURER_CONTRACT_TOOLMAKER": "Expert Tinker Contract",
    "T5_LABOURER_CONTRACT_TOOLMAKER_DESC": "Tinkers require filled Tinker's Journals and gather various refined materials.",
    "T5_LABOURER_CONTRACT_WARRIOR": "Expert Blacksmith Contract",
    "T5_LABOURER_CONTRACT_WARRIOR_DESC": "Blacksmiths require filled Blacksmith's Journals and gather various refined materials.",
    "T5_LABOURER_CONTRACT_WOOD": "Expert Lumberjack Contract",
    "T5_LABOURER_CONTRACT_WOOD_DESC": "Lumberjacks require filled Lumberjack's Journals and gather wood.",
    "T5_LEATHER": "Cured Leather",
    "T5_LEATHER_DESC": "Advanced material used in crafting, created by refining hide.",
    "T5_LEATHER_LEVEL1": "Uncommon Cured Leather",
    "T5_LEATHER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_LEATHER_LEVEL2": "Rare Cured Leather",
    "T5_LEATHER_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_LEATHER_LEVEL3": "Exceptional Cured Leather",
    "T5_LEATHER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_LEATHER_LEVEL4": "Legendary Cured Leather",
    "T5_LEATHER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T5_LOOTCHEST_CRYSTAL_LEAGUE": "Expert's Crystal League Chest",
    "T5_MAIN_1HCROSSBOW": "Expert's Light Crossbow",
    "T5_MAIN_1HCROSSBOW_DESC": "Equipment Item",
    "T5_MAIN_ARCANESTAFF": "Expert's Arcane Staff",
    "T5_MAIN_ARCANESTAFF_DESC": "Equipment Item",
    "T5_MAIN_ARCANESTAFF_ENCHANTED": "Expert's Enchanted Arcane Staff",
    "T5_MAIN_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_ARCANESTAFF_UNDEAD": "Expert's Witchwork Staff",
    "T5_MAIN_ARCANESTAFF_UNDEAD_DESC": "Equipment Item",
    "T5_MAIN_AXE": "Expert's Battleaxe",
    "T5_MAIN_AXE_DESC": "Equipment Item",
    "T5_MAIN_AXE_ENCHANTED": "Expert's Enchanted Battleaxe",
    "T5_MAIN_AXE_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_CROSSBOW_ENCHANTED": "Expert's Enchanted Crossbow",
    "T5_MAIN_CROSSBOW_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_CURSEDSTAFF": "Expert's Cursed Staff",
    "T5_MAIN_CURSEDSTAFF_AVALON": "Expert's Shadowcaller",
    "T5_MAIN_CURSEDSTAFF_AVALON_DESC": "Equipment Item",
    "T5_MAIN_CURSEDSTAFF_DESC": "Equipment Item",
    "T5_MAIN_CURSEDSTAFF_ENCHANTED": "Expert's Enchanted Cursed Staff",
    "T5_MAIN_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_CURSEDSTAFF_UNDEAD": "Expert's Lifecurse Staff",
    "T5_MAIN_CURSEDSTAFF_UNDEAD_DESC": "Equipment Item",
    "T5_MAIN_DAGGER": "Expert's Dagger",
    "T5_MAIN_DAGGER_DESC": "Equipment Item",
    "T5_MAIN_DAGGER_ENCHANTED": "Expert's Enchanted Dagger",
    "T5_MAIN_DAGGER_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_FIRESTAFF": "Expert's Fire Staff",
    "T5_MAIN_FIRESTAFF_DESC": "Equipment Item",
    "T5_MAIN_FIRESTAFF_ENCHANTED": "Expert's Enchanted Fire Staff",
    "T5_MAIN_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_FIRESTAFF_KEEPER": "Expert's Wildfire Staff",
    "T5_MAIN_FIRESTAFF_KEEPER_DESC": "Equipment Item",
    "T5_MAIN_FROSTSTAFF": "Expert's Frost Staff",
    "T5_MAIN_FROSTSTAFF_AVALON": "Expert's Chillhowl",
    "T5_MAIN_FROSTSTAFF_AVALON_DESC": "Equipment Item",
    "T5_MAIN_FROSTSTAFF_DESC": "Equipment Item",
    "T5_MAIN_FROSTSTAFF_ENCHANTED": "Expert's Enchanted Frost Staff",
    "T5_MAIN_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_FROSTSTAFF_KEEPER": "Expert's Hoarfrost Staff",
    "T5_MAIN_FROSTSTAFF_KEEPER_DESC": "Equipment Item",
    "T5_MAIN_HAMMER": "Expert's Hammer",
    "T5_MAIN_HAMMER_DESC": "Equipment Item",
    "T5_MAIN_HAMMER_ENCHANTED": "Expert's Enchanted Hammer",
    "T5_MAIN_HAMMER_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_HOLYSTAFF": "Expert's Holy Staff",
    "T5_MAIN_HOLYSTAFF_AVALON": "Expert's Hallowfall",
    "T5_MAIN_HOLYSTAFF_AVALON_DESC": "Equipment Item",
    "T5_MAIN_HOLYSTAFF_DESC": "Equipment Item",
    "T5_MAIN_HOLYSTAFF_ENCHANTED": "Expert's Enchanted Holy Staff",
    "T5_MAIN_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_HOLYSTAFF_MORGANA": "Expert's Lifetouch Staff",
    "T5_MAIN_HOLYSTAFF_MORGANA_DESC": "Equipment Item",
    "T5_MAIN_MACE": "Expert's Mace",
    "T5_MAIN_MACE_DESC": "Equipment Item",
    "T5_MAIN_MACE_ENCHANTED": "Expert's Enchanted Mace",
    "T5_MAIN_MACE_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_MACE_HELL": "Expert's Incubus Mace",
    "T5_MAIN_MACE_HELL_DESC": "Equipment Item",
    "T5_MAIN_NATURESTAFF": "Expert's Nature Staff",
    "T5_MAIN_NATURESTAFF_AVALON": "Expert's Ironroot Staff",
    "T5_MAIN_NATURESTAFF_AVALON_DESC": "Equipment Item",
    "T5_MAIN_NATURESTAFF_DESC": "Equipment Item",
    "T5_MAIN_NATURESTAFF_ENCHANTED": "Expert's Enchanted Nature Staff",
    "T5_MAIN_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_NATURESTAFF_KEEPER": "Expert's Druidic Staff",
    "T5_MAIN_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T5_MAIN_RAPIER_MORGANA": "Expert's Bloodletter",
    "T5_MAIN_RAPIER_MORGANA_DESC": "Equipment Item",
    "T5_MAIN_REPEATINGCROSSBOW": "Expert's Repeating Crossbow",
    "T5_MAIN_REPEATINGCROSSBOW_DESC": "Equipment Item",
    "T5_MAIN_ROCKMACE_KEEPER": "Expert's Bedrock Mace",
    "T5_MAIN_ROCKMACE_KEEPER_DESC": "Equipment Item",
    "T5_MAIN_SCIMITAR_MORGANA": "Expert's Clarent Blade",
    "T5_MAIN_SCIMITAR_MORGANA_DESC": "Equipment Item",
    "T5_MAIN_SPEAR": "Expert's Spear",
    "T5_MAIN_SPEAR_DESC": "Equipment Item",
    "T5_MAIN_SPEAR_ENCHANTED": "Expert's Enchanted Spear",
    "T5_MAIN_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T5_MAIN_SPEAR_KEEPER": "Expert's Heron Spear",
    "T5_MAIN_SPEAR_KEEPER_DESC": "Equipment Item",
    "T5_MAIN_SPEAR_LANCE_AVALON": "Expert's Daybreaker",
    "T5_MAIN_SPEAR_LANCE_AVALON_DESC": "Equipment Item",
    "T5_MAIN_SWORD": "Expert's Broadsword",
    "T5_MAIN_SWORD_DESC": "Equipment Item",
    "T5_MAIN_SWORD_ENCHANTED": "Expert's Enchanted Broadsword",
    "T5_MAIN_SWORD_ENCHANTED_DESC": "Equipment Item",
    "T5_MEAL_OMELETTE": "Goose Omelette",
    "T5_MEAL_OMELETTE_AVALON": "Avalonian Goose Omelette",
    "T5_MEAL_OMELETTE_AVALON_DESC": "Avalonian meal that reduces cooldown periods and casting times, while also increasing your defense for a long period.",
    "T5_MEAL_OMELETTE_DESC": "Solid meal that reduces cooldown periods and casting times for a long period.",
    "T5_MEAL_OMELETTE_FISH": "Drybrook Crab Omelette",
    "T5_MEAL_PIE": "Goose Pie",
    "T5_MEAL_PIE_DESC": "Solid meal that increases maximum load and gathering yield for a long period.",
    "T5_MEAL_PIE_FISH": "Mountain Blindeye Pie",
    "T5_MEAL_ROAST": "Roast Goose",
    "T5_MEAL_ROAST_DESC": "A savory meal that heals you based on the damage you deal for a long period.",
    "T5_MEAL_ROAST_FISH": "Roasted Clearhaze Snapper",
    "T5_MEAL_ROAST_FISH_DESC": "A savory meal that heals you based on the damage you deal and raises your max health for a long period.",
    "T5_MEAL_SOUP": "Cabbage Soup",
    "T5_MEAL_SOUP_DESC": "Simple meal that increases health regeneration outside of combat for a long period.",
    "T5_MEAL_SOUP_FISH": "Blackbog Clam Soup",
    "T5_MEAT": "Raw Goose",
    "T5_MEAT_DESC": "Cooking ingredient, used in various recipes.",
    "T5_METALBAR": "Titanium Steel Bar",
    "T5_METALBAR_DESC": "Advanced material used in crafting, created by refining ore.",
    "T5_METALBAR_LEVEL1": "Uncommon Titanium Steel Bar",
    "T5_METALBAR_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_METALBAR_LEVEL2": "Rare Titanium Steel Bar",
    "T5_METALBAR_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_METALBAR_LEVEL3": "Exceptional Titanium Steel Bar",
    "T5_METALBAR_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_METALBAR_LEVEL4": "Legendary Titanium Steel Bar",
    "T5_METALBAR_LEVEL4_DESC": "Legendary material used for crafting.",
    "T5_MOBDROP_BEAR_HEAD": "Bear's Head",
    "T5_MOBDROP_BEAR_HEAD_DESC": "Use to craft a trophy you can place in your house.",
    "T5_MOBDROP_HARVESTER_HEART": "Harvester's Heart",
    "T5_MOBDROP_HARVESTER_HEART_DESC": "Use to craft a trophy you can place in your house.",
    "T5_MOUNT_ARMORED_HORSE": "Expert's Armored Horse",
    "T5_MOUNT_ARMORED_HORSE_DESC": "Protected by thick plating, an armored horse is ideal for traveling through Albion's more dangerous regions at speed.",
    "T5_MOUNT_ARMORED_HORSE_MORGANA": "Morgana Mare",
    "T5_MOUNT_ARMORED_HORSE_MORGANA_DESC": "The Disciples of Morgana value strength in all things, and breed their mounts for toughness and aggression. The weight of their armor makes them unwilling to carry additional load, but allows them to charge heedless into battle.",
    "T5_MOUNT_ARMORED_HORSE_SKIN_01": "Expert's Warhorse",
    "T5_MOUNT_ARMORED_HORSE_SKIN_01_DESC": "An armored horse bearing the impressive banner of its rider's guild. Ideal for raising morale in big battles.",
    "T5_MOUNT_COUGAR_ARENA": "Arena Veteran's Armored Sabertooth",
    "T5_MOUNT_COUGAR_ARENA_DESC": "An Armored Sabertooth carrying the colors of the Arena. You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "T5_MOUNT_COUGAR_KEEPER": "Swiftclaw",
    "T5_MOUNT_COUGAR_KEEPER_DESC": "Keeper scouts have used these fast animals to scout the wilds and will never surrender a cub willingly.",
    "T5_MOUNT_COUGAR_TOURNAMENT": "Sabertooth Rex",
    "T5_MOUNT_COUGAR_TOURNAMENT_DESC": "A king amongst cats.",
    "T5_MOUNT_DIREBEAR_FW_FORTSTERLING": "Saddled Winter Bear",
    "T5_MOUNT_DIREBEAR_FW_FORTSTERLING_DESC": "Mount - A special breed originally from the mountains around Fort Sterling",
    "T5_MOUNT_DIREBOAR_FW_LYMHURST": "Saddled Wild Boar",
    "T5_MOUNT_DIREBOAR_FW_LYMHURST_DESC": "Mount - A special breed originally from the forests around Lymhurst",
    "T5_MOUNT_HORSE": "Expert's Riding Horse",
    "T5_MOUNT_HORSE_ARENA": "Arena Veteran's Armored Horse",
    "T5_MOUNT_HORSE_ARENA_DESC": "An Armored Horse carrying the colors of the Arena. You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "T5_MOUNT_HORSE_DESC": "Lean and agile, Albion horses can carry their riders quickly across the continent, but have little strength to bear heavy items.",
    "T5_MOUNT_HORSE_UNDEAD": "Bonehorse",
    "T5_MOUNT_HORSE_UNDEAD_DESC": "Less skin, more speed.",
    "T5_MOUNT_HORSE_UNDEAD_HALLOWEEN": "Horse Macabre",
    "T5_MOUNT_HORSE_UNDEAD_HALLOWEEN_DESC": "Mount - Looks spooky, but has a friendly nature.",
    "T5_MOUNT_MOABIRD_FW_BRIDGEWATCH": "Saddled Moabird",
    "T5_MOUNT_MOABIRD_FW_BRIDGEWATCH_DESC": "Mount - A special breed originally from the steppe around Bridgewatch",
    "T5_MOUNT_OX": "Expert's Transport Ox",
    "T5_MOUNT_OX_DESC": "Albion oxen are tough, and sturdy enough to carry large quantities of goods, but cannot match the pace of the continent's horses.",
    "T5_MOUNT_RAM_FW_MARTLOCK": "Saddled Bighorn Ram",
    "T5_MOUNT_RAM_FW_MARTLOCK_DESC": "Mount - A special breed originally from the highlands around Martlock",
    "T5_MOUNT_SWAMPDRAGON_FW_THETFORD": "Saddled Swamp Salamander",
    "T5_MOUNT_SWAMPDRAGON_FW_THETFORD_DESC": "Mount - A special breed originally from the swamps around Thetford",
    "T5_MOUNTUPGRADE_HORSE_CURSE": "Necromantic Elixir",
    "T5_MOUNTUPGRADE_HORSE_CURSE_DESC": "Extreme weight-loss regime for horses.",
    "T5_MOUNTUPGRADE_HORSE_MORGANA": "Morgana Mare Saddle",
    "T5_MOUNTUPGRADE_HORSE_MORGANA_DESC": "The centerpiece of a set of Morgana Mare tack, which grants superior protection compared to standard horse armor.",
    "T5_OFF_BOOK": "Expert's Tome of Spells",
    "T5_OFF_BOOK_DESC": "Equipment Item",
    "T5_OFF_BOOK_ENCHANTED": "Expert's Enchanted Tome of Spells",
    "T5_OFF_BOOK_ENCHANTED_DESC": "Equipment Item",
    "T5_OFF_BOOK_PROTOTYPE": "Book Prototype",
    "T5_OFF_BOOK_PROTOTYPE_DESC": "Prototype Item, please ignore",
    "T5_OFF_CENSER_AVALON": "Expert's Celestial Censer",
    "T5_OFF_CENSER_AVALON_DESC": "Equipment Item",
    "T5_OFF_DEMONSKULL_HELL": "Expert's Muisak",
    "T5_OFF_DEMONSKULL_HELL_DESC": "Equipment Item",
    "T5_OFF_HORN_KEEPER": "Expert's Mistcaller",
    "T5_OFF_HORN_KEEPER_DESC": "Equipment Item",
    "T5_OFF_JESTERCANE_HELL": "Expert's Leering Cane",
    "T5_OFF_JESTERCANE_HELL_DESC": "Equipment Item",
    "T5_OFF_LAMP_UNDEAD": "Expert's Cryptcandle",
    "T5_OFF_LAMP_UNDEAD_DESC": "Equipment Item",
    "T5_OFF_ORB_MORGANA": "Expert's Eye of Secrets",
    "T5_OFF_ORB_MORGANA_DESC": "Equipment Item",
    "T5_OFF_SHIELD": "Expert's Shield",
    "T5_OFF_SHIELD_AVALON": "Expert's Astral Aegis",
    "T5_OFF_SHIELD_AVALON_DESC": "Equipment Item",
    "T5_OFF_SHIELD_DESC": "Equipment Item",
    "T5_OFF_SHIELD_ENCHANTED": "Expert's Enchanted Shield",
    "T5_OFF_SHIELD_ENCHANTED_DESC": "Equipment Item",
    "T5_OFF_SHIELD_HELL": "Expert's Caitiff Shield",
    "T5_OFF_SHIELD_HELL_DESC": "Equipment Item",
    "T5_OFF_SHIELD_PROTOTYPE": "Shield Prototype",
    "T5_OFF_SHIELD_PROTOTYPE_DESC": "Prototype Item, please ignore",
    "T5_OFF_SPIKEDSHIELD_MORGANA": "Expert's Facebreaker",
    "T5_OFF_SPIKEDSHIELD_MORGANA_DESC": "Equipment Item",
    "T5_OFF_TALISMAN_AVALON": "Expert's Sacred Scepter",
    "T5_OFF_TALISMAN_AVALON_DESC": "Equipment Item",
    "T5_OFF_TORCH": "Expert's Torch",
    "T5_OFF_TORCH_DESC": "Equipment Item",
    "T5_OFF_TORCH_ENCHANTED": "Expert's Enchanted Torch",
    "T5_OFF_TORCH_ENCHANTED_DESC": "Equipment Item",
    "T5_OFF_TORCH_PROTOTYPE": "Torch Prototype",
    "T5_OFF_TORCH_PROTOTYPE_DESC": "Prototype Item, please ignore",
    "T5_OFF_TOTEM_KEEPER": "Expert's Taproot",
    "T5_OFF_TOTEM_KEEPER_DESC": "Equipment Item",
    "T5_OFF_TOWERSHIELD_UNDEAD": "Expert's Sarcophagus",
    "T5_OFF_TOWERSHIELD_UNDEAD_DESC": "Equipment Item",
    "T5_ORE": "Titanium Ore",
    "T5_ORE_DESC": "Ore used for crafting. Can be refined into metal bars or transmuted into higher-level material.",
    "T5_ORE_LEVEL1": "Uncommon Titanium Ore",
    "T5_ORE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_ORE_LEVEL2": "Rare Titanium Ore",
    "T5_ORE_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_ORE_LEVEL3": "Exceptional Titanium Ore",
    "T5_ORE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_ORE_LEVEL4": "Legendary Titanium Ore",
    "T5_ORE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T5_PLANKS": "Cedar Planks",
    "T5_PLANKS_DESC": "Advanced material used in crafting, created by refining logs.",
    "T5_PLANKS_LEVEL1": "Uncommon Cedar Planks",
    "T5_PLANKS_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_PLANKS_LEVEL2": "Rare Cedar Planks",
    "T5_PLANKS_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_PLANKS_LEVEL3": "Exceptional Cedar Planks",
    "T5_PLANKS_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_PLANKS_LEVEL4": "Legendary Cedar Planks",
    "T5_PLANKS_LEVEL4_DESC": "Legendary material used for crafting.",
    "T5_POTION_REVIVE": "Gigantify Potion",
    "T5_POTION_REVIVE_DESC": "Mystical Potion. Temporarily increases your max load and max health.",
    "T5_POTION_SLOWFIELD": "Sticky Potion",
    "T5_POTION_SLOWFIELD_DESC": "A viscous potion. Throw it on a ground location to create an area that slows enemies and reduces their damage.",
    "T5_POTION_STONESKIN": "Resistance Potion",
    "T5_POTION_STONESKIN_DESC": "Sluggish potion. Increases defenses substantially for a short period.",
    "T5_RANDOM_DUNGEON_SOLO_TOKEN_1": "Expert's Dungeon Map (Solo)",
    "T5_RANDOM_DUNGEON_SOLO_TOKEN_2": "Uncommon Expert's Dungeon Map (Solo)",
    "T5_RANDOM_DUNGEON_SOLO_TOKEN_3": "Rare Expert's Dungeon Map (Solo)",
    "T5_RANDOM_DUNGEON_SOLO_TOKEN_4": "Exceptional Expert's Dungeon Map (Solo)",
    "T5_RANDOM_DUNGEON_TOKEN_1": "Expert's Dungeon Map (Group)",
    "T5_RANDOM_DUNGEON_TOKEN_2": "Uncommon Expert's Dungeon Map (Group)",
    "T5_RANDOM_DUNGEON_TOKEN_3": "Rare Expert's Dungeon Map (Group)",
    "T5_RANDOM_DUNGEON_TOKEN_4": "Exceptional Expert's Dungeon Map (Group)",
    "T5_RELIC": "Expert's Relic",
    "T5_RELIC_DESC": "An ancient relic, used to meld artifacts and enchant equipment.",
    "T5_ROCK": "Granite",
    "T5_ROCK_DESC": "Stone used for crafting. Can be refined into stone blocks or transmuted into higher-level material.",
    "T5_ROCK_LEVEL1": "Uncommon Granite",
    "T5_ROCK_LEVEL1_DESC": "Uncommon stone, more efficient in refining.",
    "T5_ROCK_LEVEL2": "Rare Granite",
    "T5_ROCK_LEVEL2_DESC": "Rare stone, more efficient in refining.",
    "T5_ROCK_LEVEL3": "Exceptional Granite",
    "T5_ROCK_LEVEL3_DESC": "Exceptional stone, more efficient in refining.",
    "T5_RUNE": "Expert's Rune",
    "T5_RUNE_DESC": "A pulsing rune, used to meld artifacts and enchant equipment.",
    "T5_RUNE_DESTRUCTION": "Lesser Rune of Destruction",
    "T5_RUNE_DESTRUCTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T5_RUNE_MANIPULATION": "Lesser Rune of Manipulation",
    "T5_RUNE_MANIPULATION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T5_RUNE_PROTECTION": "Lesser Rune of Protection",
    "T5_RUNE_PROTECTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T5_SHARD_AVALONIAN": "Expert's Avalonian Shard",
    "T5_SHOES_CLOTH_AVALON": "Expert's Sandals of Purity",
    "T5_SHOES_CLOTH_HELL": "Expert's Fiend Sandals",
    "T5_SHOES_CLOTH_HELL_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_KEEPER": "Expert's Druid Sandals",
    "T5_SHOES_CLOTH_KEEPER_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_MORGANA": "Expert's Cultist Sandals",
    "T5_SHOES_CLOTH_MORGANA_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_ROYAL": "Expert's Royal Sandals",
    "T5_SHOES_CLOTH_ROYAL_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_SET1": "Expert's Scholar Sandals",
    "T5_SHOES_CLOTH_SET1_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_SET1_ENCHANTED": "Enchanted Expert's Scholar Sandals",
    "T5_SHOES_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_SET2": "Expert's Cleric Sandals",
    "T5_SHOES_CLOTH_SET2_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_SET2_ENCHANTED": "Enchanted Expert's Cleric Sandals",
    "T5_SHOES_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T5_SHOES_CLOTH_SET3": "Expert's Mage Sandals",
    "T5_SHOES_CLOTH_SET3_DESC": "Equipment Item",
    "T5_SHOES_GATHERER_FIBER": "Expert's Harvester Workboots",
    "T5_SHOES_GATHERER_FIBER_DESC": "Equipment Item",
    "T5_SHOES_GATHERER_FISH": "Expert's Fisherman Workboots",
    "T5_SHOES_GATHERER_FISH_DESC": "Equipment Item",
    "T5_SHOES_GATHERER_HIDE": "Expert's Skinner Workboots",
    "T5_SHOES_GATHERER_HIDE_DESC": "Equipment Item",
    "T5_SHOES_GATHERER_ORE": "Expert's Miner Workboots",
    "T5_SHOES_GATHERER_ORE_DESC": "Equipment Item",
    "T5_SHOES_GATHERER_ROCK": "Expert's Quarrier Workboots",
    "T5_SHOES_GATHERER_ROCK_DESC": "Equipment Item",
    "T5_SHOES_GATHERER_WOOD": "Expert's Lumberjack Workboots",
    "T5_SHOES_GATHERER_WOOD_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_AVALON": "Expert's Shoes of Tenacity",
    "T5_SHOES_LEATHER_HELL": "Expert's Hellion Shoes",
    "T5_SHOES_LEATHER_HELL_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_MORGANA": "Expert's Stalker Shoes",
    "T5_SHOES_LEATHER_MORGANA_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_ROYAL": "Expert's Royal Shoes",
    "T5_SHOES_LEATHER_ROYAL_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_SET1": "Expert's Mercenary Shoes",
    "T5_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_SET1_ENCHANTED": "Enchanted Expert's Mercenary Shoes",
    "T5_SHOES_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_SET2": "Expert's Hunter Shoes",
    "T5_SHOES_LEATHER_SET2_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_SET2_ENCHANTED": "Enchanted Expert's Hunter Shoes",
    "T5_SHOES_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_SET3": "Expert's Assassin Shoes",
    "T5_SHOES_LEATHER_SET3_DESC": "Equipment Item",
    "T5_SHOES_LEATHER_UNDEAD": "Expert's Specter Shoes",
    "T5_SHOES_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T5_SHOES_PLATE_AVALON": "Expert's Boots of Valor",
    "T5_SHOES_PLATE_HELL": "Expert's Demon Boots",
    "T5_SHOES_PLATE_HELL_DESC": "Equipment Item",
    "T5_SHOES_PLATE_KEEPER": "Expert's Judicator Boots",
    "T5_SHOES_PLATE_KEEPER_DESC": "Equipment Item",
    "T5_SHOES_PLATE_ROYAL": "Expert's Royal Boots",
    "T5_SHOES_PLATE_ROYAL_DESC": "Equipment Item",
    "T5_SHOES_PLATE_SET1": "Expert's Soldier Boots",
    "T5_SHOES_PLATE_SET1_DESC": "Equipment Item",
    "T5_SHOES_PLATE_SET1_ENCHANTED": "Enchanted Expert's Soldier Boots",
    "T5_SHOES_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T5_SHOES_PLATE_SET2": "Expert's Knight Boots",
    "T5_SHOES_PLATE_SET2_DESC": "Equipment Item",
    "T5_SHOES_PLATE_SET2_ENCHANTED": "Enchanted Expert's Knight Boots",
    "T5_SHOES_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T5_SHOES_PLATE_SET3": "Expert's Guardian Boots",
    "T5_SHOES_PLATE_SET3_DESC": "Equipment Item",
    "T5_SHOES_PLATE_UNDEAD": "Expert's Graveguard Boots",
    "T5_SHOES_PLATE_UNDEAD_DESC": "Equipment Item",
    "T5_SILVERBAG_NONTRADABLE": "Expert's Bag of Silver",
    "T5_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T5_SKILLBOOK_NONTRADABLE": "Expert's Tome of Insight",
    "T5_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 20,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T5_SOUL": "Expert's Soul",
    "T5_SOUL_DESC": "A tortured soul, used to meld artifacts and enchant equipment.",
    "T5_SOUL_HUNTER": "Powerful Hunter's Soul",
    "T5_SOUL_HUNTER_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T5_SOUL_MAGE": "Powerful Mage's Soul",
    "T5_SOUL_MAGE_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T5_SOUL_WARRIOR": "Powerful Warrior's Soul",
    "T5_SOUL_WARRIOR_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T5_STONEBLOCK": "Granite Block",
    "T5_STONEBLOCK_DESC": "Advanced material used in crafting, created by refining stone.",
    "T5_TEASEL": "Dragon Teasel",
    "T5_TEASEL_DESC": "Dragon Teasel is used in various alchemical decoctions",
    "T5_TRASH": "Trash",
    "T5_TRASH_DESC": "A destroyed T5 item. Cannot be repaired or salvaged.",
    "T5_WOOD": "Cedar Logs",
    "T5_WOOD_DESC": "Logs used for crafting. Can be refined into planks or transmuted into higher-level material.",
    "T5_WOOD_LEVEL1": "Uncommon Cedar Logs",
    "T5_WOOD_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T5_WOOD_LEVEL2": "Rare Cedar Logs",
    "T5_WOOD_LEVEL2_DESC": "Rare material used for crafting.",
    "T5_WOOD_LEVEL3": "Exceptional Cedar Logs",
    "T5_WOOD_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T5_WOOD_LEVEL4": "Legendary Cedar Logs",
    "T5_WOOD_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_2H_ARCANE_RINGPAIR_AVALON": "Master's Evensong",
    "T6_2H_ARCANE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T6_2H_ARCANESTAFF": "Master's Great Arcane Staff",
    "T6_2H_ARCANESTAFF_DESC": "Equipment Item",
    "T6_2H_ARCANESTAFF_ENCHANTED": "Master's Enchanted Great Arcane Staff",
    "T6_2H_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_ARCANESTAFF_HELL": "Master's Occult Staff",
    "T6_2H_ARCANESTAFF_HELL_DESC": "Equipment Item",
    "T6_2H_AXE": "Master's Greataxe",
    "T6_2H_AXE_AVALON": "Master's Realmbreaker",
    "T6_2H_AXE_AVALON_DESC": "Equipment Item",
    "T6_2H_AXE_DESC": "Equipment Item",
    "T6_2H_AXE_ENCHANTED": "Master's Enchanted Greataxe",
    "T6_2H_AXE_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_BOW": "Master's Bow",
    "T6_2H_BOW_AVALON": "Master's Mistpiercer",
    "T6_2H_BOW_AVALON_DESC": "Equipment Item",
    "T6_2H_BOW_DESC": "Equipment Item",
    "T6_2H_BOW_ENCHANTED": "Master's Enchanted Bow",
    "T6_2H_BOW_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_BOW_HELL": "Master's Wailing Bow",
    "T6_2H_BOW_HELL_DESC": "Equipment Item",
    "T6_2H_BOW_KEEPER": "Master's Bow of Badon",
    "T6_2H_BOW_KEEPER_DESC": "Equipment Item",
    "T6_2H_BOW_UNDEAD": "Undead Bow",
    "T6_2H_BOW_UNDEAD_DESC": "Equipment Item",
    "T6_2H_CLAWPAIR": "Master's Claws",
    "T6_2H_CLAWPAIR_DESC": "Equipment Item",
    "T6_2H_CLAWPAIR_ENCHANTED": "Master's Enchanted Claws",
    "T6_2H_CLAWPAIR_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_CLAYMORE": "Master's Claymore",
    "T6_2H_CLAYMORE_AVALON": "Master's Kingmaker",
    "T6_2H_CLAYMORE_AVALON_DESC": "Equipment Item",
    "T6_2H_CLAYMORE_DESC": "Equipment Item",
    "T6_2H_CLAYMORE_ENCHANTED": "Master's Enchanted Claymore",
    "T6_2H_CLAYMORE_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_CLEAVER_HELL": "Master's Carving Sword",
    "T6_2H_CLEAVER_HELL_DESC": "Equipment Item",
    "T6_2H_COMBATSTAFF_MORGANA": "Master's Black Monk Stave",
    "T6_2H_COMBATSTAFF_MORGANA_DESC": "Equipment Item",
    "T6_2H_CROSSBOW": "Master's Crossbow",
    "T6_2H_CROSSBOW_CANNON_AVALON": "Master's Energy Shaper",
    "T6_2H_CROSSBOW_CANNON_AVALON_DESC": "Equipment Item",
    "T6_2H_CROSSBOW_DESC": "Equipment Item",
    "T6_2H_CROSSBOWLARGE": "Master's Heavy Crossbow",
    "T6_2H_CROSSBOWLARGE_DESC": "Equipment Item",
    "T6_2H_CROSSBOWLARGE_ENCHANTED": "Master's Enchanted Heavy Crossbow",
    "T6_2H_CROSSBOWLARGE_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_CROSSBOWLARGE_MORGANA": "Master's Siegebow",
    "T6_2H_CROSSBOWLARGE_MORGANA_DESC": "Equipment Item",
    "T6_2H_CURSEDSTAFF": "Master's Great Cursed Staff",
    "T6_2H_CURSEDSTAFF_DESC": "Equipment Item",
    "T6_2H_CURSEDSTAFF_ENCHANTED": "Master's Enchanted Great Cursed Staff",
    "T6_2H_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_CURSEDSTAFF_MORGANA": "Master's Damnation Staff",
    "T6_2H_CURSEDSTAFF_MORGANA_DESC": "Equipment Item",
    "T6_2H_DAGGER_KATAR_AVALON": "Master's Bridled Fury",
    "T6_2H_DAGGER_KATAR_AVALON_DESC": "Equipment Item",
    "T6_2H_DAGGERPAIR": "Master's Dagger Pair",
    "T6_2H_DAGGERPAIR_DESC": "Equipment Item",
    "T6_2H_DAGGERPAIR_ENCHANTED": "Master's Enchanted Dagger Pair",
    "T6_2H_DAGGERPAIR_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_DEMONICSTAFF": "Master's Demonic Staff",
    "T6_2H_DEMONICSTAFF_DESC": "Equipment Item",
    "T6_2H_DEMONICSTAFF_ENCHANTED": "Master's Enchanted Demonic Staff",
    "T6_2H_DEMONICSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_DIVINESTAFF": "Master's Divine Staff",
    "T6_2H_DIVINESTAFF_DESC": "Equipment Item",
    "T6_2H_DIVINESTAFF_ENCHANTED": "Master's Enchanted Divine Staff",
    "T6_2H_DIVINESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_DOUBLEBLADEDSTAFF": "Master's Double Bladed Staff",
    "T6_2H_DOUBLEBLADEDSTAFF_DESC": "Equipment Item",
    "T6_2H_DOUBLEBLADEDSTAFF_ENCHANTED": "Master's Enchanted Double Bladed Staff",
    "T6_2H_DOUBLEBLADEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_DUALAXE_KEEPER": "Master's Bear Paws",
    "T6_2H_DUALAXE_KEEPER_DESC": "Equipment Item",
    "T6_2H_DUALCROSSBOW_HELL": "Master's Boltcasters",
    "T6_2H_DUALCROSSBOW_HELL_DESC": "Equipment Item",
    "T6_2H_DUALHAMMER_HELL": "Master's Forge Hammers",
    "T6_2H_DUALHAMMER_HELL_DESC": "Equipment Item",
    "T6_2H_DUALMACE_AVALON": "Master's Oathkeepers",
    "T6_2H_DUALMACE_AVALON_DESC": "Equipment Item",
    "T6_2H_DUALSCIMITAR_UNDEAD": "Master's Galatine Pair",
    "T6_2H_DUALSCIMITAR_UNDEAD_DESC": "Equipment Item",
    "T6_2H_DUALSICKLE_UNDEAD": "Master's Deathgivers",
    "T6_2H_DUALSICKLE_UNDEAD_DESC": "Equipment Item",
    "T6_2H_DUALSWORD": "Master's Dual Swords",
    "T6_2H_DUALSWORD_DESC": "Equipment Item",
    "T6_2H_ENIGMATICORB_MORGANA": "Master's Malevolent Locus",
    "T6_2H_ENIGMATICORB_MORGANA_DESC": "Equipment Item",
    "T6_2H_ENIGMATICSTAFF": "Master's Enigmatic Staff",
    "T6_2H_ENIGMATICSTAFF_DESC": "Equipment Item",
    "T6_2H_ENIGMATICSTAFF_ENCHANTED": "Master's Enchanted Enigmatic Staff",
    "T6_2H_ENIGMATICSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_FIRE_RINGPAIR_AVALON": "Master's Dawnsong",
    "T6_2H_FIRE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T6_2H_FIRESTAFF": "Master's Great Fire Staff",
    "T6_2H_FIRESTAFF_DESC": "Equipment Item",
    "T6_2H_FIRESTAFF_ENCHANTED": "Master's Enchanted Great Fire Staff",
    "T6_2H_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_FIRESTAFF_HELL": "Master's Brimstone Staff",
    "T6_2H_FIRESTAFF_HELL_DESC": "Equipment Item",
    "T6_2H_FLAIL": "Master's Morning Star",
    "T6_2H_FLAIL_DESC": "Equipment Item",
    "T6_2H_FLAIL_ENCHANTED": "Master's Enchanted Morning Star",
    "T6_2H_FLAIL_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_FROSTSTAFF": "Master's Great Frost Staff",
    "T6_2H_FROSTSTAFF_DESC": "Equipment Item",
    "T6_2H_FROSTSTAFF_ENCHANTED": "Master's Enchanted Great Frost Staff",
    "T6_2H_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_GLACIALSTAFF": "Master's Glacial Staff",
    "T6_2H_GLACIALSTAFF_DESC": "Equipment Item",
    "T6_2H_GLACIALSTAFF_ENCHANTED": "Master's Enchanted Glacial Staff",
    "T6_2H_GLACIALSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_GLAIVE": "Master's Glaive",
    "T6_2H_GLAIVE_DESC": "Equipment Item",
    "T6_2H_GLAIVE_ENCHANTED": "Master's Enchanted Glaive",
    "T6_2H_GLAIVE_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_HALBERD": "Master's Halberd",
    "T6_2H_HALBERD_DESC": "Equipment Item",
    "T6_2H_HALBERD_ENCHANTED": "Master's Enchanted Halberd",
    "T6_2H_HALBERD_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_HALBERD_MORGANA": "Master's Carrioncaller",
    "T6_2H_HALBERD_MORGANA_DESC": "Equipment Item",
    "T6_2H_HAMMER": "Master's Great Hammer",
    "T6_2H_HAMMER_AVALON": "Master's Hand of Justice",
    "T6_2H_HAMMER_AVALON_DESC": "Equipment Item",
    "T6_2H_HAMMER_DESC": "Equipment Item",
    "T6_2H_HAMMER_ENCHANTED": "Master's Enchanted Great Hammer",
    "T6_2H_HAMMER_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_HAMMER_UNDEAD": "Master's Tombhammer",
    "T6_2H_HAMMER_UNDEAD_DESC": "Equipment Item",
    "T6_2H_HARPOON_HELL": "Master's Spirithunter",
    "T6_2H_HARPOON_HELL_DESC": "Equipment Item",
    "T6_2H_HOLYSTAFF": "Master's Great Holy Staff",
    "T6_2H_HOLYSTAFF_DESC": "Equipment Item",
    "T6_2H_HOLYSTAFF_ENCHANTED": "Master's Enchanted Great Holy Staff",
    "T6_2H_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_HOLYSTAFF_HELL": "Master's Fallen Staff",
    "T6_2H_HOLYSTAFF_HELL_DESC": "Equipment Item",
    "T6_2H_HOLYSTAFF_UNDEAD": "Master's Redemption Staff",
    "T6_2H_HOLYSTAFF_UNDEAD_DESC": "Equipment Item",
    "T6_2H_ICECRYSTAL_UNDEAD": "Master's Permafrost Prism",
    "T6_2H_ICECRYSTAL_UNDEAD_DESC": "Equipment Item",
    "T6_2H_ICEGAUNTLETS_HELL": "Master's Icicle Staff",
    "T6_2H_ICEGAUNTLETS_HELL_DESC": "Equipment Item",
    "T6_2H_INFERNOSTAFF": "Master's Infernal Staff",
    "T6_2H_INFERNOSTAFF_DESC": "Equipment Item",
    "T6_2H_INFERNOSTAFF_ENCHANTED": "Master's Enchanted Infernal Staff",
    "T6_2H_INFERNOSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_INFERNOSTAFF_MORGANA": "Master's Blazing Staff",
    "T6_2H_INFERNOSTAFF_MORGANA_DESC": "Equipment Item",
    "T6_2H_IRONCLADEDSTAFF": "Master's Iron-clad Staff",
    "T6_2H_IRONCLADEDSTAFF_DESC": "Equipment Item",
    "T6_2H_IRONCLADEDSTAFF_ENCHANTED": "Master's Enchanted Iron-clad Staff",
    "T6_2H_IRONCLADEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_IRONGAUNTLETS_HELL": "Master's Black Hands",
    "T6_2H_IRONGAUNTLETS_HELL_DESC": "Equipment Item",
    "T6_2H_LONGBOW": "Master's Longbow",
    "T6_2H_LONGBOW_DESC": "Equipment Item",
    "T6_2H_LONGBOW_ENCHANTED": "Master's Enchanted Longbow",
    "T6_2H_LONGBOW_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_LONGBOW_UNDEAD": "Master's Whispering Bow",
    "T6_2H_LONGBOW_UNDEAD_DESC": "Equipment Item",
    "T6_2H_MACE": "Master's Heavy Mace",
    "T6_2H_MACE_DESC": "Equipment Item",
    "T6_2H_MACE_ENCHANTED": "Master's Enchanted Heavy Mace",
    "T6_2H_MACE_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_MACE_MORGANA": "Master's Camlann Mace",
    "T6_2H_MACE_MORGANA_DESC": "Equipment Item",
    "T6_2H_NATURESTAFF": "Master's Great Nature Staff",
    "T6_2H_NATURESTAFF_DESC": "Equipment Item",
    "T6_2H_NATURESTAFF_ENCHANTED": "Master's Enchanted Great Nature Staff",
    "T6_2H_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_NATURESTAFF_HELL": "Master's Blight Staff",
    "T6_2H_NATURESTAFF_HELL_DESC": "Equipment Item",
    "T6_2H_NATURESTAFF_KEEPER": "Master's Rampant Staff",
    "T6_2H_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T6_2H_POLEHAMMER": "Master's Polehammer",
    "T6_2H_POLEHAMMER_DESC": "Equipment Item",
    "T6_2H_POLEHAMMER_ENCHANTED": "Master's Enchanted Polehammer",
    "T6_2H_POLEHAMMER_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_QUARTERSTAFF": "Master's Quarterstaff",
    "T6_2H_QUARTERSTAFF_AVALON": "Master's Grailseeker",
    "T6_2H_QUARTERSTAFF_AVALON_DESC": "Equipment Item",
    "T6_2H_QUARTERSTAFF_DESC": "Equipment Item",
    "T6_2H_QUARTERSTAFF_ENCHANTED": "Master's Enchanted Quarterstaff",
    "T6_2H_QUARTERSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_RAM_KEEPER": "Master's Grovekeeper",
    "T6_2H_RAM_KEEPER_DESC": "Equipment Item",
    "T6_2H_REPEATINGCROSSBOW_UNDEAD": "Master's Weeping Repeater",
    "T6_2H_REPEATINGCROSSBOW_UNDEAD_DESC": "Equipment Item",
    "T6_2H_ROCKSTAFF_KEEPER": "Master's Staff of Balance",
    "T6_2H_ROCKSTAFF_KEEPER_DESC": "Equipment Item",
    "T6_2H_SCYTHE": "Master's Scythe",
    "T6_2H_SCYTHE_DESC": "Equipment Item",
    "T6_2H_SCYTHE_ENCHANTED": "Master's Enchanted Scythe",
    "T6_2H_SCYTHE_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_SCYTHE_HELL": "Master's Infernal Scythe",
    "T6_2H_SCYTHE_HELL_DESC": "Equipment Item",
    "T6_2H_SKULLORB_HELL": "Master's Cursed Skull",
    "T6_2H_SKULLORB_HELL_DESC": "Equipment Item",
    "T6_2H_SPEAR": "Master's Pike",
    "T6_2H_SPEAR_DESC": "Equipment Item",
    "T6_2H_SPEAR_ENCHANTED": "Master's Enchanted Pike",
    "T6_2H_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_TOOL_AXE": "Master's Axe",
    "T6_2H_TOOL_AXE_AVALON": "Master's Avalonian Axe",
    "T6_2H_TOOL_AXE_DESC": "Equipment Item",
    "T6_2H_TOOL_FISHINGROD": "Master's Fishing Rod",
    "T6_2H_TOOL_FISHINGROD_AVALON": "Master's Avalonian Fishing Rod",
    "T6_2H_TOOL_FISHINGROD_DESC": "Equipment Item",
    "T6_2H_TOOL_HAMMER": "Master's Stone Hammer",
    "T6_2H_TOOL_HAMMER_AVALON": "Master's Avalonian Stone Hammer",
    "T6_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T6_2H_TOOL_KNIFE": "Master's Skinning Knife",
    "T6_2H_TOOL_KNIFE_AVALON": "Master's Avalonian Skinning Knife",
    "T6_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T6_2H_TOOL_PICK": "Master's Pickaxe",
    "T6_2H_TOOL_PICK_AVALON": "Master's Avalonian Pickaxe",
    "T6_2H_TOOL_PICK_DESC": "Equipment Item",
    "T6_2H_TOOL_SICKLE": "Master's Sickle",
    "T6_2H_TOOL_SICKLE_AVALON": "Master's Avalonian Sickle",
    "T6_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T6_2H_TOOL_SIEGEHAMMER": "Master's Demolition Hammer",
    "T6_2H_TOOL_SIEGEHAMMER_AVALON": "Master's Avalonian Demolition Hammer",
    "T6_2H_TOOL_SIEGEHAMMER_DESC": "A powerful hammer designed for destroying buildings and furniture.",
    "T6_2H_TRIDENT_UNDEAD": "Master's Trinity Spear",
    "T6_2H_TRIDENT_UNDEAD_DESC": "Equipment Item",
    "T6_2H_TWINSCYTHE_HELL": "Master's Soulscythe",
    "T6_2H_TWINSCYTHE_HELL_DESC": "Equipment Item",
    "T6_2H_WARBOW": "Master's Warbow",
    "T6_2H_WARBOW_DESC": "Equipment Item",
    "T6_2H_WARBOW_ENCHANTED": "Master's Enchanted Warbow",
    "T6_2H_WARBOW_ENCHANTED_DESC": "Equipment Item",
    "T6_2H_WILDSTAFF": "Master's Wild Staff",
    "T6_2H_WILDSTAFF_DESC": "Equipment Item",
    "T6_2H_WILDSTAFF_ENCHANTED": "Master's Enchanted Wild Staff",
    "T6_2H_WILDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_ALCOHOL": "Potato Schnapps",
    "T6_ALCOHOL_DESC": "Potato Schnapps is brewed from Potatoes, and used in various alchemical decoctions.",
    "T6_ARMOR_CLOTH_AVALON": "Master's Robe of Purity",
    "T6_ARMOR_CLOTH_HELL": "Master's Fiend Robe",
    "T6_ARMOR_CLOTH_HELL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_KEEPER": "Master's Druid Robe",
    "T6_ARMOR_CLOTH_KEEPER_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_MORGANA": "Master's Cultist Robe",
    "T6_ARMOR_CLOTH_MORGANA_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_ROYAL": "Master's Royal Robe",
    "T6_ARMOR_CLOTH_ROYAL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_SET1": "Master's Scholar Robe",
    "T6_ARMOR_CLOTH_SET1_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_SET1_ENCHANTED": "Enchanted Master's Scholar Robe",
    "T6_ARMOR_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_SET2": "Master's Cleric Robe",
    "T6_ARMOR_CLOTH_SET2_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_SET2_ENCHANTED": "Enchanted Master's Cleric Robe",
    "T6_ARMOR_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_SET3": "Master's Mage Robe",
    "T6_ARMOR_CLOTH_SET3_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_SET3_ENCHANTED": "Enchanted Master's Mage Robe",
    "T6_ARMOR_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T6_ARMOR_CLOTH_UNDEAD": "Undead Robe",
    "T6_ARMOR_CLOTH_UNDEAD_DESC": "Equipment Item",
    "T6_ARMOR_GATHERER_FIBER": "Master's Harvester Garb",
    "T6_ARMOR_GATHERER_FIBER_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T6_ARMOR_GATHERER_FISH": "Master's Fisherman Garb",
    "T6_ARMOR_GATHERER_FISH_DESC": "Equipment Item\nGatherer Gear helps you gather more of its resource type",
    "T6_ARMOR_GATHERER_HIDE": "Master's Skinner Garb",
    "T6_ARMOR_GATHERER_HIDE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T6_ARMOR_GATHERER_ORE": "Master's Miner Garb",
    "T6_ARMOR_GATHERER_ORE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T6_ARMOR_GATHERER_ROCK": "Master's Quarrier Garb",
    "T6_ARMOR_GATHERER_ROCK_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T6_ARMOR_GATHERER_WOOD": "Master's Lumberjack Garb",
    "T6_ARMOR_GATHERER_WOOD_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T6_ARMOR_LEATHER_AVALON": "Master's Jacket of Tenacity",
    "T6_ARMOR_LEATHER_HELL": "Master's Hellion Jacket",
    "T6_ARMOR_LEATHER_HELL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_KEEPER": "Keeper Leather Armor",
    "T6_ARMOR_LEATHER_KEEPER_DESC": "Equipment Item",
    "T6_ARMOR_LEATHER_MORGANA": "Master's Stalker Jacket",
    "T6_ARMOR_LEATHER_MORGANA_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_ROYAL": "Master's Royal Jacket",
    "T6_ARMOR_LEATHER_ROYAL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_SET1": "Master's Mercenary Jacket",
    "T6_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_SET1_ENCHANTED": "Enchanted Master's Mercenary Jacket",
    "T6_ARMOR_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_SET2": "Master's Hunter Jacket",
    "T6_ARMOR_LEATHER_SET2_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_SET2_ENCHANTED": "Enchanted Master's Hunter Jacket",
    "T6_ARMOR_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_SET3": "Master's Assassin Jacket",
    "T6_ARMOR_LEATHER_SET3_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_SET3_ENCHANTED": "Enchanted Master's Assassin Jacket",
    "T6_ARMOR_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_LEATHER_UNDEAD": "Master's Specter Jacket",
    "T6_ARMOR_LEATHER_UNDEAD_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T6_ARMOR_PLATE_AVALON": "Master's Armor of Valor",
    "T6_ARMOR_PLATE_HELL": "Master's Demon Armor",
    "T6_ARMOR_PLATE_HELL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_KEEPER": "Master's Judicator Armor",
    "T6_ARMOR_PLATE_KEEPER_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_MORGANA": "Morgana Plate Armor",
    "T6_ARMOR_PLATE_MORGANA_DESC": "Equipment Item",
    "T6_ARMOR_PLATE_ROYAL": "Master's Royal Armor",
    "T6_ARMOR_PLATE_ROYAL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_SET1": "Master's Soldier Armor",
    "T6_ARMOR_PLATE_SET1_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_SET1_ENCHANTED": "Enchanted Master's Soldier Armor",
    "T6_ARMOR_PLATE_SET1_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_SET2": "Master's Knight Armor",
    "T6_ARMOR_PLATE_SET2_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_SET2_ENCHANTED": "Enchanted Master's Knight Armor",
    "T6_ARMOR_PLATE_SET2_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_SET3": "Master's Guardian Armor",
    "T6_ARMOR_PLATE_SET3_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_SET3_ENCHANTED": "Enchanted Master's Guardian Armor",
    "T6_ARMOR_PLATE_SET3_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARMOR_PLATE_UNDEAD": "Master's Graveguard Armor",
    "T6_ARMOR_PLATE_UNDEAD_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T6_ARTEFACT_2H_ARCANE_RINGPAIR_AVALON": "Master's Hypnotic Harmonic Ring",
    "T6_ARTEFACT_2H_ARCANESTAFF_HELL": "Master's Occult Orb",
    "T6_ARTEFACT_2H_AXE_AVALON": "Master's Avalonian Battle Memoir",
    "T6_ARTEFACT_2H_BOW_AVALON": "Master's Immaculately Crafted Riser",
    "T6_ARTEFACT_2H_BOW_HELL": "Master's Demonic Arrowheads",
    "T6_ARTEFACT_2H_BOW_KEEPER": "Master's Carved bone",
    "T6_ARTEFACT_2H_CLAYMORE_AVALON": "Master's Remnants of the Old King",
    "T6_ARTEFACT_2H_CLEAVER_HELL": "Master's Demonic Blade",
    "T6_ARTEFACT_2H_COMBATSTAFF_MORGANA": "Master's Reinforced Morgana Pole",
    "T6_ARTEFACT_2H_CROSSBOW_CANNON_AVALON": "Master's Humming Avalonian Whirligig",
    "T6_ARTEFACT_2H_CROSSBOWLARGE_MORGANA": "Master's Alluring Bolts",
    "T6_ARTEFACT_2H_CURSEDSTAFF_MORGANA": "Master's Bloodforged Catalyst",
    "T6_ARTEFACT_2H_DAGGER_KATAR_AVALON": "Master's Bloodstained Antiquities",
    "T6_ARTEFACT_2H_DUALAXE_KEEPER": "Master's Keeper Axeheads",
    "T6_ARTEFACT_2H_DUALCROSSBOW_HELL": "Master's Hellish Bolts",
    "T6_ARTEFACT_2H_DUALHAMMER_HELL": "Master's Hellish Hammer Heads",
    "T6_ARTEFACT_2H_DUALMACE_AVALON": "Master's Broken Oaths",
    "T6_ARTEFACT_2H_DUALSCIMITAR_UNDEAD": "Master's Cursed Blades",
    "T6_ARTEFACT_2H_DUALSICKLE_UNDEAD": "Master's Ghastly Blades",
    "T6_ARTEFACT_2H_ENIGMATICORB_MORGANA": "Master's Possessed Catalyst",
    "T6_ARTEFACT_2H_FIRE_RINGPAIR_AVALON": "Master's Glowing Harmonic Ring",
    "T6_ARTEFACT_2H_FIRESTAFF_HELL": "Master's Burning Orb",
    "T6_ARTEFACT_2H_HALBERD_MORGANA": "Master's Morgana Halberd Head",
    "T6_ARTEFACT_2H_HAMMER_AVALON": "Master's Massive Metallic Hand",
    "T6_ARTEFACT_2H_HAMMER_UNDEAD": "Master's Ancient Hammer Head",
    "T6_ARTEFACT_2H_HARPOON_HELL": "Master's Infernal Harpoon Tip",
    "T6_ARTEFACT_2H_HOLYSTAFF_HELL": "Master's Infernal Scroll",
    "T6_ARTEFACT_2H_HOLYSTAFF_UNDEAD": "Master's Ghastly Scroll",
    "T6_ARTEFACT_2H_ICECRYSTAL_UNDEAD": "Master's Cursed Frozen Crystal",
    "T6_ARTEFACT_2H_ICEGAUNTLETS_HELL": "Master's Icicle Orb",
    "T6_ARTEFACT_2H_INFERNOSTAFF_MORGANA": "Master's Unholy Scroll",
    "T6_ARTEFACT_2H_IRONGAUNTLETS_HELL": "Master's Black Leather",
    "T6_ARTEFACT_2H_LONGBOW_UNDEAD": "Master's Ghastly Arrows",
    "T6_ARTEFACT_2H_MACE_MORGANA": "Master's Imbued Mace Head",
    "T6_ARTEFACT_2H_NATURESTAFF_HELL": "Master's Symbol of Blight",
    "T6_ARTEFACT_2H_NATURESTAFF_KEEPER": "Master's Preserved Log",
    "T6_ARTEFACT_2H_QUARTERSTAFF_AVALON": "Master's Timeworn Walking Staff",
    "T6_ARTEFACT_2H_RAM_KEEPER": "Master's Engraved Log",
    "T6_ARTEFACT_2H_REPEATINGCROSSBOW_UNDEAD": "Master's Lost Crossbow Mechanism",
    "T6_ARTEFACT_2H_ROCKSTAFF_KEEPER": "Master's Preserved Rocks",
    "T6_ARTEFACT_2H_SCYTHE_HELL": "Master's Hellish Sicklehead",
    "T6_ARTEFACT_2H_SKULLORB_HELL": "Master's Cursed Jawbone",
    "T6_ARTEFACT_2H_TRIDENT_UNDEAD": "Master's Cursed Barbs",
    "T6_ARTEFACT_2H_TWINSCYTHE_HELL": "Master's Hellish Sicklehead Pair",
    "T6_ARTEFACT_ARMOR_CLOTH_AVALON": "Master's Sanctified Belt",
    "T6_ARTEFACT_ARMOR_CLOTH_HELL": "Master's Infernal Cloth Folds",
    "T6_ARTEFACT_ARMOR_CLOTH_KEEPER": "Master's Druidic Feathers",
    "T6_ARTEFACT_ARMOR_CLOTH_MORGANA": "Master's Alluring Amulet",
    "T6_ARTEFACT_ARMOR_LEATHER_AVALON": "Master's Augured Sash",
    "T6_ARTEFACT_ARMOR_LEATHER_HELL": "Master's Demonhide Leather",
    "T6_ARTEFACT_ARMOR_LEATHER_MORGANA": "Master's Imbued Leather Folds",
    "T6_ARTEFACT_ARMOR_LEATHER_UNDEAD": "Master's Ghastly Leather",
    "T6_ARTEFACT_ARMOR_PLATE_AVALON": "Master's Exalted Plating",
    "T6_ARTEFACT_ARMOR_PLATE_HELL": "Master's Demonic Plates",
    "T6_ARTEFACT_ARMOR_PLATE_KEEPER": "Master's Preserved Animal Fur",
    "T6_ARTEFACT_ARMOR_PLATE_UNDEAD": "Master's Ancient Chain Rings",
    "T6_ARTEFACT_HEAD_CLOTH_AVALON": "Master's Sanctified Mask",
    "T6_ARTEFACT_HEAD_CLOTH_HELL": "Master's Infernal Cloth Visor",
    "T6_ARTEFACT_HEAD_CLOTH_KEEPER": "Master's Druidic Preserved Beak",
    "T6_ARTEFACT_HEAD_CLOTH_MORGANA": "Master's Alluring Padding",
    "T6_ARTEFACT_HEAD_LEATHER_AVALON": "Master's Augured Padding",
    "T6_ARTEFACT_HEAD_LEATHER_HELL": "Master's Demonhide Padding",
    "T6_ARTEFACT_HEAD_LEATHER_MORGANA": "Master's Imbued Visor",
    "T6_ARTEFACT_HEAD_LEATHER_UNDEAD": "Master's Ghastly Visor",
    "T6_ARTEFACT_HEAD_PLATE_AVALON": "Master's Exalted Visor",
    "T6_ARTEFACT_HEAD_PLATE_HELL": "Master's Demonic Scraps",
    "T6_ARTEFACT_HEAD_PLATE_KEEPER": "Master's Carved Skull Padding",
    "T6_ARTEFACT_HEAD_PLATE_UNDEAD": "Master's Ancient Padding",
    "T6_ARTEFACT_MAIN_ARCANESTAFF_UNDEAD": "Master's Lost Arcane Crystal",
    "T6_ARTEFACT_MAIN_CURSEDSTAFF_AVALON": "Master's Fractured Opaque Orb",
    "T6_ARTEFACT_MAIN_CURSEDSTAFF_UNDEAD": "Master's Lost Cursed Crystal",
    "T6_ARTEFACT_MAIN_FIRESTAFF_KEEPER": "Master's Wildfire Orb",
    "T6_ARTEFACT_MAIN_FROSTSTAFF_AVALON": "Master's Chilled Crystaline Shard",
    "T6_ARTEFACT_MAIN_FROSTSTAFF_KEEPER": "Master's Hoarfrost Orb",
    "T6_ARTEFACT_MAIN_HOLYSTAFF_AVALON": "Master's Messianic Curio",
    "T6_ARTEFACT_MAIN_HOLYSTAFF_MORGANA": "Master's Possessed Scroll",
    "T6_ARTEFACT_MAIN_MACE_HELL": "Master's Infernal Mace Head",
    "T6_ARTEFACT_MAIN_NATURESTAFF_AVALON": "Master's Uprooted Perennial Sapling",
    "T6_ARTEFACT_MAIN_NATURESTAFF_KEEPER": "Master's Druidic Inscriptions",
    "T6_ARTEFACT_MAIN_RAPIER_MORGANA": "Master's Hardened Debole",
    "T6_ARTEFACT_MAIN_ROCKMACE_KEEPER": "Master's Runed Rock",
    "T6_ARTEFACT_MAIN_SCIMITAR_MORGANA": "Master's Bloodforged Blade",
    "T6_ARTEFACT_MAIN_SPEAR_KEEPER": "Master's Keeper Spearhead",
    "T6_ARTEFACT_MAIN_SPEAR_LANCE_AVALON": "Master's Ruined Ancestral Vamplate",
    "T6_ARTEFACT_OFF_CENSER_AVALON": "Master's Severed Celestial Keepsake",
    "T6_ARTEFACT_OFF_DEMONSKULL_HELL": "Master's Demonic Jawbone",
    "T6_ARTEFACT_OFF_HORN_KEEPER": "Master's Runed Horn",
    "T6_ARTEFACT_OFF_JESTERCANE_HELL": "Master's Hellish Handle",
    "T6_ARTEFACT_OFF_LAMP_UNDEAD": "Master's Ghastly Candle",
    "T6_ARTEFACT_OFF_ORB_MORGANA": "Master's Alluring Crystal",
    "T6_ARTEFACT_OFF_SHIELD_AVALON": "Master's Crushed Avalonian Heirloom",
    "T6_ARTEFACT_OFF_SHIELD_HELL": "Master's Infernal Shield Core",
    "T6_ARTEFACT_OFF_SPIKEDSHIELD_MORGANA": "Master's Bloodforged Spikes",
    "T6_ARTEFACT_OFF_TALISMAN_AVALON": "Master's Shattered Avalonian Memento",
    "T6_ARTEFACT_OFF_TOTEM_KEEPER": "Master's Inscribed Stone",
    "T6_ARTEFACT_OFF_TOWERSHIELD_UNDEAD": "Master's Ancient Shield Core",
    "T6_ARTEFACT_SHOES_CLOTH_AVALON": "Master's Sanctified Bindings",
    "T6_ARTEFACT_SHOES_CLOTH_HELL": "Master's Infernal Cloth Bindings",
    "T6_ARTEFACT_SHOES_CLOTH_KEEPER": "Master's Druidic Bindings",
    "T6_ARTEFACT_SHOES_CLOTH_MORGANA": "Master's Alluring Bindings",
    "T6_ARTEFACT_SHOES_LEATHER_AVALON": "Master's Augured Fasteners",
    "T6_ARTEFACT_SHOES_LEATHER_HELL": "Master's Demonhide Bindings",
    "T6_ARTEFACT_SHOES_LEATHER_MORGANA": "Master's Imbued Soles",
    "T6_ARTEFACT_SHOES_LEATHER_UNDEAD": "Master's Ghastly Bindings",
    "T6_ARTEFACT_SHOES_PLATE_AVALON": "Master's Exalted Greave",
    "T6_ARTEFACT_SHOES_PLATE_HELL": "Master's Demonic Filling",
    "T6_ARTEFACT_SHOES_PLATE_KEEPER": "Master's Inscribed Bindings",
    "T6_ARTEFACT_SHOES_PLATE_UNDEAD": "Master's Ancient Bindings",
    "T6_BACKPACK_GATHERER_FIBER": "Master's Harvester Backpack",
    "T6_BACKPACK_GATHERER_FIBER_DESC": "Equipment Item",
    "T6_BACKPACK_GATHERER_FISH": "Master's Fisherman Backpack",
    "T6_BACKPACK_GATHERER_FISH_DESC": "Equipment Item",
    "T6_BACKPACK_GATHERER_HIDE": "Master's Skinner Backpack",
    "T6_BACKPACK_GATHERER_HIDE_DESC": "Equipment Item",
    "T6_BACKPACK_GATHERER_ORE": "Master's Miner Backpack",
    "T6_BACKPACK_GATHERER_ORE_DESC": "Equipment Item",
    "T6_BACKPACK_GATHERER_ROCK": "Master's Quarrier Backpack",
    "T6_BACKPACK_GATHERER_ROCK_DESC": "Equipment Item",
    "T6_BACKPACK_GATHERER_WOOD": "Master's Lumberjack Backpack",
    "T6_BACKPACK_GATHERER_WOOD_DESC": "Equipment Item",
    "T6_BAG": "Master's Bag",
    "T6_BAG_DESC": "Equipment Item",
    "T6_BAG_FW_BONUS_FAME": "Master's Faction Fame Bag",
    "T6_BAG_FW_BONUS_FAME_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T6_BAG_FW_BONUS_SILVER": "Master's Faction Silver Bag",
    "T6_BAG_FW_BONUS_SILVER_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T6_BAG_FW_BONUS_YIELD": "Master's Faction Yield Bag",
    "T6_BAG_FW_BONUS_YIELD_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T6_BAG_FW_FAME_BP": "Master's Faction Fame Bag Pattern",
    "T6_BAG_FW_FAME_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T6_BAG_FW_SILVER_BP": "Master's Faction Silver Bag Pattern",
    "T6_BAG_FW_SILVER_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T6_BAG_FW_YIELD_BP": "Master's Faction Yield Bag Pattern",
    "T6_BAG_FW_YIELD_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T6_BAG_INSIGHT": "Master's Satchel of Insight",
    "T6_BUTTER": "Sheep's Butter",
    "T6_BUTTER_DESC": "Sheep's Butter is used to make Sandwiches",
    "T6_CAPE": "Master's Cape",
    "T6_CAPE_ARENA_BANNER": "Arena Veteran's Medium Banner",
    "T6_CAPE_ARENA_BANNER_DESC": "Equipment Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils",
    "T6_CAPE_CLOTH_KEEPER": "Decorative Keeper Cloth Cape",
    "T6_CAPE_CLOTH_KEEPER_DESC": "Equipment Item",
    "T6_CAPE_CLOTH_MORGANA": "Decorative Morgana Cloth Cape",
    "T6_CAPE_CLOTH_MORGANA_DESC": "Equipment Item",
    "T6_CAPE_CLOTH_UNDEAD": "Decorative Undead Cloth Cape",
    "T6_CAPE_CLOTH_UNDEAD_DESC": "Equipment Item",
    "T6_CAPE_DESC": "Equipment Item",
    "T6_CAPE_LEATHER_KEEPER": "Decorative Keeper Leather Cape",
    "T6_CAPE_LEATHER_KEEPER_DESC": "Equipment Item",
    "T6_CAPE_LEATHER_MORGANA": "Decorative Morgana Leather Cape",
    "T6_CAPE_LEATHER_MORGANA_DESC": "Equipment Item",
    "T6_CAPE_LEATHER_UNDEAD": "Decorative Undead Leather Cape",
    "T6_CAPE_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T6_CAPE_PLATE_KEEPER": "Decorative Keeper Platemail Cape",
    "T6_CAPE_PLATE_KEEPER_DESC": "Equipment Item",
    "T6_CAPE_PLATE_MORGANA": "Decorative Morgana Platemail Cape",
    "T6_CAPE_PLATE_MORGANA_DESC": "Equipment Item",
    "T6_CAPE_PLATE_UNDEAD": "Decorative Undead Platemail Cape",
    "T6_CAPE_PLATE_UNDEAD_DESC": "Equipment Item",
    "T6_CAPEITEM_DEMON": "Master's Demon Cape",
    "T6_CAPEITEM_DEMON_BP": "Master's Demon Crest",
    "T6_CAPEITEM_DEMON_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_DEMON_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_FW_BRIDGEWATCH": "Master's Bridgewatch Cape",
    "T6_CAPEITEM_FW_BRIDGEWATCH_BP": "Master's Bridgewatch Crest",
    "T6_CAPEITEM_FW_BRIDGEWATCH_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_FW_BRIDGEWATCH_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_FW_FORTSTERLING": "Master's Fort Sterling Cape",
    "T6_CAPEITEM_FW_FORTSTERLING_BP": "Master's Fort Sterling Crest",
    "T6_CAPEITEM_FW_FORTSTERLING_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_FW_FORTSTERLING_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_FW_LYMHURST": "Master's Lymhurst Cape",
    "T6_CAPEITEM_FW_LYMHURST_BP": "Master's Lymhurst Crest",
    "T6_CAPEITEM_FW_LYMHURST_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_FW_LYMHURST_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_FW_MARTLOCK": "Master's Martlock Cape",
    "T6_CAPEITEM_FW_MARTLOCK_BP": "Master's Martlock Crest",
    "T6_CAPEITEM_FW_MARTLOCK_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_FW_MARTLOCK_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_FW_THETFORD": "Master's Thetford Cape",
    "T6_CAPEITEM_FW_THETFORD_BP": "Master's Thetford Crest",
    "T6_CAPEITEM_FW_THETFORD_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_FW_THETFORD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_HERETIC": "Master's Heretic Cape",
    "T6_CAPEITEM_HERETIC_BP": "Master's Heretic Crest",
    "T6_CAPEITEM_HERETIC_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_HERETIC_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_KEEPER": "Master's Keeper Cape",
    "T6_CAPEITEM_KEEPER_BP": "Master's Keeper Crest",
    "T6_CAPEITEM_KEEPER_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_KEEPER_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_MORGANA": "Master's Morgana Cape",
    "T6_CAPEITEM_MORGANA_BP": "Master's Morgana Crest",
    "T6_CAPEITEM_MORGANA_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_MORGANA_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CAPEITEM_UNDEAD": "Master's Undead Cape",
    "T6_CAPEITEM_UNDEAD_BP": "Master's Undead Crest",
    "T6_CAPEITEM_UNDEAD_BP_DESC": "Can be used to upgrade a cape",
    "T6_CAPEITEM_UNDEAD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T6_CLOTH": "Lavish Cloth",
    "T6_CLOTH_DESC": "Advanced material used in crafting, created by refining fiber.",
    "T6_CLOTH_LEVEL1": "Uncommon Lavish Cloth",
    "T6_CLOTH_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_CLOTH_LEVEL2": "Rare Lavish Cloth",
    "T6_CLOTH_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_CLOTH_LEVEL3": "Exceptional Lavish Cloth",
    "T6_CLOTH_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_CLOTH_LEVEL4": "Legendary Lavish Cloth",
    "T6_CLOTH_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_CLOTH_LEVEL5": "Mythical Lavish Cloth",
    "T6_CLOTH_LEVEL5_DESC": "Mythical material used for crafting.",
    "T6_ESSENCE": "Master's Faded Essence",
    "T6_ESSENCE_DESC": "This essence has passed its use-by date. It can be combined with others like it at an Artifact Foundry.",
    "T6_ESSENCE_HUNTER": "Holy Essence of the Hunter",
    "T6_ESSENCE_HUNTER_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T6_ESSENCE_MAGE": "Holy Essence of the Mage",
    "T6_ESSENCE_MAGE_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T6_ESSENCE_POTION": "Master's Arcane Essence",
    "T6_ESSENCE_POTION_DESC": "A magical essence, used to enchant potions",
    "T6_ESSENCE_WARRIOR": "Holy Essence of the Warrior",
    "T6_ESSENCE_WARRIOR_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T6_FARM_DIREWOLF_BABY": "Direwolf Pup",
    "T6_FARM_DIREWOLF_BABY_DESC": "A Direwolf Pup placed in a Kennel will grow into a Tame Direwolf, which can be trained into a Direwolf mount.",
    "T6_FARM_DIREWOLF_GROWN": "Tame Direwolf",
    "T6_FARM_DIREWOLF_GROWN_DESC": "Can be used to craft a Direwolf mount.",
    "T6_FARM_FOXGLOVE_SEED": "Elusive Foxglove Seeds",
    "T6_FARM_FOXGLOVE_SEED_DESC": "Elusive Foxglove Seeds are used to plant a patch of Elusive Foxglove",
    "T6_FARM_GIANTSTAG_BABY": "Master's Fawn",
    "T6_FARM_GIANTSTAG_BABY_DESC": "A fawn placed in a pasture will grow into a Tame Giant Stag. Note: Master's Tame Giant Stags can be kept in a pasture, but cannot be trained into mounts.",
    "T6_FARM_GIANTSTAG_GROWN": "Master's Tame Giant Stag",
    "T6_FARM_GIANTSTAG_GROWN_DESC": "Can be kept in a pasture, but cannot be used to craft a Master's Giant Stag mount.",
    "T6_FARM_HORSE_BABY": "Master's Foal",
    "T6_FARM_HORSE_BABY_DESC": "Grow into a Master's Horse which can be used to craft a Master's Riding Horse or a Master's Armored Horse.",
    "T6_FARM_HORSE_GROWN": "Master's Horse",
    "T6_FARM_HORSE_GROWN_DESC": "Can be used to craft a Master's Riding Horse or a Master's Armored Horse.",
    "T6_FARM_OX_BABY": "Master's Ox Calf",
    "T6_FARM_OX_BABY_DESC": "Grows into an Master's Ox which can be used to craft a Master's Transport Ox.",
    "T6_FARM_OX_GROWN": "Master's Ox",
    "T6_FARM_OX_GROWN_DESC": "Can be used to craft a Master's Transport Ox.",
    "T6_FARM_POTATO_SEED": "Potato Seeds",
    "T6_FARM_POTATO_SEED_DESC": "Potato Seeds are used to plant a patch of Potatoes",
    "T6_FARM_SHEEP_BABY": "Lamb",
    "T6_FARM_SHEEP_BABY_DESC": "You can place Lambs on your pasture for them to grow up into Sheep",
    "T6_FARM_SHEEP_GROWN": "Sheep",
    "T6_FARM_SHEEP_GROWN_DESC": "Sheep can be slaughtered to produce Raw Mutton, or left alive to produce Sheep's Milk",
    "T6_FIBER": "Redleaf Cotton",
    "T6_FIBER_DESC": "Fiber used for crafting. Can be refined into cloth or transmuted into higher-level material.",
    "T6_FIBER_LEVEL1": "Uncommon Redleaf Cotton",
    "T6_FIBER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_FIBER_LEVEL2": "Rare Redleaf Cotton",
    "T6_FIBER_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_FIBER_LEVEL3": "Exceptional Redleaf Cotton",
    "T6_FIBER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_FIBER_LEVEL4": "Legendary Redleaf Cotton",
    "T6_FIBER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_FIBER_LEVEL5": "Mythical Redleaf Cotton",
    "T6_FIBER_LEVEL5_DESC": "Mythical material used for crafting.",
    "T6_FISH_FRESHWATER_ALL_COMMON": "Brightscale Zander",
    "T6_FISH_SALTWATER_ALL_COMMON": "Strongfin Salmon",
    "T6_FOXGLOVE": "Elusive Foxglove",
    "T6_FOXGLOVE_DESC": "Elusive Foxglove is used in various alchemical decoctions",
    "T6_FRAGMENT_BLUE_F1": "Master's Scrap of Magic",
    "T6_FRAGMENT_BLUE_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_BLUE_F2": "Master's Fragment of Magic",
    "T6_FRAGMENT_BLUE_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_BLUE_F3": "Master's Shard of Magic",
    "T6_FRAGMENT_BLUE_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_GREEN_F1": "Master's Scrap of Nature",
    "T6_FRAGMENT_GREEN_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_GREEN_F2": "Master's Fragment of Nature",
    "T6_FRAGMENT_GREEN_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_GREEN_F3": "Master's Shard of Nature",
    "T6_FRAGMENT_GREEN_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_RED_F1": "Master's Scrap of Valor",
    "T6_FRAGMENT_RED_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_RED_F2": "Master's Fragment of Valor",
    "T6_FRAGMENT_RED_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FRAGMENT_RED_F3": "Master's Shard of Valor",
    "T6_FRAGMENT_RED_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T6_FURNITUREITEM_BATTLEVAULT": "Master's Battlevault",
    "T6_FURNITUREITEM_BATTLEVAULT_DESC": "A 32-slot battlevault with a 965 kg limit. Must be placed indoors.",
    "T6_FURNITUREITEM_BED": "Master's Bed",
    "T6_FURNITUREITEM_BED_DESC": "Increases maximum residents in the house by 1, and contributes to Laborer happiness. Item can only be placed indoors.",
    "T6_FURNITUREITEM_REPAIRKIT": "Master's Repair Kit",
    "T6_FURNITUREITEM_REPAIRKIT_DESC": "Repair kits are used to repair gear in the wild, however the repair fee is twice as high.",
    "T6_FURNITUREITEM_TABLE": "Master's Table",
    "T6_FURNITUREITEM_TABLE_DESC": "Contributes to Laborer happiness. Item can only be placed indoors.",
    "T6_FURNITUREITEM_TROPHY_FIBER": "Comfy Redleaf Cotton Trophy",
    "T6_FURNITUREITEM_TROPHY_FISH": "Zander Trophy",
    "T6_FURNITUREITEM_TROPHY_GENERAL": "Encyclopedia of Power",
    "T6_FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all Laborers.",
    "T6_FURNITUREITEM_TROPHY_HIDE": "Stuffed Direwolf Head",
    "T6_FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to all Gamekeeper Laborers.",
    "T6_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK": "Trophy: Tome of Knowledge",
    "T6_FURNITUREITEM_TROPHY_MAGICRESISTANCEBOOK_DESC": "Provides an increase to Magic Resist. Must be placed in a player house",
    "T6_FURNITUREITEM_TROPHY_MAGICWEAPON": "Trophy: Greater Demon's Hand Fragment",
    "T6_FURNITUREITEM_TROPHY_MAGICWEAPON_DESC": "Item can only be placed in your house. Increases your Magical Auto-Attack damage.",
    "T6_FURNITUREITEM_TROPHY_MERCENARY": "Master Mercenary's Trophy",
    "T6_FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to all Mercenary Laborers.",
    "T6_FURNITUREITEM_TROPHY_MOB": "Trophy: Direwolf's Head",
    "T6_FURNITUREITEM_TROPHY_MOB_DESC": "Provides an increase to maximum carrying capacity. Must be placed in a player house.",
    "T6_FURNITUREITEM_TROPHY_ORE": "Runite Ore Sample",
    "T6_FURNITUREITEM_TROPHY_PHYSICALARMOR": "Trophy: Heavy Armor",
    "T6_FURNITUREITEM_TROPHY_PHYSICALARMOR_DESC": "Provides an increase to Armor. Must be placed in a player house.",
    "T6_FURNITUREITEM_TROPHY_PHYSICALWEAPON": "Trophy: Heavy Weapon",
    "T6_FURNITUREITEM_TROPHY_PHYSICALWEAPON_DESC": "Provides an increase to Physical Auto-Attack damage. Must be placed in a player house.",
    "T6_FURNITUREITEM_TROPHY_ROCK": "Slate Fragment",
    "T6_FURNITUREITEM_TROPHY_WOOD": "Bloodoak Bonsai",
    "T6_GEM_EMERALD": "Extraordinary Emerald",
    "T6_GEM_EMERALD_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T6_GEM_RUBY": "Extraordinary Ruby",
    "T6_GEM_RUBY_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T6_GEM_SAPPHIRE": "Extraordinary Sapphire",
    "T6_GEM_SAPPHIRE_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T6_GVGSEASONREWARD_FAMEBUFF": "Master's Knight Vow",
    "T6_GVGSEASONREWARD_FAMEBUFF_DESC": "Increases Fame from defeating creatures and gathering resources by 3% for 90 days",
    "T6_HEAD_CLOTH_AVALON": "Master's Cowl of Purity",
    "T6_HEAD_CLOTH_HELL": "Master's Fiend Cowl",
    "T6_HEAD_CLOTH_HELL_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_KEEPER": "Master's Druid Cowl",
    "T6_HEAD_CLOTH_KEEPER_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_MORGANA": "Master's Cultist Cowl",
    "T6_HEAD_CLOTH_MORGANA_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_ROYAL": "Master's Royal Cowl",
    "T6_HEAD_CLOTH_ROYAL_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_SET1": "Master's Scholar Cowl",
    "T6_HEAD_CLOTH_SET1_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_SET1_ENCHANTED": "Enchanted Master's Scholar Cowl",
    "T6_HEAD_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_SET2": "Master's Cleric Cowl",
    "T6_HEAD_CLOTH_SET2_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_SET2_ENCHANTED": "Enchanted Master's Cleric Cowl",
    "T6_HEAD_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_SET3": "Master's Mage Cowl",
    "T6_HEAD_CLOTH_SET3_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_SET3_ENCHANTED": "Enchanted Master's Mage Cowl",
    "T6_HEAD_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_CLOTH_UNDEAD": "Undead Cloth Hood",
    "T6_HEAD_CLOTH_UNDEAD_DESC": "Equipment Item",
    "T6_HEAD_GATHERER_FIBER": "Master's Harvester Cap",
    "T6_HEAD_GATHERER_FIBER_DESC": "Equipment Item",
    "T6_HEAD_GATHERER_FISH": "Master's Fisherman Cap",
    "T6_HEAD_GATHERER_FISH_DESC": "Equipment Item",
    "T6_HEAD_GATHERER_HIDE": "Master's Skinner Cap",
    "T6_HEAD_GATHERER_HIDE_DESC": "Equipment Item",
    "T6_HEAD_GATHERER_ORE": "Master's Miner Cap",
    "T6_HEAD_GATHERER_ORE_DESC": "Equipment Item",
    "T6_HEAD_GATHERER_ROCK": "Master's Quarrier Cap",
    "T6_HEAD_GATHERER_ROCK_DESC": "Equipment Item",
    "T6_HEAD_GATHERER_WOOD": "Master's Lumberjack Cap",
    "T6_HEAD_GATHERER_WOOD_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_AVALON": "Master's Hood of Tenacity",
    "T6_HEAD_LEATHER_HELL": "Master's Hellion Hood",
    "T6_HEAD_LEATHER_HELL_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_KEEPER": "Keeper Leather Hood",
    "T6_HEAD_LEATHER_KEEPER_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_MORGANA": "Master's Stalker Hood",
    "T6_HEAD_LEATHER_MORGANA_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_ROYAL": "Master's Royal Hood",
    "T6_HEAD_LEATHER_ROYAL_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_SET1": "Master's Mercenary Hood",
    "T6_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_SET1_ENCHANTED": "Enchanted Master's Mercenary Hood",
    "T6_HEAD_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_SET2": "Master's Hunter Hood",
    "T6_HEAD_LEATHER_SET2_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_SET2_ENCHANTED": "Enchanted Master's Hunter Hood",
    "T6_HEAD_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_SET3": "Master's Assassin Hood",
    "T6_HEAD_LEATHER_SET3_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_SET3_ENCHANTED": "Enchanted Master's Assassin Hood",
    "T6_HEAD_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_LEATHER_UNDEAD": "Master's Specter Hood",
    "T6_HEAD_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T6_HEAD_PLATE_AVALON": "Master's Helmet of Valor",
    "T6_HEAD_PLATE_HELL": "Master's Demon Helmet",
    "T6_HEAD_PLATE_HELL_DESC": "Equipment Item",
    "T6_HEAD_PLATE_KEEPER": "Master's Judicator Helmet",
    "T6_HEAD_PLATE_KEEPER_DESC": "Equipment Item",
    "T6_HEAD_PLATE_MORGANA": "Morgana Plate Helm",
    "T6_HEAD_PLATE_MORGANA_DESC": "Equipment Item",
    "T6_HEAD_PLATE_ROYAL": "Master's Royal Helmet",
    "T6_HEAD_PLATE_ROYAL_DESC": "Equipment Item",
    "T6_HEAD_PLATE_SET1": "Master's Soldier Helmet",
    "T6_HEAD_PLATE_SET1_DESC": "Equipment Item",
    "T6_HEAD_PLATE_SET1_ENCHANTED": "Enchanted Master's Soldier Helmet",
    "T6_HEAD_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_PLATE_SET2": "Master's Knight Helmet",
    "T6_HEAD_PLATE_SET2_DESC": "Equipment Item",
    "T6_HEAD_PLATE_SET2_ENCHANTED": "Enchanted Master's Knight Helmet",
    "T6_HEAD_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_PLATE_SET3": "Master's Guardian Helmet",
    "T6_HEAD_PLATE_SET3_DESC": "Equipment Item",
    "T6_HEAD_PLATE_SET3_ENCHANTED": "Enchanted Master's Guardian Helmet",
    "T6_HEAD_PLATE_SET3_ENCHANTED_DESC": "Equipment Item",
    "T6_HEAD_PLATE_UNDEAD": "Master's Graveguard Helmet",
    "T6_HEAD_PLATE_UNDEAD_DESC": "Equipment Item",
    "T6_HIDE": "Robust Hide",
    "T6_HIDE_DESC": "Hide used for crafting. Can be refined into leather or transmuted into higher-level material.",
    "T6_HIDE_LEVEL1": "Uncommon Robust Hide",
    "T6_HIDE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_HIDE_LEVEL2": "Rare Robust Hide",
    "T6_HIDE_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_HIDE_LEVEL3": "Exceptional Robust Hide",
    "T6_HIDE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_HIDE_LEVEL4": "Legendary Robust Hide",
    "T6_HIDE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_HIDE_LEVEL5": "Mythical Robust Hide",
    "T6_HIDE_LEVEL5_DESC": "Mythical material used for crafting.",
    "T6_JOURNAL_FIBER": "Master Cropper's Journal (Partially Full)",
    "T6_JOURNAL_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_FIBER_EMPTY": "Master Cropper's Journal (Empty)",
    "T6_JOURNAL_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_FIBER_FULL": "Master Cropper's Journal (Full)",
    "T6_JOURNAL_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_FISHING": "Master Fisherman's Journal (Partially Full)",
    "T6_JOURNAL_FISHING_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_FISHING_EMPTY": "Master Fisherman's Journal (Empty)",
    "T6_JOURNAL_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_FISHING_FULL": "Master Fisherman's Journal (Full)",
    "T6_JOURNAL_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_HIDE": "Master Gamekeeper's Journal (Partially Full)",
    "T6_JOURNAL_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_HIDE_EMPTY": "Master Gamekeeper's Journal (Empty)",
    "T6_JOURNAL_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_HIDE_FULL": "Master Gamekeeper's Journal (Full)",
    "T6_JOURNAL_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_HUNTER": "Master Fletcher's Journal (Partially Full)",
    "T6_JOURNAL_HUNTER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_HUNTER_EMPTY": "Master Fletcher's Journal (Empty)",
    "T6_JOURNAL_HUNTER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_HUNTER_FULL": "Master Fletcher's Journal (Full)",
    "T6_JOURNAL_HUNTER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_MAGE": "Master Imbuer's Journal (Partially Full)",
    "T6_JOURNAL_MAGE_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_MAGE_EMPTY": "Master Imbuer's Journal (Empty)",
    "T6_JOURNAL_MAGE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_MAGE_FULL": "Master Imbuer's Journal (Full)",
    "T6_JOURNAL_MAGE_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_MERCENARY": "Master Mercenary's Journal (Partially Full)",
    "T6_JOURNAL_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_MERCENARY_EMPTY": "Master Mercenary's Journal (Empty)",
    "T6_JOURNAL_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_MERCENARY_FULL": "Master Mercenary's Journal (Full)",
    "T6_JOURNAL_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_ORE": "Master Prospector's Journal (Partially Full)",
    "T6_JOURNAL_ORE_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_ORE_EMPTY": "Master Prospector's Journal (Empty)",
    "T6_JOURNAL_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_ORE_FULL": "Master Prospector's Journal (Full)",
    "T6_JOURNAL_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_STONE": "Master Stonecutter's Journal (Partially Full)",
    "T6_JOURNAL_STONE_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_STONE_EMPTY": "Master Stonecutter's Journal (Empty)",
    "T6_JOURNAL_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_STONE_FULL": "Master Stonecutter's Journal (Full)",
    "T6_JOURNAL_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TOOLMAKER": "Master Tinker's Journal (Partially Full)",
    "T6_JOURNAL_TOOLMAKER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TOOLMAKER_EMPTY": "Master Tinker's Journal (Empty)",
    "T6_JOURNAL_TOOLMAKER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TOOLMAKER_FULL": "Master Tinker's Journal (Full)",
    "T6_JOURNAL_TOOLMAKER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_FIBER": "Master Cropper's Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_FIBER_EMPTY": "Master Cropper's Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_FIBER_FULL": "Master Cropper's Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_FISHING": "Master Fisherman's Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_FISHING_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_FISHING_EMPTY": "Master Fisherman's Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_FISHING_FULL": "Master Fisherman's Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_GENERAL": "Master's Generalist Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_GENERAL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_GENERAL_EMPTY": "Master's Generalist Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_GENERAL_EMPTY_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_GENERAL_FULL": "Master's Generalist Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_GENERAL_FULL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_HIDE": "Master Gamekeeper's Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_HIDE_EMPTY": "Master Gamekeeper's Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_HIDE_FULL": "Master Gamekeeper's Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_MERCENARY": "Master Mercenary's Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_MERCENARY_EMPTY": "Master Mercenary's Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_MERCENARY_FULL": "Master Mercenary's Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_ORE": "Master Prospector's Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_ORE_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_ORE_EMPTY": "Master Prospector's Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_ORE_FULL": "Master Prospector's Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_STONE": "Master Stonecutter's Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_STONE_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_STONE_EMPTY": "Master Stonecutter's Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_STONE_FULL": "Master Stonecutter's Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_WOOD": "Master Lumberjack's Trophy Journal (Partially Full)",
    "T6_JOURNAL_TROPHY_WOOD_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_WOOD_EMPTY": "Master Lumberjack's Trophy Journal (Empty)",
    "T6_JOURNAL_TROPHY_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_TROPHY_WOOD_FULL": "Master Lumberjack's Trophy Journal (Full)",
    "T6_JOURNAL_TROPHY_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_WARRIOR": "Master Blacksmith's Journal (Partially Full)",
    "T6_JOURNAL_WARRIOR_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_WARRIOR_EMPTY": "Master Blacksmith's Journal (Empty)",
    "T6_JOURNAL_WARRIOR_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_WARRIOR_FULL": "Master Blacksmith's Journal (Full)",
    "T6_JOURNAL_WARRIOR_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_WOOD": "Master Lumberjack's Journal (Partially Full)",
    "T6_JOURNAL_WOOD_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_WOOD_EMPTY": "Master Lumberjack's Journal (Empty)",
    "T6_JOURNAL_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_JOURNAL_WOOD_FULL": "Master Lumberjack's Journal (Full)",
    "T6_JOURNAL_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T6_LABOURER_CONTRACT_FIBER": "Master Cropper Contract",
    "T6_LABOURER_CONTRACT_FIBER_DESC": "Croppers require filled Cropper's Journals and gather fiber.",
    "T6_LABOURER_CONTRACT_FISHERMAN": "Master Fisherman Contract",
    "T6_LABOURER_CONTRACT_FISHERMAN_DESC": "Fishermen require filled Fisherman's Journals and catch fish.",
    "T6_LABOURER_CONTRACT_HIDE": "Master Gamekeeper Contract",
    "T6_LABOURER_CONTRACT_HIDE_DESC": "Gamekeepers require filled Gamekeeper's Journals and gather hide.",
    "T6_LABOURER_CONTRACT_HUNTER": "Master Fletcher Contract",
    "T6_LABOURER_CONTRACT_HUNTER_DESC": "Fletchers require filled Fletcher's Journals and gather various refined materials.",
    "T6_LABOURER_CONTRACT_MAGE": "Master Imbuer Contract",
    "T6_LABOURER_CONTRACT_MAGE_DESC": "Imbuers require filled Imbuer's Journals and gather various refined materials.",
    "T6_LABOURER_CONTRACT_MERCENARY": "Master Mercenary Contract",
    "T6_LABOURER_CONTRACT_MERCENARY_DESC": "Mercenaries require filled Mercenary's Journals' and gather Silver.",
    "T6_LABOURER_CONTRACT_ORE": "Master Prospector Contract",
    "T6_LABOURER_CONTRACT_ORE_DESC": "Prospectors require filled Prospector's Journals and gather ore.",
    "T6_LABOURER_CONTRACT_STONE": "Master Stonecutter Contract",
    "T6_LABOURER_CONTRACT_STONE_DESC": "Stonecutters require filled Stonecutter's Journals and gather stone.",
    "T6_LABOURER_CONTRACT_TOOLMAKER": "Master Tinker Contract",
    "T6_LABOURER_CONTRACT_TOOLMAKER_DESC": "Tinkers require filled Tinker's Journals and gather various refined materials.",
    "T6_LABOURER_CONTRACT_WARRIOR": "Master Blacksmith Contract",
    "T6_LABOURER_CONTRACT_WARRIOR_DESC": "Blacksmiths require filled Blacksmith's Journals and gather various refined materials.",
    "T6_LABOURER_CONTRACT_WOOD": "Master Lumberjack Contract",
    "T6_LABOURER_CONTRACT_WOOD_DESC": "Lumberjacks require filled Lumberjack's Journals and gather wood.",
    "T6_LEATHER": "Hardened Leather",
    "T6_LEATHER_DESC": "Advanced material used in crafting, created by refining hide.",
    "T6_LEATHER_LEVEL1": "Uncommon Hardened Leather",
    "T6_LEATHER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_LEATHER_LEVEL2": "Rare Hardened Leather",
    "T6_LEATHER_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_LEATHER_LEVEL3": "Exceptional Hardened Leather",
    "T6_LEATHER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_LEATHER_LEVEL4": "Legendary Hardened Leather",
    "T6_LEATHER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_LEATHER_LEVEL5": "Mythical Hardened Leather",
    "T6_LEATHER_LEVEL5_DESC": "Mythical material used for crafting.",
    "T6_LOOTCHEST_CRYSTAL_LEAGUE": "Master's Crystal League Chest",
    "T6_MAIN_1HCROSSBOW": "Master's Light Crossbow",
    "T6_MAIN_1HCROSSBOW_DESC": "Equipment Item",
    "T6_MAIN_ARCANESTAFF": "Master's Arcane Staff",
    "T6_MAIN_ARCANESTAFF_DESC": "Equipment Item",
    "T6_MAIN_ARCANESTAFF_ENCHANTED": "Master's Enchanted Arcane Staff",
    "T6_MAIN_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_ARCANESTAFF_UNDEAD": "Master's Witchwork Staff",
    "T6_MAIN_ARCANESTAFF_UNDEAD_DESC": "Equipment Item",
    "T6_MAIN_AXE": "Master's Battleaxe",
    "T6_MAIN_AXE_DESC": "Equipment Item",
    "T6_MAIN_AXE_ENCHANTED": "Master's Enchanted Battleaxe",
    "T6_MAIN_AXE_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_AXE_KEEPER": "Keeper Axe",
    "T6_MAIN_AXE_KEEPER_DESC": "Equipment Item",
    "T6_MAIN_CROSSBOW_ENCHANTED": "Master's Enchanted Crossbow",
    "T6_MAIN_CROSSBOW_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_CURSEDSTAFF": "Master's Cursed Staff",
    "T6_MAIN_CURSEDSTAFF_AVALON": "Master's Shadowcaller",
    "T6_MAIN_CURSEDSTAFF_AVALON_DESC": "Equipment Item",
    "T6_MAIN_CURSEDSTAFF_DESC": "Equipment Item",
    "T6_MAIN_CURSEDSTAFF_ENCHANTED": "Master's Enchanted Cursed Staff",
    "T6_MAIN_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_CURSEDSTAFF_UNDEAD": "Master's Lifecurse Staff",
    "T6_MAIN_CURSEDSTAFF_UNDEAD_DESC": "Equipment Item",
    "T6_MAIN_DAGGER": "Master's Dagger",
    "T6_MAIN_DAGGER_DESC": "Equipment Item",
    "T6_MAIN_DAGGER_ENCHANTED": "Master's Enchanted Dagger",
    "T6_MAIN_DAGGER_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_FIRESTAFF": "Master's Fire Staff",
    "T6_MAIN_FIRESTAFF_DESC": "Equipment Item",
    "T6_MAIN_FIRESTAFF_ENCHANTED": "Master's Enchanted Fire Staff",
    "T6_MAIN_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_FIRESTAFF_KEEPER": "Master's Wildfire Staff",
    "T6_MAIN_FIRESTAFF_KEEPER_DESC": "Equipment Item",
    "T6_MAIN_FROSTSTAFF": "Master's Frost Staff",
    "T6_MAIN_FROSTSTAFF_AVALON": "Master's Chillhowl",
    "T6_MAIN_FROSTSTAFF_AVALON_DESC": "Equipment Item",
    "T6_MAIN_FROSTSTAFF_DESC": "Equipment Item",
    "T6_MAIN_FROSTSTAFF_ENCHANTED": "Master's Enchanted Frost Staff",
    "T6_MAIN_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_FROSTSTAFF_KEEPER": "Master's Hoarfrost Staff",
    "T6_MAIN_FROSTSTAFF_KEEPER_DESC": "Equipment Item",
    "T6_MAIN_FROSTSTAFF_UNDEAD": "Undead Staff",
    "T6_MAIN_FROSTSTAFF_UNDEAD_DESC": "Equipment Item",
    "T6_MAIN_HAMMER": "Master's Hammer",
    "T6_MAIN_HAMMER_DESC": "Equipment Item",
    "T6_MAIN_HAMMER_ENCHANTED": "Master's Enchanted Hammer",
    "T6_MAIN_HAMMER_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_HOLYSTAFF": "Master's Holy Staff",
    "T6_MAIN_HOLYSTAFF_AVALON": "Master's Hallowfall",
    "T6_MAIN_HOLYSTAFF_AVALON_DESC": "Equipment Item",
    "T6_MAIN_HOLYSTAFF_DESC": "Equipment Item",
    "T6_MAIN_HOLYSTAFF_ENCHANTED": "Master's Enchanted Holy Staff",
    "T6_MAIN_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_HOLYSTAFF_MORGANA": "Master's Lifetouch Staff",
    "T6_MAIN_HOLYSTAFF_MORGANA_DESC": "Equipment Item",
    "T6_MAIN_MACE": "Master's Mace",
    "T6_MAIN_MACE_DESC": "Equipment Item",
    "T6_MAIN_MACE_ENCHANTED": "Master's Enchanted Mace",
    "T6_MAIN_MACE_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_MACE_HELL": "Master's Incubus Mace",
    "T6_MAIN_MACE_HELL_DESC": "Equipment Item",
    "T6_MAIN_MACE_MORGANA": "Morgana Mace",
    "T6_MAIN_MACE_MORGANA_DESC": "Equipment Item",
    "T6_MAIN_NATURESTAFF": "Master's Nature Staff",
    "T6_MAIN_NATURESTAFF_AVALON": "Master's Ironroot Staff",
    "T6_MAIN_NATURESTAFF_AVALON_DESC": "Equipment Item",
    "T6_MAIN_NATURESTAFF_DESC": "Equipment Item",
    "T6_MAIN_NATURESTAFF_ENCHANTED": "Master's Enchanted Nature Staff",
    "T6_MAIN_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_NATURESTAFF_KEEPER": "Master's Druidic Staff",
    "T6_MAIN_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T6_MAIN_RAPIER_MORGANA": "Master's Bloodletter",
    "T6_MAIN_RAPIER_MORGANA_DESC": "Equipment Item",
    "T6_MAIN_REPEATINGCROSSBOW": "Master's Repeating Crossbow",
    "T6_MAIN_REPEATINGCROSSBOW_DESC": "Equipment Item",
    "T6_MAIN_REPEATINGCROSSBOW_ENCHANTED": "Master's Enchanted Repeating Crossbow",
    "T6_MAIN_REPEATINGCROSSBOW_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_ROCKMACE_KEEPER": "Master's Bedrock Mace",
    "T6_MAIN_ROCKMACE_KEEPER_DESC": "Equipment Item",
    "T6_MAIN_SCIMITAR_MORGANA": "Master's Clarent Blade",
    "T6_MAIN_SCIMITAR_MORGANA_DESC": "Equipment Item",
    "T6_MAIN_SPEAR": "Master's Spear",
    "T6_MAIN_SPEAR_DESC": "Equipment Item",
    "T6_MAIN_SPEAR_ENCHANTED": "Master's Enchanted Spear",
    "T6_MAIN_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_SPEAR_KEEPER": "Master's Heron Spear",
    "T6_MAIN_SPEAR_KEEPER_DESC": "Equipment Item",
    "T6_MAIN_SPEAR_LANCE_AVALON": "Master's Daybreaker",
    "T6_MAIN_SPEAR_LANCE_AVALON_DESC": "Equipment Item",
    "T6_MAIN_SWORD": "Master's Broadsword",
    "T6_MAIN_SWORD_DESC": "Equipment Item",
    "T6_MAIN_SWORD_ENCHANTED": "Master's Enchanted Broadsword",
    "T6_MAIN_SWORD_ENCHANTED_DESC": "Equipment Item",
    "T6_MAIN_SWORD_UNDEAD": "Undead Sword",
    "T6_MAIN_SWORD_UNDEAD_DESC": "Equipment Item",
    "T6_MEAL_SALAD": "Potato Salad",
    "T6_MEAL_SALAD_DESC": "Simple snack that increases crafting speed and quality for a short period.",
    "T6_MEAL_SALAD_FISH": "Deepwater Kraken Salad",
    "T6_MEAL_SANDWICH": "Mutton Sandwich",
    "T6_MEAL_SANDWICH_AVALON": "Avalonian Mutton Sandwich",
    "T6_MEAL_SANDWICH_AVALON_DESC": "Avalonian meal that increases maximum health and CC Duration for a long period.",
    "T6_MEAL_SANDWICH_DESC": "Sophisticated meal that increases maximum health for a long period.",
    "T6_MEAL_SANDWICH_FISH": "Rushwater Lurcher Sandwich",
    "T6_MEAL_STEW": "Mutton Stew",
    "T6_MEAL_STEW_AVALON": "Avalonian Mutton Stew",
    "T6_MEAL_STEW_AVALON_DESC": "Avalonian meal that increases combat damage and health regeneration for a long period.",
    "T6_MEAL_STEW_DESC": "Sophisticated meal that increases combat damage for a long period.",
    "T6_MEAL_STEW_FISH": "Redspring Eel Stew",
    "T6_MEAT": "Raw Mutton",
    "T6_MEAT_DESC": "Cooking ingredient, used in various recipes.",
    "T6_METALBAR": "Runite Steel Bar",
    "T6_METALBAR_DESC": "Advanced material used in crafting, created by refining ore.",
    "T6_METALBAR_LEVEL1": "Uncommon Runite Steel Bar",
    "T6_METALBAR_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_METALBAR_LEVEL2": "Rare Runite Steel Bar",
    "T6_METALBAR_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_METALBAR_LEVEL3": "Exceptional Runite Steel Bar",
    "T6_METALBAR_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_METALBAR_LEVEL4": "Legendary Runite Steel Bar",
    "T6_METALBAR_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_METALBAR_LEVEL5": "Mythical Runite Steel Bar",
    "T6_METALBAR_LEVEL5_DESC": "Mythical material used for crafting.",
    "T6_MILK": "Sheep's Milk",
    "T6_MILK_DESC": "Sheep's Milk is used in various meals and potions, and can be turned into Sheep's Butter",
    "T6_MOBDROP_ARMOR": "Heavy Armor Fragment",
    "T6_MOBDROP_ARMOR_DESC": "Use to craft a trophy you can place in your house.",
    "T6_MOBDROP_BOOK": "Pages from the Tome of Knowledge",
    "T6_MOBDROP_BOOK_DESC": "Use to craft a trophy you can place in your house.",
    "T6_MOBDROP_DIREWOLF_HEAD": "Direwolf's Head",
    "T6_MOBDROP_DIREWOLF_HEAD_DESC": "Use to craft a trophy you can place in your house.",
    "T6_MOBDROP_MACE": "Heavy Weapon Fragment",
    "T6_MOBDROP_MACE_DESC": "Use to craft a trophy you can place in your house.",
    "T6_MOBDROP_MORGANA_HAND": "Greater Demon's Hand Fragment",
    "T6_MOBDROP_MORGANA_HAND_DESC": "Use to craft a trophy you can place in your house.",
    "T6_MOUNT_ARMORED_HORSE": "Master's Armored Horse",
    "T6_MOUNT_ARMORED_HORSE_DESC": "Protected by thick plating, an armored horse is ideal for traveling through Albion's more dangerous regions at speed.",
    "T6_MOUNT_ARMORED_HORSE_SKIN_01": "Master's Warhorse",
    "T6_MOUNT_ARMORED_HORSE_SKIN_01_DESC": "An armored horse bearing the impressive banner of its rider's guild. Ideal for raising morale in big battles.",
    "T6_MOUNT_CHAMELEON_ADC": "Giant Chameleon",
    "T6_MOUNT_CHAMELEON_ADC_DESC": "Adventurer's Challenge Reward - This chameleon is master of disguise, changing its skin color makes it invisible to enemy eyes.",
    "T6_MOUNT_DIREWOLF": "Direwolf",
    "T6_MOUNT_DIREWOLF_DESC": "One of Albion's fastest mounts, the Direwolf specializes in hunting, pursuit, and evasion.",
    "T6_MOUNT_DIREWOLF_SPECTER": "Specter Wolf",
    "T6_MOUNT_DIREWOLF_SPECTER_DESC": "Mount - A materialized spirit of a Direwolf.",
    "T6_MOUNT_DIREWOLF_WHITE": "Ghostwolf",
    "T6_MOUNT_DIREWOLF_WHITE_DESC": "A rare, pure-white direwolf.",
    "T6_MOUNT_FROSTRAM_ADC": "Frost Ram",
    "T6_MOUNT_FROSTRAM_ADC_DESC": "Adventurer's Challenge Reward - This mount's skillful leap makes it hard to catch.",
    "T6_MOUNT_GIANTSTAG": "Master's Giant Stag",
    "T6_MOUNT_GIANTSTAG_DESC": "Stags are fast and strong, making them favored mounts of gatherers and couriers.",
    "T6_MOUNT_GIANTSTAG_XMAS": "Yule Stag",
    "T6_MOUNT_GIANTSTAG_XMAS_DESC": "The Yule Stag shows its owner's respect for Yuletide, celebrating the time of Midwinter when the Fey are closest to Albion.",
    "T6_MOUNT_HORSE": "Master's Riding Horse",
    "T6_MOUNT_HORSE_DESC": "Lean and agile, Albion horses can carry their riders quickly across the continent, but have little strength to bear heavy items.",
    "T6_MOUNT_OX": "Master's Transport Ox",
    "T6_MOUNT_OX_DESC": "Albion oxen are tough, and sturdy enough to carry large quantities of goods, but cannot match the pace of the continent's horses.",
    "T6_MOUNT_SIEGE_BALLISTA": "Siege Ballista",
    "T6_MOUNT_SIEGE_BALLISTA_DESC": "Battle Mount - Immune to displacement effects.",
    "T6_MOUNT_SIEGE_BALLISTA_LEGACY": "Siege Ballista (Legacy)",
    "T6_MOUNT_SIEGE_BALLISTA_LEGACY_DESC": "This item was crafted before an economic update. Can be exchanged for its original energy value for a limited time.",
    "T6_MOUNTUPGRADE_GIANTSTAG_XMAS": "Decorative Stag Bridle",
    "T6_MOUNTUPGRADE_GIANTSTAG_XMAS_DESC": "This bridle allows you to decorate a Giant Stag for Yuletide.",
    "T6_OFF_BOOK": "Master's Tome of Spells",
    "T6_OFF_BOOK_DESC": "Equipment Item",
    "T6_OFF_BOOK_ENCHANTED": "Master's Enchanted Tome of Spells",
    "T6_OFF_BOOK_ENCHANTED_DESC": "Equipment Item",
    "T6_OFF_BOOK_UNDEAD": "Undead Tome of Spells",
    "T6_OFF_BOOK_UNDEAD_DESC": "Equipment Item",
    "T6_OFF_CENSER_AVALON": "Master's Celestial Censer",
    "T6_OFF_CENSER_AVALON_DESC": "Equipment Item",
    "T6_OFF_DEMONSKULL_HELL": "Master's Muisak",
    "T6_OFF_DEMONSKULL_HELL_DESC": "Equipment Item",
    "T6_OFF_HORN_KEEPER": "Master's Mistcaller",
    "T6_OFF_HORN_KEEPER_DESC": "Equipment Item",
    "T6_OFF_JESTERCANE_HELL": "Master's Leering Cane",
    "T6_OFF_JESTERCANE_HELL_DESC": "Equipment Item",
    "T6_OFF_LAMP_UNDEAD": "Master's Cryptcandle",
    "T6_OFF_LAMP_UNDEAD_DESC": "Equipment Item",
    "T6_OFF_ORB_MORGANA": "Master's Eye of Secrets",
    "T6_OFF_ORB_MORGANA_DESC": "Equipment Item",
    "T6_OFF_SHIELD": "Master's Shield",
    "T6_OFF_SHIELD_AVALON": "Master's Astral Aegis",
    "T6_OFF_SHIELD_AVALON_DESC": "Equipment Item",
    "T6_OFF_SHIELD_DESC": "Equipment Item",
    "T6_OFF_SHIELD_ENCHANTED": "Master's Enchanted Shield",
    "T6_OFF_SHIELD_ENCHANTED_DESC": "Equipment Item",
    "T6_OFF_SHIELD_HELL": "Master's Caitiff Shield",
    "T6_OFF_SHIELD_HELL_DESC": "Equipment Item",
    "T6_OFF_SPIKEDSHIELD_MORGANA": "Master's Facebreaker",
    "T6_OFF_SPIKEDSHIELD_MORGANA_DESC": "Equipment Item",
    "T6_OFF_TALISMAN_AVALON": "Master's Sacred Scepter",
    "T6_OFF_TALISMAN_AVALON_DESC": "Equipment Item",
    "T6_OFF_TORCH": "Master's Torch",
    "T6_OFF_TORCH_DESC": "Equipment Item",
    "T6_OFF_TORCH_ENCHANTED": "Master's Enchanted Torch",
    "T6_OFF_TORCH_ENCHANTED_DESC": "Equipment Item",
    "T6_OFF_TOTEM_KEEPER": "Master's Taproot",
    "T6_OFF_TOTEM_KEEPER_DESC": "Equipment Item",
    "T6_OFF_TOWERSHIELD_UNDEAD": "Master's Sarcophagus",
    "T6_OFF_TOWERSHIELD_UNDEAD_DESC": "Equipment Item",
    "T6_ORE": "Runite Ore",
    "T6_ORE_DESC": "Ore used for crafting. Can be refined into metal bars or transmuted into higher-level material.",
    "T6_ORE_LEVEL1": "Uncommon Runite Ore",
    "T6_ORE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_ORE_LEVEL2": "Rare Runite Ore",
    "T6_ORE_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_ORE_LEVEL3": "Exceptional Runite Ore",
    "T6_ORE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_ORE_LEVEL4": "Legendary Runite Ore",
    "T6_ORE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_ORE_LEVEL5": "Mythical Runite Ore",
    "T6_ORE_LEVEL5_DESC": "Mythical material used for crafting.",
    "T6_PLANKS": "Bloodoak Planks",
    "T6_PLANKS_DESC": "Advanced material used in crafting, created by refining logs.",
    "T6_PLANKS_LEVEL1": "Uncommon Bloodoak Planks",
    "T6_PLANKS_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_PLANKS_LEVEL2": "Rare Bloodoak Planks",
    "T6_PLANKS_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_PLANKS_LEVEL3": "Exceptional Bloodoak Planks",
    "T6_PLANKS_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_PLANKS_LEVEL4": "Legendary Bloodoak Planks",
    "T6_PLANKS_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_PLANKS_LEVEL5": "Mythical Bloodoak Planks",
    "T6_PLANKS_LEVEL5_DESC": "Mythic material used for crafting.",
    "T6_POTATO": "Potatoes",
    "T6_POTATO_DESC": "Potatoes are used in a variety of meals",
    "T6_POTION_COOLDOWN": "Poison Potion",
    "T6_POTION_COOLDOWN_DESC": "Poisoned Potion. Can be thrown at enemies to poison them.",
    "T6_POTION_ENERGY": "Major Energy Potion",
    "T6_POTION_ENERGY_DESC": "Fizzing potion. Instantly restores some energy.",
    "T6_POTION_HEAL": "Major Healing Potion",
    "T6_POTION_HEAL_DESC": "Glowing potion. Restores some health over time.",
    "T6_RANDOM_DUNGEON_ELITE_TOKEN_1": "Master's Dungeon Map (Large Group)",
    "T6_RANDOM_DUNGEON_ELITE_TOKEN_2": "Uncommon Master's Dungeon Map (Large Group)",
    "T6_RANDOM_DUNGEON_ELITE_TOKEN_3": "Rare Master's Dungeon Map (Large Group)",
    "T6_RANDOM_DUNGEON_ELITE_TOKEN_4": "Exceptional Master's Dungeon Map (Large Group)",
    "T6_RANDOM_DUNGEON_SOLO_TOKEN_1": "Master's Dungeon Map (Solo)",
    "T6_RANDOM_DUNGEON_SOLO_TOKEN_2": "Uncommon Master's Dungeon Map (Solo)",
    "T6_RANDOM_DUNGEON_SOLO_TOKEN_3": "Rare Master's Dungeon Map (Solo)",
    "T6_RANDOM_DUNGEON_SOLO_TOKEN_4": "Exceptional Master's Dungeon Map (Solo)",
    "T6_RANDOM_DUNGEON_TOKEN_1": "Master's Dungeon Map (Group)",
    "T6_RANDOM_DUNGEON_TOKEN_2": "Uncommon Master's Dungeon Map (Group)",
    "T6_RANDOM_DUNGEON_TOKEN_3": "Rare Master's Dungeon Map (Group)",
    "T6_RANDOM_DUNGEON_TOKEN_4": "Exceptional Master's Dungeon Map (Group)",
    "T6_RELIC": "Master's Relic",
    "T6_RELIC_DESC": "An ancient relic, used to meld artifacts and enchant equipment.",
    "T6_RELIC_DESTRUCTION": "Timeworn Relic of Destruction",
    "T6_RELIC_DESTRUCTION_DESC": "Special material used in crafting. It can be transmuted into a better relic.",
    "T6_RELIC_MANIPULATION": "Timeworn Relic of Manipulation",
    "T6_RELIC_MANIPULATION_DESC": "Special material used in crafting. It can be transmuted into a better relic.",
    "T6_RELIC_PROTECTION": "Timeworn Relic of Protection",
    "T6_RELIC_PROTECTION_DESC": "Special material used in crafting. It can be transmuted into a better relic.",
    "T6_ROCK": "Slate",
    "T6_ROCK_DESC": "Stone used for crafting. Can be refined into stone blocks or transmuted into higher-level material.",
    "T6_ROCK_LEVEL1": "Uncommon Slate",
    "T6_ROCK_LEVEL1_DESC": "Uncommon stone, more efficient in refining.",
    "T6_ROCK_LEVEL2": "Rare Slate",
    "T6_ROCK_LEVEL2_DESC": "Rare stone, more efficient in refining.",
    "T6_ROCK_LEVEL3": "Exceptional Slate",
    "T6_ROCK_LEVEL3_DESC": "Exceptional stone, more efficient in refining.",
    "T6_RUNE": "Master's Rune",
    "T6_RUNE_DESC": "A pulsing rune, used to meld artifacts and enchant equipment.",
    "T6_RUNE_DESTRUCTION": "Greater Rune of Destruction",
    "T6_RUNE_DESTRUCTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T6_RUNE_MANIPULATION": "Greater Rune of Manipulation",
    "T6_RUNE_MANIPULATION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T6_RUNE_PROTECTION": "Greater Rune of Protection",
    "T6_RUNE_PROTECTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T6_SHARD_AVALONIAN": "Master's Avalonian Shard",
    "T6_SHOES_CLOTH_AVALON": "Master's Sandals of Purity",
    "T6_SHOES_CLOTH_HELL": "Master's Fiend Sandals",
    "T6_SHOES_CLOTH_HELL_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_KEEPER": "Master's Druid Sandals",
    "T6_SHOES_CLOTH_KEEPER_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_MORGANA": "Master's Cultist Sandals",
    "T6_SHOES_CLOTH_MORGANA_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_ROYAL": "Master's Royal Sandals",
    "T6_SHOES_CLOTH_ROYAL_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_SET1": "Master's Scholar Sandals",
    "T6_SHOES_CLOTH_SET1_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_SET1_ENCHANTED": "Enchanted Master's Scholar Sandals",
    "T6_SHOES_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_SET2": "Master's Cleric Sandals",
    "T6_SHOES_CLOTH_SET2_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_SET2_ENCHANTED": "Enchanted Master's Cleric Sandals",
    "T6_SHOES_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_SET3": "Master's Mage Sandals",
    "T6_SHOES_CLOTH_SET3_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_SET3_ENCHANTED": "Enchanted Master's Mage Sandals",
    "T6_SHOES_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_CLOTH_UNDEAD": "Undead Cloth Shoes",
    "T6_SHOES_CLOTH_UNDEAD_DESC": "Equipment Item",
    "T6_SHOES_GATHERER_FIBER": "Master's Harvester Workboots",
    "T6_SHOES_GATHERER_FIBER_DESC": "Equipment Item",
    "T6_SHOES_GATHERER_FISH": "Master's Fisherman Workboots",
    "T6_SHOES_GATHERER_FISH_DESC": "Equipment Item",
    "T6_SHOES_GATHERER_HIDE": "Master's Skinner Workboots",
    "T6_SHOES_GATHERER_HIDE_DESC": "Equipment Item",
    "T6_SHOES_GATHERER_ORE": "Master's Miner Workboots",
    "T6_SHOES_GATHERER_ORE_DESC": "Equipment Item",
    "T6_SHOES_GATHERER_ROCK": "Master's Quarrier Workboots",
    "T6_SHOES_GATHERER_ROCK_DESC": "Equipment Item",
    "T6_SHOES_GATHERER_WOOD": "Master's Lumberjack Workboots",
    "T6_SHOES_GATHERER_WOOD_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_AVALON": "Master's Shoes of Tenacity",
    "T6_SHOES_LEATHER_HELL": "Master's Hellion Shoes",
    "T6_SHOES_LEATHER_HELL_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_KEEPER": "Keeper Leather Shoes",
    "T6_SHOES_LEATHER_KEEPER_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_MORGANA": "Master's Stalker Shoes",
    "T6_SHOES_LEATHER_MORGANA_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_ROYAL": "Master's Royal Shoes",
    "T6_SHOES_LEATHER_ROYAL_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_SET1": "Master's Mercenary Shoes",
    "T6_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_SET1_ENCHANTED": "Enchanted Master's Mercenary Shoes",
    "T6_SHOES_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_SET2": "Master's Hunter Shoes",
    "T6_SHOES_LEATHER_SET2_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_SET2_ENCHANTED": "Enchanted Master's Hunter Shoes",
    "T6_SHOES_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_SET3": "Master's Assassin Shoes",
    "T6_SHOES_LEATHER_SET3_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_SET3_ENCHANTED": "Enchanted Master's Assassin Shoes",
    "T6_SHOES_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_LEATHER_UNDEAD": "Master's Specter Shoes",
    "T6_SHOES_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T6_SHOES_PLATE_AVALON": "Master's Boots of Valor",
    "T6_SHOES_PLATE_HELL": "Master's Demon Boots",
    "T6_SHOES_PLATE_HELL_DESC": "Equipment Item",
    "T6_SHOES_PLATE_KEEPER": "Master's Judicator Boots",
    "T6_SHOES_PLATE_KEEPER_DESC": "Equipment Item",
    "T6_SHOES_PLATE_MORGANA": "Morgana Plate Boots",
    "T6_SHOES_PLATE_MORGANA_DESC": "Equipment Item",
    "T6_SHOES_PLATE_ROYAL": "Master's Royal Boots",
    "T6_SHOES_PLATE_ROYAL_DESC": "Equipment Item",
    "T6_SHOES_PLATE_SET1": "Master's Soldier Boots",
    "T6_SHOES_PLATE_SET1_DESC": "Equipment Item",
    "T6_SHOES_PLATE_SET1_ENCHANTED": "Enchanted Master's Soldier Boots",
    "T6_SHOES_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_PLATE_SET2": "Master's Knight Boots",
    "T6_SHOES_PLATE_SET2_DESC": "Equipment Item",
    "T6_SHOES_PLATE_SET2_ENCHANTED": "Enchanted Master's Knight Boots",
    "T6_SHOES_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_PLATE_SET3": "Master's Guardian Boots",
    "T6_SHOES_PLATE_SET3_DESC": "Equipment Item",
    "T6_SHOES_PLATE_SET3_ENCHANTED": "Enchanted Master's Guardian Boots",
    "T6_SHOES_PLATE_SET3_ENCHANTED_DESC": "Equipment Item",
    "T6_SHOES_PLATE_UNDEAD": "Master's Graveguard Boots",
    "T6_SHOES_PLATE_UNDEAD_DESC": "Equipment Item",
    "T6_SILVERBAG_NONTRADABLE": "Master's Bag of Silver",
    "T6_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T6_SKILLBOOK_NONTRADABLE": "Master's Tome of Insight",
    "T6_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 50,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T6_SOUL": "Master's Soul",
    "T6_SOUL_DESC": "A tortured soul, used to meld artifacts and enchant equipment.",
    "T6_SOUL_HUNTER": "Mighty Hunter's Soul",
    "T6_SOUL_HUNTER_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T6_SOUL_MAGE": "Mighty Mage's Soul",
    "T6_SOUL_MAGE_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T6_SOUL_WARRIOR": "Mighty Warrior's Soul",
    "T6_SOUL_WARRIOR_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T6_STONEBLOCK": "Slate Block",
    "T6_STONEBLOCK_DESC": "Advanced material used in crafting, created by refining stone.",
    "T6_TRASH": "Trash",
    "T6_TRASH_DESC": "A destroyed T6 item. Cannot be repaired or salvaged.",
    "T6_WOOD": "Bloodoak Logs",
    "T6_WOOD_DESC": "Logs used for crafting. Can be refined into planks or transmuted into higher-level material.",
    "T6_WOOD_LEVEL1": "Uncommon Bloodoak Logs",
    "T6_WOOD_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T6_WOOD_LEVEL2": "Rare Bloodoak Logs",
    "T6_WOOD_LEVEL2_DESC": "Rare material used for crafting.",
    "T6_WOOD_LEVEL3": "Exceptional Bloodoak Logs",
    "T6_WOOD_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T6_WOOD_LEVEL4": "Legendary Bloodoak Logs",
    "T6_WOOD_LEVEL4_DESC": "Legendary material used for crafting.",
    "T6_WOOD_LEVEL5": "Mythical Bloodoak Logs",
    "T6_WOOD_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_2H_ARCANE_RINGPAIR_AVALON": "Grandmaster's Evensong",
    "T7_2H_ARCANE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T7_2H_ARCANESTAFF": "Grandmaster's Great Arcane Staff",
    "T7_2H_ARCANESTAFF_DESC": "Equipment Item",
    "T7_2H_ARCANESTAFF_ENCHANTED": "Grandmaster's Enchanted Great Arcane Staff",
    "T7_2H_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_ARCANESTAFF_HELL": "Grandmaster's Occult Staff",
    "T7_2H_ARCANESTAFF_HELL_DESC": "Equipment Item",
    "T7_2H_AXE": "Grandmaster's Greataxe",
    "T7_2H_AXE_AVALON": "Grandmaster's Realmbreaker",
    "T7_2H_AXE_AVALON_DESC": "Equipment Item",
    "T7_2H_AXE_DESC": "Equipment item",
    "T7_2H_AXE_ENCHANTED": "Grandmaster's Enchanted Greataxe",
    "T7_2H_AXE_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_BOW": "Grandmaster's Bow",
    "T7_2H_BOW_AVALON": "Grandmaster's Mistpiercer",
    "T7_2H_BOW_AVALON_DESC": "Equipment Item",
    "T7_2H_BOW_DESC": "Equipment Item",
    "T7_2H_BOW_ENCHANTED": "Grandmaster's Enchanted Bow",
    "T7_2H_BOW_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_BOW_HELL": "Grandmaster's Wailing Bow",
    "T7_2H_BOW_HELL_DESC": "Equipment Item",
    "T7_2H_BOW_KEEPER": "Grandmaster's Bow of Badon",
    "T7_2H_BOW_KEEPER_DESC": "Equipment Item",
    "T7_2H_CLAWPAIR": "Grandmaster's Claws",
    "T7_2H_CLAWPAIR_DESC": "Equipment Item",
    "T7_2H_CLAWPAIR_ENCHANTED": "Grandmaster's Enchanted Claws",
    "T7_2H_CLAWPAIR_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_CLAYMORE": "Grandmaster's Claymore",
    "T7_2H_CLAYMORE_AVALON": "Grandmaster's Kingmaker",
    "T7_2H_CLAYMORE_AVALON_DESC": "Equipment Item",
    "T7_2H_CLAYMORE_DESC": "Equipment Item",
    "T7_2H_CLAYMORE_ENCHANTED": "Grandmaster's Enchanted Claymore",
    "T7_2H_CLAYMORE_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_CLEAVER_HELL": "Grandmaster's Carving Sword",
    "T7_2H_CLEAVER_HELL_DESC": "Equipment Item",
    "T7_2H_COMBATSTAFF_MORGANA": "Grandmaster's Black Monk Stave",
    "T7_2H_COMBATSTAFF_MORGANA_DESC": "Equipment Item",
    "T7_2H_CROSSBOW": "Grandmaster's Crossbow",
    "T7_2H_CROSSBOW_CANNON_AVALON": "Grandmaster's Energy Shaper",
    "T7_2H_CROSSBOW_CANNON_AVALON_DESC": "Equipment Item",
    "T7_2H_CROSSBOW_DESC": "Equipment Item",
    "T7_2H_CROSSBOWLARGE": "Grandmaster's Heavy Crossbow",
    "T7_2H_CROSSBOWLARGE_DESC": "Equipment Item",
    "T7_2H_CROSSBOWLARGE_ENCHANTED": "Grandmaster's Enchanted Heavy Crossbow",
    "T7_2H_CROSSBOWLARGE_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_CROSSBOWLARGE_MORGANA": "Grandmaster's Siegebow",
    "T7_2H_CROSSBOWLARGE_MORGANA_DESC": "Equipment Item",
    "T7_2H_CURSEDSTAFF": "Grandmaster's Great Cursed Staff",
    "T7_2H_CURSEDSTAFF_DESC": "Equipment Item",
    "T7_2H_CURSEDSTAFF_ENCHANTED": "Grandmaster's Enchanted Great Cursed Staff",
    "T7_2H_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_CURSEDSTAFF_MORGANA": "Grandmaster's Damnation Staff",
    "T7_2H_CURSEDSTAFF_MORGANA_DESC": "Equipment Item",
    "T7_2H_DAGGER_KATAR_AVALON": "Grandmaster's Bridled Fury",
    "T7_2H_DAGGER_KATAR_AVALON_DESC": "Equipment Item",
    "T7_2H_DAGGERPAIR": "Grandmaster's Dagger Pair",
    "T7_2H_DAGGERPAIR_DESC": "Equipment Item",
    "T7_2H_DAGGERPAIR_ENCHANTED": "Grandmaster's Enchanted Dagger Pair",
    "T7_2H_DAGGERPAIR_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_DEMONICSTAFF": "Grandmaster's Demonic Staff",
    "T7_2H_DEMONICSTAFF_DESC": "Equipment Item",
    "T7_2H_DEMONICSTAFF_ENCHANTED": "Grandmaster's Enchanted Demonic Staff",
    "T7_2H_DEMONICSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_DIVINESTAFF": "Grandmaster's Divine Staff",
    "T7_2H_DIVINESTAFF_DESC": "Equipment Item",
    "T7_2H_DIVINESTAFF_ENCHANTED": "Grandmaster's Enchanted Divine Staff",
    "T7_2H_DIVINESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_DOUBLEBLADEDSTAFF": "Grandmaster's Double Bladed Staff",
    "T7_2H_DOUBLEBLADEDSTAFF_DESC": "Equipment Item",
    "T7_2H_DOUBLEBLADEDSTAFF_ENCHANTED": "Grandmaster's Enchanted Double Bladed Staff",
    "T7_2H_DOUBLEBLADEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_DUALAXE_KEEPER": "Grandmaster's Bear Paws",
    "T7_2H_DUALAXE_KEEPER_DESC": "Equipment Item",
    "T7_2H_DUALCROSSBOW_HELL": "Grandmaster's Boltcasters",
    "T7_2H_DUALCROSSBOW_HELL_DESC": "Equipment Item",
    "T7_2H_DUALHAMMER_HELL": "Grandmaster's Forge Hammers",
    "T7_2H_DUALHAMMER_HELL_DESC": "Equipment Item",
    "T7_2H_DUALMACE_AVALON": "Grandmaster's Oathkeepers",
    "T7_2H_DUALMACE_AVALON_DESC": "Equipment Item",
    "T7_2H_DUALSCIMITAR_UNDEAD": "Grandmaster's Galatine Pair",
    "T7_2H_DUALSCIMITAR_UNDEAD_DESC": "Equipment Item",
    "T7_2H_DUALSICKLE_UNDEAD": "Grandmaster's Deathgivers",
    "T7_2H_DUALSICKLE_UNDEAD_DESC": "Equipment Item",
    "T7_2H_DUALSWORD": "Grandmaster's Dual Swords",
    "T7_2H_DUALSWORD_DESC": "Equipment Item",
    "T7_2H_ENIGMATICORB_MORGANA": "Grandmaster's Malevolent Locus",
    "T7_2H_ENIGMATICORB_MORGANA_DESC": "Equipment Item",
    "T7_2H_ENIGMATICSTAFF": "Grandmaster's Enigmatic Staff",
    "T7_2H_ENIGMATICSTAFF_DESC": "Equipment Item",
    "T7_2H_ENIGMATICSTAFF_ENCHANTED": "Grandmaster's Enchanted Enigmatic Staff",
    "T7_2H_ENIGMATICSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_FIRE_RINGPAIR_AVALON": "Grandmaster's Dawnsong",
    "T7_2H_FIRE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T7_2H_FIRESTAFF": "Grandmaster's Great Fire Staff",
    "T7_2H_FIRESTAFF_DESC": "Equipment Item",
    "T7_2H_FIRESTAFF_ENCHANTED": "Grandmaster's Enchanted Great Fire Staff",
    "T7_2H_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_FIRESTAFF_HELL": "Grandmaster's Brimstone Staff",
    "T7_2H_FIRESTAFF_HELL_DESC": "Equipment Item",
    "T7_2H_FLAIL": "Grandmaster's Morning Star",
    "T7_2H_FLAIL_DESC": "Equipment Item",
    "T7_2H_FLAIL_ENCHANTED": "Grandmaster's Enchanted Morning Star",
    "T7_2H_FLAIL_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_FROSTSTAFF": "Grandmaster's Great Frost Staff",
    "T7_2H_FROSTSTAFF_DESC": "Equipment Item",
    "T7_2H_FROSTSTAFF_ENCHANTED": "Grandmaster's Enchanted Great Frost Staff",
    "T7_2H_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_GLACIALSTAFF": "Grandmaster's Glacial Staff",
    "T7_2H_GLACIALSTAFF_DESC": "Equipment Item",
    "T7_2H_GLACIALSTAFF_ENCHANTED": "Grandmaster's Enchanted Glacial Staff",
    "T7_2H_GLACIALSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_GLAIVE": "Grandmaster's Glaive",
    "T7_2H_GLAIVE_DESC": "Equipment Item",
    "T7_2H_GLAIVE_ENCHANTED": "Grandmaster's Enchanted Glaive",
    "T7_2H_GLAIVE_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_HALBERD": "Grandmaster's Halberd",
    "T7_2H_HALBERD_DESC": "Equipment Item",
    "T7_2H_HALBERD_ENCHANTED": "Grandmaster's Enchanted Halberd",
    "T7_2H_HALBERD_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_HALBERD_MORGANA": "Grandmaster's Carrioncaller",
    "T7_2H_HALBERD_MORGANA_DESC": "Equipment Item",
    "T7_2H_HAMMER": "Grandmaster's Great Hammer",
    "T7_2H_HAMMER_AVALON": "Grandmaster's Hand of Justice",
    "T7_2H_HAMMER_AVALON_DESC": "Equipment Item",
    "T7_2H_HAMMER_DESC": "Equipment Item",
    "T7_2H_HAMMER_ENCHANTED": "Grandmaster's Enchanted Great Hammer",
    "T7_2H_HAMMER_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_HAMMER_UNDEAD": "Grandmaster's Tombhammer",
    "T7_2H_HAMMER_UNDEAD_DESC": "Equipment Item",
    "T7_2H_HARPOON_HELL": "Grandmaster's Spirithunter",
    "T7_2H_HARPOON_HELL_DESC": "Equipment Item",
    "T7_2H_HOLYSTAFF": "Grandmaster's Great Holy Staff",
    "T7_2H_HOLYSTAFF_DESC": "Equipment Item",
    "T7_2H_HOLYSTAFF_ENCHANTED": "Grandmaster's Enchanted Great Holy Staff",
    "T7_2H_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_HOLYSTAFF_HELL": "Grandmaster's Fallen Staff",
    "T7_2H_HOLYSTAFF_HELL_DESC": "Equipment Item",
    "T7_2H_HOLYSTAFF_UNDEAD": "Grandmaster's Redemption Staff",
    "T7_2H_HOLYSTAFF_UNDEAD_DESC": "Equipment Item",
    "T7_2H_ICECRYSTAL_UNDEAD": "Grandmaster's Permafrost Prism",
    "T7_2H_ICECRYSTAL_UNDEAD_DESC": "Equipment Item",
    "T7_2H_ICEGAUNTLETS_HELL": "Grandmaster's Icicle Staff",
    "T7_2H_ICEGAUNTLETS_HELL_DESC": "Equipment Item",
    "T7_2H_INFERNOSTAFF": "Grandmaster's Infernal Staff",
    "T7_2H_INFERNOSTAFF_DESC": "Equipment Item",
    "T7_2H_INFERNOSTAFF_ENCHANTED": "Grandmaster's Enchanted Infernal Staff",
    "T7_2H_INFERNOSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_INFERNOSTAFF_MORGANA": "Grandmaster's Blazing Staff",
    "T7_2H_INFERNOSTAFF_MORGANA_DESC": "Equipment Item",
    "T7_2H_IRONCLADEDSTAFF": "Grandmaster's Iron-clad Staff",
    "T7_2H_IRONCLADEDSTAFF_DESC": "Equipment Item",
    "T7_2H_IRONCLADEDSTAFF_ENCHANTED": "Grandmaster's Enchanted Iron-clad Staff",
    "T7_2H_IRONCLADEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_IRONGAUNTLETS_HELL": "Grandmaster's Black Hands",
    "T7_2H_IRONGAUNTLETS_HELL_DESC": "Equipment Item",
    "T7_2H_LONGBOW": "Grandmaster's Longbow",
    "T7_2H_LONGBOW_DESC": "Equipment Item",
    "T7_2H_LONGBOW_ENCHANTED": "Grandmaster's Enchanted Longbow",
    "T7_2H_LONGBOW_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_LONGBOW_UNDEAD": "Grandmaster's Whispering Bow",
    "T7_2H_LONGBOW_UNDEAD_DESC": "Equipment Item",
    "T7_2H_MACE": "Grandmaster's Heavy Mace",
    "T7_2H_MACE_DESC": "Equipment Item",
    "T7_2H_MACE_ENCHANTED": "Grandmaster's Enchanted Heavy Mace",
    "T7_2H_MACE_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_MACE_MORGANA": "Grandmaster's Camlann Mace",
    "T7_2H_MACE_MORGANA_DESC": "Equipment Item",
    "T7_2H_NATURESTAFF": "Grandmaster's Great Nature Staff",
    "T7_2H_NATURESTAFF_DESC": "Equipment Item",
    "T7_2H_NATURESTAFF_ENCHANTED": "Grandmaster's Enchanted Great Nature Staff",
    "T7_2H_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_NATURESTAFF_HELL": "Grandmaster's Blight Staff",
    "T7_2H_NATURESTAFF_HELL_DESC": "Equipment Item",
    "T7_2H_NATURESTAFF_KEEPER": "Grandmaster's Rampant Staff",
    "T7_2H_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T7_2H_POLEHAMMER": "Grandmaster's Polehammer",
    "T7_2H_POLEHAMMER_DESC": "Equipment Item",
    "T7_2H_POLEHAMMER_ENCHANTED": "Grandmaster's Enchanted Polehammer",
    "T7_2H_POLEHAMMER_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_QUARTERSTAFF": "Grandmaster's Quarterstaff",
    "T7_2H_QUARTERSTAFF_AVALON": "Grandmaster's Grailseeker",
    "T7_2H_QUARTERSTAFF_AVALON_DESC": "Equipment Item",
    "T7_2H_QUARTERSTAFF_DESC": "Equipment Item",
    "T7_2H_QUARTERSTAFF_ENCHANTED": "Grandmaster's Enchanted Quarterstaff",
    "T7_2H_QUARTERSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_RAM_KEEPER": "Grandmaster's Grovekeeper",
    "T7_2H_RAM_KEEPER_DESC": "Equipment Item",
    "T7_2H_REPEATINGCROSSBOW_UNDEAD": "Grandmaster's Weeping Repeater",
    "T7_2H_REPEATINGCROSSBOW_UNDEAD_DESC": "Equipment Item",
    "T7_2H_ROCKSTAFF_KEEPER": "Grandmaster's Staff of Balance",
    "T7_2H_ROCKSTAFF_KEEPER_DESC": "Equipment Item",
    "T7_2H_SCYTHE": "Grandmaster's Scythe",
    "T7_2H_SCYTHE_DESC": "Equipment Item",
    "T7_2H_SCYTHE_ENCHANTED": "Grandmaster's Enchanted Scythe",
    "T7_2H_SCYTHE_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_SCYTHE_HELL": "Grandmaster's Infernal Scythe",
    "T7_2H_SCYTHE_HELL_DESC": "Equipment Item",
    "T7_2H_SKULLORB_HELL": "Grandmaster's Cursed Skull",
    "T7_2H_SKULLORB_HELL_DESC": "Equipment Item",
    "T7_2H_SPEAR": "Grandmaster's Pike",
    "T7_2H_SPEAR_DESC": "Equipment Item",
    "T7_2H_SPEAR_ENCHANTED": "Grandmaster's Enchanted Pike",
    "T7_2H_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_TOOL_AXE": "Grandmaster's Axe",
    "T7_2H_TOOL_AXE_AVALON": "Grandmaster's Avalonian Axe",
    "T7_2H_TOOL_AXE_DESC": "Equipment Item",
    "T7_2H_TOOL_FISHINGROD": "Grandmaster's Fishing Rod",
    "T7_2H_TOOL_FISHINGROD_AVALON": "Grandmaster's Avalonian Fishing Rod",
    "T7_2H_TOOL_FISHINGROD_DESC": "Equipment Item",
    "T7_2H_TOOL_HAMMER": "Grandmaster's Stone Hammer",
    "T7_2H_TOOL_HAMMER_AVALON": "Grandmaster's Avalonian Stone Hammer",
    "T7_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T7_2H_TOOL_KNIFE": "Grandmaster's Skinning Knife",
    "T7_2H_TOOL_KNIFE_AVALON": "Grandmaster's Avalonian Skinning Knife",
    "T7_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T7_2H_TOOL_PICK": "Grandmaster's Pickaxe",
    "T7_2H_TOOL_PICK_AVALON": "Grandmaster's Avalonian Pickaxe",
    "T7_2H_TOOL_PICK_DESC": "Equipment Item",
    "T7_2H_TOOL_SICKLE": "Grandmaster's Sickle",
    "T7_2H_TOOL_SICKLE_AVALON": "Grandmaster's Avalonian Sickle",
    "T7_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T7_2H_TOOL_SIEGEHAMMER": "Grandmaster's Demolition Hammer",
    "T7_2H_TOOL_SIEGEHAMMER_AVALON": "Grandmaster's Avalonian Demolition Hammer",
    "T7_2H_TOOL_SIEGEHAMMER_DESC": "A powerful hammer designed for destroying buildings and furniture.",
    "T7_2H_TRIDENT_UNDEAD": "Grandmaster's Trinity Spear",
    "T7_2H_TRIDENT_UNDEAD_DESC": "Equipment Item",
    "T7_2H_TWINSCYTHE_HELL": "Grandmaster's Soulscythe",
    "T7_2H_TWINSCYTHE_HELL_DESC": "Equipment Item",
    "T7_2H_WARBOW": "Grandmaster's Warbow",
    "T7_2H_WARBOW_DESC": "Equipment Item",
    "T7_2H_WARBOW_ENCHANTED": "Grandmaster's Enchanted Warbow",
    "T7_2H_WARBOW_ENCHANTED_DESC": "Equipment Item",
    "T7_2H_WILDSTAFF": "Grandmaster's Wild Staff",
    "T7_2H_WILDSTAFF_DESC": "Equipment Item",
    "T7_2H_WILDSTAFF_ENCHANTED": "Grandmaster's Enchanted Wild Staff",
    "T7_2H_WILDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_ALCOHOL": "Corn Hooch",
    "T7_ALCOHOL_DESC": "Corn Hooch is brewed from Corn, and used in various alchemical decoctions",
    "T7_ARMOR_CLOTH_AVALON": "Grandmaster's Robe of Purity",
    "T7_ARMOR_CLOTH_HELL": "Grandmaster's Fiend Robe",
    "T7_ARMOR_CLOTH_HELL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_KEEPER": "Grandmaster's Druid Robe",
    "T7_ARMOR_CLOTH_KEEPER_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_MORGANA": "Grandmaster's Cultist Robe",
    "T7_ARMOR_CLOTH_MORGANA_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_ROYAL": "Grandmaster's Royal Robe",
    "T7_ARMOR_CLOTH_ROYAL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_SET1": "Grandmaster's Scholar Robe",
    "T7_ARMOR_CLOTH_SET1_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_SET1_ENCHANTED": "Enchanted Grandmaster's Scholar Robe",
    "T7_ARMOR_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_SET2": "Grandmaster's Cleric Robe",
    "T7_ARMOR_CLOTH_SET2_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_SET2_ENCHANTED": "Enchanted Grandmaster's Cleric Robe",
    "T7_ARMOR_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_SET3": "Grandmaster's Mage Robe",
    "T7_ARMOR_CLOTH_SET3_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_CLOTH_SET3_ENCHANTED": "Enchanted Grandmaster's Mage Robe",
    "T7_ARMOR_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T7_ARMOR_GATHERER_FIBER": "Grandmaster's Harvester Garb",
    "T7_ARMOR_GATHERER_FIBER_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T7_ARMOR_GATHERER_FISH": "Grandmaster's Fisherman Garb",
    "T7_ARMOR_GATHERER_FISH_DESC": "Equipment Item\nGatherer Gear helps you gather more of its resource type",
    "T7_ARMOR_GATHERER_HIDE": "Grandmaster's Skinner Garb",
    "T7_ARMOR_GATHERER_HIDE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T7_ARMOR_GATHERER_ORE": "Grandmaster's Miner Garb",
    "T7_ARMOR_GATHERER_ORE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T7_ARMOR_GATHERER_ROCK": "Grandmaster's Quarrier Garb",
    "T7_ARMOR_GATHERER_ROCK_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T7_ARMOR_GATHERER_WOOD": "Grandmaster's Lumberjack Garb",
    "T7_ARMOR_GATHERER_WOOD_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T7_ARMOR_LEATHER_AVALON": "Grandmaster's Jacket of Tenacity",
    "T7_ARMOR_LEATHER_HELL": "Grandmaster's Hellion Jacket",
    "T7_ARMOR_LEATHER_HELL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_MORGANA": "Grandmaster's Stalker Jacket",
    "T7_ARMOR_LEATHER_MORGANA_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_ROYAL": "Grandmaster's Royal Jacket",
    "T7_ARMOR_LEATHER_ROYAL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_SET1": "Grandmaster's Mercenary Jacket",
    "T7_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_SET1_ENCHANTED": "Enchanted Grandmaster's Mercenary Jacket",
    "T7_ARMOR_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_SET2": "Grandmaster's Hunter Jacket",
    "T7_ARMOR_LEATHER_SET2_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_SET2_ENCHANTED": "Enchanted Grandmaster's Hunter Jacket",
    "T7_ARMOR_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_SET3": "Grandmaster's Assassin Jacket",
    "T7_ARMOR_LEATHER_SET3_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_SET3_ENCHANTED": "Enchanted Grandmaster's Assassin Jacket",
    "T7_ARMOR_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_LEATHER_UNDEAD": "Grandmaster's Specter Jacket",
    "T7_ARMOR_LEATHER_UNDEAD_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T7_ARMOR_PLATE_AVALON": "Grandmaster's Armor of Valor",
    "T7_ARMOR_PLATE_HELL": "Grandmaster's Demon Armor",
    "T7_ARMOR_PLATE_HELL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_KEEPER": "Grandmaster's Judicator Armor",
    "T7_ARMOR_PLATE_KEEPER_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_ROYAL": "Grandmaster's Royal Armor",
    "T7_ARMOR_PLATE_ROYAL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_SET1": "Grandmaster's Soldier Armor",
    "T7_ARMOR_PLATE_SET1_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_SET1_ENCHANTED": "Enchanted Grandmaster's Soldier Armor",
    "T7_ARMOR_PLATE_SET1_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_SET2": "Grandmaster's Knight Armor",
    "T7_ARMOR_PLATE_SET2_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_SET2_ENCHANTED": "Enchanted Grandmaster's Knight Armor",
    "T7_ARMOR_PLATE_SET2_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_SET3": "Grandmaster's Guardian Armor",
    "T7_ARMOR_PLATE_SET3_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_SET3_ENCHANTED": "Enchanted Grandmaster's Guardian Armor",
    "T7_ARMOR_PLATE_SET3_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARMOR_PLATE_UNDEAD": "Grandmaster's Graveguard Armor",
    "T7_ARMOR_PLATE_UNDEAD_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T7_ARTEFACT_2H_ARCANE_RINGPAIR_AVALON": "Grandmaster's Hypnotic Harmonic Ring",
    "T7_ARTEFACT_2H_ARCANESTAFF_HELL": "Grandmaster's Occult Orb",
    "T7_ARTEFACT_2H_AXE_AVALON": "Grandmaster's Avalonian Battle Memoir",
    "T7_ARTEFACT_2H_BOW_AVALON": "Grandmaster's Immaculately Crafted Riser",
    "T7_ARTEFACT_2H_BOW_HELL": "Grandmaster's Demonic Arrowheads",
    "T7_ARTEFACT_2H_BOW_KEEPER": "Grandmaster's Carved Bone",
    "T7_ARTEFACT_2H_CLAYMORE_AVALON": "Grandmaster's Remnants of the Old King",
    "T7_ARTEFACT_2H_CLEAVER_HELL": "Grandmaster's Demonic Blade",
    "T7_ARTEFACT_2H_COMBATSTAFF_MORGANA": "Grandmaster's Reinforced Morgana Pole",
    "T7_ARTEFACT_2H_CROSSBOW_CANNON_AVALON": "Grandmaster's Humming Avalonian Whirligig",
    "T7_ARTEFACT_2H_CROSSBOWLARGE_MORGANA": "Grandmaster's Alluring Bolts",
    "T7_ARTEFACT_2H_CURSEDSTAFF_MORGANA": "Grandmaster's Bloodforged Catalyst",
    "T7_ARTEFACT_2H_DAGGER_KATAR_AVALON": "Grandmaster's Bloodstained Antiquities",
    "T7_ARTEFACT_2H_DUALAXE_KEEPER": "Grandmaster's Keeper Axeheads",
    "T7_ARTEFACT_2H_DUALCROSSBOW_HELL": "Grandmaster's Hellish Bolts",
    "T7_ARTEFACT_2H_DUALHAMMER_HELL": "Grandmaster's Hellish Hammer Heads",
    "T7_ARTEFACT_2H_DUALMACE_AVALON": "Grandmaster's Broken Oaths",
    "T7_ARTEFACT_2H_DUALSCIMITAR_UNDEAD": "Grandmaster's Cursed Blades",
    "T7_ARTEFACT_2H_DUALSICKLE_UNDEAD": "Grandmaster's Ghastly Blades",
    "T7_ARTEFACT_2H_ENIGMATICORB_MORGANA": "Grandmaster's Possessed Catalyst",
    "T7_ARTEFACT_2H_FIRE_RINGPAIR_AVALON": "Grandmaster's Glowing Harmonic Ring",
    "T7_ARTEFACT_2H_FIRESTAFF_HELL": "Grandmaster's Burning Orb",
    "T7_ARTEFACT_2H_HALBERD_MORGANA": "Grandmaster's Morgana Halberd Head",
    "T7_ARTEFACT_2H_HAMMER_AVALON": "Grandmaster's Massive Metallic Hand",
    "T7_ARTEFACT_2H_HAMMER_UNDEAD": "Grandmaster's Ancient Hammer Head",
    "T7_ARTEFACT_2H_HARPOON_HELL": "Grandmaster's Infernal Harpoon Tip",
    "T7_ARTEFACT_2H_HOLYSTAFF_HELL": "Grandmaster's Infernal Scroll",
    "T7_ARTEFACT_2H_HOLYSTAFF_UNDEAD": "Grandmaster's Ghastly Scroll",
    "T7_ARTEFACT_2H_ICECRYSTAL_UNDEAD": "Grandmaster's Cursed Frozen Crystal",
    "T7_ARTEFACT_2H_ICEGAUNTLETS_HELL": "Grandmaster's Icicle Orb",
    "T7_ARTEFACT_2H_INFERNOSTAFF_MORGANA": "Grandmaster's Unholy Scroll",
    "T7_ARTEFACT_2H_IRONGAUNTLETS_HELL": "Grandmaster's Black Leather",
    "T7_ARTEFACT_2H_LONGBOW_UNDEAD": "Grandmaster's Ghastly Arrows",
    "T7_ARTEFACT_2H_MACE_MORGANA": "Grandmaster's Imbued Mace Head",
    "T7_ARTEFACT_2H_NATURESTAFF_HELL": "Grandmaster's Symbol of Blight",
    "T7_ARTEFACT_2H_NATURESTAFF_KEEPER": "Grandmaster's Preserved Log",
    "T7_ARTEFACT_2H_QUARTERSTAFF_AVALON": "Grandmaster's Timeworn Walking Staff",
    "T7_ARTEFACT_2H_RAM_KEEPER": "Grandmaster's Engraved Log",
    "T7_ARTEFACT_2H_REPEATINGCROSSBOW_UNDEAD": "Grandmaster's Lost Crossbow Mechanism",
    "T7_ARTEFACT_2H_ROCKSTAFF_KEEPER": "Grandmaster's Preserved Rocks",
    "T7_ARTEFACT_2H_SCYTHE_HELL": "Grandmaster's Hellish Sicklehead",
    "T7_ARTEFACT_2H_SKULLORB_HELL": "Grandmaster's Cursed Jawbone",
    "T7_ARTEFACT_2H_TRIDENT_UNDEAD": "Grandmaster's Cursed Barbs",
    "T7_ARTEFACT_2H_TWINSCYTHE_HELL": "Grandmaster's Hellish Sicklehead Pair",
    "T7_ARTEFACT_ARMOR_CLOTH_AVALON": "Grandmaster's Sanctified Belt",
    "T7_ARTEFACT_ARMOR_CLOTH_HELL": "Grandmaster's Infernal Cloth Folds",
    "T7_ARTEFACT_ARMOR_CLOTH_KEEPER": "Grandmaster's Druidic Feathers",
    "T7_ARTEFACT_ARMOR_CLOTH_MORGANA": "Grandmaster's Alluring Amulet",
    "T7_ARTEFACT_ARMOR_LEATHER_AVALON": "Grandmaster's Augured Sash",
    "T7_ARTEFACT_ARMOR_LEATHER_HELL": "Grandmaster's Demonhide Leather",
    "T7_ARTEFACT_ARMOR_LEATHER_MORGANA": "Grandmaster's Imbued Leather Folds",
    "T7_ARTEFACT_ARMOR_LEATHER_UNDEAD": "Grandmaster's Ghastly Leather",
    "T7_ARTEFACT_ARMOR_PLATE_AVALON": "Grandmaster's Exalted Plating",
    "T7_ARTEFACT_ARMOR_PLATE_HELL": "Grandmaster's Demonic Plates",
    "T7_ARTEFACT_ARMOR_PLATE_KEEPER": "Grandmaster's Preserved Animal Fur",
    "T7_ARTEFACT_ARMOR_PLATE_UNDEAD": "Grandmaster's Ancient Chain Rings",
    "T7_ARTEFACT_HEAD_CLOTH_AVALON": "Grandmaster's Sanctified Mask",
    "T7_ARTEFACT_HEAD_CLOTH_HELL": "Grandmaster's Infernal Cloth Visor",
    "T7_ARTEFACT_HEAD_CLOTH_KEEPER": "Grandmaster's Druidic Preserved Beak",
    "T7_ARTEFACT_HEAD_CLOTH_MORGANA": "Grandmaster's Alluring Padding",
    "T7_ARTEFACT_HEAD_LEATHER_AVALON": "Grandmaster's Augured Padding",
    "T7_ARTEFACT_HEAD_LEATHER_HELL": "Grandmaster's Demonhide Padding",
    "T7_ARTEFACT_HEAD_LEATHER_MORGANA": "Grandmaster's Imbued Visor",
    "T7_ARTEFACT_HEAD_LEATHER_UNDEAD": "Grandmaster's Ghastly Visor",
    "T7_ARTEFACT_HEAD_PLATE_AVALON": "Grandmaster's Exalted Visor",
    "T7_ARTEFACT_HEAD_PLATE_HELL": "Grandmaster's Demonic Scraps",
    "T7_ARTEFACT_HEAD_PLATE_KEEPER": "Grandmaster's Carved Skull Padding",
    "T7_ARTEFACT_HEAD_PLATE_UNDEAD": "Grandmaster's Ancient Padding",
    "T7_ARTEFACT_MAIN_ARCANESTAFF_UNDEAD": "Grandmaster's Lost Arcane Crystal",
    "T7_ARTEFACT_MAIN_CURSEDSTAFF_AVALON": "Grandmaster's Fractured Opaque Orb",
    "T7_ARTEFACT_MAIN_CURSEDSTAFF_UNDEAD": "Grandmaster's Lost Cursed Crystal",
    "T7_ARTEFACT_MAIN_FIRESTAFF_KEEPER": "Grandmaster's Wildfire Orb",
    "T7_ARTEFACT_MAIN_FROSTSTAFF_AVALON": "Grandmaster's Chilled Crystaline Shard",
    "T7_ARTEFACT_MAIN_FROSTSTAFF_KEEPER": "Grandmaster's Hoarfrost Orb",
    "T7_ARTEFACT_MAIN_HOLYSTAFF_AVALON": "Grandmaster's Messianic Curio",
    "T7_ARTEFACT_MAIN_HOLYSTAFF_MORGANA": "Grandmaster's Possessed Scroll",
    "T7_ARTEFACT_MAIN_MACE_HELL": "Grandmaster's Infernal Mace Head",
    "T7_ARTEFACT_MAIN_NATURESTAFF_AVALON": "Grandmaster's Uprooted Perennial Sapling",
    "T7_ARTEFACT_MAIN_NATURESTAFF_KEEPER": "Grandmaster's Druidic Inscriptions",
    "T7_ARTEFACT_MAIN_RAPIER_MORGANA": "Grandmaster's Hardened Debole",
    "T7_ARTEFACT_MAIN_ROCKMACE_KEEPER": "Grandmaster's Runed Rock",
    "T7_ARTEFACT_MAIN_SCIMITAR_MORGANA": "Grandmaster's Bloodforged Blade",
    "T7_ARTEFACT_MAIN_SPEAR_KEEPER": "Grandmaster's Keeper Spearhead",
    "T7_ARTEFACT_MAIN_SPEAR_LANCE_AVALON": "Grandmaster's Ruined Ancestral Vamplate",
    "T7_ARTEFACT_OFF_CENSER_AVALON": "Grandmaster's Severed Celestial Keepsake",
    "T7_ARTEFACT_OFF_DEMONSKULL_HELL": "Grandmaster's Demonic Jawbone",
    "T7_ARTEFACT_OFF_HORN_KEEPER": "Grandmaster's Runed Horn",
    "T7_ARTEFACT_OFF_JESTERCANE_HELL": "Grandmaster's Hellish Handle",
    "T7_ARTEFACT_OFF_LAMP_UNDEAD": "Grandmaster's Ghastly Candle",
    "T7_ARTEFACT_OFF_ORB_MORGANA": "Grandmaster's Alluring Crystal",
    "T7_ARTEFACT_OFF_SHIELD_AVALON": "Grandmaster's Crushed Avalonian Heirloom",
    "T7_ARTEFACT_OFF_SHIELD_HELL": "Grandmaster's Infernal Shield Core",
    "T7_ARTEFACT_OFF_SPIKEDSHIELD_MORGANA": "Grandmaster's Bloodforged Spikes",
    "T7_ARTEFACT_OFF_TALISMAN_AVALON": "Grandmaster's Shattered Avalonian Memento",
    "T7_ARTEFACT_OFF_TOTEM_KEEPER": "Grandmaster's Inscribed Stone",
    "T7_ARTEFACT_OFF_TOWERSHIELD_UNDEAD": "Grandmaster's Ancient Shield Core",
    "T7_ARTEFACT_SHOES_CLOTH_AVALON": "Grandmaster's Sanctified Bindings",
    "T7_ARTEFACT_SHOES_CLOTH_HELL": "Grandmaster's Infernal Cloth Bindings",
    "T7_ARTEFACT_SHOES_CLOTH_KEEPER": "Grandmaster's Druidic Bindings",
    "T7_ARTEFACT_SHOES_CLOTH_MORGANA": "Grandmaster's Alluring Bindings",
    "T7_ARTEFACT_SHOES_LEATHER_AVALON": "Grandmaster's Augured Fasteners",
    "T7_ARTEFACT_SHOES_LEATHER_HELL": "Grandmaster's Demonhide Bindings",
    "T7_ARTEFACT_SHOES_LEATHER_MORGANA": "Grandmaster's Imbued Soles",
    "T7_ARTEFACT_SHOES_LEATHER_UNDEAD": "Grandmaster's Ghastly Bindings",
    "T7_ARTEFACT_SHOES_PLATE_AVALON": "Grandmaster's Exalted Greave",
    "T7_ARTEFACT_SHOES_PLATE_HELL": "Grandmaster's Demonic Filling",
    "T7_ARTEFACT_SHOES_PLATE_KEEPER": "Grandmaster's Inscribed Bindings",
    "T7_ARTEFACT_SHOES_PLATE_UNDEAD": "Grandmaster's Ancient Bindings",
    "T7_BACKPACK_GATHERER_FIBER": "Grandmaster's Harvester Backpack",
    "T7_BACKPACK_GATHERER_FIBER_DESC": "Equipment Item",
    "T7_BACKPACK_GATHERER_FISH": "Grandmaster's Fisherman Backpack",
    "T7_BACKPACK_GATHERER_FISH_DESC": "Equipment Item",
    "T7_BACKPACK_GATHERER_HIDE": "Grandmaster's Skinner Backpack",
    "T7_BACKPACK_GATHERER_HIDE_DESC": "Equipment Item",
    "T7_BACKPACK_GATHERER_ORE": "Grandmaster's Miner Backpack",
    "T7_BACKPACK_GATHERER_ORE_DESC": "Equipment Item",
    "T7_BACKPACK_GATHERER_ROCK": "Grandmaster's Quarrier Backpack",
    "T7_BACKPACK_GATHERER_ROCK_DESC": "Equipment Item",
    "T7_BACKPACK_GATHERER_WOOD": "Grandmaster's Lumberjack Backpack",
    "T7_BACKPACK_GATHERER_WOOD_DESC": "Equipment Item",
    "T7_BAG": "Grandmaster's Bag",
    "T7_BAG_DESC": "Equipment Item",
    "T7_BAG_FW_BONUS_FAME": "Grandmaster's Faction Fame Bag",
    "T7_BAG_FW_BONUS_FAME_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T7_BAG_FW_BONUS_SILVER": "Grandmaster's Faction Silver Bag",
    "T7_BAG_FW_BONUS_SILVER_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T7_BAG_FW_BONUS_YIELD": "Grandmaster's Faction Yield Bag",
    "T7_BAG_FW_BONUS_YIELD_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T7_BAG_FW_FAME_BP": "Grandmaster's Faction Fame Bag Pattern",
    "T7_BAG_FW_FAME_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T7_BAG_FW_SILVER_BP": "Grandmaster's Faction Silver Bag Pattern",
    "T7_BAG_FW_SILVER_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T7_BAG_FW_YIELD_BP": "Grandmaster's Faction Yield Bag Pattern",
    "T7_BAG_FW_YIELD_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T7_BAG_INSIGHT": "Grandmaster's Satchel of Insight",
    "T7_CAPE": "Grandmaster's Cape",
    "T7_CAPE_DESC": "Equipment Item",
    "T7_CAPEITEM_DEMON": "Grandmaster's Demon Cape",
    "T7_CAPEITEM_DEMON_BP": "Grandmaster's Demon Crest",
    "T7_CAPEITEM_DEMON_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_DEMON_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_FW_BRIDGEWATCH": "Grandmaster's Bridgewatch Cape",
    "T7_CAPEITEM_FW_BRIDGEWATCH_BP": "Grandmaster's Bridgewatch Crest",
    "T7_CAPEITEM_FW_BRIDGEWATCH_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_FW_BRIDGEWATCH_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_FW_FORTSTERLING": "Grandmaster's Fort Sterling Cape",
    "T7_CAPEITEM_FW_FORTSTERLING_BP": "Grandmaster's Fort Sterling Crest",
    "T7_CAPEITEM_FW_FORTSTERLING_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_FW_FORTSTERLING_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_FW_LYMHURST": "Grandmaster's Lymhurst Cape",
    "T7_CAPEITEM_FW_LYMHURST_BP": "Grandmaster's Lymhurst Crest",
    "T7_CAPEITEM_FW_LYMHURST_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_FW_LYMHURST_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_FW_MARTLOCK": "Grandmaster's Martlock Cape",
    "T7_CAPEITEM_FW_MARTLOCK_BP": "Grandmaster's Martlock Crest",
    "T7_CAPEITEM_FW_MARTLOCK_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_FW_MARTLOCK_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_FW_THETFORD": "Grandmaster's Thetford Cape",
    "T7_CAPEITEM_FW_THETFORD_BP": "Grandmaster's Thetford Crest",
    "T7_CAPEITEM_FW_THETFORD_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_FW_THETFORD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_HERETIC": "Grandmaster's Heretic Cape",
    "T7_CAPEITEM_HERETIC_BP": "Grandmaster's Heretic Crest",
    "T7_CAPEITEM_HERETIC_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_HERETIC_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_KEEPER": "Grandmaster's Keeper Cape",
    "T7_CAPEITEM_KEEPER_BP": "Grandmaster's Keeper Crest",
    "T7_CAPEITEM_KEEPER_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_KEEPER_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_MORGANA": "Grandmaster's Morgana Cape",
    "T7_CAPEITEM_MORGANA_BP": "Grandmaster's Morgana Crest",
    "T7_CAPEITEM_MORGANA_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_MORGANA_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CAPEITEM_UNDEAD": "Grandmaster's Undead Cape",
    "T7_CAPEITEM_UNDEAD_BP": "Grandmaster's Undead Crest",
    "T7_CAPEITEM_UNDEAD_BP_DESC": "Can be used to upgrade a cape",
    "T7_CAPEITEM_UNDEAD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T7_CLOTH": "Opulent Cloth",
    "T7_CLOTH_DESC": "Advanced material used in crafting, created by refining fiber.",
    "T7_CLOTH_LEVEL1": "Uncommon Opulent Cloth",
    "T7_CLOTH_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_CLOTH_LEVEL2": "Rare Opulent Cloth",
    "T7_CLOTH_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_CLOTH_LEVEL3": "Exceptional Opulent Cloth",
    "T7_CLOTH_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_CLOTH_LEVEL4": "Legendary Opulent Cloth",
    "T7_CLOTH_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_CLOTH_LEVEL5": "Mythical Opulent Cloth",
    "T7_CLOTH_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_CORN": "Bundle of Corn",
    "T7_CORN_DESC": "Corn is used in a variety of foods",
    "T7_ESSENCE": "Grandmaster's Faded Essence",
    "T7_ESSENCE_DESC": "This essence has passed its use-by date. It can be combined with others like it at an Artifact Foundry.",
    "T7_ESSENCE_HUNTER": "Sacred Essence of the Hunter",
    "T7_ESSENCE_HUNTER_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T7_ESSENCE_MAGE": "Sacred Essence of the Mage",
    "T7_ESSENCE_MAGE_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T7_ESSENCE_POTION": "Grandmaster's Arcane Essence",
    "T7_ESSENCE_POTION_DESC": "A magical essence, used to enchant potions",
    "T7_ESSENCE_WARRIOR": "Sacred Essence of the Warrior",
    "T7_ESSENCE_WARRIOR_DESC": "Special material used in crafting. It can be transmuted into a better essence.",
    "T7_FARM_CORN_SEED": "Corn Seeds",
    "T7_FARM_CORN_SEED_DESC": "Corn Seeds are used to plant a patch of Corn",
    "T7_FARM_DIREBOAR_BABY": "Direboar Piglet",
    "T7_FARM_DIREBOAR_BABY_DESC": "Grows into a Tame Direboar. which can be used to craft a Saddled Direboar Mount.",
    "T7_FARM_DIREBOAR_GROWN": "Tame Direboar",
    "T7_FARM_DIREBOAR_GROWN_DESC": "Can be used to craft a Saddled Direboar Mount.",
    "T7_FARM_HORSE_BABY": "Grandmaster's Foal",
    "T7_FARM_HORSE_BABY_DESC": "Grow into a Grandmaster's Horse which can be used to craft a Grandmaster's Riding Horse or a Grandmaster's Armored Horse.",
    "T7_FARM_HORSE_GROWN": "Grandmaster's Horse",
    "T7_FARM_HORSE_GROWN_DESC": "Can be used to craft a Grandmaster's Riding Horse or a Grandmaster's Armored Horse.",
    "T7_FARM_MULLEIN_SEED": "Firetouched Mullein Seeds",
    "T7_FARM_MULLEIN_SEED_DESC": "Firetouched Mullein Seeds are used to plant a patch of Firetouched Mullein",
    "T7_FARM_OX_BABY": "Grandmaster's Ox Calf",
    "T7_FARM_OX_BABY_DESC": "Grows into an Grandmaster's Ox which can be used to craft a Grandmaster's Transport Ox.",
    "T7_FARM_OX_GROWN": "Grandmaster's Ox",
    "T7_FARM_OX_GROWN_DESC": "Can be used to craft a Grandmaster's Transport Ox.",
    "T7_FARM_PIG_BABY": "Piglet",
    "T7_FARM_PIG_BABY_DESC": "You can Place piglets on your pasture for them to grow up into Pigs",
    "T7_FARM_PIG_GROWN": "Pig",
    "T7_FARM_PIG_GROWN_DESC": "Pigs can be slaughtered to produce Raw Pork",
    "T7_FARM_SWAMPDRAGON_BABY": "Swamp Dragon Pup",
    "T7_FARM_SWAMPDRAGON_BABY_DESC": "Grows into a Tame Swamp Dragon, which can be used to craft a Saddled Swamp Dragon mount.",
    "T7_FARM_SWAMPDRAGON_GROWN": "Tame Swamp Dragon",
    "T7_FARM_SWAMPDRAGON_GROWN_DESC": "Can be used to craft a Saddled Swamp Dragon mount.",
    "T7_FIBER": "Sunflax",
    "T7_FIBER_DESC": "Fiber used for crafting. Can be refined into cloth or transmuted into higher-level material.",
    "T7_FIBER_LEVEL1": "Uncommon Sunflax",
    "T7_FIBER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_FIBER_LEVEL2": "Rare Sunflax",
    "T7_FIBER_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_FIBER_LEVEL3": "Exceptional Sunflax",
    "T7_FIBER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_FIBER_LEVEL4": "Legendary Sunflax",
    "T7_FIBER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_FIBER_LEVEL5": "Mythical Sunflax",
    "T7_FIBER_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_FISH_FRESHWATER_ALL_COMMON": "Danglemouth Catfish",
    "T7_FISH_FRESHWATER_AVALON_RARE": "Puremist Snapper",
    "T7_FISH_FRESHWATER_FOREST_RARE": "Deadwater Eel",
    "T7_FISH_FRESHWATER_HIGHLANDS_RARE": "Thunderfall Lurcher",
    "T7_FISH_FRESHWATER_MOUNTAIN_RARE": "Frostpeak Deadeye",
    "T7_FISH_FRESHWATER_STEPPE_RARE": "Dusthole Crab",
    "T7_FISH_FRESHWATER_SWAMP_RARE": "Blackbog Clam",
    "T7_FISH_SALTWATER_ALL_COMMON": "Bluefin Tuna",
    "T7_FISH_SALTWATER_ALL_RARE": "Deepwater Kraken",
    "T7_FRAGMENT_BLUE_F1": "Grandmaster's Scrap of Magic",
    "T7_FRAGMENT_BLUE_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_BLUE_F2": "Grandmaster's Fragment of Magic",
    "T7_FRAGMENT_BLUE_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_BLUE_F3": "Grandmaster's Shard of Magic",
    "T7_FRAGMENT_BLUE_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_GREEN_F1": "Grandmaster's Scrap of Nature",
    "T7_FRAGMENT_GREEN_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_GREEN_F2": "Grandmaster's Fragment of Nature",
    "T7_FRAGMENT_GREEN_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_GREEN_F3": "Grandmaster's Shard of Nature",
    "T7_FRAGMENT_GREEN_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_RED_F1": "Grandmaster's Scrap of Valor",
    "T7_FRAGMENT_RED_F1_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_RED_F2": "Grandmaster's Fragment of Valor",
    "T7_FRAGMENT_RED_F2_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FRAGMENT_RED_F3": "Grandmaster's Shard of Valor",
    "T7_FRAGMENT_RED_F3_DESC": "Can be melded into an artifact, or transmuted into a higher-tier version or a different aspect.",
    "T7_FURNITUREITEM_BATTLEVAULT": "Grandmaster's Battlevault",
    "T7_FURNITUREITEM_BATTLEVAULT_DESC": "A 32-slot battlevault with a 1255 kg limit. Must be placed indoors.",
    "T7_FURNITUREITEM_BED": "Grandmaster's Bed",
    "T7_FURNITUREITEM_BED_DESC": "Increases maximum residents in the house by 1, and contributes to Laborer happiness. Item can only be placed indoors.",
    "T7_FURNITUREITEM_REPAIRKIT": "Grandmaster's Repair Kit",
    "T7_FURNITUREITEM_REPAIRKIT_DESC": "Repair kits are used to repair gear in the wild, however the repair fee is twice as high.",
    "T7_FURNITUREITEM_TABLE": "Grandmaster's Table",
    "T7_FURNITUREITEM_TABLE_DESC": "Contributes to Laborer happiness. Item can only be placed indoors.",
    "T7_FURNITUREITEM_TROPHY_FIBER": "Fine Sunflax Trophy",
    "T7_FURNITUREITEM_TROPHY_FISH": "Catfish Trophy",
    "T7_FURNITUREITEM_TROPHY_GENERAL": "Occult Octavo",
    "T7_FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all Laborers.",
    "T7_FURNITUREITEM_TROPHY_HIDE": "Stuffed Direboar Head",
    "T7_FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to all Gamekeeper Laborers.",
    "T7_FURNITUREITEM_TROPHY_MERCENARY": "Grandmaster Mercenary's Trophy",
    "T7_FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to all Mercenary Laborers.",
    "T7_FURNITUREITEM_TROPHY_MOB": "Trophy: Direboar's Head",
    "T7_FURNITUREITEM_TROPHY_MOB_DESC": "Provides an increase to maximum carrying capacity. Must be placed indoors.",
    "T7_FURNITUREITEM_TROPHY_ORE": "Meteorite Ore Sample",
    "T7_FURNITUREITEM_TROPHY_ROCK": "Basalt Fragment",
    "T7_FURNITUREITEM_TROPHY_WOOD": "Ashenbark Bonsai",
    "T7_GEM_EMERALD": "Flawless Emerald",
    "T7_GEM_EMERALD_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T7_GEM_RUBY": "Flawless Ruby",
    "T7_GEM_RUBY_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T7_GEM_SAPPHIRE": "Flawless Sapphire",
    "T7_GEM_SAPPHIRE_DESC": "Special material used in crafting. It can be transmuted into a better quality gem.",
    "T7_GVGSEASONREWARD_FAMEBUFF": "Grandmaster's Knight Vow",
    "T7_GVGSEASONREWARD_FAMEBUFF_DESC": "Increases Fame from defeating creatures and gathering resources by 4% for 90 days",
    "T7_HEAD_CLOTH_AVALON": "Grandmaster's Cowl of Purity",
    "T7_HEAD_CLOTH_HELL": "Grandmaster's Fiend Cowl",
    "T7_HEAD_CLOTH_HELL_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_KEEPER": "Grandmaster's Druid Cowl",
    "T7_HEAD_CLOTH_KEEPER_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_MORGANA": "Grandmaster's Cultist Cowl",
    "T7_HEAD_CLOTH_MORGANA_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_ROYAL": "Grandmaster's Royal Cowl",
    "T7_HEAD_CLOTH_ROYAL_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_SET1": "Grandmaster's Scholar Cowl",
    "T7_HEAD_CLOTH_SET1_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_SET1_ENCHANTED": "Enchanted Grandmaster's Scholar Cowl",
    "T7_HEAD_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_SET2": "Grandmaster's Cleric Cowl",
    "T7_HEAD_CLOTH_SET2_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_SET2_ENCHANTED": "Enchanted Grandmaster's Cleric Cowl",
    "T7_HEAD_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_SET3": "Grandmaster's Mage Cowl",
    "T7_HEAD_CLOTH_SET3_DESC": "Equipment Item",
    "T7_HEAD_CLOTH_SET3_ENCHANTED": "Enchanted Grandmaster's Mage Cowl",
    "T7_HEAD_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_GATHERER_FIBER": "Grandmaster's Harvester Cap",
    "T7_HEAD_GATHERER_FIBER_DESC": "Equipment Item",
    "T7_HEAD_GATHERER_FISH": "Grandmaster's Fisherman Cap",
    "T7_HEAD_GATHERER_FISH_DESC": "Equipment Item",
    "T7_HEAD_GATHERER_HIDE": "Grandmaster's Skinner Cap",
    "T7_HEAD_GATHERER_HIDE_DESC": "Equipment Item",
    "T7_HEAD_GATHERER_ORE": "Grandmaster's Miner Cap",
    "T7_HEAD_GATHERER_ORE_DESC": "Equipment Item",
    "T7_HEAD_GATHERER_ROCK": "Grandmaster's Quarrier Cap",
    "T7_HEAD_GATHERER_ROCK_DESC": "Equipment Item",
    "T7_HEAD_GATHERER_WOOD": "Grandmaster's Lumberjack Cap",
    "T7_HEAD_GATHERER_WOOD_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_AVALON": "Grandmaster's Hood of Tenacity",
    "T7_HEAD_LEATHER_HELL": "Grandmaster's Hellion Hood",
    "T7_HEAD_LEATHER_HELL_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_MORGANA": "Grandmaster's Stalker Hood",
    "T7_HEAD_LEATHER_MORGANA_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_ROYAL": "Grandmaster's Royal Hood",
    "T7_HEAD_LEATHER_ROYAL_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_SET1": "Grandmaster's Mercenary Hood",
    "T7_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_SET1_ENCHANTED": "Enchanted Grandmaster's Mercenary Hood",
    "T7_HEAD_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_SET2": "Grandmaster's Hunter Hood",
    "T7_HEAD_LEATHER_SET2_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_SET2_ENCHANTED": "Enchanted Grandmaster's Hunter Hood",
    "T7_HEAD_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_SET3": "Grandmaster's Assassin Hood",
    "T7_HEAD_LEATHER_SET3_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_SET3_ENCHANTED": "Enchanted Grandmaster's Assassin Hood",
    "T7_HEAD_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_LEATHER_UNDEAD": "Grandmaster's Specter Hood",
    "T7_HEAD_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T7_HEAD_PLATE_AVALON": "Grandmaster's Helmet of Valor",
    "T7_HEAD_PLATE_HELL": "Grandmaster's Demon Helmet",
    "T7_HEAD_PLATE_HELL_DESC": "Equipment Item",
    "T7_HEAD_PLATE_KEEPER": "Grandmaster's Judicator Helmet",
    "T7_HEAD_PLATE_KEEPER_DESC": "Equipment Item",
    "T7_HEAD_PLATE_ROYAL": "Grandmaster's Royal Helmet",
    "T7_HEAD_PLATE_ROYAL_DESC": "Equipment Item",
    "T7_HEAD_PLATE_SET1": "Grandmaster's Soldier Helmet",
    "T7_HEAD_PLATE_SET1_DESC": "Equipment Item",
    "T7_HEAD_PLATE_SET1_ENCHANTED": "Enchanted Grandmaster's Soldier Helmet",
    "T7_HEAD_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_PLATE_SET2": "Grandmaster's Knight Helmet",
    "T7_HEAD_PLATE_SET2_DESC": "Equipment Item",
    "T7_HEAD_PLATE_SET2_ENCHANTED": "Enchanted Grandmaster's Knight Helmet",
    "T7_HEAD_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_PLATE_SET3": "Grandmaster's Guardian Helmet",
    "T7_HEAD_PLATE_SET3_DESC": "Equipment Item",
    "T7_HEAD_PLATE_SET3_ENCHANTED": "Enchanted Grandmaster's Guardian Helmet",
    "T7_HEAD_PLATE_SET3_ENCHANTED_DESC": "Equipment Item",
    "T7_HEAD_PLATE_UNDEAD": "Grandmaster's Graveguard Helmet",
    "T7_HEAD_PLATE_UNDEAD_DESC": "Equipment Item",
    "T7_HIDE": "Thick Hide",
    "T7_HIDE_DESC": "Hide used for crafting. Can be refined into leather or transmuted into higher-level material.",
    "T7_HIDE_LEVEL1": "Uncommon Thick Hide",
    "T7_HIDE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_HIDE_LEVEL2": "Rare Thick Hide",
    "T7_HIDE_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_HIDE_LEVEL3": "Exceptional Thick Hide",
    "T7_HIDE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_HIDE_LEVEL4": "Legendary Thick Hide",
    "T7_HIDE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_HIDE_LEVEL5": "Mythical Thick Hide",
    "T7_HIDE_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_JOURNAL_FIBER": "Grandmaster Cropper's Journal (Partially Full)",
    "T7_JOURNAL_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_FIBER_EMPTY": "Grandmaster Cropper's Journal (Empty)",
    "T7_JOURNAL_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_FIBER_FULL": "Grandmaster Cropper's Journal (Full)",
    "T7_JOURNAL_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_FISHING": "Grandmaster Fisherman's Journal (Partially Full)",
    "T7_JOURNAL_FISHING_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_FISHING_EMPTY": "Grandmaster Fisherman's Journal (Empty)",
    "T7_JOURNAL_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_FISHING_FULL": "Grandmaster Fisherman's Journal (Full)",
    "T7_JOURNAL_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_HIDE": "Grandmaster Gamekeeper's Journal (Partially Full)",
    "T7_JOURNAL_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_HIDE_EMPTY": "Grandmaster Gamekeeper's Journal (Empty)",
    "T7_JOURNAL_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_HIDE_FULL": "Grandmaster Gamekeeper's Journal (Full)",
    "T7_JOURNAL_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_HUNTER": "Grandmaster Fletcher's Journal (Partially Full)",
    "T7_JOURNAL_HUNTER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_HUNTER_EMPTY": "Grandmaster Fletcher's Journal (Empty)",
    "T7_JOURNAL_HUNTER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_HUNTER_FULL": "Grandmaster Fletcher's Journal (Full)",
    "T7_JOURNAL_HUNTER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_MAGE": "Grandmaster Imbuer's Journal (Partially Full)",
    "T7_JOURNAL_MAGE_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_MAGE_EMPTY": "Grandmaster Imbuer's Journal (Empty)",
    "T7_JOURNAL_MAGE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_MAGE_FULL": "Grandmaster Imbuer's Journal (Full)",
    "T7_JOURNAL_MAGE_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_MERCENARY": "Grandmaster Mercenary's Journal (Partially Full)",
    "T7_JOURNAL_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_MERCENARY_EMPTY": "Grandmaster Mercenary's Journal (Empty)",
    "T7_JOURNAL_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_MERCENARY_FULL": "Grandmaster Mercenary's Journal (Full)",
    "T7_JOURNAL_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_ORE": "Grandmaster Prospector's Journal (Partially Full)",
    "T7_JOURNAL_ORE_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_ORE_EMPTY": "Grandmaster Prospector's Journal (Empty)",
    "T7_JOURNAL_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_ORE_FULL": "Grandmaster Prospector's Journal (Full)",
    "T7_JOURNAL_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_STONE": "Grandmaster Stonecutter's Journal (Partially Full)",
    "T7_JOURNAL_STONE_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_STONE_EMPTY": "Grandmaster Stonecutter's Journal (Empty)",
    "T7_JOURNAL_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_STONE_FULL": "Grandmaster Stonecutter's Journal (Full)",
    "T7_JOURNAL_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TOOLMAKER": "Grandmaster Tinker's Journal (Partially Full)",
    "T7_JOURNAL_TOOLMAKER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TOOLMAKER_EMPTY": "Grandmaster Tinker's Journal (Empty)",
    "T7_JOURNAL_TOOLMAKER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TOOLMAKER_FULL": "Grandmaster Tinker's Journal (Full)",
    "T7_JOURNAL_TOOLMAKER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_FIBER": "Grandmaster Cropper's Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_FIBER_EMPTY": "Grandmaster Cropper's Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_FIBER_FULL": "Grandmaster Cropper's Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_FISHING": "Grandmaster Fisherman's Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_FISHING_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_FISHING_EMPTY": "Grandmaster Fisherman's Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_FISHING_FULL": "Grandmaster Fisherman's Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_GENERAL": "Grandmaster's Generalist Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_GENERAL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_GENERAL_EMPTY": "Grandmaster's Generalist Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_GENERAL_EMPTY_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_GENERAL_FULL": "Grandmaster's Generalist Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_GENERAL_FULL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_HIDE": "Grandmaster Gamekeeper's Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_HIDE_EMPTY": "Grandmaster Gamekeeper's Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_HIDE_FULL": "Grandmaster Gamekeeper's Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_MERCENARY": "Grandmaster Mercenary's Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_MERCENARY_EMPTY": "Grandmaster Mercenary's Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_MERCENARY_FULL": "Grandmaster Mercenary's Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_ORE": "Grandmaster Prospector's Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_ORE_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_ORE_EMPTY": "Grandmaster Prospector's Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_ORE_FULL": "Grandmaster Prospector's Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_STONE": "Grandmaster Stonecutter's Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_STONE_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_STONE_EMPTY": "Grandmaster Stonecutter's Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_STONE_FULL": "Grandmaster Stonecutter's Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_WOOD": "Grandmaster Lumberjack's Trophy Journal (Partially Full)",
    "T7_JOURNAL_TROPHY_WOOD_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_WOOD_EMPTY": "Grandmaster Lumberjack's Trophy Journal (Empty)",
    "T7_JOURNAL_TROPHY_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_TROPHY_WOOD_FULL": "Grandmaster Lumberjack's Trophy Journal (Full)",
    "T7_JOURNAL_TROPHY_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_WARRIOR": "Grandmaster Blacksmith's Journal (Partially Full)",
    "T7_JOURNAL_WARRIOR_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_WARRIOR_EMPTY": "Grandmaster Blacksmith's Journal (Empty)",
    "T7_JOURNAL_WARRIOR_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_WARRIOR_FULL": "Grandmaster Blacksmith's Journal (Full)",
    "T7_JOURNAL_WARRIOR_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_WOOD": "Grandmaster Lumberjack's Journal (Partially Full)",
    "T7_JOURNAL_WOOD_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_WOOD_EMPTY": "Grandmaster Lumberjack's Journal (Empty)",
    "T7_JOURNAL_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_JOURNAL_WOOD_FULL": "Grandmaster Lumberjack's Journal (Full)",
    "T7_JOURNAL_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T7_LABOURER_CONTRACT_FIBER": "Grandmaster Cropper Contract",
    "T7_LABOURER_CONTRACT_FIBER_DESC": "Croppers require filled Cropper's Journals and gather fiber.",
    "T7_LABOURER_CONTRACT_FISHERMAN": "Grandmaster Fisherman Contract",
    "T7_LABOURER_CONTRACT_FISHERMAN_DESC": "Fishermen require filled Fisherman's Journals and catch fish.",
    "T7_LABOURER_CONTRACT_HIDE": "Grandmaster Gamekeeper Contract",
    "T7_LABOURER_CONTRACT_HIDE_DESC": "Gamekeepers require filled Gamekeeper's Journals and gather hide.",
    "T7_LABOURER_CONTRACT_HUNTER": "Grandmaster Fletcher Contract",
    "T7_LABOURER_CONTRACT_HUNTER_DESC": "Fletchers require filled Fletcher's Journals and gather various refined materials.",
    "T7_LABOURER_CONTRACT_MAGE": "Grandmaster Imbuer Contract",
    "T7_LABOURER_CONTRACT_MAGE_DESC": "Imbuers require filled Imbuer's Journals and gather various refined materials.",
    "T7_LABOURER_CONTRACT_MERCENARY": "Grandmaster Mercenary Contract",
    "T7_LABOURER_CONTRACT_MERCENARY_DESC": "Mercenaries require filled Mercenary's Journals' and gather Silver.",
    "T7_LABOURER_CONTRACT_ORE": "Grandmaster Prospector Contract",
    "T7_LABOURER_CONTRACT_ORE_DESC": "Prospectors require filled Prospector's Journals and gather ore.",
    "T7_LABOURER_CONTRACT_STONE": "Grandmaster Stonecutter Contract",
    "T7_LABOURER_CONTRACT_STONE_DESC": "Stonecutters require filled Stonecutter's Journals and gather stone.",
    "T7_LABOURER_CONTRACT_TOOLMAKER": "Grandmaster Tinker Contract",
    "T7_LABOURER_CONTRACT_TOOLMAKER_DESC": "Tinkers require filled Tinker's Journals and gather various refined materials.",
    "T7_LABOURER_CONTRACT_WARRIOR": "Grandmaster Blacksmith Contract",
    "T7_LABOURER_CONTRACT_WARRIOR_DESC": "Blacksmiths require filled Blacksmith's Journals and gather various refined materials.",
    "T7_LABOURER_CONTRACT_WOOD": "Grandmaster Lumberjack Contract",
    "T7_LABOURER_CONTRACT_WOOD_DESC": "Lumberjacks require filled Lumberjack's Journals and gather wood.",
    "T7_LEATHER": "Reinforced Leather",
    "T7_LEATHER_DESC": "Advanced material used in crafting, created by refining hide.",
    "T7_LEATHER_LEVEL1": "Uncommon Reinforced Leather",
    "T7_LEATHER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_LEATHER_LEVEL2": "Rare Reinforced Leather",
    "T7_LEATHER_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_LEATHER_LEVEL3": "Exceptional Reinforced Leather",
    "T7_LEATHER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_LEATHER_LEVEL4": "Legendary Reinforced Leather",
    "T7_LEATHER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_LEATHER_LEVEL5": "Mythical Reinforced Leather",
    "T7_LEATHER_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_LOOTCHEST_CRYSTAL_LEAGUE": "Grandmaster's Crystal League Chest",
    "T7_MAIN_1HCROSSBOW": "Grandmaster's Light Crossbow",
    "T7_MAIN_1HCROSSBOW_DESC": "Equipment Item",
    "T7_MAIN_ARCANESTAFF": "Grandmaster's Arcane Staff",
    "T7_MAIN_ARCANESTAFF_DESC": "Equipment Item",
    "T7_MAIN_ARCANESTAFF_ENCHANTED": "Grandmaster's Enchanted Arcane Staff",
    "T7_MAIN_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_ARCANESTAFF_UNDEAD": "Grandmaster's Witchwork Staff",
    "T7_MAIN_ARCANESTAFF_UNDEAD_DESC": "Equipment Item",
    "T7_MAIN_AXE": "Grandmaster's Battleaxe",
    "T7_MAIN_AXE_DESC": "Equipment Item",
    "T7_MAIN_AXE_ENCHANTED": "Grandmaster's Enchanted Battleaxe",
    "T7_MAIN_AXE_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_CROSSBOW_ENCHANTED": "Grandmaster's Enchanted Crossbow",
    "T7_MAIN_CROSSBOW_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_CURSEDSTAFF": "Grandmaster's Cursed Staff",
    "T7_MAIN_CURSEDSTAFF_AVALON": "Grandmaster's Shadowcaller",
    "T7_MAIN_CURSEDSTAFF_AVALON_DESC": "Equipment Item",
    "T7_MAIN_CURSEDSTAFF_DESC": "Equipment Item",
    "T7_MAIN_CURSEDSTAFF_ENCHANTED": "Grandmaster's Enchanted Cursed Staff",
    "T7_MAIN_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_CURSEDSTAFF_UNDEAD": "Grandmaster's Lifecurse Staff",
    "T7_MAIN_CURSEDSTAFF_UNDEAD_DESC": "Equipment Item",
    "T7_MAIN_DAGGER": "Grandmaster's Dagger",
    "T7_MAIN_DAGGER_DESC": "Equipment Item",
    "T7_MAIN_DAGGER_ENCHANTED": "Grandmaster's Enchanted Dagger",
    "T7_MAIN_DAGGER_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_FIRESTAFF": "Grandmaster's Fire Staff",
    "T7_MAIN_FIRESTAFF_DESC": "Equipment Item",
    "T7_MAIN_FIRESTAFF_ENCHANTED": "Grandmaster's Enchanted Fire Staff",
    "T7_MAIN_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_FIRESTAFF_KEEPER": "Grandmaster's Wildfire Staff",
    "T7_MAIN_FIRESTAFF_KEEPER_DESC": "Equipment Item",
    "T7_MAIN_FROSTSTAFF": "Grandmaster's Frost Staff",
    "T7_MAIN_FROSTSTAFF_AVALON": "Grandmaster's Chillhowl",
    "T7_MAIN_FROSTSTAFF_AVALON_DESC": "Equipment Item",
    "T7_MAIN_FROSTSTAFF_DESC": "Equipment Item",
    "T7_MAIN_FROSTSTAFF_ENCHANTED": "Grandmaster's Enchanted Frost Staff",
    "T7_MAIN_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_FROSTSTAFF_KEEPER": "Grandmaster's Hoarfrost Staff",
    "T7_MAIN_FROSTSTAFF_KEEPER_DESC": "Equipment Item",
    "T7_MAIN_HAMMER": "Grandmaster's Hammer",
    "T7_MAIN_HAMMER_DESC": "Equipment Item",
    "T7_MAIN_HAMMER_ENCHANTED": "Grandmaster's Enchanted Hammer",
    "T7_MAIN_HAMMER_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_HOLYSTAFF": "Grandmaster's Holy Staff",
    "T7_MAIN_HOLYSTAFF_AVALON": "Grandmaster's Hallowfall",
    "T7_MAIN_HOLYSTAFF_AVALON_DESC": "Equipment Item",
    "T7_MAIN_HOLYSTAFF_DESC": "Equipment Item",
    "T7_MAIN_HOLYSTAFF_ENCHANTED": "Grandmaster's Enchanted Holy Staff",
    "T7_MAIN_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_HOLYSTAFF_MORGANA": "Grandmaster's Lifetouch Staff",
    "T7_MAIN_HOLYSTAFF_MORGANA_DESC": "Equipment Item",
    "T7_MAIN_MACE": "Grandmaster's Mace",
    "T7_MAIN_MACE_DESC": "Equipment Item",
    "T7_MAIN_MACE_ENCHANTED": "Grandmaster's Enchanted Mace",
    "T7_MAIN_MACE_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_MACE_HELL": "Grandmaster's Incubus Mace",
    "T7_MAIN_MACE_HELL_DESC": "Equipment Item",
    "T7_MAIN_NATURESTAFF": "Grandmaster's Nature Staff",
    "T7_MAIN_NATURESTAFF_AVALON": "Grandmaster's Ironroot Staff",
    "T7_MAIN_NATURESTAFF_AVALON_DESC": "Equipment Item",
    "T7_MAIN_NATURESTAFF_DESC": "Equipment Item",
    "T7_MAIN_NATURESTAFF_ENCHANTED": "Grandmaster's Enchanted Nature Staff",
    "T7_MAIN_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_NATURESTAFF_KEEPER": "Grandmaster's Druidic Staff",
    "T7_MAIN_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T7_MAIN_RAPIER_MORGANA": "Grandmaster's Bloodletter",
    "T7_MAIN_RAPIER_MORGANA_DESC": "Equipment Item",
    "T7_MAIN_REPEATINGCROSSBOW": "Grandmaster's Repeating Crossbow",
    "T7_MAIN_REPEATINGCROSSBOW_DESC": "Equipment Item",
    "T7_MAIN_REPEATINGCROSSBOW_ENCHANTED": "Grandmaster's Enchanted Repeating Crossbow",
    "T7_MAIN_REPEATINGCROSSBOW_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_ROCKMACE_KEEPER": "Grandmaster's Bedrock Mace",
    "T7_MAIN_ROCKMACE_KEEPER_DESC": "Equipment Item",
    "T7_MAIN_SCIMITAR_MORGANA": "Grandmaster's Clarent Blade",
    "T7_MAIN_SCIMITAR_MORGANA_DESC": "Equipment Item",
    "T7_MAIN_SPEAR": "Grandmaster's Spear",
    "T7_MAIN_SPEAR_DESC": "Equipment Item",
    "T7_MAIN_SPEAR_ENCHANTED": "Grandmaster's Enchanted Spear",
    "T7_MAIN_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T7_MAIN_SPEAR_KEEPER": "Grandmaster's Heron Spear",
    "T7_MAIN_SPEAR_KEEPER_DESC": "Equipment Item",
    "T7_MAIN_SPEAR_LANCE_AVALON": "Grandmaster's Daybreaker",
    "T7_MAIN_SPEAR_LANCE_AVALON_DESC": "Equipment Item",
    "T7_MAIN_SWORD": "Grandmaster's Broadsword",
    "T7_MAIN_SWORD_DESC": "Equipment Item",
    "T7_MAIN_SWORD_ENCHANTED": "Grandmaster's Enchanted Broadsword",
    "T7_MAIN_SWORD_ENCHANTED_DESC": "Equipment Item",
    "T7_MEAL_OMELETTE": "Pork Omelette",
    "T7_MEAL_OMELETTE_AVALON": "Avalonian Pork Omelette",
    "T7_MEAL_OMELETTE_AVALON_DESC": "Avalonian meal that reduces cooldown periods and casting times, while also increasing your defense for a long period.",
    "T7_MEAL_OMELETTE_DESC": "Solid meal that reduces cooldown periods and casting times for a long period.",
    "T7_MEAL_OMELETTE_FISH": "Dusthole Crab Omelette",
    "T7_MEAL_PIE": "Pork Pie",
    "T7_MEAL_PIE_DESC": "Solid meal that increases maximum load and gathering yield for a long period.",
    "T7_MEAL_PIE_FISH": "Frostpeak Deadeye Pie",
    "T7_MEAL_ROAST": "Roast Pork",
    "T7_MEAL_ROAST_DESC": "A savory meal that heals you based on the damage you deal for a long period.",
    "T7_MEAL_ROAST_FISH": "Roasted Puremist Snapper",
    "T7_MEAL_ROAST_FISH_DESC": "A savory meal that heals you based on the damage you deal and raises your max health for a long period.",
    "T7_MEAT": "Raw Pork",
    "T7_MEAT_DESC": "Cooking ingredient, used in various recipes.",
    "T7_METALBAR": "Meteorite Steel Bar",
    "T7_METALBAR_DESC": "Advanced material used in crafting, created by refining ore.",
    "T7_METALBAR_LEVEL1": "Uncommon Meteorite Steel Bar",
    "T7_METALBAR_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_METALBAR_LEVEL2": "Rare Meteorite Steel Bar",
    "T7_METALBAR_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_METALBAR_LEVEL3": "Exceptional Meteorite Steel Bar",
    "T7_METALBAR_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_METALBAR_LEVEL4": "Legendary Meteorite Steel Bar",
    "T7_METALBAR_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_METALBAR_LEVEL5": "Mythical Meteorite Steel Bar",
    "T7_METALBAR_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_MOBDROP_DIREBOAR_HEAD": "Direboar's Head",
    "T7_MOBDROP_DIREBOAR_HEAD_DESC": "Use to craft a trophy you can place in your house",
    "T7_MOUNT_ARMORED_HORSE": "Grandmaster's Armored Horse",
    "T7_MOUNT_ARMORED_HORSE_DESC": "Protected by thick plating, an armored horse is ideal for traveling through Albion's more dangerous regions at speed.",
    "T7_MOUNT_ARMORED_HORSE_SKIN_01": "Grandmaster's Warhorse",
    "T7_MOUNT_ARMORED_HORSE_SKIN_01_DESC": "An armored horse bearing the impressive banner of its rider's guild. Ideal for raising morale in big battles.",
    "T7_MOUNT_ARMORED_SWAMPDRAGON_BATTLE": "Venom Basilisk",
    "T7_MOUNT_ARMORED_SWAMPDRAGON_BATTLE_DESC": "Battle Mount - This armored mount can lunge at enemies and poison them. Immune to displacement effects.",
    "T7_MOUNT_ARMORED_SWAMPDRAGON_BATTLE_LEGACY": "Venom Basilisk (Legacy)",
    "T7_MOUNT_ARMORED_SWAMPDRAGON_BATTLE_LEGACY_DESC": "This item was crafted before an economic update. Can be exchanged for its original energy value for a limited time.",
    "T7_MOUNT_DIREBOAR": "Saddled Direboar",
    "T7_MOUNT_DIREBOAR_DESC": "Mount",
    "T7_MOUNT_HORSE": "Grandmaster's Riding Horse",
    "T7_MOUNT_HORSE_DESC": "Lean and agile, Albion horses can carry their riders quickly across the continent, but have little strength to bear heavy items.",
    "T7_MOUNT_HUSKY_ADC": "Snow Husky",
    "T7_MOUNT_HUSKY_ADC_DESC": "Adventurer's Challenge Reward - A very good sprinter with a positive and loyal attitude towards humans.",
    "T7_MOUNT_MONITORLIZARD_ADC": "Pest Lizard",
    "T7_MOUNT_MONITORLIZARD_ADC_DESC": "Adventurer's Challenge Reward - Quick and hard to catch, this baleful creature can emit intoxicating poison when threatened.",
    "T7_MOUNT_OX": "Grandmaster's Transport Ox",
    "T7_MOUNT_OX_DESC": "Albion oxen are tough, and sturdy enough to carry large quantities of goods, but cannot match the pace of the continent's horses.",
    "T7_MOUNT_SWAMPDRAGON": "Saddled Swamp Dragon",
    "T7_MOUNT_SWAMPDRAGON_AVALON_BASILISK": "Avalonian Basilisk",
    "T7_MOUNT_SWAMPDRAGON_AVALON_BASILISK_DESC": "A Swamp Dragon infused with Avalonian Energy. Can discharge energy to escape from attackers.",
    "T7_MOUNT_SWAMPDRAGON_BATTLE": "Flame Basilisk",
    "T7_MOUNT_SWAMPDRAGON_BATTLE_DESC": "Battle Mount - This mount can breathe fire on enemies and ignite them from a distance. Immune to displacement effects.",
    "T7_MOUNT_SWAMPDRAGON_BATTLE_LEGACY": "Flame Basilisk (Legacy)",
    "T7_MOUNT_SWAMPDRAGON_BATTLE_LEGACY_DESC": "This item was crafted before an economic update. Can be exchanged for its original energy value for a limited time.",
    "T7_MOUNT_SWAMPDRAGON_DESC": "Mount",
    "T7_MOUNT_TERRORBIRD_ADC": "Saddled Terrorbird",
    "T7_MOUNT_TERRORBIRD_ADC_DESC": "Adventurer's Challenge Reward - These animals like to toy with humans, but once trained become very fast and reliable companions.",
    "T7_MULLEIN": "Firetouched Mullein",
    "T7_MULLEIN_DESC": "Firetouched Mullein is used in various alchemical decoctions.",
    "T7_OFF_BOOK": "Grandmaster's Tome of Spells",
    "T7_OFF_BOOK_DESC": "Equipment Item",
    "T7_OFF_BOOK_ENCHANTED": "Grandmaster's Enchanted Tome of Spells",
    "T7_OFF_BOOK_ENCHANTED_DESC": "Equipment Item",
    "T7_OFF_CENSER_AVALON": "Grandmaster's Celestial Censer",
    "T7_OFF_CENSER_AVALON_DESC": "Equipment Item",
    "T7_OFF_DEMONSKULL_HELL": "Grandmaster's Muisak",
    "T7_OFF_DEMONSKULL_HELL_DESC": "Equipment Item",
    "T7_OFF_HORN_KEEPER": "Grandmaster's Mistcaller",
    "T7_OFF_HORN_KEEPER_DESC": "Equipment Item",
    "T7_OFF_JESTERCANE_HELL": "Grandmaster's Leering Cane",
    "T7_OFF_JESTERCANE_HELL_DESC": "Equipment Item",
    "T7_OFF_LAMP_UNDEAD": "Grandmaster's Cryptcandle",
    "T7_OFF_LAMP_UNDEAD_DESC": "Equipment Item",
    "T7_OFF_ORB_MORGANA": "Grandmaster's Eye of Secrets",
    "T7_OFF_ORB_MORGANA_DESC": "Equipment Item",
    "T7_OFF_SHIELD": "Grandmaster's Shield",
    "T7_OFF_SHIELD_AVALON": "Grandmaster's Astral Aegis",
    "T7_OFF_SHIELD_AVALON_DESC": "Equipment Item",
    "T7_OFF_SHIELD_DESC": "Equipment Item",
    "T7_OFF_SHIELD_ENCHANTED": "Grandmaster's Enchanted Shield",
    "T7_OFF_SHIELD_ENCHANTED_DESC": "Equipment Item",
    "T7_OFF_SHIELD_HELL": "Grandmaster's Caitiff Shield",
    "T7_OFF_SHIELD_HELL_DESC": "Equipment Item",
    "T7_OFF_SPIKEDSHIELD_MORGANA": "Grandmaster's Facebreaker",
    "T7_OFF_SPIKEDSHIELD_MORGANA_DESC": "Equipment Item",
    "T7_OFF_TALISMAN_AVALON": "Grandmaster's Sacred Scepter",
    "T7_OFF_TALISMAN_AVALON_DESC": "Equipment Item",
    "T7_OFF_TORCH": "Grandmaster's Torch",
    "T7_OFF_TORCH_DESC": "Equipment Item",
    "T7_OFF_TORCH_ENCHANTED": "Grandmaster's Enchanted Torch",
    "T7_OFF_TORCH_ENCHANTED_DESC": "Equipment Item",
    "T7_OFF_TOTEM_KEEPER": "Grandmaster's Taproot",
    "T7_OFF_TOTEM_KEEPER_DESC": "Equipment Item",
    "T7_OFF_TOWERSHIELD_UNDEAD": "Grandmaster's Sarcophagus",
    "T7_OFF_TOWERSHIELD_UNDEAD_DESC": "Equipment Item",
    "T7_ORE": "Meteorite Ore",
    "T7_ORE_DESC": "Ore used for crafting. Can be refined into metal bars or transmuted into higher-level material.",
    "T7_ORE_LEVEL1": "Uncommon Meteorite Ore",
    "T7_ORE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_ORE_LEVEL2": "Rare Meteorite Ore",
    "T7_ORE_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_ORE_LEVEL3": "Exceptional Meteorite Ore",
    "T7_ORE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_ORE_LEVEL4": "Legendary Meteorite Ore",
    "T7_ORE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_ORE_LEVEL5": "Mythical Meteorite Ore",
    "T7_ORE_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_PLANKS": "Ashenbark Planks",
    "T7_PLANKS_DESC": "Advanced material used in crafting, created by refining logs.",
    "T7_PLANKS_LEVEL1": "Uncommon Ashenbark Planks",
    "T7_PLANKS_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_PLANKS_LEVEL2": "Rare Ashenbark Planks",
    "T7_PLANKS_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_PLANKS_LEVEL3": "Exceptional Ashenbark Planks",
    "T7_PLANKS_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_PLANKS_LEVEL4": "Legendary Ashenbark Planks",
    "T7_PLANKS_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_PLANKS_LEVEL5": "Mythical Ashenbark Planks",
    "T7_PLANKS_LEVEL5_DESC": "Mythical material used for crafting.",
    "T7_POTION_REVIVE": "Major Gigantify Potion",
    "T7_POTION_REVIVE_DESC": "Mystical Potion. Temporarily increases your max load and max health.",
    "T7_POTION_SLOWFIELD": "Major Sticky Potion",
    "T7_POTION_SLOWFIELD_DESC": "A viscous potion. Throw it on a ground location to create an area that slows enemies and reduces their damage.",
    "T7_POTION_STONESKIN": "Major Resistance Potion",
    "T7_POTION_STONESKIN_DESC": "Sluggish potion. Increases defenses substantially for a short period.",
    "T7_RANDOM_DUNGEON_ELITE_TOKEN_1": "Grandmaster's Dungeon Map (Large Group)",
    "T7_RANDOM_DUNGEON_ELITE_TOKEN_2": "Uncommon Grandmaster's Dungeon Map (Large Group)",
    "T7_RANDOM_DUNGEON_ELITE_TOKEN_3": "Rare Grandmaster's Dungeon Map (Large Group)",
    "T7_RANDOM_DUNGEON_ELITE_TOKEN_4": "Exceptional Grandmaster's Dungeon Map (Large Group)",
    "T7_RANDOM_DUNGEON_SOLO_TOKEN_1": "Grandmaster's Dungeon Map (Solo)",
    "T7_RANDOM_DUNGEON_SOLO_TOKEN_2": "Uncommon Grandmaster's Dungeon Map (Solo)",
    "T7_RANDOM_DUNGEON_SOLO_TOKEN_3": "Rare Grandmaster's Dungeon Map (Solo)",
    "T7_RANDOM_DUNGEON_SOLO_TOKEN_4": "Exceptional Grandmaster's Dungeon Map (Solo)",
    "T7_RANDOM_DUNGEON_TOKEN_1": "Grandmaster's Dungeon Map (Group)",
    "T7_RANDOM_DUNGEON_TOKEN_2": "Uncommon Grandmaster's Dungeon Map (Group)",
    "T7_RANDOM_DUNGEON_TOKEN_3": "Rare Grandmaster's Dungeon Map (Group)",
    "T7_RANDOM_DUNGEON_TOKEN_4": "Exceptional Grandmaster's Dungeon Map (Group)",
    "T7_RELIC": "Grandmaster's Relic",
    "T7_RELIC_DESC": "An ancient relic, used to meld artifacts and enchant equipment.",
    "T7_RELIC_DESTRUCTION": "Ancient Relic of Destruction",
    "T7_RELIC_DESTRUCTION_DESC": "Special material used in crafting. It can be transmuted into a better relic.",
    "T7_RELIC_MANIPULATION": "Ancient Relic of Manipulation",
    "T7_RELIC_MANIPULATION_DESC": "Special material used in crafting. It can be transmuted into a better relic.",
    "T7_RELIC_PROTECTION": "Ancient Relic of Protection",
    "T7_RELIC_PROTECTION_DESC": "Special material used in crafting. It can be transmuted into a better relic.",
    "T7_ROCK": "Basalt",
    "T7_ROCK_DESC": "Stone used for crafting. Can be refined into stone blocks or transmuted into higher-level material.",
    "T7_ROCK_LEVEL1": "Uncommon Basalt",
    "T7_ROCK_LEVEL1_DESC": "Uncommon stone, more efficient in refining.",
    "T7_ROCK_LEVEL2": "Rare Basalt",
    "T7_ROCK_LEVEL2_DESC": "Rare stone, more efficient in refining.",
    "T7_ROCK_LEVEL3": "Exceptional Basalt",
    "T7_ROCK_LEVEL3_DESC": "Exceptional stone, more efficient in refining.",
    "T7_RUNE": "Grandmaster's Rune",
    "T7_RUNE_DESC": "A pulsing rune, used to meld artifacts and enchant equipment.",
    "T7_RUNE_DESTRUCTION": "Grand Rune of Destruction",
    "T7_RUNE_DESTRUCTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T7_RUNE_MANIPULATION": "Grand Rune of Manipulation",
    "T7_RUNE_MANIPULATION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T7_RUNE_PROTECTION": "Grand Rune of Protection",
    "T7_RUNE_PROTECTION_DESC": "Special material used in crafting. It can be transmuted into a better rune.",
    "T7_SHARD_AVALONIAN": "Grandmaster's Avalonian Shard",
    "T7_SHOES_CLOTH_AVALON": "Grandmaster's Sandals of Purity",
    "T7_SHOES_CLOTH_HELL": "Grandmaster's Fiend Sandals",
    "T7_SHOES_CLOTH_HELL_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_KEEPER": "Grandmaster's Druid Sandals",
    "T7_SHOES_CLOTH_KEEPER_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_MORGANA": "Grandmaster's Cultist Sandals",
    "T7_SHOES_CLOTH_MORGANA_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_ROYAL": "Grandmaster's Royal Sandals",
    "T7_SHOES_CLOTH_ROYAL_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_SET1": "Grandmaster's Scholar Sandals",
    "T7_SHOES_CLOTH_SET1_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_SET1_ENCHANTED": "Enchanted Grandmaster's Scholar Sandals",
    "T7_SHOES_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_SET2": "Grandmaster's Cleric Sandals",
    "T7_SHOES_CLOTH_SET2_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_SET2_ENCHANTED": "Enchanted Grandmaster's Cleric Sandals",
    "T7_SHOES_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_SET3": "Grandmaster's Mage Sandals",
    "T7_SHOES_CLOTH_SET3_DESC": "Equipment Item",
    "T7_SHOES_CLOTH_SET3_ENCHANTED": "Enchanted Grandmaster's Mage Sandals",
    "T7_SHOES_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_GATHERER_FIBER": "Grandmaster's Harvester Workboots",
    "T7_SHOES_GATHERER_FIBER_DESC": "Equipment Item",
    "T7_SHOES_GATHERER_FISH": "Grandmaster's Fisherman Workboots",
    "T7_SHOES_GATHERER_FISH_DESC": "Equipment Item",
    "T7_SHOES_GATHERER_HIDE": "Grandmaster's Skinner Workboots",
    "T7_SHOES_GATHERER_HIDE_DESC": "Equipment Item",
    "T7_SHOES_GATHERER_ORE": "Grandmaster's Miner Workboots",
    "T7_SHOES_GATHERER_ORE_DESC": "Equipment Item",
    "T7_SHOES_GATHERER_ROCK": "Grandmaster's Quarrier Workboots",
    "T7_SHOES_GATHERER_ROCK_DESC": "Equipment Item",
    "T7_SHOES_GATHERER_WOOD": "Grandmaster's Lumberjack Workboots",
    "T7_SHOES_GATHERER_WOOD_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_AVALON": "Grandmaster's Shoes of Tenacity",
    "T7_SHOES_LEATHER_HELL": "Grandmaster's Hellion Shoes",
    "T7_SHOES_LEATHER_HELL_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_MORGANA": "Grandmaster's Stalker Shoes",
    "T7_SHOES_LEATHER_MORGANA_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_ROYAL": "Grandmaster's Royal Shoes",
    "T7_SHOES_LEATHER_ROYAL_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_SET1": "Grandmaster's Mercenary Shoes",
    "T7_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_SET1_ENCHANTED": "Enchanted Grandmaster's Mercenary Shoes",
    "T7_SHOES_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_SET2": "Grandmaster's Hunter Shoes",
    "T7_SHOES_LEATHER_SET2_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_SET2_ENCHANTED": "Enchanted Grandmaster's Hunter Shoes",
    "T7_SHOES_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_SET3": "Grandmaster's Assassin Shoes",
    "T7_SHOES_LEATHER_SET3_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_SET3_ENCHANTED": "Enchanted Grandmaster's Assassin Shoes",
    "T7_SHOES_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_LEATHER_UNDEAD": "Grandmaster's Specter Shoes",
    "T7_SHOES_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T7_SHOES_PLATE_AVALON": "Grandmaster's Boots of Valor",
    "T7_SHOES_PLATE_HELL": "Grandmaster's Demon Boots",
    "T7_SHOES_PLATE_HELL_DESC": "Equipment Item",
    "T7_SHOES_PLATE_KEEPER": "Grandmaster's Judicator Boots",
    "T7_SHOES_PLATE_KEEPER_DESC": "Equipment Item",
    "T7_SHOES_PLATE_ROYAL": "Grandmaster's Royal Boots",
    "T7_SHOES_PLATE_ROYAL_DESC": "Equipment Item",
    "T7_SHOES_PLATE_SET1": "Grandmaster's Soldier Boots",
    "T7_SHOES_PLATE_SET1_DESC": "Equipment Item",
    "T7_SHOES_PLATE_SET1_ENCHANTED": "Enchanted Grandmaster's Soldier Boots",
    "T7_SHOES_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_PLATE_SET2": "Grandmaster's Knight Boots",
    "T7_SHOES_PLATE_SET2_DESC": "Equipment Item",
    "T7_SHOES_PLATE_SET2_ENCHANTED": "Enchanted Grandmaster's Knight Boots",
    "T7_SHOES_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_PLATE_SET3": "Grandmaster's Guardian Boots",
    "T7_SHOES_PLATE_SET3_DESC": "Equipment Item",
    "T7_SHOES_PLATE_SET3_ENCHANTED": "Enchanted Grandmaster's Guardian Boots",
    "T7_SHOES_PLATE_SET3_ENCHANTED_DESC": "Equipment Item",
    "T7_SHOES_PLATE_UNDEAD": "Grandmaster's Graveguard Boots",
    "T7_SHOES_PLATE_UNDEAD_DESC": "Equipment Item",
    "T7_SILVERBAG_NONTRADABLE": "Grandmaster's Bag of Silver",
    "T7_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T7_SKILLBOOK_NONTRADABLE": "Grandmaster's Tome of Insight",
    "T7_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 100,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T7_SOUL": "Grandmaster's Soul",
    "T7_SOUL_DESC": "A tortured soul, used to meld artifacts and enchant equipment.",
    "T7_SOUL_HUNTER": "Heroic Hunter's Soul",
    "T7_SOUL_HUNTER_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T7_SOUL_MAGE": "Heroic Mage's Soul",
    "T7_SOUL_MAGE_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T7_SOUL_WARRIOR": "Heroic Warrior's Soul",
    "T7_SOUL_WARRIOR_DESC": "Special material used for crafting. It can be transmuted to a greater soul.",
    "T7_STONEBLOCK": "Basalt Block",
    "T7_STONEBLOCK_DESC": "Advanced material used in crafting, created by refining stone.",
    "T7_TRASH": "Trash",
    "T7_TRASH_DESC": "A destroyed T7 item. Cannot be repaired or salvaged.",
    "T7_WOOD": "Ashenbark Logs",
    "T7_WOOD_DESC": "Logs used for crafting. Can be refined into planks or transmuted into higher-level material.",
    "T7_WOOD_LEVEL1": "Uncommon Ashenbark Logs",
    "T7_WOOD_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T7_WOOD_LEVEL2": "Rare Ashenbark Logs",
    "T7_WOOD_LEVEL2_DESC": "Rare material used for crafting.",
    "T7_WOOD_LEVEL3": "Exceptional Ashenbark Logs",
    "T7_WOOD_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T7_WOOD_LEVEL4": "Legendary Ashenbark Logs",
    "T7_WOOD_LEVEL4_DESC": "Legendary material used for crafting.",
    "T7_WOOD_LEVEL5": "Mythical Ashenbark Logs",
    "T7_WOOD_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_2H_ARCANE_RINGPAIR_AVALON": "Elder's Evensong",
    "T8_2H_ARCANE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T8_2H_ARCANESTAFF": "Elder's Great Arcane Staff",
    "T8_2H_ARCANESTAFF_DESC": "Equipment Item",
    "T8_2H_ARCANESTAFF_ENCHANTED": "Elder's Enchanted Great Arcane Staff",
    "T8_2H_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_ARCANESTAFF_HELL": "Elder's Occult Staff",
    "T8_2H_ARCANESTAFF_HELL_DESC": "Equipment Item",
    "T8_2H_AXE": "The Hand of Khor",
    "T8_2H_AXE_AVALON": "Elder's Realmbreaker",
    "T8_2H_AXE_AVALON_DESC": "Equipment Item",
    "T8_2H_AXE_DESC": "Equipment Item - an Elder's Greataxe, named to honor the player Khor and his victories in the Alpha.",
    "T8_2H_AXE_ENCHANTED": "Enchanted Hand of Khor",
    "T8_2H_AXE_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_BOW": "Elder's Bow",
    "T8_2H_BOW_AVALON": "Elder's Mistpiercer",
    "T8_2H_BOW_AVALON_DESC": "Equipment Item",
    "T8_2H_BOW_DESC": "Equipment Item",
    "T8_2H_BOW_ENCHANTED": "Elder's Enchanted Bow",
    "T8_2H_BOW_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_BOW_HELL": "Elder's Wailing Bow",
    "T8_2H_BOW_HELL_DESC": "Equipment Item",
    "T8_2H_BOW_KEEPER": "Elder's Bow of Badon",
    "T8_2H_BOW_KEEPER_DESC": "Equipment Item",
    "T8_2H_CLAWPAIR": "Elder's Claws",
    "T8_2H_CLAWPAIR_DESC": "Equipment Item",
    "T8_2H_CLAWPAIR_ENCHANTED": "Elder's Enchanted Claws",
    "T8_2H_CLAWPAIR_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_CLAYMORE": "Elder's Claymore",
    "T8_2H_CLAYMORE_AVALON": "Elder's Kingmaker",
    "T8_2H_CLAYMORE_AVALON_DESC": "Equipment Item",
    "T8_2H_CLAYMORE_DESC": "Equipment Item",
    "T8_2H_CLAYMORE_ENCHANTED": "Elder's Enchanted Claymore",
    "T8_2H_CLAYMORE_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_CLEAVER_HELL": "Elder's Carving Sword",
    "T8_2H_CLEAVER_HELL_DESC": "Equipment Item",
    "T8_2H_COMBATSTAFF_MORGANA": "Elder's Black Monk Stave",
    "T8_2H_COMBATSTAFF_MORGANA_DESC": "Equipment Item",
    "T8_2H_CROSSBOW": "Elder's Crossbow",
    "T8_2H_CROSSBOW_CANNON_AVALON": "Elder's Energy Shaper",
    "T8_2H_CROSSBOW_CANNON_AVALON_DESC": "Equipment Item",
    "T8_2H_CROSSBOW_DESC": "Equipment Item",
    "T8_2H_CROSSBOWLARGE": "Elder's Heavy Crossbow",
    "T8_2H_CROSSBOWLARGE_DESC": "Equipment Item",
    "T8_2H_CROSSBOWLARGE_ENCHANTED": "Elder's Enchanted Heavy Crossbow",
    "T8_2H_CROSSBOWLARGE_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_CROSSBOWLARGE_MORGANA": "Elder's Siegebow",
    "T8_2H_CROSSBOWLARGE_MORGANA_DESC": "Equipment Item",
    "T8_2H_CURSEDSTAFF": "Elder's Great Cursed Staff",
    "T8_2H_CURSEDSTAFF_DESC": "Equipment Item",
    "T8_2H_CURSEDSTAFF_ENCHANTED": "Elder's Enchanted Great Cursed Staff",
    "T8_2H_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_CURSEDSTAFF_MORGANA": "Elder's Damnation Staff",
    "T8_2H_CURSEDSTAFF_MORGANA_DESC": "Equipment Item",
    "T8_2H_DAGGER_KATAR_AVALON": "Elder's Bridled Fury",
    "T8_2H_DAGGER_KATAR_AVALON_DESC": "Equipment Item",
    "T8_2H_DAGGERPAIR": "Elder's Dagger Pair",
    "T8_2H_DAGGERPAIR_DESC": "Equipment Item",
    "T8_2H_DAGGERPAIR_ENCHANTED": "Elder's Enchanted Dagger Pair",
    "T8_2H_DAGGERPAIR_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_DEMONICSTAFF": "Elder's Demonic Staff",
    "T8_2H_DEMONICSTAFF_DESC": "Equipment Item",
    "T8_2H_DEMONICSTAFF_ENCHANTED": "Elder's Enchanted Demonic Staff",
    "T8_2H_DEMONICSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_DIVINESTAFF": "Elder's Divine Staff",
    "T8_2H_DIVINESTAFF_DESC": "Equipment Item",
    "T8_2H_DIVINESTAFF_ENCHANTED": "Elder's Enchanted Divine Staff",
    "T8_2H_DIVINESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_DOUBLEBLADEDSTAFF": "Elder's Double Bladed Staff",
    "T8_2H_DOUBLEBLADEDSTAFF_DESC": "Equipment Item",
    "T8_2H_DOUBLEBLADEDSTAFF_ENCHANTED": "Elder's Enchanted Double Bladed Staff",
    "T8_2H_DOUBLEBLADEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_DUALAXE_KEEPER": "Elder's Bear Paws",
    "T8_2H_DUALAXE_KEEPER_DESC": "Equipment Item",
    "T8_2H_DUALCROSSBOW_HELL": "Elder's Boltcasters",
    "T8_2H_DUALCROSSBOW_HELL_DESC": "Equipment Item",
    "T8_2H_DUALHAMMER_HELL": "Elder's Forge Hammers",
    "T8_2H_DUALHAMMER_HELL_DESC": "Equipment Item",
    "T8_2H_DUALMACE_AVALON": "Elder's Oathkeepers",
    "T8_2H_DUALMACE_AVALON_DESC": "Equipment Item",
    "T8_2H_DUALSCIMITAR_UNDEAD": "Elder's Galatine Pair",
    "T8_2H_DUALSCIMITAR_UNDEAD_DESC": "Equipment Item",
    "T8_2H_DUALSICKLE_UNDEAD": "Elder's Deathgivers",
    "T8_2H_DUALSICKLE_UNDEAD_DESC": "Equipment Item",
    "T8_2H_DUALSWORD": "Elder's Dual Swords",
    "T8_2H_DUALSWORD_DESC": "Equipment Item",
    "T8_2H_ENIGMATICORB_MORGANA": "Elder's Malevolent Locus",
    "T8_2H_ENIGMATICORB_MORGANA_DESC": "Equipment Item",
    "T8_2H_ENIGMATICSTAFF": "Elder's Enigmatic Staff",
    "T8_2H_ENIGMATICSTAFF_DESC": "Equipment Item",
    "T8_2H_ENIGMATICSTAFF_ENCHANTED": "Elder's Enchanted Enigmatic Staff",
    "T8_2H_ENIGMATICSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_FIRE_RINGPAIR_AVALON": "Elder's Dawnsong",
    "T8_2H_FIRE_RINGPAIR_AVALON_DESC": "Equipment Item",
    "T8_2H_FIRESTAFF": "Vendetta's Wrath",
    "T8_2H_FIRESTAFF_DESC": "Equipment Item - an Elder's Great Fire Staff, named after the guild 'Vendetta' to honor its victories in the Alpha.",
    "T8_2H_FIRESTAFF_ENCHANTED": "Elder's Enchanted Fire Staff",
    "T8_2H_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_FIRESTAFF_HELL": "Elder's Brimstone Staff",
    "T8_2H_FIRESTAFF_HELL_DESC": "Equipment Item",
    "T8_2H_FLAIL": "Elder's Morning Star",
    "T8_2H_FLAIL_DESC": "Equipment Item",
    "T8_2H_FLAIL_ENCHANTED": "Elder's Enchanted Morning Star",
    "T8_2H_FLAIL_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_FROSTSTAFF": "Elder's Great Frost Staff",
    "T8_2H_FROSTSTAFF_DESC": "Equipment Item",
    "T8_2H_FROSTSTAFF_ENCHANTED": "Elder's Enchanted Great Frost Staff",
    "T8_2H_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_GLACIALSTAFF": "Elder's Glacial Staff",
    "T8_2H_GLACIALSTAFF_DESC": "Equipment Item",
    "T8_2H_GLACIALSTAFF_ENCHANTED": "Elder's Enchanted Glacial Staff",
    "T8_2H_GLACIALSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_GLAIVE": "Elder's Glaive",
    "T8_2H_GLAIVE_DESC": "Equipment Item",
    "T8_2H_GLAIVE_ENCHANTED": "Elder's Enchanted Glaive",
    "T8_2H_GLAIVE_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_HALBERD": "Elder's Halberd",
    "T8_2H_HALBERD_DESC": "Equipment Item",
    "T8_2H_HALBERD_ENCHANTED": "Elder's Enchanted Halberd",
    "T8_2H_HALBERD_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_HALBERD_MORGANA": "Elder's Carrioncaller",
    "T8_2H_HALBERD_MORGANA_DESC": "Equipment Item",
    "T8_2H_HAMMER": "Elder's Great Hammer",
    "T8_2H_HAMMER_AVALON": "Elder's Hand of Justice",
    "T8_2H_HAMMER_AVALON_DESC": "Equipment Item",
    "T8_2H_HAMMER_DESC": "Equipment Item",
    "T8_2H_HAMMER_ENCHANTED": "Elder's Enchanted Great Hammer",
    "T8_2H_HAMMER_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_HAMMER_UNDEAD": "Elder's Tombhammer",
    "T8_2H_HAMMER_UNDEAD_DESC": "Equipment Item",
    "T8_2H_HARPOON_HELL": "Elder's Spirithunter",
    "T8_2H_HARPOON_HELL_DESC": "Equipment Item",
    "T8_2H_HOLYSTAFF": "Elder's Great Holy Staff",
    "T8_2H_HOLYSTAFF_DESC": "Equipment Item",
    "T8_2H_HOLYSTAFF_ENCHANTED": "Elder's Enchanted Great Holy Staff",
    "T8_2H_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_HOLYSTAFF_HELL": "Elder's Fallen Staff",
    "T8_2H_HOLYSTAFF_HELL_DESC": "Equipment Item",
    "T8_2H_HOLYSTAFF_UNDEAD": "Elder's Redemption Staff",
    "T8_2H_HOLYSTAFF_UNDEAD_DESC": "Equipment Item",
    "T8_2H_ICECRYSTAL_UNDEAD": "Elder's Permafrost Prism",
    "T8_2H_ICECRYSTAL_UNDEAD_DESC": "Equipment Item",
    "T8_2H_ICEGAUNTLETS_HELL": "Elder's Icicle Staff",
    "T8_2H_ICEGAUNTLETS_HELL_DESC": "Equipment Item",
    "T8_2H_INFERNOSTAFF": "Elder's Infernal Staff",
    "T8_2H_INFERNOSTAFF_DESC": "Equipment Item",
    "T8_2H_INFERNOSTAFF_ENCHANTED": "Elder's Enchanted Infernal Staff",
    "T8_2H_INFERNOSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_INFERNOSTAFF_MORGANA": "Elder's Blazing Staff",
    "T8_2H_INFERNOSTAFF_MORGANA_DESC": "Equipment Item",
    "T8_2H_IRONCLADEDSTAFF": "Elder's Iron-clad Staff",
    "T8_2H_IRONCLADEDSTAFF_DESC": "Equipment Item",
    "T8_2H_IRONCLADEDSTAFF_ENCHANTED": "Elder's Enchanted Iron-clad Staff",
    "T8_2H_IRONCLADEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_IRONGAUNTLETS_HELL": "Elder's Black Hands",
    "T8_2H_IRONGAUNTLETS_HELL_DESC": "Equipment Item",
    "T8_2H_LONGBOW": "Elder's Longbow",
    "T8_2H_LONGBOW_DESC": "Equipment Item",
    "T8_2H_LONGBOW_ENCHANTED": "Elder's Enchanted Longbow",
    "T8_2H_LONGBOW_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_LONGBOW_UNDEAD": "Elder's Whispering Bow",
    "T8_2H_LONGBOW_UNDEAD_DESC": "Equipment Item",
    "T8_2H_MACE": "Elder's Heavy Mace",
    "T8_2H_MACE_DESC": "Equipment Item",
    "T8_2H_MACE_ENCHANTED": "Elder's Enchanted Mace",
    "T8_2H_MACE_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_MACE_MORGANA": "Elder's Camlann Mace",
    "T8_2H_MACE_MORGANA_DESC": "Equipment Item",
    "T8_2H_NATURESTAFF": "Elder's Great Nature Staff",
    "T8_2H_NATURESTAFF_DESC": "Equipment Item",
    "T8_2H_NATURESTAFF_ENCHANTED": "Elder's Enchanted Great Nature Staff",
    "T8_2H_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_NATURESTAFF_HELL": "Elder's Blight Staff",
    "T8_2H_NATURESTAFF_HELL_DESC": "Equipment Item",
    "T8_2H_NATURESTAFF_KEEPER": "Elder's Rampant Staff",
    "T8_2H_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T8_2H_POLEHAMMER": "Elder's Polehammer",
    "T8_2H_POLEHAMMER_DESC": "Equipment Item",
    "T8_2H_POLEHAMMER_ENCHANTED": "Elder's Enchanted Polehammer",
    "T8_2H_POLEHAMMER_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_QUARTERSTAFF": "Elder's Quarterstaff",
    "T8_2H_QUARTERSTAFF_AVALON": "Elder's Grailseeker",
    "T8_2H_QUARTERSTAFF_AVALON_DESC": "Equipment Item",
    "T8_2H_QUARTERSTAFF_DESC": "Equipment Item",
    "T8_2H_QUARTERSTAFF_ENCHANTED": "Elder's Enchanted Quarterstaff",
    "T8_2H_QUARTERSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_RAM_KEEPER": "Elder's Grovekeeper",
    "T8_2H_RAM_KEEPER_DESC": "Equipment Item",
    "T8_2H_REPEATINGCROSSBOW_UNDEAD": "Elder's Weeping Repeater",
    "T8_2H_REPEATINGCROSSBOW_UNDEAD_DESC": "Equipment Item",
    "T8_2H_ROCKSTAFF_KEEPER": "Elder's Staff of Balance",
    "T8_2H_ROCKSTAFF_KEEPER_DESC": "Equipment Item",
    "T8_2H_SCYTHE": "Elder's Scythe",
    "T8_2H_SCYTHE_DESC": "Equipment Item",
    "T8_2H_SCYTHE_ENCHANTED": "Elder's Enchanted Scythe",
    "T8_2H_SCYTHE_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_SCYTHE_HELL": "Elder's Infernal Scythe",
    "T8_2H_SCYTHE_HELL_DESC": "Equipment Item",
    "T8_2H_SKULLORB_HELL": "Elder's Cursed Skull",
    "T8_2H_SKULLORB_HELL_DESC": "Equipment Item",
    "T8_2H_SPEAR": "Elder's Pike",
    "T8_2H_SPEAR_DESC": "Equipment Item",
    "T8_2H_SPEAR_ENCHANTED": "Elder's Enchanted Pike",
    "T8_2H_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_TOOL_AXE": "Elder's Axe",
    "T8_2H_TOOL_AXE_AVALON": "Elder's Avalonian Axe",
    "T8_2H_TOOL_AXE_DESC": "Equipment Item",
    "T8_2H_TOOL_FISHINGROD": "Elder's Fishing Rod",
    "T8_2H_TOOL_FISHINGROD_AVALON": "Elder's Avalonian Fishing Rod",
    "T8_2H_TOOL_FISHINGROD_DESC": "Equipment Item",
    "T8_2H_TOOL_HAMMER": "Elder's Stone Hammer",
    "T8_2H_TOOL_HAMMER_AVALON": "Elder's Avalonian Stone Hammer",
    "T8_2H_TOOL_HAMMER_DESC": "Equipment Item",
    "T8_2H_TOOL_KNIFE": "Elder's Skinning Knife",
    "T8_2H_TOOL_KNIFE_AVALON": "Elder's Avalonian Skinning Knife",
    "T8_2H_TOOL_KNIFE_DESC": "Equipment Item",
    "T8_2H_TOOL_PICK": "Elder's Pickaxe",
    "T8_2H_TOOL_PICK_AVALON": "Elder's Avalonian Pickaxe",
    "T8_2H_TOOL_PICK_DESC": "Equipment Item",
    "T8_2H_TOOL_SICKLE": "Elder's Sickle",
    "T8_2H_TOOL_SICKLE_AVALON": "Elder's Avalonian Sickle",
    "T8_2H_TOOL_SICKLE_DESC": "Equipment Item",
    "T8_2H_TOOL_SIEGEHAMMER": "Elder's Demolition Hammer",
    "T8_2H_TOOL_SIEGEHAMMER_AVALON": "Elder's Avalonian Demolition Hammer",
    "T8_2H_TOOL_SIEGEHAMMER_DESC": "A powerful hammer designed for destroying buildings and furniture.",
    "T8_2H_TRIDENT_UNDEAD": "Elder's Trinity Spear",
    "T8_2H_TRIDENT_UNDEAD_DESC": "Equipment Item",
    "T8_2H_TWINSCYTHE_HELL": "Elder's Soulscythe",
    "T8_2H_TWINSCYTHE_HELL_DESC": "Equipment Item",
    "T8_2H_WARBOW": "Elder's Warbow",
    "T8_2H_WARBOW_DESC": "Equipment Item",
    "T8_2H_WARBOW_ENCHANTED": "Elder's Enchanted Warbow",
    "T8_2H_WARBOW_ENCHANTED_DESC": "Equipment Item",
    "T8_2H_WILDSTAFF": "Elder's Wild Staff",
    "T8_2H_WILDSTAFF_DESC": "Equipment Item",
    "T8_2H_WILDSTAFF_ENCHANTED": "Elder's Enchanted Wild Staff",
    "T8_2H_WILDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_ALCOHOL": "Pumpkin Moonshine",
    "T8_ALCOHOL_DESC": "Pumpkin Moonshine is brewed from Pumpkins, and used in various alchemical decoctions",
    "T8_ARMOR_CLOTH_AVALON": "Elder's Robe of Purity",
    "T8_ARMOR_CLOTH_HELL": "Elder's Fiend Robe",
    "T8_ARMOR_CLOTH_HELL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_KEEPER": "Elder's Druid Robe",
    "T8_ARMOR_CLOTH_KEEPER_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_MORGANA": "Elder's Cultist Robe",
    "T8_ARMOR_CLOTH_MORGANA_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_ROYAL": "Elder's Royal Robe",
    "T8_ARMOR_CLOTH_ROYAL_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_SET1": "Elder's Scholar Robe",
    "T8_ARMOR_CLOTH_SET1_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_SET1_ENCHANTED": "Enchanted Elder's Scholar Robe",
    "T8_ARMOR_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_SET2": "Elder's Cleric Robe",
    "T8_ARMOR_CLOTH_SET2_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_SET2_ENCHANTED": "Enchanted Elder's Cleric Robe",
    "T8_ARMOR_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_SET3": "Elder's Mage Robe",
    "T8_ARMOR_CLOTH_SET3_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_CLOTH_SET3_ENCHANTED": "Enchanted Elder's Mage Robe",
    "T8_ARMOR_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item\nCloth Armors offer limited defense, but excel at offense.",
    "T8_ARMOR_GATHERER_FIBER": "Elder's Harvester Garb",
    "T8_ARMOR_GATHERER_FIBER_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T8_ARMOR_GATHERER_FISH": "Elder's Fisherman Garb",
    "T8_ARMOR_GATHERER_FISH_DESC": "Equipment Item\nGatherer Gear helps you gather more of its resource type",
    "T8_ARMOR_GATHERER_HIDE": "Elder's Skinner Garb",
    "T8_ARMOR_GATHERER_HIDE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T8_ARMOR_GATHERER_ORE": "Elder's Miner Garb",
    "T8_ARMOR_GATHERER_ORE_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T8_ARMOR_GATHERER_ROCK": "Elder's Quarrier Garb",
    "T8_ARMOR_GATHERER_ROCK_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T8_ARMOR_GATHERER_WOOD": "Elder's Lumberjack Garb",
    "T8_ARMOR_GATHERER_WOOD_DESC": "Equipment Item\nGatherer Gear allows you to gather more of the corresponding resource type.",
    "T8_ARMOR_LEATHER_AVALON": "Elder's Jacket of Tenacity",
    "T8_ARMOR_LEATHER_HELL": "Elder's Hellion Jacket",
    "T8_ARMOR_LEATHER_HELL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_MORGANA": "Elder's Stalker Jacket",
    "T8_ARMOR_LEATHER_MORGANA_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_ROYAL": "Elder's Royal Jacket",
    "T8_ARMOR_LEATHER_ROYAL_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_SET1": "Elder's Mercenary Jacket",
    "T8_ARMOR_LEATHER_SET1_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_SET1_ENCHANTED": "Enchanted Elder's Mercenary Jacket",
    "T8_ARMOR_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_SET2": "Elder's Hunter Jacket",
    "T8_ARMOR_LEATHER_SET2_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_SET2_ENCHANTED": "Enchanted Elder's Hunter Jacket",
    "T8_ARMOR_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_SET3": "Elder's Assassin Jacket",
    "T8_ARMOR_LEATHER_SET3_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_SET3_ENCHANTED": "Enchanted Elder's Assassin Jacket",
    "T8_ARMOR_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_LEATHER_UNDEAD": "Elder's Specter Jacket",
    "T8_ARMOR_LEATHER_UNDEAD_DESC": "Equipment Item\nLeather Armors are balanced between defense and offense.",
    "T8_ARMOR_PLATE_AVALON": "Elder's Armor of Valor",
    "T8_ARMOR_PLATE_HELL": "Elder's Demon Armor",
    "T8_ARMOR_PLATE_HELL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_KEEPER": "Elder's Judicator Armor",
    "T8_ARMOR_PLATE_KEEPER_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_ROYAL": "Elder's Royal Armor",
    "T8_ARMOR_PLATE_ROYAL_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_SET1": "Elder's Soldier Armor",
    "T8_ARMOR_PLATE_SET1_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_SET1_ENCHANTED": "Enchanted Elder's Soldier Armor",
    "T8_ARMOR_PLATE_SET1_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_SET2": "Elder's Knight Armor",
    "T8_ARMOR_PLATE_SET2_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_SET2_ENCHANTED": "Enchanted Elder's Knight Armor",
    "T8_ARMOR_PLATE_SET2_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_SET3": "Elder's Guardian Armor",
    "T8_ARMOR_PLATE_SET3_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_SET3_ENCHANTED": "Enchanted Elder's Guardian Armor",
    "T8_ARMOR_PLATE_SET3_ENCHANTED_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARMOR_PLATE_UNDEAD": "Elder's Graveguard Armor",
    "T8_ARMOR_PLATE_UNDEAD_DESC": "Equipment Item\nPlate Armors offer high defense, but are low on offense.",
    "T8_ARTEFACT_2H_ARCANE_RINGPAIR_AVALON": "Elder's Hypnotic Harmonic Ring",
    "T8_ARTEFACT_2H_ARCANESTAFF_HELL": "Elder's Occult Orb",
    "T8_ARTEFACT_2H_AXE_AVALON": "Elder's Avalonian Battle Memoir",
    "T8_ARTEFACT_2H_BOW_AVALON": "Elder's Immaculately Crafted Riser",
    "T8_ARTEFACT_2H_BOW_HELL": "Elder's Demonic Arrowheads",
    "T8_ARTEFACT_2H_BOW_KEEPER": "Elder's Carved bone",
    "T8_ARTEFACT_2H_CLAYMORE_AVALON": "Elder's Remnants of the Old King",
    "T8_ARTEFACT_2H_CLEAVER_HELL": "Elder's Demonic Blade",
    "T8_ARTEFACT_2H_COMBATSTAFF_MORGANA": "Elder's Reinforced Morgana Pole",
    "T8_ARTEFACT_2H_CROSSBOW_CANNON_AVALON": "Elder's Humming Avalonian Whirligig",
    "T8_ARTEFACT_2H_CROSSBOWLARGE_MORGANA": "Elder's Alluring Bolts",
    "T8_ARTEFACT_2H_CURSEDSTAFF_MORGANA": "Elder's Bloodforged Catalyst",
    "T8_ARTEFACT_2H_DAGGER_KATAR_AVALON": "Elder's Bloodstained Antiquities",
    "T8_ARTEFACT_2H_DUALAXE_KEEPER": "Elder's Keeper Axeheads",
    "T8_ARTEFACT_2H_DUALCROSSBOW_HELL": "Elder's Hellish Bolts",
    "T8_ARTEFACT_2H_DUALHAMMER_HELL": "Elder's Hellish Hammer Heads",
    "T8_ARTEFACT_2H_DUALMACE_AVALON": "Elder's Broken Oaths",
    "T8_ARTEFACT_2H_DUALSCIMITAR_UNDEAD": "Elder's Cursed Blades",
    "T8_ARTEFACT_2H_DUALSICKLE_UNDEAD": "Elder's Ghastly Blades",
    "T8_ARTEFACT_2H_ENIGMATICORB_MORGANA": "Elder's Possessed Catalyst",
    "T8_ARTEFACT_2H_FIRE_RINGPAIR_AVALON": "Elder's Glowing Harmonic Ring",
    "T8_ARTEFACT_2H_FIRESTAFF_HELL": "Elder's Burning Orb",
    "T8_ARTEFACT_2H_HALBERD_MORGANA": "Elder's Morgana Halberd Head",
    "T8_ARTEFACT_2H_HAMMER_AVALON": "Elder's Massive Metallic Hand",
    "T8_ARTEFACT_2H_HAMMER_UNDEAD": "Elder's Ancient Hammer Head",
    "T8_ARTEFACT_2H_HARPOON_HELL": "Elder's Infernal Harpoon Tip",
    "T8_ARTEFACT_2H_HOLYSTAFF_HELL": "Elder's Infernal Scroll",
    "T8_ARTEFACT_2H_HOLYSTAFF_UNDEAD": "Elder's Ghastly Scroll",
    "T8_ARTEFACT_2H_ICECRYSTAL_UNDEAD": "Elder's Cursed Frozen Crystal",
    "T8_ARTEFACT_2H_ICEGAUNTLETS_HELL": "Elder's Icicle Orb",
    "T8_ARTEFACT_2H_INFERNOSTAFF_MORGANA": "Elder's Unholy Scroll",
    "T8_ARTEFACT_2H_IRONGAUNTLETS_HELL": "Elder's Black Leather",
    "T8_ARTEFACT_2H_LONGBOW_UNDEAD": "Elder's Ghastly Arrows",
    "T8_ARTEFACT_2H_MACE_MORGANA": "Elder's Imbued Mace Head",
    "T8_ARTEFACT_2H_NATURESTAFF_HELL": "Elder's Symbol of Blight",
    "T8_ARTEFACT_2H_NATURESTAFF_KEEPER": "Elder's Preserved Log",
    "T8_ARTEFACT_2H_QUARTERSTAFF_AVALON": "Elder's Timeworn Walking Staff",
    "T8_ARTEFACT_2H_RAM_KEEPER": "Elder's Engraved Log",
    "T8_ARTEFACT_2H_REPEATINGCROSSBOW_UNDEAD": "Elder's Lost Crossbow Mechanism",
    "T8_ARTEFACT_2H_ROCKSTAFF_KEEPER": "Elder's Preserved Rocks",
    "T8_ARTEFACT_2H_SCYTHE_HELL": "Elder's Hellish Sicklehead",
    "T8_ARTEFACT_2H_SKULLORB_HELL": "Elder's Cursed Jawbone",
    "T8_ARTEFACT_2H_TRIDENT_UNDEAD": "Elder's Cursed Barbs",
    "T8_ARTEFACT_2H_TWINSCYTHE_HELL": "Elder's Hellish Sicklehead Pair",
    "T8_ARTEFACT_ARMOR_CLOTH_AVALON": "Elder's Sanctified Belt",
    "T8_ARTEFACT_ARMOR_CLOTH_HELL": "Elder's Infernal Cloth Folds",
    "T8_ARTEFACT_ARMOR_CLOTH_KEEPER": "Elder's Druidic Feathers",
    "T8_ARTEFACT_ARMOR_CLOTH_MORGANA": "Elder's Alluring Amulet",
    "T8_ARTEFACT_ARMOR_LEATHER_AVALON": "Elder's Augured Sash",
    "T8_ARTEFACT_ARMOR_LEATHER_HELL": "Elder's Demonhide Leather",
    "T8_ARTEFACT_ARMOR_LEATHER_MORGANA": "Elder's Imbued Leather Folds",
    "T8_ARTEFACT_ARMOR_LEATHER_UNDEAD": "Elder's Ghastly Leather",
    "T8_ARTEFACT_ARMOR_PLATE_AVALON": "Elder's Exalted Plating",
    "T8_ARTEFACT_ARMOR_PLATE_HELL": "Elder's Demonic Plates",
    "T8_ARTEFACT_ARMOR_PLATE_KEEPER": "Elder's Preserved Animal Fur",
    "T8_ARTEFACT_ARMOR_PLATE_UNDEAD": "Elder's Ancient Chain Rings",
    "T8_ARTEFACT_HEAD_CLOTH_AVALON": "Elder's Sanctified Mask",
    "T8_ARTEFACT_HEAD_CLOTH_HELL": "Elder's Infernal Cloth Visor",
    "T8_ARTEFACT_HEAD_CLOTH_KEEPER": "Elder's Druidic Preserved Beak",
    "T8_ARTEFACT_HEAD_CLOTH_MORGANA": "Elder's Alluring Padding",
    "T8_ARTEFACT_HEAD_LEATHER_AVALON": "Elder's Augured Padding",
    "T8_ARTEFACT_HEAD_LEATHER_HELL": "Elder's Demonhide Padding",
    "T8_ARTEFACT_HEAD_LEATHER_MORGANA": "Elder's Imbued Visor",
    "T8_ARTEFACT_HEAD_LEATHER_UNDEAD": "Elder's Ghastly Visor",
    "T8_ARTEFACT_HEAD_PLATE_AVALON": "Elder's Exalted Visor",
    "T8_ARTEFACT_HEAD_PLATE_HELL": "Elder's Demonic Scraps",
    "T8_ARTEFACT_HEAD_PLATE_KEEPER": "Elder's Carved Skull Padding",
    "T8_ARTEFACT_HEAD_PLATE_UNDEAD": "Elder's Ancient Padding",
    "T8_ARTEFACT_MAIN_ARCANESTAFF_UNDEAD": "Elder's Lost Arcane Crystal",
    "T8_ARTEFACT_MAIN_CURSEDSTAFF_AVALON": "Elder's Fractured Opaque Orb",
    "T8_ARTEFACT_MAIN_CURSEDSTAFF_UNDEAD": "Elder's Lost Cursed Crystal",
    "T8_ARTEFACT_MAIN_FIRESTAFF_KEEPER": "Elder's Wildfire Orb",
    "T8_ARTEFACT_MAIN_FROSTSTAFF_AVALON": "Elder's Chilled Crystaline Shard",
    "T8_ARTEFACT_MAIN_FROSTSTAFF_KEEPER": "Elder's Hoarfrost Orb",
    "T8_ARTEFACT_MAIN_HOLYSTAFF_AVALON": "Elder's Messianic Curio",
    "T8_ARTEFACT_MAIN_HOLYSTAFF_MORGANA": "Elder's Possessed Scroll",
    "T8_ARTEFACT_MAIN_MACE_HELL": "Elder's Infernal Mace Head",
    "T8_ARTEFACT_MAIN_NATURESTAFF_AVALON": "Elder's Uprooted Perennial Sapling",
    "T8_ARTEFACT_MAIN_NATURESTAFF_KEEPER": "Elder's Druidic Inscriptions",
    "T8_ARTEFACT_MAIN_RAPIER_MORGANA": "Elder's Hardened Debole",
    "T8_ARTEFACT_MAIN_ROCKMACE_KEEPER": "Elder's Runed Rock",
    "T8_ARTEFACT_MAIN_SCIMITAR_MORGANA": "Elder's Bloodforged Blade",
    "T8_ARTEFACT_MAIN_SPEAR_KEEPER": "Elder's Keeper Spearhead",
    "T8_ARTEFACT_MAIN_SPEAR_LANCE_AVALON": "Elder's Ruined Ancestral Vamplate",
    "T8_ARTEFACT_OFF_CENSER_AVALON": "Elder's Severed Celestial Keepsake",
    "T8_ARTEFACT_OFF_DEMONSKULL_HELL": "Elder's Demonic Jawbone",
    "T8_ARTEFACT_OFF_HORN_KEEPER": "Elder's Runed Horn",
    "T8_ARTEFACT_OFF_JESTERCANE_HELL": "Elder's Hellish Handle",
    "T8_ARTEFACT_OFF_LAMP_UNDEAD": "Elder's Ghastly Candle",
    "T8_ARTEFACT_OFF_ORB_MORGANA": "Elder's Alluring Crystal",
    "T8_ARTEFACT_OFF_SHIELD_AVALON": "Elder's Crushed Avalonian Heirloom",
    "T8_ARTEFACT_OFF_SHIELD_HELL": "Elder's Infernal Shield Core",
    "T8_ARTEFACT_OFF_SPIKEDSHIELD_MORGANA": "Elder's Bloodforged Spikes",
    "T8_ARTEFACT_OFF_TALISMAN_AVALON": "Elder's Shattered Avalonian Memento",
    "T8_ARTEFACT_OFF_TOTEM_KEEPER": "Elder's Inscribed Stone",
    "T8_ARTEFACT_OFF_TOWERSHIELD_UNDEAD": "Elder's Ancient Shield Core",
    "T8_ARTEFACT_SHOES_CLOTH_AVALON": "Elder's Sanctified Bindings",
    "T8_ARTEFACT_SHOES_CLOTH_HELL": "Elder's Infernal Cloth Bindings",
    "T8_ARTEFACT_SHOES_CLOTH_KEEPER": "Elder's Druidic Bindings",
    "T8_ARTEFACT_SHOES_CLOTH_MORGANA": "Elder's Alluring Bindings",
    "T8_ARTEFACT_SHOES_LEATHER_AVALON": "Elder's Augured Fasteners",
    "T8_ARTEFACT_SHOES_LEATHER_HELL": "Elder's Demonhide Bindings",
    "T8_ARTEFACT_SHOES_LEATHER_MORGANA": "Elder's Imbued Soles",
    "T8_ARTEFACT_SHOES_LEATHER_UNDEAD": "Elder's Ghastly Bindings",
    "T8_ARTEFACT_SHOES_PLATE_AVALON": "Elder's Exalted Greave",
    "T8_ARTEFACT_SHOES_PLATE_HELL": "Elder's Demonic Filling",
    "T8_ARTEFACT_SHOES_PLATE_KEEPER": "Elder's Inscribed Bindings",
    "T8_ARTEFACT_SHOES_PLATE_UNDEAD": "Elder's Ancient Bindings",
    "T8_BACKPACK_GATHERER_FIBER": "Elder's Harvester Backpack",
    "T8_BACKPACK_GATHERER_FIBER_DESC": "Equipment Item",
    "T8_BACKPACK_GATHERER_FISH": "Elder's Fisherman Backpack",
    "T8_BACKPACK_GATHERER_FISH_DESC": "Equipment Item",
    "T8_BACKPACK_GATHERER_HIDE": "Elder's Skinner Backpack",
    "T8_BACKPACK_GATHERER_HIDE_DESC": "Equipment Item",
    "T8_BACKPACK_GATHERER_ORE": "Elder's Miner Backpack",
    "T8_BACKPACK_GATHERER_ORE_DESC": "Equipment Item",
    "T8_BACKPACK_GATHERER_ROCK": "Elder's Quarrier Backpack",
    "T8_BACKPACK_GATHERER_ROCK_DESC": "Equipment Item",
    "T8_BACKPACK_GATHERER_WOOD": "Elder's Lumberjack Backpack",
    "T8_BACKPACK_GATHERER_WOOD_DESC": "Equipment Item",
    "T8_BAG": "Elder's Bag",
    "T8_BAG_DESC": "Equipment Item",
    "T8_BAG_FW_BONUS_FAME": "Elder's Faction Fame Bag",
    "T8_BAG_FW_BONUS_FAME_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T8_BAG_FW_BONUS_SILVER": "Elder's Faction Silver Bag",
    "T8_BAG_FW_BONUS_SILVER_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T8_BAG_FW_BONUS_YIELD": "Elder's Faction Yield Bag",
    "T8_BAG_FW_BONUS_YIELD_DESC": "This bag is crafted from local faction resources and gives special bonuses",
    "T8_BAG_FW_FAME_BP": "Elder's Faction Fame Bag Pattern",
    "T8_BAG_FW_FAME_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T8_BAG_FW_SILVER_BP": "Elder's Faction Silver Bag Pattern",
    "T8_BAG_FW_SILVER_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T8_BAG_FW_YIELD_BP": "Elder's Faction Yield Bag Pattern",
    "T8_BAG_FW_YIELD_BP_DESC": "This pattern can be used as a crafting resource to craft the finished bag",
    "T8_BAG_INSIGHT": "Elder's Satchel of Insight",
    "T8_BUTTER": "Cow's Butter",
    "T8_BUTTER_DESC": "Cow's Butter is used to make Sandwiches",
    "T8_CAPE": "Elder's Cape",
    "T8_CAPE_ARENA_BANNER": "Arena Veteran's Large Banner",
    "T8_CAPE_ARENA_BANNER_DESC": "Equipment Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils",
    "T8_CAPE_DESC": "Equipment Item",
    "T8_CAPEITEM_DEMON": "Elder's Demon Cape",
    "T8_CAPEITEM_DEMON_BP": "Elder's Demon Crest",
    "T8_CAPEITEM_DEMON_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_DEMON_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_FW_BRIDGEWATCH": "Elder's Bridgewatch Cape",
    "T8_CAPEITEM_FW_BRIDGEWATCH_BP": "Elder's Bridgewatch Crest",
    "T8_CAPEITEM_FW_BRIDGEWATCH_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_FW_BRIDGEWATCH_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_FW_FORTSTERLING": "Elder's Fort Sterling Cape",
    "T8_CAPEITEM_FW_FORTSTERLING_BP": "Elder's Fort Sterling Crest",
    "T8_CAPEITEM_FW_FORTSTERLING_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_FW_FORTSTERLING_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_FW_LYMHURST": "Elder's Lymhurst Cape",
    "T8_CAPEITEM_FW_LYMHURST_BP": "Elder's Lymhurst Crest",
    "T8_CAPEITEM_FW_LYMHURST_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_FW_LYMHURST_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_FW_MARTLOCK": "Elder's Martlock Cape",
    "T8_CAPEITEM_FW_MARTLOCK_BP": "Elder's Martlock Crest",
    "T8_CAPEITEM_FW_MARTLOCK_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_FW_MARTLOCK_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_FW_THETFORD": "Elder's Thetford Cape",
    "T8_CAPEITEM_FW_THETFORD_BP": "Elder's Thetford Crest",
    "T8_CAPEITEM_FW_THETFORD_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_FW_THETFORD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_HERETIC": "Elder's Heretic Cape",
    "T8_CAPEITEM_HERETIC_BP": "Elder's Heretic Crest",
    "T8_CAPEITEM_HERETIC_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_HERETIC_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_KEEPER": "Elder's Keeper Cape",
    "T8_CAPEITEM_KEEPER_BP": "Elder's Keeper Crest",
    "T8_CAPEITEM_KEEPER_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_KEEPER_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_MORGANA": "Elder's Morgana Cape",
    "T8_CAPEITEM_MORGANA_BP": "Elder's Morgana Crest",
    "T8_CAPEITEM_MORGANA_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_MORGANA_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CAPEITEM_UNDEAD": "Elder's Undead Cape",
    "T8_CAPEITEM_UNDEAD_BP": "Elder's Undead Crest",
    "T8_CAPEITEM_UNDEAD_BP_DESC": "Can be used to upgrade a cape",
    "T8_CAPEITEM_UNDEAD_DESC": "Equipment Item - Crested Capes offer an additional passive spell.",
    "T8_CLOTH": "Baroque Cloth",
    "T8_CLOTH_DESC": "Advanced material used in crafting, created by refining fiber.",
    "T8_CLOTH_LEVEL1": "Uncommon Baroque Cloth",
    "T8_CLOTH_LEVEL1_DESC": "Uncommon material used in crafting.",
    "T8_CLOTH_LEVEL2": "Rare Baroque Cloth",
    "T8_CLOTH_LEVEL2_DESC": "Rare material used in crafting.",
    "T8_CLOTH_LEVEL3": "Exceptional Baroque Cloth",
    "T8_CLOTH_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_CLOTH_LEVEL4": "Legendary Baroque Cloth",
    "T8_CLOTH_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_CLOTH_LEVEL5": "Mythical Baroque Cloth",
    "T8_CLOTH_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_ESSENCE": "Elder's Faded Essence",
    "T8_ESSENCE_DESC": "This essence has passed its use-by date. It can be combined with others like it at an Artifact Foundry.",
    "T8_ESSENCE_HUNTER": "Divine Essence of the Hunter",
    "T8_ESSENCE_HUNTER_DESC": "Special material used in crafting.",
    "T8_ESSENCE_MAGE": "Divine Essence of the Mage",
    "T8_ESSENCE_MAGE_DESC": "Special material used in crafting.",
    "T8_ESSENCE_POTION": "Elder's Arcane Essence",
    "T8_ESSENCE_POTION_DESC": "A magical essence, used to enchant potions",
    "T8_ESSENCE_WARRIOR": "Divine Essence of the Warrior",
    "T8_ESSENCE_WARRIOR_DESC": "Special material used in crafting.",
    "T8_FARM_COW_BABY": "Calf",
    "T8_FARM_COW_BABY_DESC": "You can place Calves on your pasture for them to grow up into Cows",
    "T8_FARM_COW_GROWN": "Cow",
    "T8_FARM_COW_GROWN_DESC": "Cows can be slaughtered to produce Raw Beef, or left alive to produce Cow's Milk",
    "T8_FARM_DIREBEAR_BABY": "Direbear Cub",
    "T8_FARM_DIREBEAR_BABY_DESC": "Grows into a Tame Direbear, which can be used to craft a Saddled Direbear Mount.",
    "T8_FARM_DIREBEAR_GROWN": "Tame Direbear",
    "T8_FARM_DIREBEAR_GROWN_DESC": "Can be used to craft a Saddled Direbear mount.",
    "T8_FARM_DIREWOLF_BABY": "Ghostwolf Pup",
    "T8_FARM_DIREWOLF_BABY_DESC": "A Ghostwolf Pup placed in a Kennel will grow into a Tame Ghostwolf. Note: Ghostwolf Pups and Tame Ghostwolves can be kept in a kennel, but cannot be trained into Ghostwolf mounts.",
    "T8_FARM_DIREWOLF_GROWN": "Tame Ghostwolf",
    "T8_FARM_DIREWOLF_GROWN_DESC": "Can be displayed in a kennel, but cannot be used to craft a Ghostwolf mount.",
    "T8_FARM_HORSE_BABY": "Elder's Foal",
    "T8_FARM_HORSE_BABY_DESC": "Grow into a Elder's Horse which can be used to craft an Elder's Riding Horse or an Elder's Armored Horse.",
    "T8_FARM_HORSE_GROWN": "Elder's Horse",
    "T8_FARM_HORSE_GROWN_DESC": "Can be used to craft an Elder's Riding Horse or an Elder's Armored Horse.",
    "T8_FARM_MAMMOTH_BABY": "Mammoth Calf",
    "T8_FARM_MAMMOTH_BABY_DESC": "A Mammoth Calf placed in a Kennel will grow into a Tame Mammoth, which can be trained into a Mammoth mount.",
    "T8_FARM_MAMMOTH_GROWN": "Tame Mammoth",
    "T8_FARM_MAMMOTH_GROWN_DESC": "Can be used to craft a Mammoth mount.",
    "T8_FARM_OX_BABY": "Elder's Ox Calf",
    "T8_FARM_OX_BABY_DESC": "Grows into an Elder's Ox which can be used to craft an Elder's Transport Ox.",
    "T8_FARM_OX_GROWN": "Elder's Ox",
    "T8_FARM_OX_GROWN_DESC": "Can be used to craft a Elder's Transport Ox.",
    "T8_FARM_PUMPKIN_SEED": "Pumpkin Seeds",
    "T8_FARM_PUMPKIN_SEED_DESC": "Pumpkin Seeds are used to plant a patch of Pumpkins",
    "T8_FARM_SWAMP_DRAGON_BABY": "Swamp Dragon Pup",
    "T8_FARM_SWAMP_DRAGON_BABY_DESC": "A Swamp Dragon Pup placed in a Kennel will grow into a Tame Swamp Dragon, which can be trained into a Swamp Dragon mount.",
    "T8_FARM_SWAMP_DRAGON_GROWN": "Tame Swamp Dragon",
    "T8_FARM_SWAMP_DRAGON_GROWN_DESC": "Can be used to craft a Swamp Dragon mount.",
    "T8_FARM_YARROW_SEED": "Ghoul Yarrow Seeds",
    "T8_FARM_YARROW_SEED_DESC": "Ghoul Yarrow Seeds are used to plant a patch of Ghoul Yarrow",
    "T8_FIBER": "Ghost Hemp",
    "T8_FIBER_DESC": "Fiber used for crafting. Can be refined into cloth or transmuted into higher-level material.",
    "T8_FIBER_LEVEL1": "Uncommon Ghost Hemp",
    "T8_FIBER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T8_FIBER_LEVEL2": "Rare Ghost Hemp",
    "T8_FIBER_LEVEL2_DESC": "Rare material used for crafting.",
    "T8_FIBER_LEVEL3": "Exceptional Ghost Hemp",
    "T8_FIBER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_FIBER_LEVEL4": "Legendary Ghost Hemp",
    "T8_FIBER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_FIBER_LEVEL5": "Mythical Ghost Hemp",
    "T8_FIBER_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_FISH_FRESHWATER_ALL_COMMON": "River Sturgeon",
    "T8_FISH_SALTWATER_ALL_BOSS_SHARK": "Shark",
    "T8_FISH_SALTWATER_ALL_BOSS_SHARK_DESC": "A monster fish! Can be used to craft a trophy for your house.",
    "T8_FISH_SALTWATER_ALL_COMMON": "Steelscale Swordfish",
    "T8_FRAGMENT_BLUE_F1": "Elder's Scrap of Magic",
    "T8_FRAGMENT_BLUE_F1_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_BLUE_F2": "Elder's Fragment of Magic",
    "T8_FRAGMENT_BLUE_F2_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_BLUE_F3": "Elder's Shard of Magic",
    "T8_FRAGMENT_BLUE_F3_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_GREEN_F1": "Elder's Scrap of Nature",
    "T8_FRAGMENT_GREEN_F1_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_GREEN_F2": "Elder's Fragment of Nature",
    "T8_FRAGMENT_GREEN_F2_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_GREEN_F3": "Elder's Shard of Nature",
    "T8_FRAGMENT_GREEN_F3_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_RED_F1": "Elder's Scrap of Valor",
    "T8_FRAGMENT_RED_F1_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_RED_F2": "Elder's Fragment of Valor",
    "T8_FRAGMENT_RED_F2_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FRAGMENT_RED_F3": "Elder's Shard of Valor",
    "T8_FRAGMENT_RED_F3_DESC": "Can be melded into an artifact or transmuted into a different aspect.",
    "T8_FURNITUREITEM_BATTLEVAULT": "Elder's Battlevault",
    "T8_FURNITUREITEM_BATTLEVAULT_DESC": "A 32-slot battlevault with a 1631 kg limit. Must be placed indoors.",
    "T8_FURNITUREITEM_BED": "Elder's Bed",
    "T8_FURNITUREITEM_BED_DESC": "Increases maximum residents in the house by 1, and contributes to Laborer happiness. Item can only be placed indoors.",
    "T8_FURNITUREITEM_REPAIRKIT": "Elder's Repair Kit",
    "T8_FURNITUREITEM_REPAIRKIT_DESC": "Repair kits are used to repair gear in the wild, however the repair fee is twice as high.",
    "T8_FURNITUREITEM_TABLE": "Elder's Table",
    "T8_FURNITUREITEM_TABLE_DESC": "Contributes to Laborer happiness. Item can only be placed indoors.",
    "T8_FURNITUREITEM_TROPHY_FIBER": "Exquisite Ghost Hemp Trophy",
    "T8_FURNITUREITEM_TROPHY_FISH": "Swordfish Trophy",
    "T8_FURNITUREITEM_TROPHY_FISHING_BOSS": "Trophy Shark",
    "T8_FURNITUREITEM_TROPHY_FISHING_BOSS_DESC": "A glorious fishing trophy! Adds a small amount of happiness to all types of Laborers in your house.",
    "T8_FURNITUREITEM_TROPHY_GENERAL": "Ledger of Truths",
    "T8_FURNITUREITEM_TROPHY_GENERAL_DESC": "Adds a small amount of happiness to all Laborers.",
    "T8_FURNITUREITEM_TROPHY_HIDE": "Stuffed Direbear Head",
    "T8_FURNITUREITEM_TROPHY_HIDE_DESC": "Adds a respectable amount of happiness to all Gamekeeper Laborers.",
    "T8_FURNITUREITEM_TROPHY_MERCENARY": "Elder Mercenary's Trophy",
    "T8_FURNITUREITEM_TROPHY_MERCENARY_DESC": "Adds a respectable amount of happiness to all Mercenary Laborers.",
    "T8_FURNITUREITEM_TROPHY_MOB": "Trophy: Direbear's Head",
    "T8_FURNITUREITEM_TROPHY_MOB_DESC": "Grants an increase to maximum carrying capacity. Must be placed indoors.",
    "T8_FURNITUREITEM_TROPHY_ORE": "Adamantium Ore Sample",
    "T8_FURNITUREITEM_TROPHY_ROCK": "Marble Fragment",
    "T8_FURNITUREITEM_TROPHY_WOOD": "Whitewood Bonsai",
    "T8_GEM_EMERALD": "Perfect Emerald",
    "T8_GEM_EMERALD_DESC": "Special material used in crafting.",
    "T8_GEM_RUBY": "Perfect Ruby",
    "T8_GEM_RUBY_DESC": "Special material used in crafting.",
    "T8_GEM_SAPPHIRE": "Perfect Sapphire",
    "T8_GEM_SAPPHIRE_DESC": "Special material used in crafting.",
    "T8_GVGSEASONREWARD_FAMEBUFF": "Elder's Knight Vow",
    "T8_GVGSEASONREWARD_FAMEBUFF_DESC": "Increases Fame from defeating creatures and gathering resources by 5% for 90 days",
    "T8_HEAD_CLOTH_AVALON": "Elder's Cowl of Purity",
    "T8_HEAD_CLOTH_HELL": "Elder's Fiend Cowl",
    "T8_HEAD_CLOTH_HELL_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_KEEPER": "Elder's Druid Cowl",
    "T8_HEAD_CLOTH_KEEPER_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_MORGANA": "Elder's Cultist Cowl",
    "T8_HEAD_CLOTH_MORGANA_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_ROYAL": "Elder's Royal Cowl",
    "T8_HEAD_CLOTH_ROYAL_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_SET1": "Elder's Scholar Cowl",
    "T8_HEAD_CLOTH_SET1_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_SET1_ENCHANTED": "Enchanted Elder's Scholar Cowl",
    "T8_HEAD_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_SET2": "Elder's Cleric Cowl",
    "T8_HEAD_CLOTH_SET2_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_SET2_ENCHANTED": "Enchanted Elder's Cleric Cowl",
    "T8_HEAD_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_SET3": "Elder's Mage Cowl",
    "T8_HEAD_CLOTH_SET3_DESC": "Equipment Item",
    "T8_HEAD_CLOTH_SET3_ENCHANTED": "Enchanted Elder's Mage Cowl",
    "T8_HEAD_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_GATHERER_FIBER": "Elder's Harvester Cap",
    "T8_HEAD_GATHERER_FIBER_DESC": "Equipment Item",
    "T8_HEAD_GATHERER_FISH": "Elder's Fisherman Cap",
    "T8_HEAD_GATHERER_FISH_DESC": "Equipment Item",
    "T8_HEAD_GATHERER_HIDE": "Elder's Skinner Cap",
    "T8_HEAD_GATHERER_HIDE_DESC": "Equipment Item",
    "T8_HEAD_GATHERER_ORE": "Elder's Miner Cap",
    "T8_HEAD_GATHERER_ORE_DESC": "Equipment Item",
    "T8_HEAD_GATHERER_ROCK": "Elder's Quarrier Cap",
    "T8_HEAD_GATHERER_ROCK_DESC": "Equipment Item",
    "T8_HEAD_GATHERER_WOOD": "Elder's Lumberjack Cap",
    "T8_HEAD_GATHERER_WOOD_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_AVALON": "Elder's Hood of Tenacity",
    "T8_HEAD_LEATHER_HELL": "Elder's Hellion Hood",
    "T8_HEAD_LEATHER_HELL_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_MORGANA": "Elder's Stalker Hood",
    "T8_HEAD_LEATHER_MORGANA_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_ROYAL": "Elder's Royal Hood",
    "T8_HEAD_LEATHER_ROYAL_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_SET1": "Elder's Mercenary Hood",
    "T8_HEAD_LEATHER_SET1_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_SET1_ENCHANTED": "Enchanted Elder's Mercenary Hood",
    "T8_HEAD_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_SET2": "Elder's Hunter Hood",
    "T8_HEAD_LEATHER_SET2_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_SET2_ENCHANTED": "Enchanted Elder's Hunter Hood",
    "T8_HEAD_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_SET3": "Elder's Assassin Hood",
    "T8_HEAD_LEATHER_SET3_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_SET3_ENCHANTED": "Enchanted Elder's Assassin Hood",
    "T8_HEAD_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_LEATHER_UNDEAD": "Elder's Specter Hood",
    "T8_HEAD_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T8_HEAD_PLATE_AVALON": "Elder's Helmet of Valor",
    "T8_HEAD_PLATE_HELL": "Elder's Demon Helmet",
    "T8_HEAD_PLATE_HELL_DESC": "Equipment Item",
    "T8_HEAD_PLATE_KEEPER": "Elder's Judicator Helmet",
    "T8_HEAD_PLATE_KEEPER_DESC": "Equipment Item",
    "T8_HEAD_PLATE_ROYAL": "Elder's Royal Helmet",
    "T8_HEAD_PLATE_ROYAL_DESC": "Equipment Item",
    "T8_HEAD_PLATE_SET1": "Elder's Soldier Helmet",
    "T8_HEAD_PLATE_SET1_DESC": "Equipment Item",
    "T8_HEAD_PLATE_SET1_ENCHANTED": "Enchanted Elder's Soldier Helmet",
    "T8_HEAD_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_PLATE_SET2": "Elder's Knight Helmet",
    "T8_HEAD_PLATE_SET2_DESC": "Equipment Item",
    "T8_HEAD_PLATE_SET2_ENCHANTED": "Enchanted Elder's Knight Helmet",
    "T8_HEAD_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_PLATE_SET3": "Elder's Guardian Helmet",
    "T8_HEAD_PLATE_SET3_DESC": "Equipment Item",
    "T8_HEAD_PLATE_SET3_ENCHANTED": "Enchanted Elder's Guardian Helmet",
    "T8_HEAD_PLATE_SET3_ENCHANTED_DESC": "Equipment Item",
    "T8_HEAD_PLATE_UNDEAD": "Elder's Graveguard Helmet",
    "T8_HEAD_PLATE_UNDEAD_DESC": "Equipment Item",
    "T8_HIDE": "Resilient Hide",
    "T8_HIDE_DESC": "Hide used for crafting. Can be refined into leather or transmuted into higher-level material.",
    "T8_HIDE_LEVEL1": "Uncommon Resilient Hide",
    "T8_HIDE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T8_HIDE_LEVEL2": "Rare Resilient Hide",
    "T8_HIDE_LEVEL2_DESC": "Rare material used for crafting.",
    "T8_HIDE_LEVEL3": "Exceptional Resilient Hide",
    "T8_HIDE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_HIDE_LEVEL4": "Legendary Resilient Hide",
    "T8_HIDE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_HIDE_LEVEL5": "Mythical Resilient Hide",
    "T8_HIDE_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_JOURNAL_FIBER": "Elder Cropper's Journal (Partially Full)",
    "T8_JOURNAL_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_FIBER_EMPTY": "Elder Cropper's Journal (Empty)",
    "T8_JOURNAL_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_FIBER_FULL": "Elder Cropper's Journal (Full)",
    "T8_JOURNAL_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_FISHING": "Elder Fisherman's Journal (Partially Full)",
    "T8_JOURNAL_FISHING_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_FISHING_EMPTY": "Elder Fisherman's Journal (Empty)",
    "T8_JOURNAL_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_FISHING_FULL": "Elder Fisherman's Journal (Full)",
    "T8_JOURNAL_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by fishing, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_HIDE": "Elder Gamekeeper's Journal (Partially Full)",
    "T8_JOURNAL_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_HIDE_EMPTY": "Elder Gamekeeper's Journal (Empty)",
    "T8_JOURNAL_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_HIDE_FULL": "Elder Gamekeeper's Journal (Full)",
    "T8_JOURNAL_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_HUNTER": "Elder Fletcher's Journal (Partially Full)",
    "T8_JOURNAL_HUNTER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_HUNTER_EMPTY": "Elder Fletcher's Journal (Empty)",
    "T8_JOURNAL_HUNTER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_HUNTER_FULL": "Elder Fletcher's Journal (Full)",
    "T8_JOURNAL_HUNTER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Hunter's Lodge, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_MAGE": "Elder Imbuer's Journal (Partially Full)",
    "T8_JOURNAL_MAGE_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_MAGE_EMPTY": "Elder Imbuer's Journal (Empty)",
    "T8_JOURNAL_MAGE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_MAGE_FULL": "Elder Imbuer's Journal (Full)",
    "T8_JOURNAL_MAGE_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Mage's Tower, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_MERCENARY": "Elder Mercenary's Journal (Partially Full)",
    "T8_JOURNAL_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_MERCENARY_EMPTY": "Elder Mercenary's Journal (Empty)",
    "T8_JOURNAL_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_MERCENARY_FULL": "Elder Mercenary's Journal (Full)",
    "T8_JOURNAL_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_ORE": "Elder Prospector's Journal (Partially Full)",
    "T8_JOURNAL_ORE_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_ORE_EMPTY": "Elder Prospector's Journal (Empty)",
    "T8_JOURNAL_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_ORE_FULL": "Elder Prospector's Journal (Full)",
    "T8_JOURNAL_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_STONE": "Elder Stonecutter's Journal (Partially Full)",
    "T8_JOURNAL_STONE_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_STONE_EMPTY": "Elder Stonecutter's Journal (Empty)",
    "T8_JOURNAL_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_STONE_FULL": "Elder Stonecutter's Journal (Full)",
    "T8_JOURNAL_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TOOLMAKER": "Elder Tinker's Journal (Partially Full)",
    "T8_JOURNAL_TOOLMAKER_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TOOLMAKER_EMPTY": "Elder Tinker's Journal (Empty)",
    "T8_JOURNAL_TOOLMAKER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TOOLMAKER_FULL": "Elder Tinker's Journal (Full)",
    "T8_JOURNAL_TOOLMAKER_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Toolmaker, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_FIBER": "Elder Cropper's Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_FIBER_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_FIBER_EMPTY": "Elder Cropper's Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_FIBER_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_FIBER_FULL": "Elder Cropper's Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_FIBER_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Fiber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_FISHING": "Elder Fisherman's Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_FISHING_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_FISHING_EMPTY": "Elder Fisherman's Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_FISHING_EMPTY_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_FISHING_FULL": "Elder Fisherman's Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_FISHING_FULL_DESC": "Acquired from a Laborer. Can be filled by catching Fish of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_GENERAL": "Elder's Generalist Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_GENERAL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_GENERAL_EMPTY": "Elder's Generalist Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_GENERAL_EMPTY_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_GENERAL_FULL": "Elder's Generalist Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_GENERAL_FULL_DESC": "Acquired from a Laborer. Can be filled by earning Fame in any way, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_HIDE": "Elder Gamekeeper's Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_HIDE_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_HIDE_EMPTY": "Elder Gamekeeper's Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_HIDE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_HIDE_FULL": "Elder Gamekeeper's Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_HIDE_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Hides of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_MERCENARY": "Elder Mercenary's Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_MERCENARY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_MERCENARY_EMPTY": "Elder Mercenary's Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_MERCENARY_EMPTY_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_MERCENARY_FULL": "Elder Mercenary's Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_MERCENARY_FULL_DESC": "Acquired from a Laborer. Can be filled by killing NPCs of its tier or higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_ORE": "Elder Prospector's Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_ORE_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_ORE_EMPTY": "Elder Prospector's Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_ORE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_ORE_FULL": "Elder Prospector's Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_ORE_FULL_DESC": "Acquired from a Laborer. Can be filled by mining Ore of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_STONE": "Elder Stonecutter's Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_STONE_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_STONE_EMPTY": "Elder Stonecutter's Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_STONE_EMPTY_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_STONE_FULL": "Elder Stonecutter's Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_STONE_FULL_DESC": "Acquired from a Laborer. Can be filled by quarrying Stone of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_WOOD": "Elder Lumberjack's Trophy Journal (Partially Full)",
    "T8_JOURNAL_TROPHY_WOOD_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_WOOD_EMPTY": "Elder Lumberjack's Trophy Journal (Empty)",
    "T8_JOURNAL_TROPHY_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_TROPHY_WOOD_FULL": "Elder Lumberjack's Trophy Journal (Full)",
    "T8_JOURNAL_TROPHY_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by cutting down Timber of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_WARRIOR": "Elder Blacksmith's Journal (Partially Full)",
    "T8_JOURNAL_WARRIOR_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_WARRIOR_EMPTY": "Elder Blacksmith's Journal (Empty)",
    "T8_JOURNAL_WARRIOR_EMPTY_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_WARRIOR_FULL": "Elder Blacksmith's Journal (Full)",
    "T8_JOURNAL_WARRIOR_FULL_DESC": "Acquired from a Laborer. Can be filled by crafting items of its tier at a Forge, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_WOOD": "Elder Lumberjack's Journal (Partially Full)",
    "T8_JOURNAL_WOOD_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_WOOD_EMPTY": "Elder Lumberjack's Journal (Empty)",
    "T8_JOURNAL_WOOD_EMPTY_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_JOURNAL_WOOD_FULL": "Elder Lumberjack's Journal (Full)",
    "T8_JOURNAL_WOOD_FULL_DESC": "Acquired from a Laborer. Can be filled by harvesting Wood of its tier or up to two tiers higher, and then returned to the Laborer to start them on a job.",
    "T8_LABOURER_CONTRACT_FIBER": "Elder Cropper Contract",
    "T8_LABOURER_CONTRACT_FIBER_DESC": "Croppers require filled Cropper's Journals and gather fiber.",
    "T8_LABOURER_CONTRACT_FISHERMAN": "Elder Fisherman Contract",
    "T8_LABOURER_CONTRACT_FISHERMAN_DESC": "Fishermen require filled Fisherman's Journals and catch fish.",
    "T8_LABOURER_CONTRACT_HIDE": "Elder Gamekeeper Contract",
    "T8_LABOURER_CONTRACT_HIDE_DESC": "Gamekeepers require filled Gamekeeper's Journals and gather hide.",
    "T8_LABOURER_CONTRACT_HUNTER": "Elder Fletcher Contract",
    "T8_LABOURER_CONTRACT_HUNTER_DESC": "Fletchers require filled Fletcher's Journals and gather various refined materials.",
    "T8_LABOURER_CONTRACT_MAGE": "Elder Imbuer Contract",
    "T8_LABOURER_CONTRACT_MAGE_DESC": "Imbuers require filled Imbuer's Journals and gather various refined materials.",
    "T8_LABOURER_CONTRACT_MERCENARY": "Elder Mercenary Contract",
    "T8_LABOURER_CONTRACT_MERCENARY_DESC": "Mercenaries require filled Mercenary's Journals' and gather Silver.",
    "T8_LABOURER_CONTRACT_ORE": "Elder Prospector Contract",
    "T8_LABOURER_CONTRACT_ORE_DESC": "Prospectors require filled Prospector's Journals and gather ore.",
    "T8_LABOURER_CONTRACT_STONE": "Elder Stonecutter Contract",
    "T8_LABOURER_CONTRACT_STONE_DESC": "Stonecutters require filled Stonecutter's Journals and gather stone.",
    "T8_LABOURER_CONTRACT_TOOLMAKER": "Elder Tinker Contract",
    "T8_LABOURER_CONTRACT_TOOLMAKER_DESC": "Tinkers require filled Tinker's Journals and gather various refined materials.",
    "T8_LABOURER_CONTRACT_WARRIOR": "Elder Blacksmith Contract",
    "T8_LABOURER_CONTRACT_WARRIOR_DESC": "Blacksmiths require filled Blacksmith's Journals and gather various refined materials.",
    "T8_LABOURER_CONTRACT_WOOD": "Elder Lumberjack Contract",
    "T8_LABOURER_CONTRACT_WOOD_DESC": "Lumberjacks require filled Lumberjack's Journals and gather wood.",
    "T8_LEATHER": "Fortified Leather",
    "T8_LEATHER_DESC": "Advanced material used in crafting, created by refining hide.",
    "T8_LEATHER_LEVEL1": "Uncommon Fortified Leather",
    "T8_LEATHER_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T8_LEATHER_LEVEL2": "Rare Fortified Leather",
    "T8_LEATHER_LEVEL2_DESC": "Rare material used for crafting.",
    "T8_LEATHER_LEVEL3": "Exceptional Fortified Leather",
    "T8_LEATHER_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_LEATHER_LEVEL4": "Legendary Fortified Leather",
    "T8_LEATHER_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_LEATHER_LEVEL5": "Mythical Fortified Leather",
    "T8_LEATHER_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_LOOTCHEST_CRYSTAL_LEAGUE": "Elder's Crystal League Chest",
    "T8_MAIN_1HCROSSBOW": "Elder's Light Crossbow",
    "T8_MAIN_1HCROSSBOW_DESC": "Equipment Item",
    "T8_MAIN_ARCANESTAFF": "Elder's Arcane Staff",
    "T8_MAIN_ARCANESTAFF_DESC": "Equipment Item",
    "T8_MAIN_ARCANESTAFF_ENCHANTED": "Elder's Enchanted Arcane Staff",
    "T8_MAIN_ARCANESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_ARCANESTAFF_UNDEAD": "Elder's Witchwork Staff",
    "T8_MAIN_ARCANESTAFF_UNDEAD_DESC": "Equipment Item",
    "T8_MAIN_AXE": "Elder's Battleaxe",
    "T8_MAIN_AXE_DESC": "Equipment Item",
    "T8_MAIN_AXE_ENCHANTED": "Elder's Enchanted Battleaxe",
    "T8_MAIN_AXE_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_CROSSBOW_ENCHANTED": "Elder's Enchanted Crossbow",
    "T8_MAIN_CROSSBOW_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_CURSEDSTAFF": "Elder's Cursed Staff",
    "T8_MAIN_CURSEDSTAFF_AVALON": "Elder's Shadowcaller",
    "T8_MAIN_CURSEDSTAFF_AVALON_DESC": "Equipment Item",
    "T8_MAIN_CURSEDSTAFF_DESC": "Equipment Item",
    "T8_MAIN_CURSEDSTAFF_ENCHANTED": "Elder's Enchanted Cursed Staff",
    "T8_MAIN_CURSEDSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_CURSEDSTAFF_UNDEAD": "Elder's Lifecurse Staff",
    "T8_MAIN_CURSEDSTAFF_UNDEAD_DESC": "Equipment Item",
    "T8_MAIN_DAGGER": "Elder's Dagger",
    "T8_MAIN_DAGGER_DESC": "Equipment Item",
    "T8_MAIN_DAGGER_ENCHANTED": "Elder's Enchanted Dagger",
    "T8_MAIN_DAGGER_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_FIRESTAFF": "Elder's Fire Staff",
    "T8_MAIN_FIRESTAFF_DESC": "Equipment Item",
    "T8_MAIN_FIRESTAFF_ENCHANTED": "Elder's Enchanted Fire Staff",
    "T8_MAIN_FIRESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_FIRESTAFF_KEEPER": "Elder's Wildfire Staff",
    "T8_MAIN_FIRESTAFF_KEEPER_DESC": "Equipment Item",
    "T8_MAIN_FROSTSTAFF": "Elder's Frost Staff",
    "T8_MAIN_FROSTSTAFF_AVALON": "Elder's Chillhowl",
    "T8_MAIN_FROSTSTAFF_AVALON_DESC": "Equipment Item",
    "T8_MAIN_FROSTSTAFF_DESC": "Equipment Item",
    "T8_MAIN_FROSTSTAFF_ENCHANTED": "Elder's Enchanted Frost Staff",
    "T8_MAIN_FROSTSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_FROSTSTAFF_KEEPER": "Elder's Hoarfrost Staff",
    "T8_MAIN_FROSTSTAFF_KEEPER_DESC": "Equipment Item",
    "T8_MAIN_HAMMER": "Elder's Hammer",
    "T8_MAIN_HAMMER_DESC": "Equipment Item",
    "T8_MAIN_HAMMER_ENCHANTED": "Elder's Enchanted Hammer",
    "T8_MAIN_HAMMER_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_HOLYSTAFF": "Elder's Holy Staff",
    "T8_MAIN_HOLYSTAFF_AVALON": "Elder's Hallowfall",
    "T8_MAIN_HOLYSTAFF_AVALON_DESC": "Equipment Item",
    "T8_MAIN_HOLYSTAFF_DESC": "Equipment Item",
    "T8_MAIN_HOLYSTAFF_ENCHANTED": "Elder's Enchanted Holy Staff",
    "T8_MAIN_HOLYSTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_HOLYSTAFF_MORGANA": "Elder's Lifetouch Staff",
    "T8_MAIN_HOLYSTAFF_MORGANA_DESC": "Equipment Item",
    "T8_MAIN_MACE": "Elder's Mace",
    "T8_MAIN_MACE_DESC": "Equipment Item",
    "T8_MAIN_MACE_ENCHANTED": "Elder's Enchanted Mace",
    "T8_MAIN_MACE_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_MACE_HELL": "Elder's Incubus Mace",
    "T8_MAIN_MACE_HELL_DESC": "Equipment Item",
    "T8_MAIN_NATURESTAFF": "Elder's Nature Staff",
    "T8_MAIN_NATURESTAFF_AVALON": "Elder's Ironroot Staff",
    "T8_MAIN_NATURESTAFF_AVALON_DESC": "Equipment Item",
    "T8_MAIN_NATURESTAFF_DESC": "Equipment Item",
    "T8_MAIN_NATURESTAFF_ENCHANTED": "Elder's Enchanted Nature Staff",
    "T8_MAIN_NATURESTAFF_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_NATURESTAFF_KEEPER": "Elder's Druidic Staff",
    "T8_MAIN_NATURESTAFF_KEEPER_DESC": "Equipment Item",
    "T8_MAIN_RAPIER_MORGANA": "Elder's Bloodletter",
    "T8_MAIN_RAPIER_MORGANA_DESC": "Equipment Item",
    "T8_MAIN_REPEATINGCROSSBOW": "Elder's Repeating Crossbow",
    "T8_MAIN_REPEATINGCROSSBOW_DESC": "Equipment Item",
    "T8_MAIN_REPEATINGCROSSBOW_ENCHANTED": "Elder's Enchanted Repeating Crossbow",
    "T8_MAIN_REPEATINGCROSSBOW_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_ROCKMACE_KEEPER": "Elder's Bedrock Mace",
    "T8_MAIN_ROCKMACE_KEEPER_DESC": "Equipment Item",
    "T8_MAIN_SCIMITAR_MORGANA": "Elder's Clarent Blade",
    "T8_MAIN_SCIMITAR_MORGANA_DESC": "Equipment Item",
    "T8_MAIN_SPEAR": "Elder's Spear",
    "T8_MAIN_SPEAR_DESC": "Equipment Item",
    "T8_MAIN_SPEAR_ENCHANTED": "Elder's Enchanted Spear",
    "T8_MAIN_SPEAR_ENCHANTED_DESC": "Equipment Item",
    "T8_MAIN_SPEAR_KEEPER": "Elder's Heron Spear",
    "T8_MAIN_SPEAR_KEEPER_DESC": "Equipment Item",
    "T8_MAIN_SPEAR_LANCE_AVALON": "Elder's Daybreaker",
    "T8_MAIN_SPEAR_LANCE_AVALON_DESC": "Equipment Item",
    "T8_MAIN_SWORD": "Elder's Broadsword",
    "T8_MAIN_SWORD_DESC": "Equipment Item",
    "T8_MAIN_SWORD_ENCHANTED": "Elder's Enchanted Broadsword",
    "T8_MAIN_SWORD_ENCHANTED_DESC": "Equipment Item",
    "T8_MEAL_SANDWICH": "Beef Sandwich",
    "T8_MEAL_SANDWICH_AVALON": "Avalonian Beef Sandwich",
    "T8_MEAL_SANDWICH_AVALON_DESC": "Avalonian meal that increases maximum health and CC Duration for a long period.",
    "T8_MEAL_SANDWICH_DESC": "Sophisticated meal that increases maximum health for a long period.",
    "T8_MEAL_SANDWICH_FISH": "Thunderfall Lurcher Sandwich",
    "T8_MEAL_STEW": "Beef Stew",
    "T8_MEAL_STEW_AVALON": "Avalonian Beef Stew",
    "T8_MEAL_STEW_AVALON_DESC": "Avalonian meal that increases combat damage and health regeneration for a long period.",
    "T8_MEAL_STEW_DESC": "Sophisticated meal that increases combat damage for a long period.",
    "T8_MEAL_STEW_FISH": "Deadwater Eel Stew",
    "T8_MEAT": "Raw Beef",
    "T8_MEAT_DESC": "Cooking ingredient, used in various recipes.",
    "T8_METALBAR": "Adamantium Steel Bar",
    "T8_METALBAR_DESC": "Advanced material used in crafting, created by refining ore.",
    "T8_METALBAR_LEVEL1": "Uncommon Adamantium Steel Bar",
    "T8_METALBAR_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T8_METALBAR_LEVEL2": "Rare Adamantium Steel Bar",
    "T8_METALBAR_LEVEL2_DESC": "Rare material used for crafting.",
    "T8_METALBAR_LEVEL3": "Exceptional Adamantium Steel Bar",
    "T8_METALBAR_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_METALBAR_LEVEL4": "Legendary Adamantium Steel Bar",
    "T8_METALBAR_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_METALBAR_LEVEL5": "Mythical Adamantium Steel Bar",
    "T8_METALBAR_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_MILK": "Cow's Milk",
    "T8_MILK_DESC": "Cow's Milk is used in various meals and potions, and can be turned into Cow's Butter.",
    "T8_MOBDROP_DIREBEAR_HEAD": "Direbear's Head",
    "T8_MOBDROP_DIREBEAR_HEAD_DESC": "Use to craft a trophy you can place in your house.",
    "T8_MOUNT_ARMORED_HORSE": "Elder's Armored Horse",
    "T8_MOUNT_ARMORED_HORSE_DESC": "Protected by thick plating, an armored horse is ideal for traveling through Albion's more dangerous regions at speed.",
    "T8_MOUNT_ARMORED_HORSE_MORGANA": "Morgana Nightmare",
    "T8_MOUNT_ARMORED_HORSE_MORGANA_DESC": "Every Morgana horse-breeder dreams of birthing a foal angry and aggressive enough to survive demonic possession. The resulting creature is almost as dangerous to its rider as it is to its enemies.",
    "T8_MOUNT_ARMORED_HORSE_SKIN_01": "Elder's Warhorse",
    "T8_MOUNT_ARMORED_HORSE_SKIN_01_DESC": "An armored horse bearing the impressive banner of its rider's guild. Ideal for raising morale in big battles.",
    "T8_MOUNT_COUGAR_KEEPER": "Rageclaw",
    "T8_MOUNT_COUGAR_KEEPER_DESC": "The fastest and most aggressive swiftclaw cubs are raised as rageclaws: battle mounts for berserker cavalry. Raised from birth to tolerate the fury of battle, rageclaws deliver their riders right into the heart of the enemy ranks.",
    "T8_MOUNT_DIREBEAR": "Saddled Direbear",
    "T8_MOUNT_DIREBEAR_DESC": "Mount",
    "T8_MOUNT_HORSE": "Elder's Riding Horse",
    "T8_MOUNT_HORSE_DESC": "Lean and agile, Albion horses can carry their riders quickly across the continent, but have little strength to bear heavy items.",
    "T8_MOUNT_HORSE_UNDEAD": "Spectral Bonehorse",
    "T8_MOUNT_HORSE_UNDEAD_DESC": "Secret rituals allow the spirit of an ancient knight's mount to animate the cooling corpse of a sacrificial horse. Loyal and obedient, its appearance nevertheless strikes fear into its foes.",
    "T8_MOUNT_MAMMOTH_BATTLE": "Elder's Command Mammoth",
    "T8_MOUNT_MAMMOTH_BATTLE_DESC": "Battle Mount - This war mammoth's command platform allows its rider to direct and bolster allies. Immune to crowd control.",
    "T8_MOUNT_MAMMOTH_BATTLE_LEGACY": "Elder's Command Mammoth (Legacy)",
    "T8_MOUNT_MAMMOTH_BATTLE_LEGACY_DESC": "This item was crafted before an economic update. Can be exchanged for its original energy value for a limited time.",
    "T8_MOUNT_MAMMOTH_TRANSPORT": "Elder's Transport Mammoth",
    "T8_MOUNT_MAMMOTH_TRANSPORT_DESC": "What a mammoth lacks in speed, it makes up for in enormous carrying capacity. Mammoths are the favored transport of anyone wishing to move really, really large quantities of goods.",
    "T8_MOUNT_OX": "Elder's Transport Ox",
    "T8_MOUNT_OX_DESC": "Oxen are commonly used for transporting large quantities of items in Albion, as they are slow but are not easily stopped.",
    "T8_MOUNT_SWAMP_DRAGON": "Elder's Swamp Dragon",
    "T8_MOUNT_SWAMP_DRAGON_DESC": "Can actively support in big fights by debuffing enemies",
    "T8_MOUNTUPGRADE_COUGAR_KEEPER": "Sacred Bone Marrow",
    "T8_MOUNTUPGRADE_COUGAR_KEEPER_DESC": "Consecrated Keeper Bone Marrow, that when used in a ritual has the power to transform a cougar into a mighty Rageclaw.",
    "T8_MOUNTUPGRADE_HORSE_CURSE": "Spectral Mask",
    "T8_MOUNTUPGRADE_HORSE_CURSE_DESC": "When bound to an undead horse with dark rituals, it will grant the horse additional powers of the undead realm.",
    "T8_MOUNTUPGRADE_HORSE_MORGANA": "Infernal Horseshoes",
    "T8_MOUNTUPGRADE_HORSE_MORGANA_DESC": "Acts as an entryway for demonic possession on Morgana Horses",
    "T8_OFF_BOOK": "Rosalia's Diary",
    "T8_OFF_BOOK_DESC": "Equipment Item - an Elder's Tome of Spells, named to honor the player Rosalia's continued support over the years.",
    "T8_OFF_BOOK_ENCHANTED": "Elder's Enchanted Tome of Spells",
    "T8_OFF_BOOK_ENCHANTED_DESC": "Equipment Item",
    "T8_OFF_CENSER_AVALON": "Elder's Celestial Censer",
    "T8_OFF_CENSER_AVALON_DESC": "Equipment Item",
    "T8_OFF_DEMONSKULL_HELL": "Elder's Muisak",
    "T8_OFF_DEMONSKULL_HELL_DESC": "Equipment Item",
    "T8_OFF_HORN_KEEPER": "Elder's Mistcaller",
    "T8_OFF_HORN_KEEPER_DESC": "Equipment Item",
    "T8_OFF_JESTERCANE_HELL": "Elder's Leering Cane",
    "T8_OFF_JESTERCANE_HELL_DESC": "Equipment Item",
    "T8_OFF_LAMP_UNDEAD": "Elder's Cryptcandle",
    "T8_OFF_LAMP_UNDEAD_DESC": "Equipment Item",
    "T8_OFF_ORB_MORGANA": "Elder's Eye of Secrets",
    "T8_OFF_ORB_MORGANA_DESC": "Equipment Item",
    "T8_OFF_SHIELD": "Elder's Shield",
    "T8_OFF_SHIELD_AVALON": "Elder's Astral Aegis",
    "T8_OFF_SHIELD_AVALON_DESC": "Equipment Item",
    "T8_OFF_SHIELD_DESC": "Equipment Item",
    "T8_OFF_SHIELD_ENCHANTED": "Elder's Enchanted Shield",
    "T8_OFF_SHIELD_ENCHANTED_DESC": "Equipment Item",
    "T8_OFF_SHIELD_HELL": "Elder's Caitiff Shield",
    "T8_OFF_SHIELD_HELL_DESC": "Equipment Item",
    "T8_OFF_SPIKEDSHIELD_MORGANA": "Elder's Facebreaker",
    "T8_OFF_SPIKEDSHIELD_MORGANA_DESC": "Equipment Item",
    "T8_OFF_TALISMAN_AVALON": "Elder's Sacred Scepter",
    "T8_OFF_TALISMAN_AVALON_DESC": "Equipment Item",
    "T8_OFF_TORCH": "Elder's Torch",
    "T8_OFF_TORCH_DESC": "Equipment Item",
    "T8_OFF_TORCH_ENCHANTED": "Elder's Enchanted Torch",
    "T8_OFF_TORCH_ENCHANTED_DESC": "Equipment Item",
    "T8_OFF_TOTEM_KEEPER": "Elder's Taproot",
    "T8_OFF_TOTEM_KEEPER_DESC": "Equipment Item",
    "T8_OFF_TOWERSHIELD_UNDEAD": "Elder's Sarcophagus",
    "T8_OFF_TOWERSHIELD_UNDEAD_DESC": "Equipment Item",
    "T8_ORE": "Adamantium Ore",
    "T8_ORE_DESC": "Ore used for crafting. Can be refined into metal bars or transmuted into higher-level material.",
    "T8_ORE_LEVEL1": "Uncommon Adamantium Ore",
    "T8_ORE_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T8_ORE_LEVEL2": "Rare Adamantium Ore",
    "T8_ORE_LEVEL2_DESC": "Rare material used for crafting.",
    "T8_ORE_LEVEL3": "Exceptional Adamantium Ore",
    "T8_ORE_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_ORE_LEVEL4": "Legendary Adamantium Ore",
    "T8_ORE_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_ORE_LEVEL5": "Mythical Adamantium Ore",
    "T8_ORE_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_PLANKS": "Whitewood Planks",
    "T8_PLANKS_DESC": "Advanced material used in crafting, created by refining logs.",
    "T8_PLANKS_LEVEL1": "Uncommon Whitewood Planks",
    "T8_PLANKS_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T8_PLANKS_LEVEL2": "Rare Whitewood Planks",
    "T8_PLANKS_LEVEL2_DESC": "Rare material used for crafting.",
    "T8_PLANKS_LEVEL3": "Exceptional Whitewood Planks",
    "T8_PLANKS_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_PLANKS_LEVEL4": "Legendary Whitewood Planks",
    "T8_PLANKS_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_PLANKS_LEVEL5": "Mythical Whitewood Planks",
    "T8_PLANKS_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_POTION_CLEANSE": "Invisibility Potion",
    "T8_POTION_CLEANSE_DESC": "Clear potion. Makes you temporarily invisible after drinking",
    "T8_POTION_COOLDOWN": "Major Poison Potion",
    "T8_POTION_COOLDOWN_DESC": "Poisoned Potion. Can be thrown at enemies to poison them.",
    "T8_PUMPKIN": "Pumpkin",
    "T8_PUMPKIN_DESC": "Pumpkins are used in a variety of meals",
    "T8_RANDOM_DUNGEON_ELITE_TOKEN_1": "Elder's Dungeon Map (Large Group)",
    "T8_RANDOM_DUNGEON_ELITE_TOKEN_2": "Uncommon Elder's Dungeon Map (Large Group)",
    "T8_RANDOM_DUNGEON_ELITE_TOKEN_3": "Rare Elder's Dungeon Map (Large Group)",
    "T8_RANDOM_DUNGEON_ELITE_TOKEN_4": "Exceptional Elder's Dungeon Map (Large Group)",
    "T8_RANDOM_DUNGEON_SOLO_TOKEN_1": "Elder's Dungeon Map (Solo)",
    "T8_RANDOM_DUNGEON_SOLO_TOKEN_2": "Uncommon Elder's Dungeon Map (Solo)",
    "T8_RANDOM_DUNGEON_SOLO_TOKEN_3": "Rare Elder's Dungeon Map (Solo)",
    "T8_RANDOM_DUNGEON_SOLO_TOKEN_4": "Exceptional Elder's Dungeon Map (Solo)",
    "T8_RANDOM_DUNGEON_TOKEN_1": "Elder's Dungeon Map (Group)",
    "T8_RANDOM_DUNGEON_TOKEN_2": "Uncommon Elder's Dungeon Map (Group)",
    "T8_RANDOM_DUNGEON_TOKEN_3": "Rare Elder's Dungeon Map (Group)",
    "T8_RANDOM_DUNGEON_TOKEN_4": "Exceptional Elder's Dungeon Map (Group)",
    "T8_RELIC": "Elder's Relic",
    "T8_RELIC_DESC": "An ancient relic, used to meld artifacts and enchant equipment.",
    "T8_RELIC_DESTRUCTION": "Primeval Relic of Destruction",
    "T8_RELIC_DESTRUCTION_DESC": "Special material used in crafting.",
    "T8_RELIC_MANIPULATION": "Primeval Relic of Manipulation",
    "T8_RELIC_MANIPULATION_DESC": "Special material used in crafting.",
    "T8_RELIC_PROTECTION": "Primeval Relic of Protection",
    "T8_RELIC_PROTECTION_DESC": "Special material used in crafting.",
    "T8_ROCK": "Marble",
    "T8_ROCK_DESC": "Stone used for crafting. Can be refined into stone blocks or transmuted into higher-level material.",
    "T8_ROCK_LEVEL1": "Uncommon Marble",
    "T8_ROCK_LEVEL1_DESC": "Uncommon stone, more efficient in refining.",
    "T8_ROCK_LEVEL2": "Rare Marble",
    "T8_ROCK_LEVEL2_DESC": "Rare stone, more efficient in refining.",
    "T8_ROCK_LEVEL3": "Exceptional Marble",
    "T8_ROCK_LEVEL3_DESC": "Exceptional stone, more efficient in refining.",
    "T8_RUNE": "Elder's Rune",
    "T8_RUNE_DESC": "A pulsing rune, used to meld artifacts and enchant equipment.",
    "T8_RUNE_DESTRUCTION": "Exalted Rune of Destruction",
    "T8_RUNE_DESTRUCTION_DESC": "Special material used in crafting.",
    "T8_RUNE_MANIPULATION": "Exalted Rune of Manipulation",
    "T8_RUNE_MANIPULATION_DESC": "Special material used in crafting.",
    "T8_RUNE_PROTECTION": "Exalted Rune of Protection",
    "T8_RUNE_PROTECTION_DESC": "Special material used in crafting.",
    "T8_SHARD_AVALONIAN": "Elder's Avalonian Shard",
    "T8_SHOES_CLOTH_AVALON": "Elder's Sandals of Purity",
    "T8_SHOES_CLOTH_HELL": "Elder's Fiend Sandals",
    "T8_SHOES_CLOTH_HELL_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_KEEPER": "Elder's Druid Sandals",
    "T8_SHOES_CLOTH_KEEPER_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_MORGANA": "Elder's Cultist Sandals",
    "T8_SHOES_CLOTH_MORGANA_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_ROYAL": "Elder's Royal Sandals",
    "T8_SHOES_CLOTH_ROYAL_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_SET1": "Elder's Scholar Sandals",
    "T8_SHOES_CLOTH_SET1_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_SET1_ENCHANTED": "Enchanted Elder's Scholar Sandals",
    "T8_SHOES_CLOTH_SET1_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_SET2": "Elder's Cleric Sandals",
    "T8_SHOES_CLOTH_SET2_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_SET2_ENCHANTED": "Enchanted Elder's Cleric Sandals",
    "T8_SHOES_CLOTH_SET2_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_SET3": "Elder's Mage Sandals",
    "T8_SHOES_CLOTH_SET3_DESC": "Equipment Item",
    "T8_SHOES_CLOTH_SET3_ENCHANTED": "Enchanted Elder's Mage Sandals",
    "T8_SHOES_CLOTH_SET3_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_GATHERER_FIBER": "Elder's Harvester Workboots",
    "T8_SHOES_GATHERER_FIBER_DESC": "Equipment Item",
    "T8_SHOES_GATHERER_FISH": "Elder's Fisherman Workboots",
    "T8_SHOES_GATHERER_FISH_DESC": "Equipment Item",
    "T8_SHOES_GATHERER_HIDE": "Elder's Skinner Workboots",
    "T8_SHOES_GATHERER_HIDE_DESC": "Equipment Item",
    "T8_SHOES_GATHERER_ORE": "Elder's Miner Workboots",
    "T8_SHOES_GATHERER_ORE_DESC": "Equipment Item",
    "T8_SHOES_GATHERER_ROCK": "Elder's Quarrier Workboots",
    "T8_SHOES_GATHERER_ROCK_DESC": "Equipment Item",
    "T8_SHOES_GATHERER_WOOD": "Elder's Lumberjack Workboots",
    "T8_SHOES_GATHERER_WOOD_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_AVALON": "Elder's Shoes of Tenacity",
    "T8_SHOES_LEATHER_HELL": "Elder's Hellion Shoes",
    "T8_SHOES_LEATHER_HELL_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_MORGANA": "Elder's Stalker Shoes",
    "T8_SHOES_LEATHER_MORGANA_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_ROYAL": "Elder's Royal Shoes",
    "T8_SHOES_LEATHER_ROYAL_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_SET1": "Elder's Mercenary Shoes",
    "T8_SHOES_LEATHER_SET1_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_SET1_ENCHANTED": "Enchanted Elder's Mercenary Shoes",
    "T8_SHOES_LEATHER_SET1_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_SET2": "Elder's Hunter Shoes",
    "T8_SHOES_LEATHER_SET2_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_SET2_ENCHANTED": "Enchanted Elder's Hunter Shoes",
    "T8_SHOES_LEATHER_SET2_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_SET3": "Elder's Assassin Shoes",
    "T8_SHOES_LEATHER_SET3_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_SET3_ENCHANTED": "Enchanted Elder's Assassin Shoes",
    "T8_SHOES_LEATHER_SET3_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_LEATHER_UNDEAD": "Elder's Specter Shoes",
    "T8_SHOES_LEATHER_UNDEAD_DESC": "Equipment Item",
    "T8_SHOES_PLATE_AVALON": "Elder's Boots of Valor",
    "T8_SHOES_PLATE_HELL": "Elder's Demon Boots",
    "T8_SHOES_PLATE_HELL_DESC": "Equipment Item",
    "T8_SHOES_PLATE_KEEPER": "Elder's Judicator Boots",
    "T8_SHOES_PLATE_KEEPER_DESC": "Equipment Item",
    "T8_SHOES_PLATE_ROYAL": "Elder's Royal Boots",
    "T8_SHOES_PLATE_ROYAL_DESC": "Equipment Item",
    "T8_SHOES_PLATE_SET1": "Elder's Soldier Boots",
    "T8_SHOES_PLATE_SET1_DESC": "Equipment Item",
    "T8_SHOES_PLATE_SET1_ENCHANTED": "Enchanted Elder's Soldier Boots",
    "T8_SHOES_PLATE_SET1_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_PLATE_SET2": "Elder's Knight Boots",
    "T8_SHOES_PLATE_SET2_DESC": "Equipment Item",
    "T8_SHOES_PLATE_SET2_ENCHANTED": "Enchanted Elder's Knight Boots",
    "T8_SHOES_PLATE_SET2_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_PLATE_SET3": "Elder's Guardian Boots",
    "T8_SHOES_PLATE_SET3_DESC": "Equipment Item",
    "T8_SHOES_PLATE_SET3_ENCHANTED": "Enchanted Elder's Guardian Boots",
    "T8_SHOES_PLATE_SET3_ENCHANTED_DESC": "Equipment Item",
    "T8_SHOES_PLATE_UNDEAD": "Elder's Graveguard Boots",
    "T8_SHOES_PLATE_UNDEAD_DESC": "Equipment Item",
    "T8_SILVERBAG_NONTRADABLE": "Elder's Bag of Silver",
    "T8_SILVERBAG_NONTRADABLE_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "T8_SKILLBOOK_NONTRADABLE": "Elder's Tome of Insight",
    "T8_SKILLBOOK_NONTRADABLE_DESC": "A crystallization of ancient wisdom. Instantly rewards 200,000 combat fame.\nMake sure to wear eligible gear when consuming this manual.\n\nThis reward is not modified by any zone or premium bonuses and is non-tradable.",
    "T8_SOUL": "Elder's Soul",
    "T8_SOUL_DESC": "A tortured soul, used to meld artifacts and enchant equipment.",
    "T8_SOUL_HUNTER": "Supreme Hunter's Soul",
    "T8_SOUL_HUNTER_DESC": "Special material used for crafting.",
    "T8_SOUL_MAGE": "Supreme Mage's Soul",
    "T8_SOUL_MAGE_DESC": "Special material used for crafting.",
    "T8_SOUL_WARRIOR": "Supreme Warrior's Soul",
    "T8_SOUL_WARRIOR_DESC": "Special material used for crafting.",
    "T8_STONEBLOCK": "Marble Block",
    "T8_STONEBLOCK_DESC": "Advanced material used in crafting, created by refining stone.",
    "T8_TRASH": "Trash",
    "T8_TRASH_DESC": "A destroyed T8 item. Cannot be repaired or salvaged.",
    "T8_WOOD": "Whitewood Logs",
    "T8_WOOD_DESC": "Logs used for crafting. Can be refined into planks or transmuted into higher-level material.",
    "T8_WOOD_LEVEL1": "Uncommon Whitewood Logs",
    "T8_WOOD_LEVEL1_DESC": "Uncommon material used for crafting.",
    "T8_WOOD_LEVEL2": "Rare Whitewood Logs",
    "T8_WOOD_LEVEL2_DESC": "Rare material used for crafting.",
    "T8_WOOD_LEVEL3": "Exceptional Whitewood Logs",
    "T8_WOOD_LEVEL3_DESC": "Exceptional material used for crafting.",
    "T8_WOOD_LEVEL4": "Legendary Whitewood Logs",
    "T8_WOOD_LEVEL4_DESC": "Legendary material used for crafting.",
    "T8_WOOD_LEVEL5": "Mythical Whitewood Logs",
    "T8_WOOD_LEVEL5_DESC": "Mythical material used for crafting.",
    "T8_YARROW": "Ghoul Yarrow",
    "T8_YARROW_DESC": "Ghoul Yarrow is used in various alchemical decoctions",
    "TREASURE_AVALON_RARITY1": "Golden Frame",
    "TREASURE_AVALON_RARITY1_DESC": "A Golden Frame that always sells in any Royal City Marketplace for 10000 Silver",
    "TREASURE_AVALON_RARITY2": "Golden Gyroscope",
    "TREASURE_AVALON_RARITY2_DESC": "A Golden Gyroscope that always sells in any Royal City Marketplace for 50000 Silver",
    "TREASURE_AVALON_RARITY3": "Golden Sextant",
    "TREASURE_AVALON_RARITY3_DESC": "A Golden Sextant that always sells in any Royal City Marketplace for 250000 Silver",
    "TREASURE_CEREMONIAL_RARITY1": "Ornamental Scepter",
    "TREASURE_CEREMONIAL_RARITY1_DESC": "An Ornamental Scepter that always sells in Thetford marketplace for 1000 Silver",
    "TREASURE_CEREMONIAL_RARITY2": "Globus Cruciger",
    "TREASURE_CEREMONIAL_RARITY2_DESC": "A Globus Cruciger that always sells in Thetford marketplace for 5000 Silver",
    "TREASURE_CEREMONIAL_RARITY3": "Golden Crown",
    "TREASURE_CEREMONIAL_RARITY3_DESC": "A Golden Crown that always sells in Thetford marketplace for 25000 Silver",
    "TREASURE_DECORATIVE_RARITY1": "Simple Stone Toy",
    "TREASURE_DECORATIVE_RARITY1_DESC": "A Simple Stone Toy that always sells in Fort Sterling marketplace for 1000 Silver",
    "TREASURE_DECORATIVE_RARITY2": "Stone Mask",
    "TREASURE_DECORATIVE_RARITY2_DESC": "A Stone Mask that always sells in Fort Sterling marketplace for 5000 Silver",
    "TREASURE_DECORATIVE_RARITY3": "Stone Idol",
    "TREASURE_DECORATIVE_RARITY3_DESC": "A Stone Idol that always sells in Fort Sterling marketplace for 25000 Silver",
    "TREASURE_KNOWLEDGE_RARITY1": "Corrupted Scroll",
    "TREASURE_KNOWLEDGE_RARITY1_DESC": "A Corrupted Scroll that always sells in Martlock marketplace for 1000 Silver",
    "TREASURE_KNOWLEDGE_RARITY2": "Thin Booklet",
    "TREASURE_KNOWLEDGE_RARITY2_DESC": "A Thin Booklet that that always sells in Martlock marketplace for 5000 Silver",
    "TREASURE_KNOWLEDGE_RARITY3": "Ancient Tome",
    "TREASURE_KNOWLEDGE_RARITY3_DESC": "An Ancient Tome that always sells in Martlock marketplace for 25000 Silver",
    "TREASURE_RITUAL_RARITY1": "Ritual Candles",
    "TREASURE_RITUAL_RARITY1_DESC": "Ritual Candles that always sell in Caerleon marketplace for 1000 Silver",
    "TREASURE_RITUAL_RARITY2": "Blood Chalice",
    "TREASURE_RITUAL_RARITY2_DESC": "A Blood Chalice that always sells in Caerleon marketplace for 5000 Silver",
    "TREASURE_RITUAL_RARITY3": "Sacrificial Dagger",
    "TREASURE_RITUAL_RARITY3_DESC": "A Sacrificial Dagger that always sells in Caerleon marketplace for 25000 Silver",
    "TREASURE_SILVERWARE_RARITY1": "Silver Cup",
    "TREASURE_SILVERWARE_RARITY1_DESC": "A Silver Cup that always sells in Lymhurst marketplace for 1000 Silver",
    "TREASURE_SILVERWARE_RARITY2": "Silver Mirror",
    "TREASURE_SILVERWARE_RARITY2_DESC": "A Silver Mirror that always sells in Lymhurst marketplace for 5000 Silver",
    "TREASURE_SILVERWARE_RARITY3": "Silver Candelabrum",
    "TREASURE_SILVERWARE_RARITY3_DESC": "A Silver Candelabrum that always sells in Lymhurst marketplace for 25000 Silver",
    "TREASURE_TRIBAL_RARITY1": "Feather Talisman",
    "TREASURE_TRIBAL_RARITY1_DESC": "A Feather Talisman that always sells in Bridgewatch marketplace for 1000 Silver",
    "TREASURE_TRIBAL_RARITY2": "Dreamcatcher",
    "TREASURE_TRIBAL_RARITY2_DESC": "A Dreamcatcher that always sells in Bridgewatch marketplace for 5000 Silver",
    "TREASURE_TRIBAL_RARITY3": "Holy Fetish",
    "TREASURE_TRIBAL_RARITY3_DESC": "A Holy Fetish that always sells in Bridgewatch marketplace for 25000 Silver",
    "UNIQUE_ARMOR_FOUNDER_ELITE": "Explorer's Armor",
    "UNIQUE_ARMOR_FOUNDER_ELITE_DESC": "Equipment Item",
    "UNIQUE_ARMOR_FOUNDER_LEGENDARY": "Legendary Explorer's Armor",
    "UNIQUE_ARMOR_FOUNDER_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_ARMOR_STARTERPACK_ELITE": "Adventurer's Jacket",
    "UNIQUE_ARMOR_STARTERPACK_ELITE_DESC": "Equipment Item",
    "UNIQUE_ARMOR_STARTERPACK_LEGENDARY": "Legendary Adventurer's Armor",
    "UNIQUE_ARMOR_STARTERPACK_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_ARMOR_VANITY_ARENA_SET_01": "Arena Veteran's Cloak",
    "UNIQUE_ARMOR_VANITY_ARENA_SET_01_DESC": "Vanity Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils",
    "UNIQUE_ARMOR_VANITY_BARD": "Bard's Suit",
    "UNIQUE_ARMOR_VANITY_DRESS_BLACK": "Noblewoman's Dress",
    "UNIQUE_ARMOR_VANITY_DRESS_BLUE": "Blue Princess Dress",
    "UNIQUE_ARMOR_VANITY_DRESS_RED": "Red Tulip Dress",
    "UNIQUE_ARMOR_VANITY_DRESS_RED_DESC": "Equipment item - Usually worn at festivities",
    "UNIQUE_ARMOR_VANITY_EASTER": "Bunny Stalker Overalls",
    "UNIQUE_ARMOR_VANITY_EASTER_DESC": "Equipment item - Clothing specialized for bunny hunting.",
    "UNIQUE_ARMOR_VANITY_INNKEEPER": "Innkeeper's Shirt",
    "UNIQUE_ARMOR_VANITY_JESTER": "Jester Costume",
    "UNIQUE_ARMOR_VANITY_JESTER_DESC": "Equipment Item - Not suited for fighting",
    "UNIQUE_ARMOR_VANITY_KNIGHT": "Knight Adventurer's Armor",
    "UNIQUE_ARMOR_VANITY_KNIGHT_GUILD_COLORED": "Knight Adventurer's Guild Armor",
    "UNIQUE_ARMOR_VANITY_PIRATE": "Navigator's Coat",
    "UNIQUE_ARMOR_VANITY_PIRATE_DESC": "Equipment Item",
    "UNIQUE_ARMOR_VANITY_PLAGUEDOC": "Hygienic Coat",
    "UNIQUE_ARMOR_VANITY_PLAGUEDOC_DESC": "Equipment Item",
    "UNIQUE_ARMOR_VANITY_PRIEST": "Monk's Robe",
    "UNIQUE_ARMOR_VANITY_RICH_NOBLE": "Rich Noble's Doublet",
    "UNIQUE_ARMOR_VANITY_RICH_NOBLE_DESC": "Equipment item - Usually worn at festivities",
    "UNIQUE_ARMOR_VANITY_ROGUE": "Rogue Adventurer's Armor",
    "UNIQUE_ARMOR_VANITY_ROGUE_GUILD_COLORED": "Rogue Adventurer's Guild Armor",
    "UNIQUE_ARMOR_VANITY_SANTACLAUS": "Yule Coat",
    "UNIQUE_ARMOR_VANITY_SANTACLAUS_DESC": "Equipment item - Clothing to celebrate Midwinter",
    "UNIQUE_ARMOR_VANITY_SKELETON": "Ribcage",
    "UNIQUE_ARMOR_VANITY_SKELETON_DESC": "Equipment Item",
    "UNIQUE_ARMOR_VANITY_SKELETON_UNDEAD": "Undead Ribcage",
    "UNIQUE_ARMOR_VANITY_WEDDING_DRESS": "Bridal Dress",
    "UNIQUE_ARMOR_VANITY_WEDDING_DRESS_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_ARMOR_VANITY_WEDDING_TUXEDO": "Groom Suit",
    "UNIQUE_ARMOR_VANITY_WEDDING_TUXEDO_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_AVATAR_ADC_TOKENLOCKED_01": "Avatar: Adventurer",
    "UNIQUE_AVATAR_AND_AVATARFRAME_DESC": "Using this non-tradable item permanently unlocks an Avatar and Avatar Ring on this character.",
    "UNIQUE_AVATAR_DESC": "Using this non-tradable item permanently unlocks an Avatar on this character.",
    "UNIQUE_AVATAR_GVGSEASON_04": "Avatar: Guild Season 4",
    "UNIQUE_AVATAR_GVGSEASON_04_DESC": "Using this non-tradable item permanently unlocks an Avatar on this character.",
    "UNIQUE_AVATAR_GVGSEASON_05": "Avatar: Guild Season 5",
    "UNIQUE_AVATAR_GVGSEASON_05_DESC": "Using this non-tradable item permanently unlocks an Avatar on this character.",
    "UNIQUE_AVATAR_GVGSEASON_06": "Avatar: Guild Season 6",
    "UNIQUE_AVATAR_GVGSEASON_06_DESC": "Using this non-tradable item permanently unlocks an Avatar on this character.",
    "UNIQUE_AVATAR_GVGSEASON_07": "Avatar: Guild Season 7",
    "UNIQUE_AVATAR_GVGSEASON_07_DESC": "Using this non-tradable item permanently unlocks an Avatar on this character.",
    "UNIQUE_AVATAR_GVGSEASON_08": "Avatar: Guild Season 8",
    "UNIQUE_AVATAR_GVGSEASON_09": "Avatar: Guild Season 9",
    "UNIQUE_AVATAR_GVGSEASON_10": "Avatar: Guild Season 10",
    "UNIQUE_AVATAR_GVGSEASON_AVALON_INVASION": "Avatar: Avalonian Invasion",
    "UNIQUE_AVATARRING_ADC_APR2019": "Avatar Ring: Hunter Challenge",
    "UNIQUE_AVATARRING_ADC_APR2019_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Hunter Challenge 2019' on this character.",
    "UNIQUE_AVATARRING_ADC_AUG2019": "Avatar Ring: Divine Challenge",
    "UNIQUE_AVATARRING_ADC_AUG2019_DESC": "Using this non-tradable item permanently unlocks an Avatar Ring on this character.",
    "UNIQUE_AVATARRING_ADC_DEC2018": "Avatar Ring: Yuletide Challenge",
    "UNIQUE_AVATARRING_ADC_DEC2018_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Yuletide Challenge 2018' on this character.",
    "UNIQUE_AVATARRING_ADC_FEB2019": "Avatar Ring: Carnival Challenge",
    "UNIQUE_AVATARRING_ADC_FEB2019_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Carnival Challenge 2019' on this character.",
    "UNIQUE_AVATARRING_ADC_JAN2019": "Avatar Ring: Frost Challenge",
    "UNIQUE_AVATARRING_ADC_JAN2019_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Frost Challenge' on this character.",
    "UNIQUE_AVATARRING_ADC_JUL2019": "Avatar Ring: Undead Challenge",
    "UNIQUE_AVATARRING_ADC_JUL2019_DESC": "Using this non-tradable item permanently unlocks an Avatar Ring on this character.",
    "UNIQUE_AVATARRING_ADC_JUN2019": "Avatar Ring: Knight Challenge",
    "UNIQUE_AVATARRING_ADC_JUN2019_DESC": "Using this non-tradable item permanently unlocks an Avatar Ring on this character.",
    "UNIQUE_AVATARRING_ADC_MAR2019": "Avatar Ring: Keeper Challenge",
    "UNIQUE_AVATARRING_ADC_MAR2019_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Keeper Challenge 2019' on this character.",
    "UNIQUE_AVATARRING_ADC_MAY2019": "Avatar Ring: Morgana Challenge",
    "UNIQUE_AVATARRING_ADC_MAY2019_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Morgana Challenge 2019' on this character.",
    "UNIQUE_AVATARRING_ADC_NOV2018": "Avatar Ring: Grim Challenge",
    "UNIQUE_AVATARRING_ADC_NOV2018_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Grim Challenge 2018' on this character.",
    "UNIQUE_AVATARRING_ADC_OCT2019": "Avatar Ring: Harvest Challenge",
    "UNIQUE_AVATARRING_ADC_SEP2019": "Avatar Ring: Heretic Challenge",
    "UNIQUE_AVATARRING_ADC_TOKENLOCKED_01": "Avatar Ring: Adventurer",
    "UNIQUE_AVATARRING_ADC_TOKENLOCKED_ARCANE": "Avatar Ring: Enigma",
    "UNIQUE_AVATARRING_ADC_TOKENLOCKED_FIRE": "Avatar Ring: Inferno",
    "UNIQUE_AVATARRING_ADC_TOKENLOCKED_NATURE": "Avatar Ring: Nature Spirit",
    "UNIQUE_AVATARRING_ADC_TOKENLOCKED_SWORDS": "Avatar Ring: Crossed Blades",
    "UNIQUE_AVATARRING_CHARITY_MARCH2020": "Avatar Ring: Staff of Hermes",
    "UNIQUE_AVATARRING_DESC": "Using this non-tradable item permanently unlocks an Avatar Ring on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_1ST": "Avatar Ring: Season 1st Place",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_1ST_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Season 1st Place' on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_2ND": "Avatar Ring: Season 2nd Place",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_2ND_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Season  2nd Place' on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_3RD": "Avatar Ring: Season 3rd Place",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_3RD_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Season 3rd Place' on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_AVALON_INVASION": "Avatar Ring: Avalonian Invasion",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_BRONZE": "Avatar Ring Set: Season Bronze Rank",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_BRONZE_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring Set 'Season Bronze Rank' on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_CRYSTAL": "Avatar Ring Set: Season Crystal Rank",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_CRYSTAL_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring Set 'Season Crystal Rank' on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_GOLD": "Avatar Ring Set: Season Gold Rank",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_GOLD_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring Set 'Season Gold Rank' on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_IRON": "Avatar Ring: Season Iron Rank",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_IRON_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Season Iron Rank' on this character.",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_SILVER": "Avatar Ring Set: Season Silver Rank",
    "UNIQUE_AVATARRING_GVGSEASONREWARD_SILVER_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring Set 'Season Silver Rank' on this character.",
    "UNIQUE_AVATARRING_ORIGINAL_PLAYER": "Avatar Ring: Seasoned Adventurer",
    "UNIQUE_AVATARRING_ORIGINAL_PLAYER_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Seasoned Adventurer' on this character.",
    "UNIQUE_AVATARRING_TELLAFRIEND": "Avatar Ring: Recruiter",
    "UNIQUE_AVATARRING_TELLAFRIEND_02": "Avatar Ring: Wolf Hood",
    "UNIQUE_AVATARRING_TELLAFRIEND_02_DESC": "Using this non-tradable item permanently unlocks an Avatar Ring on this character.",
    "UNIQUE_AVATARRING_TELLAFRIEND_DESC": "Using this non-tradable item permanently unlocks the Avatar Ring 'Recruiter' on this character.",
    "UNIQUE_BACKPACK_VANITY_EASTER": "Bunny Stalker Basket",
    "UNIQUE_BACKPACK_VANITY_EASTER_DESC": "Equipment item - Clothing specialized for bunny hunting.",
    "UNIQUE_BACKPACK_VANITY_SANTACLAUS": "Yule Backpack",
    "UNIQUE_BACKPACK_VANITY_SANTACLAUS_DESC": "Equipment item - Helps when carrying presents",
    "UNIQUE_CAPE_BLOODHOUND_TELLAFRIEND": "Recruiter's Cape - Rottweiler",
    "UNIQUE_CAPE_BLOODHOUND_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_FOUNDER_LEGENDARY": "Legendary Explorer's Cloak",
    "UNIQUE_CAPE_FOUNDER_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_CAPE_RAM_TELLAFRIEND": "Recruiter's Fur Cape",
    "UNIQUE_CAPE_RAM_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_SLAINFOX_TELLAFRIEND": "Recruiter's Fur Cape",
    "UNIQUE_CAPE_SLAINFOX_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_STARTERPACK_LEGENDARY": "Legendary Adventurer's Cloak",
    "UNIQUE_CAPE_STARTERPACK_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_CAPE_TELLAFRIEND": "Recruiter's Cape",
    "UNIQUE_CAPE_TELLAFRIEND_02": "Riuros Cape",
    "UNIQUE_CAPE_TELLAFRIEND_02_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_TELLAFRIEND_BANNER": "Recruiter's Banner",
    "UNIQUE_CAPE_TELLAFRIEND_BANNER_02": "Ogronios Banner",
    "UNIQUE_CAPE_TELLAFRIEND_BANNER_02_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_TELLAFRIEND_BANNER_DESC": "Equipment Item",
    "UNIQUE_CAPE_TELLAFRIEND_BATRIDER": "Master of Bats Cape",
    "UNIQUE_CAPE_TELLAFRIEND_BATRIDER_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_TELLAFRIEND_DESC": "Equipment Item",
    "UNIQUE_CAPE_TIGER_TELLAFRIEND": "Recruiter's Tiger Cape",
    "UNIQUE_CAPE_TIGER_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_TOAD_TELLAFRIEND": "Recruiter's Cape - Toad",
    "UNIQUE_CAPE_TOAD_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CAPE_VANITY_ARENA_SET_01": "Arena Veteran's Cape",
    "UNIQUE_CAPE_VANITY_ARENA_SET_01_DESC": "Vanity Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils",
    "UNIQUE_CAPE_VANITY_KNIGHT": "Knight Adventurer's Cape",
    "UNIQUE_CAPE_VANITY_KNIGHT_GUILD_COLORED": "Knight Adventurer's Guild Cape",
    "UNIQUE_CAPE_VANITY_ROGUE": "Rogue Adventurer's Cape",
    "UNIQUE_CAPE_VANITY_ROGUE_GUILD_COLORED": "Rogue Adventurer's Guild Cape",
    "UNIQUE_CAPE_VANITY_SKELETON": "Ragged Cape",
    "UNIQUE_CAPE_VANITY_SKELETON_DESC": "Equipment Item",
    "UNIQUE_CAPE_VANITY_SKELETON_UNDEAD": "Ragged Undead Cape",
    "UNIQUE_CAPE_VANITY_WEDDING_TUXEDO": "Groom Cape",
    "UNIQUE_CAPE_VANITY_WEDDING_TUXEDO_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_CAPE_WOLF_GREY_TELLAFRIEND": "Recruiter's Grey Wolf Cape",
    "UNIQUE_CAPE_WOLF_GREY_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_CONSUMABLE_EVENT_EASTER_2020_CHOCOLATE": "Chocolate",
    "UNIQUE_CONSUMABLE_EVENT_EASTER_2020_CHOCOLATE_DESC": "Consuming will increase happiness!\nAnd body weight...",
    "UNIQUE_CONSUMABLE_EVENT_EASTER_2020_EGG": "Surprise Egg",
    "UNIQUE_CONSUMABLE_EVENT_EASTER_2020_EGG_DESC": "This egg is surprisingly warm.",
    "UNIQUE_CONSUMABLE_EVENT_WINTER_2017": "Snowball",
    "UNIQUE_CONSUMABLE_EVENT_WINTER_2017_DESC": "Throw at others to start a snowball fight!",
    "UNIQUE_FOCUSPOTION_ADC_GENERAL_01": "Focus Restoration Potion",
    "UNIQUE_FOCUSPOTION_ADC_GENERAL_01_DESC": "A powerful magic potion able to restore a significant number of Focus Points.",
    "UNIQUE_FOCUSPOTION_ADC_NONTRADABLE_01": "Focus Restoration Potion",
    "UNIQUE_FOCUSPOTION_ADC_NONTRADABLE_01_DESC": "A powerful magic potion able to restore a significant number of Focus Points.",
    "UNIQUE_FOCUSPOTION_TUTORIAL_01": "Diluted Focus Restoration Potion",
    "UNIQUE_FOCUSPOTION_TUTORIAL_01_DESC": "An often diluted magic potion able to restore a small number of Focus Points.",
    "UNIQUE_FURNITUREITEM_ADC_GLASS_SPHERE_A": "Glass Sphere",
    "UNIQUE_FURNITUREITEM_ADC_GLASS_SPHERE_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_ADC_GRAVE_A": "Tomb of the Unknown",
    "UNIQUE_FURNITUREITEM_ADC_GRAVE_A_DESC": "Here lies a fallen warrior without a name.",
    "UNIQUE_FURNITUREITEM_ADC_GRAVE_B": "Memorial of the Fallen",
    "UNIQUE_FURNITUREITEM_ADC_GRAVE_B_DESC": "A monument dedicated to the unknown souls lost in the wars of Albion.",
    "UNIQUE_FURNITUREITEM_ADC_GRIM_COFFIN": "Empty Coffin",
    "UNIQUE_FURNITUREITEM_ADC_GRIM_HEADSTONE": "Grim Gravestone",
    "UNIQUE_FURNITUREITEM_ADC_GRIM_LANTERN": "Grim Lantern",
    "UNIQUE_FURNITUREITEM_ADC_GRIM_WEEPINGWOMAN": "Weeping Woman Statue",
    "UNIQUE_FURNITUREITEM_ADC_HALLOWEEN_CAULDRON_A": "Halloween Cauldron",
    "UNIQUE_FURNITUREITEM_ADC_HALLOWEEN_PUMPKIN_LANTERN_A": "Scary Pumpkin Lantern",
    "UNIQUE_FURNITUREITEM_ADC_HALLOWEEN_PUMPKIN_LANTERN_B": "Friendly Pumpkin Lantern",
    "UNIQUE_FURNITUREITEM_ADC_HALLOWEEN_SCARECROW_A": "Halloween Scarecrow",
    "UNIQUE_FURNITUREITEM_ADC_HALLOWEEN_SCARECROW_PYRE_A": "Halloween Pyre",
    "UNIQUE_FURNITUREITEM_ADC_HALLOWEEN_TREE_LANTERN_A": "Halloween Lantern",
    "UNIQUE_FURNITUREITEM_ADC_HEALING_CIRCLE_A": "Magic Rune Circle",
    "UNIQUE_FURNITUREITEM_ADC_HEALING_CIRCLE_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_ADC_ICESCULPTURE_A": "Ice Sculpture: Bonecrusher Berserker",
    "UNIQUE_FURNITUREITEM_ADC_ICESCULPTURE_A_DESC": "Skillfully crafted Ice Sculpture.",
    "UNIQUE_FURNITUREITEM_ADC_ICESCULPTURE_B": "Ice Sculpture: Cursed Archer",
    "UNIQUE_FURNITUREITEM_ADC_ICESCULPTURE_B_DESC": "Skillfully crafted Ice Sculpture.",
    "UNIQUE_FURNITUREITEM_ADC_ICESCULPTURE_C": "Ice Sculpture: Obsessed Cultist",
    "UNIQUE_FURNITUREITEM_ADC_ICESCULPTURE_C_DESC": "Skillfully crafted Ice Sculpture.",
    "UNIQUE_FURNITUREITEM_ADC_RUG_DIREBEAR": "Direbear Rug",
    "UNIQUE_FURNITUREITEM_ADC_RUG_DIREBEAR_DESC": "Can be used to decorate houses",
    "UNIQUE_FURNITUREITEM_ADC_RUG_WOLF": "Wolf Rug",
    "UNIQUE_FURNITUREITEM_ADC_RUG_WOLF_DESC": "Can be used to decorate houses",
    "UNIQUE_FURNITUREITEM_ADC_STATUE_MAGE_A": "Mage Statue",
    "UNIQUE_FURNITUREITEM_ADC_STATUE_MAGE_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_ADC_STATUE_MOUNTED_DIREWOLF_A": "Wolf Rider Statue (L)",
    "UNIQUE_FURNITUREITEM_ADC_STATUE_MOUNTED_DIREWOLF_A_DESC": "A statue of a Hunter on a Direwolf, facing left",
    "UNIQUE_FURNITUREITEM_ADC_STATUE_MOUNTED_DIREWOLF_B": "Wolf Rider Statue (R)",
    "UNIQUE_FURNITUREITEM_ADC_STATUE_MOUNTED_DIREWOLF_B_DESC": "A statue of a Hunter on a Direwolf, facing right",
    "UNIQUE_FURNITUREITEM_ADC_STUFFED_BEAR": "Taxidermy Bear",
    "UNIQUE_FURNITUREITEM_ADC_STUFFED_BEAR_DESC": "Sculpture of a bear, used as a decoration by hunters.",
    "UNIQUE_FURNITUREITEM_ADC_STUFFED_FOX": "Taxidermy Fox",
    "UNIQUE_FURNITUREITEM_ADC_STUFFED_FOX_DESC": "Sculpture of a fox, used as a decoration by hunters.",
    "UNIQUE_FURNITUREITEM_ADC_STUFFED_WOLF": "Taxidermy Wolf",
    "UNIQUE_FURNITUREITEM_ADC_STUFFED_WOLF_DESC": "Sculpture of a wolf, used as a decoration by hunters.",
    "UNIQUE_FURNITUREITEM_EASTER_CHEST": "Egg-shaped Chest",
    "UNIQUE_FURNITUREITEM_EASTER_CHEST_DESC": "A small, strangely-shaped container.",
    "UNIQUE_FURNITUREITEM_FOUNDER_CERTIFICATE": "Founder's Certificate",
    "UNIQUE_FURNITUREITEM_FOUNDER_CERTIFICATE_DESC": "Decoration Item. Must be placed indoors.",
    "UNIQUE_FURNITUREITEM_FOUNDER_LOOKINGGLASS": "Explorer's Spyglass",
    "UNIQUE_FURNITUREITEM_FOUNDER_LOOKINGGLASS_DESC": "Adds a small amount of happiness to all Laborers.",
    "UNIQUE_FURNITUREITEM_FOUNDER_STATUE": "Founder's Statue",
    "UNIQUE_FURNITUREITEM_FOUNDER_STATUE_DESC": "Decoration Item. Must be placed outside.",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_09_1ST": "1st Place Statue - Season 9",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_09_1ST_DESC": "Decoration Item - A statue to honor the winner of Season 9: Elevate",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_09_2ND": "2nd Place Statue - Season 9",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_09_2ND_DESC": "Decoration Item - A statue to honor the second-place winner of Season 9: Bloco de Rua",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_09_3RD": "3rd Place Statue - Season 9",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_09_3RD_DESC": "Decoration Item - A statue to honor the third-place winner of Season 9: RANG",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_10_1ST": "1st Place Statue - Season 10",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_10_2ND": "2nd Place Statue - Season 10",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_10_3RD": "3rd Place Statue - Season 10",
    "UNIQUE_FURNITUREITEM_GVG_SEASON_NOTREADY_DESC": "Decoration Item - Still under construction; automatically transforms into a placeable statue once it has been sculpted.",
    "UNIQUE_FURNITUREITEM_HERETIC_ANIMAL_CAGES": "Heretic Animal Cages",
    "UNIQUE_FURNITUREITEM_HERETIC_ANIMAL_CAGES_DESC": "The Heretics are known for poaching and trapping small animals for food.",
    "UNIQUE_FURNITUREITEM_HERETIC_BARREL_BURNING_A": "Heretic Burning Barrel",
    "UNIQUE_FURNITUREITEM_HERETIC_CONSTRUCT": "Heretic Scarecrow",
    "UNIQUE_FURNITUREITEM_HERETIC_FLAG": "Heretic Flag",
    "UNIQUE_FURNITUREITEM_HERETIC_FLAG_DESC": "The Heretics have formed under this peculiar banner.",
    "UNIQUE_FURNITUREITEM_HERETIC_FOOD_PILE": "Heretic Food Stash",
    "UNIQUE_FURNITUREITEM_HERETIC_FOOD_PILE_DESC": "Doesn't smell very good...",
    "UNIQUE_FURNITUREITEM_HERETIC_GAME_TABLE": "Heretic Game Table",
    "UNIQUE_FURNITUREITEM_HERETIC_GAME_TABLE_DESC": "The table is filled with scribbles of the game rules. There doesn't seem to be a real point to the game, yet they all play it...",
    "UNIQUE_FURNITUREITEM_HERETIC_JUNKPILE": "Heretic Junkpile",
    "UNIQUE_FURNITUREITEM_HERETIC_LANTERN": "Heretic Lantern",
    "UNIQUE_FURNITUREITEM_HERETIC_PALLISADE": "Heretic Palisade",
    "UNIQUE_FURNITUREITEM_HERETIC_PALLISADE_DESC": "The Heretics aren't known for their skill in construction.",
    "UNIQUE_FURNITUREITEM_HERETIC_PLANNING_TABLE": "Heretic Chief's Table",
    "UNIQUE_FURNITUREITEM_HERETIC_PLANNING_TABLE_DESC": "It's filled with incoherent scribbles, random rants and just a hint of sanity.",
    "UNIQUE_FURNITUREITEM_HERETIC_STOVE_A": "Heretic Stove",
    "UNIQUE_FURNITUREITEM_HERETIC_TENT": "Heretic Tent",
    "UNIQUE_FURNITUREITEM_HERETIC_TENT_DESC": "The original settlers of Albion used tents such as these.",
    "UNIQUE_FURNITUREITEM_HERETIC_TRAINING_DUMMY": "Heretic Training Dummy",
    "UNIQUE_FURNITUREITEM_HERETIC_TRAINING_DUMMY_DESC": "Used by those nasty Heretics to train their skills...",
    "UNIQUE_FURNITUREITEM_HERETIC_WEAPON_RACK": "Heretic Weapon Rack",
    "UNIQUE_FURNITUREITEM_HERETIC_WEAPON_RACK_DESC": "With weapons like these, it's a miracle the Heretics are able to put up a fight.",
    "UNIQUE_FURNITUREITEM_HERETICS_TOOL_BOARD_A": "Heretic Toolboard",
    "UNIQUE_FURNITUREITEM_KEEPER_ALTAR_A": "Keeper Altar",
    "UNIQUE_FURNITUREITEM_KEEPER_ALTAR_A_DESC": "A Keeper altar covered in ceremonial candles.",
    "UNIQUE_FURNITUREITEM_KEEPER_CAMP_FIRE_A": "Keeper Campfire",
    "UNIQUE_FURNITUREITEM_KEEPER_CAMP_FIRE_A_DESC": "A common Keeper campfire.",
    "UNIQUE_FURNITUREITEM_KEEPER_CANDLE_A": "Keeper Ceremonial Candle",
    "UNIQUE_FURNITUREITEM_KEEPER_CANDLE_A_DESC": "Keepers tend to decorate their holy sites with candles such as these.",
    "UNIQUE_FURNITUREITEM_KEEPER_CAULDRON": "Keeper Cauldron",
    "UNIQUE_FURNITUREITEM_KEEPER_CAULDRON_DESC": "A big cauldron used by the Keepers to cook their meals and hang their meat over to give it a nice smoky flavor.",
    "UNIQUE_FURNITUREITEM_KEEPER_FIREBOWL": "Keeper Fire Bowl",
    "UNIQUE_FURNITUREITEM_KEEPER_FIREBOWL_DESC": "A mysterious glowing oil is inside this bowl. It is probably safer to not try drinking from it.",
    "UNIQUE_FURNITUREITEM_KEEPER_FLAG_A": "Keeper Flag",
    "UNIQUE_FURNITUREITEM_KEEPER_FLAG_A_DESC": "A Keeper flag which is commonly used to mark their territory.",
    "UNIQUE_FURNITUREITEM_KEEPER_HEATER": "Keeper Rock Fireplace",
    "UNIQUE_FURNITUREITEM_KEEPER_HEATER_DESC": "A fireplace carved into a big rock. The Keepers use these to keep their caves warm and cozy.",
    "UNIQUE_FURNITUREITEM_KEEPER_SHRINE_A": "Keeper Shrine",
    "UNIQUE_FURNITUREITEM_KEEPER_SHRINE_A_DESC": "Keepers tend to decorate their shrines with the bones of dead animals.",
    "UNIQUE_FURNITUREITEM_KEEPER_STAR_OF_POWER_A": "Keeper Star of Power",
    "UNIQUE_FURNITUREITEM_KEEPER_STAR_OF_POWER_A_DESC": "The Keeper druids sometimes imbue the very ground they stand on with magical power to amplify their own.",
    "UNIQUE_FURNITUREITEM_KEEPER_SYMBOL_A": "Keeper Symbol",
    "UNIQUE_FURNITUREITEM_KEEPER_SYMBOL_A_DESC": "A symbol commonly used by the Keepers to mark their territory.",
    "UNIQUE_FURNITUREITEM_KEEPER_SYMBOL_OF_POWER_A": "Keeper Symbol of Power",
    "UNIQUE_FURNITUREITEM_KEEPER_SYMBOL_OF_POWER_A_DESC": "The more powerful Keepers tend to mark their lairs with the bones of animals they have killed to show their strength.",
    "UNIQUE_FURNITUREITEM_KNIGHT_CARPET_A": "Regal Carpet",
    "UNIQUE_FURNITUREITEM_KNIGHT_CARPET_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_KNIGHT_ROUNDTABLE_A": "Round Table",
    "UNIQUE_FURNITUREITEM_KNIGHT_ROUNDTABLE_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_KNIGHT_STATUE_A": "Knight Statue",
    "UNIQUE_FURNITUREITEM_KNIGHT_STATUE_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_KNIGHT_THRONE_A": "Stone Throne",
    "UNIQUE_FURNITUREITEM_KNIGHT_THRONE_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_ARCHWAY_A": "Morgana Stone Archway",
    "UNIQUE_FURNITUREITEM_MORGANA_ARCHWAY_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_CAMPFIRE_D": "Cauldron (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_CAMPFIRE_D_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_CANDLESTAND_A": "Morgana Candle Stand",
    "UNIQUE_FURNITUREITEM_MORGANA_CANDLESTAND_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_CARPET_A": "Morgana Carpet",
    "UNIQUE_FURNITUREITEM_MORGANA_CARPET_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_FIREBOWL_B": "Simple Brazier (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_FIREBOWL_B_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_FIREBOWL_C": "Reinforced Brazier (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_FIREBOWL_C_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_PENTAGRAM": "Pentagram (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_PENTAGRAM_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_PRISON_CELL_C": "Prisoner Cage (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_PRISON_CELL_C_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_SACRIFICE_ALTAR_A": "Raven Standard Shrine (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_SACRIFICE_ALTAR_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_SIEGE_BALLISTA_A": "Siege Ballista (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_SIEGE_BALLISTA_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_STANDARD_A": "Raven Standard (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_STANDARD_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_STATUE_A": "Morgana Cultist Statue",
    "UNIQUE_FURNITUREITEM_MORGANA_STATUE_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_TENT_A": "Soldier's Tent (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_TENT_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_TORCH_A": "Flambeau (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_TORCH_A_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_TORCH_C": "Raven Standard Flambeau (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_TORCH_C_DESC": "Decorative furniture item which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_MORGANA_WEAPONCRATE_A": "Army Crate (Disciples of Morgana)",
    "UNIQUE_FURNITUREITEM_MORGANA_WEAPONCRATE_A_DESC": "Container with 64 slots which can be salvaged for Silver.",
    "UNIQUE_FURNITUREITEM_OLD_OUTLAND_CARPET": "Outlands Map Carpet",
    "UNIQUE_FURNITUREITEM_OLD_OUTLAND_CARPET_DESC": "Decorative furniture. A carpet with a map of the Outlands from before the Avalonian Invasion.",
    "UNIQUE_FURNITUREITEM_SEALED_CAERLEON_REALMGATE": "Caerleon Realmgate",
    "UNIQUE_FURNITUREITEM_SEALED_CAERLEON_REALMGATE_DESC": "Decorative furniture. A recreation of the Caerleon portal, which was sacrificed to prevent the Avalonian Invasion.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_BANNER_A": "Recruiter's Guild Banner",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_BANNER_A_DESC": "Guild Banner. Recruiter Reward which can only be placed outdoors.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_A": "Recruiter's Crate",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_A_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_B": "Recruiter's Chest",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_B_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_BARREL": "Recruiter's Barrel-crate",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_BARREL_B": "Recruiter's Storage-Barrel",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_BARREL_B_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_BARREL_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_C": "Recruiter's Wooden Chest",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_C_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_COMPANION": "Recruiter's Companion Crate",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_COMPANION_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_MERLINCUBE": "Recruiter's Merlyn Cube",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_MERLINCUBE_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_SARCOPHAGUS": "Recruiter's Sarcophagus Chest",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_CHEST_SARCOPHAGUS_DESC": "Container with 64 slots, earned by spreading the word.",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_DEER_STATUE": "Recruiter's Deer Statue",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_DEER_STATUE_DESC": "Decoration Item - Recruiter Reward which can be placed outdoors",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_HUNTER_STATUE": "Recruiter's Hunter Statue",
    "UNIQUE_FURNITUREITEM_TELLAFRIEND_HUNTER_STATUE_DESC": "Decoration Item - Recruiter Reward which can be placed outdoors",
    "UNIQUE_FURNITUREITEM_VANITY_ARENA_BANNER_01": "Modest Arena Display",
    "UNIQUE_FURNITUREITEM_VANITY_ARENA_BANNER_01_DESC": "This will look great on your player island! You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "UNIQUE_FURNITUREITEM_VANITY_ARENA_BANNER_02": "Grand Arena Display",
    "UNIQUE_FURNITUREITEM_VANITY_ARENA_BANNER_02_DESC": "This will look great on your player island! You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "UNIQUE_FURNITUREITEM_VANITY_ARENA_BANNER_03": "Glorious Arena Display",
    "UNIQUE_FURNITUREITEM_VANITY_ARENA_BANNER_03_DESC": "This will look great on your player island! You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "UNIQUE_FURNITUREITEM_VICTORY_TROPHY": "Skull of $craftedby",
    "UNIQUE_FURNITUREITEM_VICTORY_TROPHY_DESC": "The skull of a vanquished foe.",
    "UNIQUE_FURNITUREITEM_XMAS_FILL_CITY_TREE_A": "Decorated Pine Tree",
    "UNIQUE_FURNITUREITEM_XMAS_FILL_CITY_TREE_A_DESC": "Pine tree decorated with candles.",
    "UNIQUE_FURNITUREITEM_XMAS_FILL_CITY_TREE_B": "Small Decorated Pine Tree",
    "UNIQUE_FURNITUREITEM_XMAS_FILL_CITY_TREE_B_DESC": "Small pine tree with Yule decoration.",
    "UNIQUE_FURNITUREITEM_XMAS_PRESENT": "Present Box",
    "UNIQUE_FURNITUREITEM_XMAS_PRESENT_DESC": "Small present - Container with 10 slots.",
    "UNIQUE_GVGTOKEN_GENERIC": "Siphoned Energy",
    "UNIQUE_GVGTOKEN_GENERIC_DESC": "Magical energy drained from leyline crystals. There's no way this could go wrong...",
    "UNIQUE_HEAD_FOUNDER_ELITE": "Explorer's Hat",
    "UNIQUE_HEAD_FOUNDER_ELITE_DESC": "Equipment Item",
    "UNIQUE_HEAD_FOUNDER_LEGENDARY": "Legendary Explorer's Hat",
    "UNIQUE_HEAD_FOUNDER_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_HEAD_STARTERPACK_ELITE": "Adventurer's Helmet",
    "UNIQUE_HEAD_STARTERPACK_ELITE_DESC": "Equipment Item",
    "UNIQUE_HEAD_STARTERPACK_LEGENDARY": "Legendary Adventurer's Hat",
    "UNIQUE_HEAD_STARTERPACK_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_HEAD_TELLAFRIEND_BATRIDER": "Master of Bats Helmet",
    "UNIQUE_HEAD_TELLAFRIEND_BATRIDER_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_HEAD_VANITY_ARENA_EYEPATCH": "Arena Veteran's Eyepatch",
    "UNIQUE_HEAD_VANITY_ARENA_EYEPATCH_DESC": "Vanity Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "UNIQUE_HEAD_VANITY_ARENA_SET_01": "Arena Veteran's Circlet",
    "UNIQUE_HEAD_VANITY_ARENA_SET_01_DESC": "Vanity Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "UNIQUE_HEAD_VANITY_BARD": "Bard's Hat",
    "UNIQUE_HEAD_VANITY_DRESS_BLACK": "Noblewoman's Jewelry",
    "UNIQUE_HEAD_VANITY_DRESS_BLUE": "Blue Princess Hat",
    "UNIQUE_HEAD_VANITY_DRESS_RED": "Red Tulip Hat",
    "UNIQUE_HEAD_VANITY_DRESS_RED_DESC": "Equipment item - Usually worn at festivities",
    "UNIQUE_HEAD_VANITY_EASTER_BROWN": "Bunny Stalker Hat",
    "UNIQUE_HEAD_VANITY_EASTER_BROWN_DESC": "Equipment item - Clothing specialized for bunny hunting. Allows you to summon a bunny as bait.",
    "UNIQUE_HEAD_VANITY_EASTER_WHITE": "Snow Bunny Stalker Hat",
    "UNIQUE_HEAD_VANITY_EASTER_WHITE_DESC": "Equipment item - Clothing specialized for bunny hunting. Allows you to summon a snow bunny as bait.",
    "UNIQUE_HEAD_VANITY_INNKEEPER": "Innkeeper's Hat",
    "UNIQUE_HEAD_VANITY_JESTER": "Jester Mask",
    "UNIQUE_HEAD_VANITY_JESTER_DESC": "Equipment Item - Not suited for fighting",
    "UNIQUE_HEAD_VANITY_KNIGHT": "Knight Adventurer's Helmet",
    "UNIQUE_HEAD_VANITY_KNIGHT_GUILD_COLORED": "Knight Adventurer's Guild Helmet",
    "UNIQUE_HEAD_VANITY_PIRATE": "Navigator's Hat",
    "UNIQUE_HEAD_VANITY_PIRATE_DESC": "Equipment Item",
    "UNIQUE_HEAD_VANITY_PLAGUEDOC": "Hygienic Mask",
    "UNIQUE_HEAD_VANITY_PLAGUEDOC_DESC": "Equipment Item",
    "UNIQUE_HEAD_VANITY_PRIEST": "Monk's Hood",
    "UNIQUE_HEAD_VANITY_PUMPKIN_01": "Grinning Pumpkin Head",
    "UNIQUE_HEAD_VANITY_PUMPKIN_01_DESC": "Equipment Item - Makes you look scary",
    "UNIQUE_HEAD_VANITY_PUMPKIN_02": "Sad Pumpkin Head",
    "UNIQUE_HEAD_VANITY_PUMPKIN_02_DESC": "Equipment Item - Makes you look scary, but sad",
    "UNIQUE_HEAD_VANITY_PUMPKIN_03": "Angry Pumpkin Head",
    "UNIQUE_HEAD_VANITY_PUMPKIN_03_DESC": "Equipment Item - Makes you look scary and angry",
    "UNIQUE_HEAD_VANITY_RICH_NOBLE": "Rich Noble's Hat",
    "UNIQUE_HEAD_VANITY_RICH_NOBLE_DESC": "Equipment item - Usually worn at festivities",
    "UNIQUE_HEAD_VANITY_ROGUE": "Rogue Adventurer's Hood",
    "UNIQUE_HEAD_VANITY_SANTACLAUS": "Yule Hat",
    "UNIQUE_HEAD_VANITY_SANTACLAUS_DESC": "Equipment item - Clothing to celebrate Midwinter",
    "UNIQUE_HEAD_VANITY_SKELETON": "Laughing Skull",
    "UNIQUE_HEAD_VANITY_SKELETON_DESC": "Equipment Item",
    "UNIQUE_HEAD_VANITY_SKELETON_UNDEAD": "Undead Skull",
    "UNIQUE_HEAD_VANITY_WEDDING_DRESS": "Bridal Veil",
    "UNIQUE_HEAD_VANITY_WEDDING_DRESS_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_HEAD_VANITY_WEDDING_TUXEDO": "Groom Hat",
    "UNIQUE_HEAD_VANITY_WEDDING_TUXEDO_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_HEAD_WOLFHOOD_TELLAFRIEND": "Recruiter's Wolf Hood",
    "UNIQUE_HEAD_WOLFHOOD_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_HEAD_XMAS": "Uncle Frost's Hat",
    "UNIQUE_HEAD_XMAS_DESC": "Vanity Item",
    "UNIQUE_HIDEOUT": "Hideout Construction Kit",
    "UNIQUE_HIDEOUT_DESC": "Hideout construction kits are used to place Guild Hideouts in the Outlands.",
    "UNIQUE_INGREDIENT_ANCHOR_FOUNDER_LEGENDARY": "Explorer's Anchor",
    "UNIQUE_INGREDIENT_ANCHOR_FOUNDER_LEGENDARY_DESC": "An unique building ingredient for the Explorer's House",
    "UNIQUE_INTERNAL_ARMOR_GAMEMASTER": "Game Master's Doublet",
    "UNIQUE_INTERNAL_ARMOR_GAMEMASTER_DESC": "Equipment Item - can only be worn by Albion Online Game Masters",
    "UNIQUE_INTERNAL_HEAD_GAMEMASTER": "Game Master's Hat",
    "UNIQUE_INTERNAL_HEAD_GAMEMASTER_DESC": "Equipment Item - can only be worn by Albion Online Game Masters",
    "UNIQUE_INTERNAL_OFF_SCROLL_GAMEMASTER": "Scroll of the Law",
    "UNIQUE_INTERNAL_OFF_SCROLL_GAMEMASTER_DESC": "Equipment Item - can only be worn by Albion Online Game Masters",
    "UNIQUE_INTERNAL_SHOES_GAMEMASTER": "Game Master's Boots",
    "UNIQUE_INTERNAL_SHOES_GAMEMASTER_DESC": "Equipment Item - can only be worn by Albion Online Game Masters",
    "UNIQUE_LOOTCHEST_ADC_APR2019": "Hunter Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_APR2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_AUG2019": "Divine Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_AUG2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_DEC2018": "Yuletide Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_DEC2018_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_FEB2019": "Carnival Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_FEB2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_JAN2019": "Frost Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_JAN2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_JUL2019": "Undead Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_JUL2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_JUN2019": "Knight Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_JUN2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_MAR2019": "Keeper Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_MAR2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_MAY2019": "Morgana Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_MAY2019_DESC": "Opening this non-tradable chest adds valuable rewards directly into your inventory!",
    "UNIQUE_LOOTCHEST_ADC_NOV2018": "Grim Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_NOV2018_DESC": "Opening this non-tradable chest adds valuable rewards from the Grim Challenge 2018 to your inventory!",
    "UNIQUE_LOOTCHEST_ADC_OCT2018_01": "Harvest Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_OCT2018_01_DESC": "Opening this non-tradable chest adds valuable rewards from the Harvest Challenge 2018 to your inventory!",
    "UNIQUE_LOOTCHEST_ADC_OCT2019": "Harvest Challenge Chest",
    "UNIQUE_LOOTCHEST_ADC_OCT2019_DESC": "Opening this non-tradable chest adds valuable rewards from the Harvest Challenge to your inventory!",
    "UNIQUE_LOOTCHEST_ADC_SEP2019": "Heretic Challenge Chest",
    "UNIQUE_LOOTCHEST_BATTLEMOUNT_BRONZE": "Bronze Battle Mount Chest",
    "UNIQUE_LOOTCHEST_BATTLEMOUNT_CRYSTAL": "Crystal Battle Mount Chest",
    "UNIQUE_LOOTCHEST_BATTLEMOUNT_GOLD": "Gold Battle Mount Chest",
    "UNIQUE_LOOTCHEST_BATTLEMOUNT_SILVER": "Silver Battle Mount Chest",
    "UNIQUE_LOOTCHEST_FIRSTREFERRAL": "Recruiter's Pile of Tomes",
    "UNIQUE_LOOTCHEST_FIRSTREFERRAL_DESC": "Opening this non-tradable pile of Tomes of Insight adds valuable tomes to your inventory.",
    "UNIQUE_LOOTCHEST_SKILLBOOKS_TELLAFRIEND": "Pile of Tomes",
    "UNIQUE_LOOTCHEST_SKILLBOOKS_TELLAFRIEND_DESC": "Opening this non-tradable pile of Tomes of Insight adds valuable tomes to your inventory.",
    "UNIQUE_MOUNT_ARMORED_EAGLE_CRYSTAL": "Crystal Battle Eagle",
    "UNIQUE_MOUNT_ARMORED_EAGLE_CRYSTAL_DESC": "Battle Mount - its powerful wings can summon a storm.",
    "UNIQUE_MOUNT_ARMORED_EAGLE_GOLD": "Gold Battle Eagle",
    "UNIQUE_MOUNT_ARMORED_EAGLE_GOLD_DESC": "Battle Mount - its powerful wings can summon a storm.",
    "UNIQUE_MOUNT_ARMORED_EAGLE_SILVER": "Silver Battle Eagle",
    "UNIQUE_MOUNT_ARMORED_EAGLE_SILVER_DESC": "Battle Mount - its powerful wings can summon a storm.",
    "UNIQUE_MOUNT_BAT_PERSONAL": "Spectral Bat",
    "UNIQUE_MOUNT_BAT_PERSONAL_DESC": "Adventurer's Challenge Reward - Fast and ethereal, with formidable speed and the ability to teleport over short distances.",
    "UNIQUE_MOUNT_BAT_TELLAFRIEND": "Recruiter's Saddled Bat",
    "UNIQUE_MOUNT_BAT_TELLAFRIEND_DESC": "Referral Mount - Can fly on its own, though with a human on top it becomes too heavy to fly over obstacles.",
    "UNIQUE_MOUNT_BATTLESPIDER_CRYSTAL": "Crystal Goliath Horseeater",
    "UNIQUE_MOUNT_BATTLESPIDER_DESC": "Battle Mount - This creature can strike fear into other battle mounts. Because of its sheer size and aggressive nature it is assumed to eat even horses in the wild.",
    "UNIQUE_MOUNT_BATTLESPIDER_GOLD": "Gold Goliath Horseeater",
    "UNIQUE_MOUNT_BATTLESPIDER_SILVER": "Silver Goliath Horseeater",
    "UNIQUE_MOUNT_BEAR_KEEPER_ADC": "Grizzly Bear",
    "UNIQUE_MOUNT_BEAR_KEEPER_ADC_DESC": "Adventurer's Challenge Reward - A strong animal that can easily carry a lot of weight. Its mighty presence alone strikes fear in any attackers.",
    "UNIQUE_MOUNT_BEETLE_CRYSTAL": "Crystal Colossus Beetle",
    "UNIQUE_MOUNT_BEETLE_CRYSTAL_DESC": "Battle Mount - can stir up dust around enemies. Have you been doing your part?",
    "UNIQUE_MOUNT_BEETLE_GOLD": "Gold Colossus Beetle",
    "UNIQUE_MOUNT_BEETLE_GOLD_DESC": "Battle Mount - can stir up dust around enemies. Have you been doing your part?",
    "UNIQUE_MOUNT_BEETLE_SILVER": "Silver Colossus Beetle",
    "UNIQUE_MOUNT_BEETLE_SILVER_DESC": "Battle Mount - can stir up dust around enemies. Have you been doing your part?",
    "UNIQUE_MOUNT_BEHEMOTH_CRYSTAL": "Crystal Behemoth",
    "UNIQUE_MOUNT_BEHEMOTH_GOLD": "Gold Behemoth",
    "UNIQUE_MOUNT_BEHEMOTH_SILVER": "Silver Behemoth",
    "UNIQUE_MOUNT_BEHEMOTH_SILVER_DESC": "Battle Mount - offers long-range attacks to support your armies in large battles.",
    "UNIQUE_MOUNT_BERNARD_TELLAFRIEND": "Recruiter's Saint Bernard",
    "UNIQUE_MOUNT_BERNARD_TELLAFRIEND_DESC": "Referral Mount - Her name is Bianca. She has a very laid-back personality and gets along with everyone.",
    "UNIQUE_MOUNT_BLACK_PANTHER_ADC": "Black Panther",
    "UNIQUE_MOUNT_BLACK_PANTHER_ADC_DESC": "Adventurer's Challenge Reward - A real hunter, very swift with the ability to temporarily sprint at high speed to catch any prey.",
    "UNIQUE_MOUNT_BLOODHOUND_TELLAFRIEND": "Recruiter's Rottweiler",
    "UNIQUE_MOUNT_BLOODHOUND_TELLAFRIEND_DESC": "Referral Mount - His name is Leopold. Though he may look tough, he's actually very sweet.",
    "UNIQUE_MOUNT_CART_STARTERPACK": "Legendary Adventurer's Cart",
    "UNIQUE_MOUNT_CART_STARTERPACK_DESC": "Mount",
    "UNIQUE_MOUNT_DIREFOX_TELLAFRIEND": "Recruiter's Dire Fox",
    "UNIQUE_MOUNT_DIREFOX_TELLAFRIEND_DESC": "Referral Mount - His name is James. Slick and a bit ruthless. When fed in a group, he always secures a big share for himself.",
    "UNIQUE_MOUNT_DIREWOLF_GREY_TELLAFRIEND": "Recruiter's Grey Wolf",
    "UNIQUE_MOUNT_DIREWOLF_GREY_TELLAFRIEND_DESC": "Mount - His name is Vezgard. Once leader of a Direwolf pack, he is not the youngest anymore, but can still easily keep up with the young wolves.",
    "UNIQUE_MOUNT_DIVINE_OWL_ADC": "Divine Owl",
    "UNIQUE_MOUNT_DIVINE_OWL_ADC_DESC": "Adventurer's Challenge Reward - A being bestowed with divine wisdom and the gift of clairvoyance.",
    "UNIQUE_MOUNT_DONKEY_HALLOWEEN": "Jack o' Donkey",
    "UNIQUE_MOUNT_DONKEY_HALLOWEEN_DESC": "Mount - His name is Ralf and he likes pumpkins.",
    "UNIQUE_MOUNT_DONKEY_UNIQUE_TELLAFRIEND": "Recruiter's Donkey",
    "UNIQUE_MOUNT_DONKEY_UNIQUE_TELLAFRIEND_DESC": "Mount - his name is Waffle",
    "UNIQUE_MOUNT_ENT_CRYSTAL": "Crystal Ancient Ent",
    "UNIQUE_MOUNT_ENT_GOLD": "Gold Ancient Ent",
    "UNIQUE_MOUNT_ENT_SILVER": "Silver Ancient Ent",
    "UNIQUE_MOUNT_ENT_SILVER_DESC": "Battle Mount - Reliable ally that spreads healing and supports an army's casters. Does not like to be roused.",
    "UNIQUE_MOUNT_GIANT_HORSE_ADC": "Giant Horse",
    "UNIQUE_MOUNT_GIANT_HORSE_ADC_DESC": "A heavy horse, also known as Cold Blood. Fearless and not easily impressed by any unforeseen threats.",
    "UNIQUE_MOUNT_GIANTSTAG_FOUNDER_EPIC": "Epic Explorer's Giant Stag",
    "UNIQUE_MOUNT_GIANTSTAG_FOUNDER_EPIC_DESC": "Mount - Reward for Epic Founders",
    "UNIQUE_MOUNT_GIANTSTAG_TELLAFRIEND": "Recruiter's Giant Stag",
    "UNIQUE_MOUNT_GIANTSTAG_TELLAFRIEND_DESC": "Referral Mount - His name is Samuel. He has good instincts and senses suspicious persons on sight, but can also be quite stubborn at times.",
    "UNIQUE_MOUNT_GIANTTOAD_02_TELLAFRIEND": "Recruiter's Giant Frog",
    "UNIQUE_MOUNT_GIANTTOAD_02_TELLAFRIEND_DESC": "Mount - Her name is Berta. Born in a backwater swamp, she dreams of someday seeing the world.",
    "UNIQUE_MOUNT_GIANTTOAD_TELLAFRIEND": "Recruiter's Toad",
    "UNIQUE_MOUNT_GIANTTOAD_TELLAFRIEND_DESC": "Mount - his name is Slippy",
    "UNIQUE_MOUNT_HERETIC_MULE_ADC": "Heretic Combat Mule",
    "UNIQUE_MOUNT_HERETIC_MULE_ADC_DESC": "Adventurer's Challenge Reward - An abomination of war that could only have been contrived by the most perverted of minds.",
    "UNIQUE_MOUNT_HORSE_FOUNDER_LEGENDARY": "Legendary Explorer's Horse",
    "UNIQUE_MOUNT_HORSE_FOUNDER_LEGENDARY_DESC": "Mount",
    "UNIQUE_MOUNT_HORSE_STARTERPACK": "Legendary Adventurer's Horse",
    "UNIQUE_MOUNT_HORSE_STARTERPACK_DESC": "Mount",
    "UNIQUE_MOUNT_HOUSEPIG": "Domesticated Hog",
    "UNIQUE_MOUNT_HOUSEPIG_DESC": "Mount - Although it doesn't look like it, it can carry a person over long distances.",
    "UNIQUE_MOUNT_HUSKYSLEIGH_TELLAFRIEND": "Recruiter's Husky Sled",
    "UNIQUE_MOUNT_HUSKYSLEIGH_TELLAFRIEND_DESC": "Mount - The perfect way to travel through cold regions while remaining wrapped up in its cozy cover. The sled is pulled by the ever-cheerful blue eyed husky named Mickey.",
    "UNIQUE_MOUNT_IMPALA_TELLAFRIEND": "Recruiter's Impala",
    "UNIQUE_MOUNT_IMPALA_TELLAFRIEND_DESC": "Mount - her name is Belle",
    "UNIQUE_MOUNT_MOABIRD_TELLAFRIEND": "Recruiter's Moabird",
    "UNIQUE_MOUNT_MOABIRD_TELLAFRIEND_DESC": "Mount - his name is Spark",
    "UNIQUE_MOUNT_MORGANA_RAVEN_ADC": "Morgana Raven",
    "UNIQUE_MOUNT_MORGANA_RAVEN_ADC_DESC": "The disciples of Morgana seem to worship this fascinating animal and will likely consider riding it to be heresy.",
    "UNIQUE_MOUNT_OX_FOUNDER_LEGENDARY": "Legendary Explorer's Ox",
    "UNIQUE_MOUNT_OX_FOUNDER_LEGENDARY_DESC": "Mount",
    "UNIQUE_MOUNT_PIG_TELLAFRIEND": "Recruiter's Pig",
    "UNIQUE_MOUNT_PIG_TELLAFRIEND_DESC": "Mount - his name is Bobble",
    "UNIQUE_MOUNT_PONY_TELLAFRIEND": "Recruiter's Pony",
    "UNIQUE_MOUNT_PONY_TELLAFRIEND_DESC": "Mount - his name is Spike",
    "UNIQUE_MOUNT_RAM_TELLAFRIEND": "Recruiter's Ram",
    "UNIQUE_MOUNT_RAM_TELLAFRIEND_DESC": "Mount - his name is Raffle",
    "UNIQUE_MOUNT_RAM_XMAS": "Yule Ram",
    "UNIQUE_MOUNT_RAM_XMAS_DESC": "Mount - With this mount you can celebrate the Midwinter Festival",
    "UNIQUE_MOUNT_RHINO_SEASON_BRONZE": "Bronze Battle Rhino",
    "UNIQUE_MOUNT_RHINO_SEASON_BRONZE_DESC": "Guild Season Reward - Exclusive reward for Bronze Rank guild members in Season 4.",
    "UNIQUE_MOUNT_RHINO_SEASON_CRYSTAL": "Crystal Battle Rhino",
    "UNIQUE_MOUNT_RHINO_SEASON_CRYSTAL_DESC": "Guild Season Reward - Exclusive reward for Crystal Rank guild members in Season 4.",
    "UNIQUE_MOUNT_RHINO_SEASON_GOLD": "Gold Battle Rhino",
    "UNIQUE_MOUNT_RHINO_SEASON_GOLD_DESC": "Guild Season Reward - Exclusive reward for Gold Rank guild members in Season 4.",
    "UNIQUE_MOUNT_RHINO_SEASON_SILVER": "Silver Battle Rhino",
    "UNIQUE_MOUNT_RHINO_SEASON_SILVER_DESC": "Guild Season Reward - Exclusive reward for Silver Rank guild members in Season 4.",
    "UNIQUE_MOUNT_SAND_SALAMANDER_TELLAFRIEND": "Recruiter's Sand Salamander",
    "UNIQUE_MOUNT_SAND_SALAMANDER_TELLAFRIEND_DESC": "Referral Mount - A very rare salamander breed from Roan's Steppe. His name is Leon, and he is very patient and easy-going.",
    "UNIQUE_MOUNT_TELLAFRIEND": "Recruiter's Horse",
    "UNIQUE_MOUNT_TELLAFRIEND_DESC": "Equipment Item",
    "UNIQUE_MOUNT_TIGER_TELLAFRIEND": "Recruiter's Tiger",
    "UNIQUE_MOUNT_TIGER_TELLAFRIEND_DESC": "Referral Mount - His name is Khan. He likes long sunbathing sessions after eating a small mammal.",
    "UNIQUE_MOUNT_TIGER_WHITE_TELLAFRIEND": "Recruiter's White Tiger",
    "UNIQUE_MOUNT_TIGER_WHITE_TELLAFRIEND_DESC": "Referral Mount - A very fast and proud animal, her name is Aava. She becomes very attached and loyal to her owner, but can be a little hostile towards strangers.",
    "UNIQUE_MOUNT_TOWER_CHARIOT_CRYSTAL": "Crystal Tower Chariot",
    "UNIQUE_MOUNT_TOWER_CHARIOT_CRYSTAL_DESC": "Battle Mount. Tower mightily over your enemies!",
    "UNIQUE_MOUNT_TOWER_CHARIOT_GOLD": "Gold Tower Chariot",
    "UNIQUE_MOUNT_TOWER_CHARIOT_GOLD_DESC": "Battle Mount. Tower mightily over your enemies!",
    "UNIQUE_MOUNT_TOWER_CHARIOT_SILVER": "Silver Tower Chariot",
    "UNIQUE_MOUNT_TOWER_CHARIOT_SILVER_DESC": "Battle Mount. Tower mightily over your enemies!",
    "UNIQUE_MOUNT_TRANSPORT_RAM_TELLAFRIEND": "Recruiter's Bighorn Ram",
    "UNIQUE_MOUNT_TRANSPORT_RAM_TELLAFRIEND_DESC": "Referral Mount - His name is Murtaugh. Not the youngest anymore, but this heavyweight has won several prizes in heavy load pulling contests.",
    "UNIQUE_MOUNT_UNDEAD_DIREBOAR_ADC": "Spectral Direboar",
    "UNIQUE_MOUNT_UNDEAD_DIREBOAR_ADC_DESC": "Adventurer's Challenge Reward - Neither burden nor death can stop this beast, which walks in two worlds at once.",
    "UNIQUE_MOUNT_YAK_TELLAFRIEND": "Recruiter's Yak",
    "UNIQUE_MOUNT_YAK_TELLAFRIEND_DESC": "Mount - his name is Bovid",
    "UNIQUE_MOUNTUPGRADE_RAM_XMAS": "Decorative Ram Bridle",
    "UNIQUE_MOUNTUPGRADE_RAM_XMAS_DESC": "This bridle allows you to decorate a Ram for Yuletide.",
    "UNIQUE_OFF_VANITY_CHARITY_MARCH2020": "Staff of Hermes",
    "UNIQUE_OFF_VANITY_INNKEEPER": "Innkeeper's Beer Mug",
    "UNIQUE_OFF_VANITY_PIRATE": "Navigator's Parrot Cage",
    "UNIQUE_OFF_VANITY_PIRATE_DESC": "Equipment Item - Draws attention",
    "UNIQUE_OFF_VANITY_PRIEST": "Monk's Walking Staff",
    "UNIQUE_OFF_VANITY_WEDDING_DRESS": "Bridal Bouquet",
    "UNIQUE_OFF_VANITY_WEDDING_DRESS_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_OFF_VANITY_WEDDING_TUXEDO": "Wedding Ring",
    "UNIQUE_OFF_VANITY_WEDDING_TUXEDO_DESC": "Equipment Item - E-Marriage is not a sin.",
    "UNIQUE_REPAIRPOWDER_ADC_GENERAL_01": "Scroll of Repair",
    "UNIQUE_REPAIRPOWDER_ADC_GENERAL_01_DESC": "A magic-infused scroll which can be consumed to instantly repair all currently equipped gear.",
    "UNIQUE_SHOES_FOUNDER_ELITE": "Explorer's Boots",
    "UNIQUE_SHOES_FOUNDER_ELITE_DESC": "Equipment Item",
    "UNIQUE_SHOES_FOUNDER_LEGENDARY": "Legendary Explorer's Boots",
    "UNIQUE_SHOES_FOUNDER_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_SHOES_RUBBERBANDING": "Rubberband Boots",
    "UNIQUE_SHOES_RUBBERBANDING_DESC": "One step forward, two steps back...",
    "UNIQUE_SHOES_STARTERPACK_ELITE": "Adventurer's Shoes",
    "UNIQUE_SHOES_STARTERPACK_ELITE_DESC": "Equipment Item",
    "UNIQUE_SHOES_STARTERPACK_LEGENDARY": "Legendary Adventurer's Boots",
    "UNIQUE_SHOES_STARTERPACK_LEGENDARY_DESC": "Equipment Item",
    "UNIQUE_SHOES_VANITY_ARENA_SET_01": "Arena Veteran's Boots",
    "UNIQUE_SHOES_VANITY_ARENA_SET_01_DESC": "Vanity Item. You can buy this Arena-specific reward from the Arena Master with Arena Sigils.",
    "UNIQUE_SHOES_VANITY_BARD": "Bard's Shoes",
    "UNIQUE_SHOES_VANITY_DRESS_BLACK": "Noblewoman's Shoes",
    "UNIQUE_SHOES_VANITY_DRESS_BLUE": "Blue Princess Shoes",
    "UNIQUE_SHOES_VANITY_DRESS_RED": "Red Tulip Shoes",
    "UNIQUE_SHOES_VANITY_DRESS_RED_DESC": "Equipment item - Usually worn at festivities",
    "UNIQUE_SHOES_VANITY_EASTER": "Bunny Stalker Shoes",
    "UNIQUE_SHOES_VANITY_EASTER_DESC": "Equipment item - Clothing specialized for bunny hunting.",
    "UNIQUE_SHOES_VANITY_INNKEEPER": "Innkeeper's Shoes",
    "UNIQUE_SHOES_VANITY_JESTER": "Jester Shoes",
    "UNIQUE_SHOES_VANITY_JESTER_DESC": "Equipment Item - Not suited for fighting",
    "UNIQUE_SHOES_VANITY_KNIGHT": "Knight Adventurer's Boots",
    "UNIQUE_SHOES_VANITY_PIRATE": "Navigator's Boots",
    "UNIQUE_SHOES_VANITY_PIRATE_DESC": "Equipment Item",
    "UNIQUE_SHOES_VANITY_PLAGUEDOC": "Hygienic Boots",
    "UNIQUE_SHOES_VANITY_PLAGUEDOC_DESC": "Equipment Item",
    "UNIQUE_SHOES_VANITY_PRIEST": "Monk's Sandals",
    "UNIQUE_SHOES_VANITY_RICH_NOBLE": "Rich Noble's Footwear",
    "UNIQUE_SHOES_VANITY_RICH_NOBLE_DESC": "Equipment item - Usually worn at festivities",
    "UNIQUE_SHOES_VANITY_ROGUE": "Rogue Adventurer's Boots",
    "UNIQUE_SHOES_VANITY_SANTACLAUS": "Yule Shoes",
    "UNIQUE_SHOES_VANITY_SANTACLAUS_DESC": "Equipment item - Clothing to celebrate Midwinter",
    "UNIQUE_SHOES_VANITY_SKELETON": "Legbones",
    "UNIQUE_SHOES_VANITY_SKELETON_DESC": "Equipment Item",
    "UNIQUE_SHOES_VANITY_SKELETON_UNDEAD": "Undead Legs",
    "UNIQUE_SHOES_VANITY_WEDDING_DRESS": "Bridal Shoes",
    "UNIQUE_SHOES_VANITY_WEDDING_DRESS_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_SHOES_VANITY_WEDDING_TUXEDO": "Groom Shoes",
    "UNIQUE_SHOES_VANITY_WEDDING_TUXEDO_DESC": "Equipment Item - for a special ceremony",
    "UNIQUE_SILVERBAG_ADC_GENERAL_01": "Bag of Silver",
    "UNIQUE_SILVERBAG_ADC_GENERAL_01_DESC": "A non-tradable consumable item which will reward a large amount of Silver when opened.",
    "UNIQUE_SKILLBOOK_ADC_GENERAL_01": "Adventurer's Tome",
    "UNIQUE_SKILLBOOK_ADC_GENERAL_01_DESC": "A non-tradable tome of ancient wisdom. Instantly rewards a very big chunk of combat fame.\nMake sure to wear eligible gear when consuming this item.\n\nThis reward is not modified by any zone or Premium bonuses.",
    "UNIQUE_UNLOCK_ARMOR_FOUNDER_ELITE": "Wardrobe Skin: Explorer's Armor",
    "UNIQUE_UNLOCK_ARMOR_FOUNDER_ELITE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Explorer's Armor' on this account.",
    "UNIQUE_UNLOCK_ARMOR_FOUNDER_LEGENDARY": "Wardrobe Skin: Legendary Explorer's Armor",
    "UNIQUE_UNLOCK_ARMOR_FOUNDER_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Explorer's Armor' on this account.",
    "UNIQUE_UNLOCK_ARMOR_STARTERPACK_ELITE": "Wardrobe Skin: Adventurer's Jacket",
    "UNIQUE_UNLOCK_ARMOR_STARTERPACK_ELITE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Adventurer's Jacket' on this account.",
    "UNIQUE_UNLOCK_ARMOR_STARTERPACK_LEGENDARY": "Wardrobe Skin: Legendary Adventurer's Armor",
    "UNIQUE_UNLOCK_ARMOR_STARTERPACK_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Adventurer's Armor' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_ARENA_SET_01": "Wardrobe Skin: Arena Veteran's Cloak",
    "UNIQUE_UNLOCK_ARMOR_VANITY_ARENA_SET_01_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Cloak' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_DRESS_RED": "Wardrobe Skin: Red Tulip Dress",
    "UNIQUE_UNLOCK_ARMOR_VANITY_DRESS_RED_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Red Tulip Dress' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_EASTER": "Wardrobe Skin: Bunny Stalker Overalls",
    "UNIQUE_UNLOCK_ARMOR_VANITY_EASTER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bunny Stalker Overalls' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_JESTER": "Wardrobe Skin: Jester Costume",
    "UNIQUE_UNLOCK_ARMOR_VANITY_JESTER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Jester Costume' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_PLAGUEDOC": "Wardrobe Skin: Hygienic Coat",
    "UNIQUE_UNLOCK_ARMOR_VANITY_PLAGUEDOC_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Hygienic Coat' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_RICH_NOBLE": "Wardrobe Skin: Rich Noble's Doublet",
    "UNIQUE_UNLOCK_ARMOR_VANITY_RICH_NOBLE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Rich Noble's Doublet' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_SANTACLAUS": "Wardrobe Skin: Yule Coat",
    "UNIQUE_UNLOCK_ARMOR_VANITY_SANTACLAUS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Yule Coat' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_SKELETON": "Wardrobe Skin: Ribcage",
    "UNIQUE_UNLOCK_ARMOR_VANITY_SKELETON_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Ribcage' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_SKELETON_UNDEAD": "Wardrobe Skin: Undead Ribcage",
    "UNIQUE_UNLOCK_ARMOR_VANITY_SKELETON_UNDEAD_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Undead Ribcage' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_WEDDING_DRESS": "Wardrobe Skin: Bridal Dress",
    "UNIQUE_UNLOCK_ARMOR_VANITY_WEDDING_DRESS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bridal Dress' on this account.",
    "UNIQUE_UNLOCK_ARMOR_VANITY_WEDDING_TUXEDO": "Wardrobe Skin: Groom Suit",
    "UNIQUE_UNLOCK_ARMOR_VANITY_WEDDING_TUXEDO_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Groom Suit' on this account.",
    "UNIQUE_UNLOCK_BACKPACK_VANITY_EASTER": "Wardrobe Skin: Bunny Stalker Basket",
    "UNIQUE_UNLOCK_BACKPACK_VANITY_EASTER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bunny Stalker Basket' on this account.",
    "UNIQUE_UNLOCK_BACKPACK_VANITY_SANTACLAUS": "Wardrobe Skin: Yule Backpack",
    "UNIQUE_UNLOCK_BACKPACK_VANITY_SANTACLAUS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Yule Backpack' on this account.",
    "UNIQUE_UNLOCK_CAPE_BLOODHOUND_TELLAFRIEND": "Wardrobe Skin: Recruiter's Cape - Rottweiler",
    "UNIQUE_UNLOCK_CAPE_BLOODHOUND_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Cape - Rottweiler' on this account.",
    "UNIQUE_UNLOCK_CAPE_FOUNDER_LEGENDARY": "Wardrobe Skin: Legendary Explorer's Cloak",
    "UNIQUE_UNLOCK_CAPE_FOUNDER_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Explorer's Cloak' on this account.",
    "UNIQUE_UNLOCK_CAPE_RAM_TELLAFRIEND": "Wardrobe Skin: Recruiter's Fur Cape",
    "UNIQUE_UNLOCK_CAPE_RAM_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Fur Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_STARTERPACK_LEGENDARY": "Wardrobe Skin: Legendary Adventurer's Cloak",
    "UNIQUE_UNLOCK_CAPE_STARTERPACK_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Adventurer's Cloak' on this account.",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND": "Wardrobe Skin: Recruiter's Cape",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_02": "Wardrobe Skin: Riuros Cape",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_02_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Riuros Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_BANNER": "Wardrobe Skin: Recruiter's Banner",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_BANNER_02": "Wardrobe Skin: Ogronios Banner",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_BANNER_02_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Ogronios Banner' on this account.",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_BANNER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Banner' on this account.",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_BATRIDER": "Wardrobe Skin: Master of Bats Cape",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_BATRIDER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Master of Bats Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_TIGER_TELLAFRIEND": "Wardrobe Skin: Recruiter's Tiger Cape",
    "UNIQUE_UNLOCK_CAPE_TIGER_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Tiger Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_TOAD_TELLAFRIEND": "Wardrobe Skin: Recruiter's Cape - Toad",
    "UNIQUE_UNLOCK_CAPE_TOAD_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Cape - Toad' on this account.",
    "UNIQUE_UNLOCK_CAPE_VANITY_ARENA_SET_01": "Wardrobe Skin: Arena Veteran's Cape",
    "UNIQUE_UNLOCK_CAPE_VANITY_ARENA_SET_01_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_VANITY_SKELETON": "Wardrobe Skin: Ragged Cape",
    "UNIQUE_UNLOCK_CAPE_VANITY_SKELETON_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Ragged Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_VANITY_SKELETON_UNDEAD": "Wardrobe Skin: Ragged Undead Cape",
    "UNIQUE_UNLOCK_CAPE_VANITY_SKELETON_UNDEAD_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Ragged Undead Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_VANITY_WEDDING_TUXEDO": "Wardrobe Skin: Groom Cape",
    "UNIQUE_UNLOCK_CAPE_VANITY_WEDDING_TUXEDO_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Groom Cape' on this account.",
    "UNIQUE_UNLOCK_CAPE_WOLF_GREY_TELLAFRIEND": "Wardrobe Skin: Recruiter's Grey Wolf Cape",
    "UNIQUE_UNLOCK_CAPE_WOLF_GREY_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Grey Wolf Cape' on this account.",
    "UNIQUE_UNLOCK_HEAD_FOUNDER_ELITE": "Wardrobe Skin: Explorer's Hat",
    "UNIQUE_UNLOCK_HEAD_FOUNDER_ELITE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Explorer's Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_FOUNDER_LEGENDARY": "Wardrobe Skin: Legendary Explorer's Hat",
    "UNIQUE_UNLOCK_HEAD_FOUNDER_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Explorer's Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_STARTERPACK_ELITE": "Wardrobe Skin: Adventurer's Helmet",
    "UNIQUE_UNLOCK_HEAD_STARTERPACK_ELITE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Adventurer's Helmet' on this account.",
    "UNIQUE_UNLOCK_HEAD_STARTERPACK_LEGENDARY": "Wardrobe Skin: Legendary Adventurer's Hat",
    "UNIQUE_UNLOCK_HEAD_STARTERPACK_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Adventurer's Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_TELLAFRIEND_BATRIDER": "Wardrobe Skin: Master of Bats Helmet",
    "UNIQUE_UNLOCK_HEAD_TELLAFRIEND_BATRIDER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Master of Bats Helmet' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_ARENA_EYEPATCH": "Wardrobe Skin: Arena Veteran's Eyepatch",
    "UNIQUE_UNLOCK_HEAD_VANITY_ARENA_EYEPATCH_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Eyepatch' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_ARENA_SET_01": "Wardrobe Skin: Arena Veteran's Circlet",
    "UNIQUE_UNLOCK_HEAD_VANITY_ARENA_SET_01_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Circlet' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_DRESS_RED": "Wardrobe Skin: Red Tulip Hat",
    "UNIQUE_UNLOCK_HEAD_VANITY_DRESS_RED_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Red Tulip Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_EASTER_BROWN": "Wardrobe Skin: Bunny Stalker Hat",
    "UNIQUE_UNLOCK_HEAD_VANITY_EASTER_BROWN_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bunny Stalker Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_EASTER_WHITE": "Wardrobe Skin: Snow Bunny Stalker Hat",
    "UNIQUE_UNLOCK_HEAD_VANITY_EASTER_WHITE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Snow Bunny Stalker Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_JESTER": "Wardrobe Skin: Jester Mask",
    "UNIQUE_UNLOCK_HEAD_VANITY_JESTER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Jester Mask' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_PLAGUEDOC": "Wardrobe Skin: Hygienic Mask",
    "UNIQUE_UNLOCK_HEAD_VANITY_PLAGUEDOC_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Hygienic Mask' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_PUMPKIN_01": "Wardrobe Skin: Grinning Pumpkin Head",
    "UNIQUE_UNLOCK_HEAD_VANITY_PUMPKIN_01_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Grinning Pumpkin Head' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_PUMPKIN_02": "Wardrobe Skin: Sad Pumpkin Head",
    "UNIQUE_UNLOCK_HEAD_VANITY_PUMPKIN_02_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Sad Pumpkin Head' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_PUMPKIN_03": "Wardrobe Skin: Angry Pumpkin Head",
    "UNIQUE_UNLOCK_HEAD_VANITY_PUMPKIN_03_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Angry Pumpkin Head' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_RICH_NOBLE": "Wardrobe Skin: Rich Noble's Hat",
    "UNIQUE_UNLOCK_HEAD_VANITY_RICH_NOBLE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Rich Noble's Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_SANTACLAUS": "Wardrobe Skin: Yule Hat",
    "UNIQUE_UNLOCK_HEAD_VANITY_SANTACLAUS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Yule Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_SKELETON": "Wardrobe Skin: Laughing Skull",
    "UNIQUE_UNLOCK_HEAD_VANITY_SKELETON_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Laughing Skull' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_SKELETON_UNDEAD": "Wardrobe Skin: Undead Skull",
    "UNIQUE_UNLOCK_HEAD_VANITY_SKELETON_UNDEAD_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Undead Skull' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_WEDDING_DRESS": "Wardrobe Skin: Bridal Veil",
    "UNIQUE_UNLOCK_HEAD_VANITY_WEDDING_DRESS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bridal Veil' on this account.",
    "UNIQUE_UNLOCK_HEAD_VANITY_WEDDING_TUXEDO": "Wardrobe Skin: Groom Hat",
    "UNIQUE_UNLOCK_HEAD_VANITY_WEDDING_TUXEDO_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Groom Hat' on this account.",
    "UNIQUE_UNLOCK_HEAD_XMAS": "Wardrobe Skin: Uncle Frost's Hat",
    "UNIQUE_UNLOCK_HEAD_XMAS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Uncle Frost's Hat' on this account.",
    "UNIQUE_UNLOCK_OFF_VANITY_CHARITY_MARCH2020": "Wardrobe Skin: Staff of Hermes",
    "UNIQUE_UNLOCK_OFF_VANITY_CHARITY_MARCH2020_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Staff of Hermes' on this account.",
    "UNIQUE_UNLOCK_OFF_VANITY_WEDDING_DRESS": "Wardrobe Skin: Bridal Bouquet",
    "UNIQUE_UNLOCK_OFF_VANITY_WEDDING_DRESS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bridal Bouquet' on this account.",
    "UNIQUE_UNLOCK_OFF_VANITY_WEDDING_TUXEDO": "Wardrobe Skin: Wedding Ring",
    "UNIQUE_UNLOCK_OFF_VANITY_WEDDING_TUXEDO_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Wedding Ring' on this account.",
    "UNIQUE_UNLOCK_SHOES_FOUNDER_ELITE": "Wardrobe Skin: Explorer's Boots",
    "UNIQUE_UNLOCK_SHOES_FOUNDER_ELITE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Explorer's Boots' on this account.",
    "UNIQUE_UNLOCK_SHOES_FOUNDER_LEGENDARY": "Wardrobe Skin: Legendary Explorer's Boots",
    "UNIQUE_UNLOCK_SHOES_FOUNDER_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Explorer's Boots' on this account.",
    "UNIQUE_UNLOCK_SHOES_STARTERPACK_ELITE": "Wardrobe Skin: Adventurer's Shoes",
    "UNIQUE_UNLOCK_SHOES_STARTERPACK_ELITE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Adventurer's Shoes' on this account.",
    "UNIQUE_UNLOCK_SHOES_STARTERPACK_LEGENDARY": "Wardrobe Skin: Legendary Adventurer's Boots",
    "UNIQUE_UNLOCK_SHOES_STARTERPACK_LEGENDARY_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legendary Adventurer's Boots' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_ARENA_SET_01": "Wardrobe Skin: Arena Veteran's Boots",
    "UNIQUE_UNLOCK_SHOES_VANITY_ARENA_SET_01_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Boots' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_DRESS_RED": "Wardrobe Skin: Red Tulip Shoes",
    "UNIQUE_UNLOCK_SHOES_VANITY_DRESS_RED_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Red Tulip Shoes' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_EASTER": "Wardrobe Skin: Bunny Stalker Shoes",
    "UNIQUE_UNLOCK_SHOES_VANITY_EASTER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bunny Stalker Shoes' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_JESTER": "Wardrobe Skin: Jester Shoes",
    "UNIQUE_UNLOCK_SHOES_VANITY_JESTER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Jester Shoes' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_PLAGUEDOC": "Wardrobe Skin: Hygienic Boots",
    "UNIQUE_UNLOCK_SHOES_VANITY_PLAGUEDOC_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Hygienic Boots' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_RICH_NOBLE": "Wardrobe Skin: Rich Noble's Footwear",
    "UNIQUE_UNLOCK_SHOES_VANITY_RICH_NOBLE_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Rich Noble's Footwear' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_SANTACLAUS": "Wardrobe Skin: Yule Shoes",
    "UNIQUE_UNLOCK_SHOES_VANITY_SANTACLAUS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Yule Shoes' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_SKELETON": "Wardrobe Skin: Legbones",
    "UNIQUE_UNLOCK_SHOES_VANITY_SKELETON_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Legbones' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_SKELETON_UNDEAD": "Wardrobe Skin: Undead Legs",
    "UNIQUE_UNLOCK_SHOES_VANITY_SKELETON_UNDEAD_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Undead Legs' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_WEDDING_DRESS": "Wardrobe Skin: Bridal Shoes",
    "UNIQUE_UNLOCK_SHOES_VANITY_WEDDING_DRESS_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Bridal Shoes' on this account.",
    "UNIQUE_UNLOCK_SHOES_VANITY_WEDDING_TUXEDO": "Wardrobe Skin: Groom Shoes",
    "UNIQUE_UNLOCK_SHOES_VANITY_WEDDING_TUXEDO_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Groom Shoes' on this account.",
    "UNIQUE_UNLOCK_SKIN_ARMORED_HORSE_ARENA": "Armored Horse Skin: Arena Veteran",
    "UNIQUE_UNLOCK_SKIN_ARMORED_HORSE_ARENA_DESC": "Consuming this item permanently unlocks the Armored Horse Skin 'Arena Veteran' on this account.",
    "UNIQUE_UNLOCK_SKIN_ARMORED_HORSE_MORGANA": "Armored Horse Skin: Morgana Mare",
    "UNIQUE_UNLOCK_SKIN_ARMORED_HORSE_MORGANA_DESC": "Consuming this item permanently unlocks the Armored Horse Skin 'Morgana Mare' on this account.",
    "UNIQUE_UNLOCK_SKIN_ARMORED_HORSE_UNDEAD": "Armored Horse Skin: Armored Bonehorse",
    "UNIQUE_UNLOCK_SKIN_ARMORED_HORSE_UNDEAD_DESC": "Consuming this item permanently unlocks the Armored Horse Skin 'Armored Bonehorse' on this account.",
    "UNIQUE_UNLOCK_SKIN_COUGAR_ARENA": "Swiftclaw Skin: Arena Veteran's Armored Sabertooth",
    "UNIQUE_UNLOCK_SKIN_COUGAR_ARENA_DESC": "Consuming this item permanently unlocks the Swiftclaw Skin 'Arena Veteran's Armored Sabertooth' on this account.",
    "UNIQUE_UNLOCK_SKIN_COUGAR_ARMORED_GREY": "Swiftclaw Skin: Steelplate Cougar",
    "UNIQUE_UNLOCK_SKIN_COUGAR_ARMORED_GREY_DESC": "Consuming this item permanently unlocks the Swiftclaw Skin 'Steelplate Cougar' on this account.",
    "UNIQUE_UNLOCK_SKIN_COUGAR_OCCULT": "Swiftclaw Skin: Occult Cougar",
    "UNIQUE_UNLOCK_SKIN_COUGAR_OCCULT_DESC": "Consuming this item permanently unlocks the Swiftclaw Skin 'Occult Cougar' on this account.",
    "UNIQUE_UNLOCK_SKIN_COUGAR_TIGER_TELLAFRIEND": "Swiftclaw Skin: Recruiter's Tiger",
    "UNIQUE_UNLOCK_SKIN_COUGAR_TIGER_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Swiftclaw Skin 'Recruiter's Tiger' on this account.",
    "UNIQUE_UNLOCK_SKIN_COUGAR_TIGER_WHITE_TELLAFRIEND": "Swiftclaw Skin: Recruiter's White Tiger",
    "UNIQUE_UNLOCK_SKIN_COUGAR_TIGER_WHITE_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Swiftclaw Skin 'Recruiter's White Tiger' on this account.",
    "UNIQUE_UNLOCK_SKIN_COUGAR_TOURNAMENT": "Swiftclaw Skin: Sabertooth Rex",
    "UNIQUE_UNLOCK_SKIN_COUGAR_TOURNAMENT_DESC": "Consuming this item permanently unlocks the Swiftclaw Skin 'Sabertooth Rex' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREBEAR_PANDA_TELLAFRIEND": "Direbear Skin: Panda",
    "UNIQUE_UNLOCK_SKIN_DIREBEAR_PANDA_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direbear Skin 'Panda' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREBOAR_HOUSEPIG": "Direboar Skin: Domesticated Hog",
    "UNIQUE_UNLOCK_SKIN_DIREBOAR_HOUSEPIG_DESC": "Consuming this item permanently unlocks the Direboar Skin 'Domesticated Hog' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREBOAR_PIG_TELLAFRIEND": "Direboar Skin: Recruiter's Pig",
    "UNIQUE_UNLOCK_SKIN_DIREBOAR_PIG_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direboar Skin 'Recruiter's Pig' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREBOAR_WHITE_TELLAFRIEND": "Direboar Skin: White Direboar",
    "UNIQUE_UNLOCK_SKIN_DIREBOAR_WHITE_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direboar Skin 'White Direboar' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_BERNARD_TELLAFRIEND": "Direwolf Skin: Recruiter's Saint Bernard",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_BERNARD_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Recruiter's Saint Bernard' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_BLOODHOUND_TELLAFRIEND": "Direwolf Skin: Recruiter's Rottweiler",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_BLOODHOUND_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Recruiter's Rottweiler' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_BOBTAIL": "Direwolf Skin: Sheepdog",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_BOBTAIL_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Sheepdog' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_DIREFOX_TELLAFRIEND": "Direwolf Skin: Recruiter's Dire Fox",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_DIREFOX_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Recruiter's Dire Fox' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_GREY_TELLAFRIEND": "Direwolf Skin: Recruiter's Grey Wolf",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_GREY_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Recruiter's Grey Wolf' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_HUSKYSLEIGH_TELLAFRIEND": "Direwolf Skin: Recruiter's Husky Sled",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_HUSKYSLEIGH_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Recruiter's Husky Sled' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_HYENA_TELLAFRIEND": "Direwolf Skin: Ironjaw Hyena",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_HYENA_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Ironjaw Hyena' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_SPECTER": "Direwolf Skin: Specter Wolf",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_SPECTER_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Specter Wolf' on this account.",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_WHITE": "Direwolf Skin: Ghostwolf",
    "UNIQUE_UNLOCK_SKIN_DIREWOLF_WHITE_DESC": "Consuming this item permanently unlocks the Direwolf Skin 'Ghostwolf' on this account.",
    "UNIQUE_UNLOCK_SKIN_DONKEY_HALLOWEEN": "Mule Skin: Jack o' Donkey",
    "UNIQUE_UNLOCK_SKIN_DONKEY_HALLOWEEN_DESC": "Consuming this item permanently unlocks the Mule Skin 'Jack o' Donkey' on this account.",
    "UNIQUE_UNLOCK_SKIN_DONKEY_UNIQUE_TELLAFRIEND": "Mule Skin: Recruiter's Donkey",
    "UNIQUE_UNLOCK_SKIN_DONKEY_UNIQUE_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Mule Skin 'Recruiter's Donkey' on this account.",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_ALPACA": "Stag Skin: Alpaca",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_ALPACA_DESC": "Consuming this item permanently unlocks the Stag Skin 'Alpaca' on this account.",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_DIVINE": "Stag Skin: Divine Stag",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_DIVINE_DESC": "Consuming this item permanently unlocks the Stag Skin 'Divine Stag' on this account.",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_IMPALA_TELLAFRIEND": "Stag Skin: Recruiter's Impala",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_IMPALA_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Stag Skin 'Recruiter's Impala' on this account.",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_TELLAFRIEND": "Stag Skin: Recruiter's Giant Stag",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Stag Skin 'Recruiter's Giant Stag' on this account.",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_WHITE": "Stag Skin: Master's Giant Stag",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_WHITE_DESC": "Consuming this item permanently unlocks the Stag Skin 'Master's Giant Stag' on this account.",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_XMAS": "Stag Skin: Yule Stag",
    "UNIQUE_UNLOCK_SKIN_GIANTSTAG_XMAS_DESC": "Consuming this item permanently unlocks the Stag Skin 'Yule Stag' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_FOUNDER_LEGENDARY": "Riding Horse Skin: Legendary Explorer",
    "UNIQUE_UNLOCK_SKIN_HORSE_FOUNDER_LEGENDARY_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Legendary Explorer' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_GUILDBANNER": "Riding Horse Skin: Jousting Horse",
    "UNIQUE_UNLOCK_SKIN_HORSE_GUILDBANNER_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Jousting Horse' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_PONY_TELLAFRIEND": "Riding Horse Skin: Recruiter's Pony",
    "UNIQUE_UNLOCK_SKIN_HORSE_PONY_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Recruiter's Pony' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_STARTERPACK": "Riding Horse Skin: Legendary Adventurer",
    "UNIQUE_UNLOCK_SKIN_HORSE_STARTERPACK_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Legendary Adventurer' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_TELLAFRIEND": "Riding Horse Skin: Recruiter",
    "UNIQUE_UNLOCK_SKIN_HORSE_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Recruiter' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_UNDEAD": "Riding Horse Skin: Bonehorse",
    "UNIQUE_UNLOCK_SKIN_HORSE_UNDEAD_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Bonehorse' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_UNDEAD_HALLOWEEN": "Riding Horse Skin: Horse Macabre",
    "UNIQUE_UNLOCK_SKIN_HORSE_UNDEAD_HALLOWEEN_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Horse Macabre' on this account.",
    "UNIQUE_UNLOCK_SKIN_HORSE_UNICORN_WHITE_TELLAFRIEND": "Riding Horse Skin: Unicorn",
    "UNIQUE_UNLOCK_SKIN_HORSE_UNICORN_WHITE_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Riding Horse Skin 'Unicorn' on this account.",
    "UNIQUE_UNLOCK_SKIN_LIZARD_SAND_SALAMANDER_TELLAFRIEND": "Swamp Dragon Skin: Recruiter's Sand Salamander",
    "UNIQUE_UNLOCK_SKIN_LIZARD_SAND_SALAMANDER_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Swamp Dragon Skin 'Recruiter's Sand Salamander' on this account.",
    "UNIQUE_UNLOCK_SKIN_OX_CART_HERETIC": "Transport Ox Skin: Heretic Cart",
    "UNIQUE_UNLOCK_SKIN_OX_CART_HERETIC_DESC": "Consuming this item permanently unlocks the Transport Ox Skin 'Heretic Cart' on this account.",
    "UNIQUE_UNLOCK_SKIN_OX_CART_STARTERPACK": "Transport Ox Skin: Legendary Adventurer's Cart",
    "UNIQUE_UNLOCK_SKIN_OX_CART_STARTERPACK_DESC": "Consuming this item permanently unlocks the Transport Ox Skin 'Legendary Adventurer's Cart' on this account.",
    "UNIQUE_UNLOCK_SKIN_OX_FOUNDER_LEGENDARY": "Transport Ox Skin: Legendary Explorer",
    "UNIQUE_UNLOCK_SKIN_OX_FOUNDER_LEGENDARY_DESC": "Consuming this item permanently unlocks the Transport Ox Skin 'Legendary Explorer' on this account.",
    "UNIQUE_UNLOCK_SKIN_OX_TRANSPORT_RAM_TELLAFRIEND": "Transport Ox Skin: Recruiter's Bighorn Ram",
    "UNIQUE_UNLOCK_SKIN_OX_TRANSPORT_RAM_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Transport Ox Skin 'Recruiter's Bighorn Ram' on this account.",
    "UNIQUE_UNLOCK_SKIN_OX_YAK_TELLAFRIEND": "Transport Ox Skin: Recruiter's Yak",
    "UNIQUE_UNLOCK_SKIN_OX_YAK_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Transport Ox Skin 'Recruiter's Yak' on this account.",
    "UNIQUE_UNLOCK_T4_CAPE_ARENA_BANNER": "Wardrobe Skin: Arena Veteran's Small Banner",
    "UNIQUE_UNLOCK_T4_CAPE_ARENA_BANNER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Small Banner' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_ARENA_BANNER": "Wardrobe Skin: Arena Veteran's Medium Banner",
    "UNIQUE_UNLOCK_T6_CAPE_ARENA_BANNER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Medium Banner' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_CLOTH_KEEPER": "Wardrobe Skin: Decorative Keeper Cloth Cape",
    "UNIQUE_UNLOCK_T6_CAPE_CLOTH_KEEPER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Keeper Cloth Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_CLOTH_MORGANA": "Wardrobe Skin: Decorative Morgana Cloth Cape",
    "UNIQUE_UNLOCK_T6_CAPE_CLOTH_MORGANA_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Morgana Cloth Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_CLOTH_UNDEAD": "Wardrobe Skin: Decorative Undead Cloth Cape",
    "UNIQUE_UNLOCK_T6_CAPE_CLOTH_UNDEAD_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Undead Cloth Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_LEATHER_KEEPER": "Wardrobe Skin: Decorative Keeper Leather Cape",
    "UNIQUE_UNLOCK_T6_CAPE_LEATHER_KEEPER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Keeper Leather Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_LEATHER_MORGANA": "Wardrobe Skin: Decorative Morgana Leather Cape",
    "UNIQUE_UNLOCK_T6_CAPE_LEATHER_MORGANA_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Morgana Leather Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_LEATHER_UNDEAD": "Wardrobe Skin: Decorative Undead Leather Cape",
    "UNIQUE_UNLOCK_T6_CAPE_LEATHER_UNDEAD_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Undead Leather Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_PLATE_KEEPER": "Wardrobe Skin: Decorative Keeper Platemail Cape",
    "UNIQUE_UNLOCK_T6_CAPE_PLATE_KEEPER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Keeper Platemail Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_PLATE_MORGANA": "Wardrobe Skin: Decorative Morgana Platemail Cape",
    "UNIQUE_UNLOCK_T6_CAPE_PLATE_MORGANA_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Morgana Platemail Cape' on this account.",
    "UNIQUE_UNLOCK_T6_CAPE_PLATE_UNDEAD": "Wardrobe Skin: Decorative Undead Platemail Cape",
    "UNIQUE_UNLOCK_T6_CAPE_PLATE_UNDEAD_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Decorative Undead Platemail Cape' on this account.",
    "UNIQUE_UNLOCK_T8_CAPE_ARENA_BANNER": "Wardrobe Skin: Arena Veteran's Large Banner",
    "UNIQUE_UNLOCK_T8_CAPE_ARENA_BANNER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Arena Veteran's Large Banner' on this account.",
    "UNIQUE_UNLOCK_UNIQUE_VANITY_2H_CHICKENGUN_EASTER": "Wardrobe Skin: The Eggsecutioner",
    "UNIQUE_UNLOCK_UNIQUE_VANITY_2H_CHICKENGUN_EASTER_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'The Eggsecutioner' on this account.",
    "UNIQUE_UNLOCK_VANITY_2H_PORTALGUN_TELLAFRIEND": "Wardrobe Skin: Recruiter's Portal Cannon",
    "UNIQUE_UNLOCK_VANITY_2H_PORTALGUN_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Portal Cannon' on this account.",
    "UNIQUE_UNLOCK_VANITY_MAIN_BEERMUG_02_TELLAFRIEND": "Wardrobe Skin: Recruiter's Ale Mug",
    "UNIQUE_UNLOCK_VANITY_MAIN_BEERMUG_02_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Ale Mug' on this account.",
    "UNIQUE_UNLOCK_VANITY_MAIN_BEERMUG_TELLAFRIEND": "Wardrobe Skin: Recruiter's Beer Mug",
    "UNIQUE_UNLOCK_VANITY_MAIN_BEERMUG_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Beer Mug' on this account.",
    "UNIQUE_UNLOCK_VANITY_MAIN_FOXCROP_TELLAFRIEND": "Wardrobe Skin: Recruiter's Fox Crop",
    "UNIQUE_UNLOCK_VANITY_MAIN_FOXCROP_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Fox Crop' on this account.",
    "UNIQUE_UNLOCK_VANITY_MAIN_HORN_TELLAFRIEND": "Wardrobe Skin: Recruiter's Hunter Horn",
    "UNIQUE_UNLOCK_VANITY_MAIN_HORN_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Hunter Horn' on this account.",
    "UNIQUE_UNLOCK_VANITY_MAIN_TRUMPET_TELLAFRIEND": "Wardrobe Skin: Recruiter's Trumpet",
    "UNIQUE_UNLOCK_VANITY_MAIN_TRUMPET_TELLAFRIEND_DESC": "Consuming this item permanently unlocks the Wardrobe Skin 'Recruiter's Trumpet' on this account.",
    "UNIQUE_VANITY_2H_BANNER_KNIGHT_GUILD_COLORED": "Knight Adventurer's Warbanner",
    "UNIQUE_VANITY_2H_CHICKENGUN_EASTER": "The Eggsecutioner",
    "UNIQUE_VANITY_2H_CHICKENGUN_EASTER_DESC": "This most Heretic of inventions comes with an unlimited supply of eggs!",
    "UNIQUE_VANITY_2H_PORTALGUN_TELLAFRIEND": "Recruiter's Portal Cannon",
    "UNIQUE_VANITY_2H_PORTALGUN_TELLAFRIEND_DESC": "Equipment Item - Recruitment Reward",
    "UNIQUE_VANITY_MAIN_BEERMUG_02_TELLAFRIEND": "Recruiter's Ale Mug",
    "UNIQUE_VANITY_MAIN_BEERMUG_02_TELLAFRIEND_DESC": "Equipment Item - Referral Reward, can't be used for fighting",
    "UNIQUE_VANITY_MAIN_BEERMUG_TELLAFRIEND": "Recruiter's Beer Mug",
    "UNIQUE_VANITY_MAIN_BEERMUG_TELLAFRIEND_DESC": "Equipment Item - Referral Reward, can't be used for fighting",
    "UNIQUE_VANITY_MAIN_FOXCROP_TELLAFRIEND": "Recruiter's Fox Crop",
    "UNIQUE_VANITY_MAIN_FOXCROP_TELLAFRIEND_DESC": "Equipment Item - Referral Reward, can be used to summon a fox",
    "UNIQUE_VANITY_MAIN_HORN_TELLAFRIEND": "Recruiter's Hunter Horn",
    "UNIQUE_VANITY_MAIN_HORN_TELLAFRIEND_DESC": "Equipment Item - Referral Reward, can't be used for fighting",
    "UNIQUE_VANITY_MAIN_POISONBOTTLE_ROGUE": "Rogue Adventurer's Poison Bottle",
    "UNIQUE_VANITY_MAIN_TRUMPET_TELLAFRIEND": "Recruiter's Trumpet",
    "UNIQUE_VANITY_MAIN_TRUMPET_TELLAFRIEND_DESC": "Equipment Item - Referral Reward, can't be used for fighting"
}
