mapping =\
{
    "T2_POTION_HEAL": "potion",
    "T4_POTION_HEAL": "potion",
    "T4_POTION_HEAL@1": "potion",
    "T6_POTION_HEAL": "potion",
    "T6_POTION_HEAL@1": "potion",
    "T2_POTION_ENERGY": "potion",
    "T4_POTION_ENERGY": "potion",
    "T4_POTION_ENERGY@1": "potion",
    "T6_POTION_ENERGY": "potion",
    "T6_POTION_ENERGY@1": "potion",
    "T3_POTION_REVIVE": "potion",
    "T5_POTION_REVIVE": "potion",
    "T5_POTION_REVIVE@1": "potion",
    "T7_POTION_REVIVE": "potion",
    "T7_POTION_REVIVE@1": "potion",
    "T3_POTION_STONESKIN": "potion",
    "T5_POTION_STONESKIN": "potion",
    "T5_POTION_STONESKIN@1": "potion",
    "T7_POTION_STONESKIN": "potion",
    "T7_POTION_STONESKIN@1": "potion",
    "T3_POTION_SLOWFIELD": "potion",
    "T5_POTION_SLOWFIELD": "potion",
    "T5_POTION_SLOWFIELD@1": "potion",
    "T7_POTION_SLOWFIELD": "potion",
    "T7_POTION_SLOWFIELD@1": "potion",
    "T4_POTION_COOLDOWN": "potion",
    "T4_POTION_COOLDOWN@1": "potion",
    "T6_POTION_COOLDOWN": "potion",
    "T6_POTION_COOLDOWN@1": "potion",
    "T8_POTION_COOLDOWN": "potion",
    "T8_POTION_COOLDOWN@1": "potion",
    "T8_POTION_CLEANSE": "potion",
    "T8_POTION_CLEANSE@1": "potion",
    "T1_MEAL_GRILLEDFISH": "food",
    "T1_MEAL_SEAWEEDSALAD": "food",
    "T1_MEAL_SOUP": "food",
    "T1_MEAL_SOUP@1": "food",
    "T1_MEAL_SOUP@2": "food",
    "T1_MEAL_SOUP@3": "food",
    "T3_MEAL_SOUP": "food",
    "T3_MEAL_SOUP@1": "food",
    "T3_MEAL_SOUP@2": "food",
    "T3_MEAL_SOUP@3": "food",
    "T5_MEAL_SOUP": "food",
    "T5_MEAL_SOUP@1": "food",
    "T5_MEAL_SOUP@2": "food",
    "T5_MEAL_SOUP@3": "food",
    "T1_MEAL_SOUP_FISH": "food",
    "T1_MEAL_SOUP_FISH@1": "food",
    "T1_MEAL_SOUP_FISH@2": "food",
    "T1_MEAL_SOUP_FISH@3": "food",
    "T3_MEAL_SOUP_FISH": "food",
    "T3_MEAL_SOUP_FISH@1": "food",
    "T3_MEAL_SOUP_FISH@2": "food",
    "T3_MEAL_SOUP_FISH@3": "food",
    "T5_MEAL_SOUP_FISH": "food",
    "T5_MEAL_SOUP_FISH@1": "food",
    "T5_MEAL_SOUP_FISH@2": "food",
    "T5_MEAL_SOUP_FISH@3": "food",
    "T2_MEAL_SALAD": "food",
    "T2_MEAL_SALAD@1": "food",
    "T2_MEAL_SALAD@2": "food",
    "T2_MEAL_SALAD@3": "food",
    "T4_MEAL_SALAD": "food",
    "T4_MEAL_SALAD@1": "food",
    "T4_MEAL_SALAD@2": "food",
    "T4_MEAL_SALAD@3": "food",
    "T6_MEAL_SALAD": "food",
    "T6_MEAL_SALAD@1": "food",
    "T6_MEAL_SALAD@2": "food",
    "T6_MEAL_SALAD@3": "food",
    "T2_MEAL_SALAD_FISH": "food",
    "T2_MEAL_SALAD_FISH@1": "food",
    "T2_MEAL_SALAD_FISH@2": "food",
    "T2_MEAL_SALAD_FISH@3": "food",
    "T4_MEAL_SALAD_FISH": "food",
    "T4_MEAL_SALAD_FISH@1": "food",
    "T4_MEAL_SALAD_FISH@2": "food",
    "T4_MEAL_SALAD_FISH@3": "food",
    "T6_MEAL_SALAD_FISH": "food",
    "T6_MEAL_SALAD_FISH@1": "food",
    "T6_MEAL_SALAD_FISH@2": "food",
    "T6_MEAL_SALAD_FISH@3": "food",
    "T3_MEAL_PIE": "food",
    "T3_MEAL_PIE@1": "food",
    "T3_MEAL_PIE@2": "food",
    "T3_MEAL_PIE@3": "food",
    "T5_MEAL_PIE": "food",
    "T5_MEAL_PIE@1": "food",
    "T5_MEAL_PIE@2": "food",
    "T5_MEAL_PIE@3": "food",
    "T7_MEAL_PIE": "food",
    "T7_MEAL_PIE@1": "food",
    "T7_MEAL_PIE@2": "food",
    "T7_MEAL_PIE@3": "food",
    "T3_MEAL_PIE_FISH": "food",
    "T3_MEAL_PIE_FISH@1": "food",
    "T3_MEAL_PIE_FISH@2": "food",
    "T3_MEAL_PIE_FISH@3": "food",
    "T5_MEAL_PIE_FISH": "food",
    "T5_MEAL_PIE_FISH@1": "food",
    "T5_MEAL_PIE_FISH@2": "food",
    "T5_MEAL_PIE_FISH@3": "food",
    "T7_MEAL_PIE_FISH": "food",
    "T7_MEAL_PIE_FISH@1": "food",
    "T7_MEAL_PIE_FISH@2": "food",
    "T7_MEAL_PIE_FISH@3": "food",
    "T3_MEAL_OMELETTE": "food",
    "T3_MEAL_OMELETTE@1": "food",
    "T3_MEAL_OMELETTE@2": "food",
    "T3_MEAL_OMELETTE@3": "food",
    "T5_MEAL_OMELETTE": "food",
    "T5_MEAL_OMELETTE@1": "food",
    "T5_MEAL_OMELETTE@2": "food",
    "T5_MEAL_OMELETTE@3": "food",
    "T7_MEAL_OMELETTE": "food",
    "T7_MEAL_OMELETTE@1": "food",
    "T7_MEAL_OMELETTE@2": "food",
    "T7_MEAL_OMELETTE@3": "food",
    "T3_MEAL_OMELETTE_FISH": "food",
    "T3_MEAL_OMELETTE_FISH@1": "food",
    "T3_MEAL_OMELETTE_FISH@2": "food",
    "T3_MEAL_OMELETTE_FISH@3": "food",
    "T5_MEAL_OMELETTE_FISH": "food",
    "T5_MEAL_OMELETTE_FISH@1": "food",
    "T5_MEAL_OMELETTE_FISH@2": "food",
    "T5_MEAL_OMELETTE_FISH@3": "food",
    "T7_MEAL_OMELETTE_FISH": "food",
    "T7_MEAL_OMELETTE_FISH@1": "food",
    "T7_MEAL_OMELETTE_FISH@2": "food",
    "T7_MEAL_OMELETTE_FISH@3": "food",
    "T3_MEAL_OMELETTE_AVALON": "food",
    "T3_MEAL_OMELETTE_AVALON@1": "food",
    "T3_MEAL_OMELETTE_AVALON@2": "food",
    "T3_MEAL_OMELETTE_AVALON@3": "food",
    "T5_MEAL_OMELETTE_AVALON": "food",
    "T5_MEAL_OMELETTE_AVALON@1": "food",
    "T5_MEAL_OMELETTE_AVALON@2": "food",
    "T5_MEAL_OMELETTE_AVALON@3": "food",
    "T7_MEAL_OMELETTE_AVALON": "food",
    "T7_MEAL_OMELETTE_AVALON@1": "food",
    "T7_MEAL_OMELETTE_AVALON@2": "food",
    "T7_MEAL_OMELETTE_AVALON@3": "food",
    "T4_MEAL_STEW": "food",
    "T4_MEAL_STEW@1": "food",
    "T4_MEAL_STEW@2": "food",
    "T4_MEAL_STEW@3": "food",
    "T6_MEAL_STEW": "food",
    "T6_MEAL_STEW@1": "food",
    "T6_MEAL_STEW@2": "food",
    "T6_MEAL_STEW@3": "food",
    "T8_MEAL_STEW": "food",
    "T8_MEAL_STEW@1": "food",
    "T8_MEAL_STEW@2": "food",
    "T8_MEAL_STEW@3": "food",
    "T4_MEAL_STEW_FISH": "food",
    "T4_MEAL_STEW_FISH@1": "food",
    "T4_MEAL_STEW_FISH@2": "food",
    "T4_MEAL_STEW_FISH@3": "food",
    "T6_MEAL_STEW_FISH": "food",
    "T6_MEAL_STEW_FISH@1": "food",
    "T6_MEAL_STEW_FISH@2": "food",
    "T6_MEAL_STEW_FISH@3": "food",
    "T8_MEAL_STEW_FISH": "food",
    "T8_MEAL_STEW_FISH@1": "food",
    "T8_MEAL_STEW_FISH@2": "food",
    "T8_MEAL_STEW_FISH@3": "food",
    "T4_MEAL_STEW_AVALON": "food",
    "T4_MEAL_STEW_AVALON@1": "food",
    "T4_MEAL_STEW_AVALON@2": "food",
    "T4_MEAL_STEW_AVALON@3": "food",
    "T6_MEAL_STEW_AVALON": "food",
    "T6_MEAL_STEW_AVALON@1": "food",
    "T6_MEAL_STEW_AVALON@2": "food",
    "T6_MEAL_STEW_AVALON@3": "food",
    "T8_MEAL_STEW_AVALON": "food",
    "T8_MEAL_STEW_AVALON@1": "food",
    "T8_MEAL_STEW_AVALON@2": "food",
    "T8_MEAL_STEW_AVALON@3": "food",
    "T4_MEAL_SANDWICH": "food",
    "T4_MEAL_SANDWICH@1": "food",
    "T4_MEAL_SANDWICH@2": "food",
    "T4_MEAL_SANDWICH@3": "food",
    "T6_MEAL_SANDWICH": "food",
    "T6_MEAL_SANDWICH@1": "food",
    "T6_MEAL_SANDWICH@2": "food",
    "T6_MEAL_SANDWICH@3": "food",
    "T8_MEAL_SANDWICH": "food",
    "T8_MEAL_SANDWICH@1": "food",
    "T8_MEAL_SANDWICH@2": "food",
    "T8_MEAL_SANDWICH@3": "food",
    "T4_MEAL_SANDWICH_FISH": "food",
    "T4_MEAL_SANDWICH_FISH@1": "food",
    "T4_MEAL_SANDWICH_FISH@2": "food",
    "T4_MEAL_SANDWICH_FISH@3": "food",
    "T6_MEAL_SANDWICH_FISH": "food",
    "T6_MEAL_SANDWICH_FISH@1": "food",
    "T6_MEAL_SANDWICH_FISH@2": "food",
    "T6_MEAL_SANDWICH_FISH@3": "food",
    "T8_MEAL_SANDWICH_FISH": "food",
    "T8_MEAL_SANDWICH_FISH@1": "food",
    "T8_MEAL_SANDWICH_FISH@2": "food",
    "T8_MEAL_SANDWICH_FISH@3": "food",
    "T4_MEAL_SANDWICH_AVALON": "food",
    "T4_MEAL_SANDWICH_AVALON@1": "food",
    "T4_MEAL_SANDWICH_AVALON@2": "food",
    "T4_MEAL_SANDWICH_AVALON@3": "food",
    "T6_MEAL_SANDWICH_AVALON": "food",
    "T6_MEAL_SANDWICH_AVALON@1": "food",
    "T6_MEAL_SANDWICH_AVALON@2": "food",
    "T6_MEAL_SANDWICH_AVALON@3": "food",
    "T8_MEAL_SANDWICH_AVALON": "food",
    "T8_MEAL_SANDWICH_AVALON@1": "food",
    "T8_MEAL_SANDWICH_AVALON@2": "food",
    "T8_MEAL_SANDWICH_AVALON@3": "food",
    "T3_MEAL_ROAST": "food",
    "T3_MEAL_ROAST@1": "food",
    "T3_MEAL_ROAST@2": "food",
    "T3_MEAL_ROAST@3": "food",
    "T5_MEAL_ROAST": "food",
    "T5_MEAL_ROAST@1": "food",
    "T5_MEAL_ROAST@2": "food",
    "T5_MEAL_ROAST@3": "food",
    "T7_MEAL_ROAST": "food",
    "T7_MEAL_ROAST@1": "food",
    "T7_MEAL_ROAST@2": "food",
    "T7_MEAL_ROAST@3": "food",
    "T3_MEAL_ROAST_FISH": "food",
    "T3_MEAL_ROAST_FISH@1": "food",
    "T3_MEAL_ROAST_FISH@2": "food",
    "T3_MEAL_ROAST_FISH@3": "food",
    "T5_MEAL_ROAST_FISH": "food",
    "T5_MEAL_ROAST_FISH@1": "food",
    "T5_MEAL_ROAST_FISH@2": "food",
    "T5_MEAL_ROAST_FISH@3": "food",
    "T7_MEAL_ROAST_FISH": "food",
    "T7_MEAL_ROAST_FISH@1": "food",
    "T7_MEAL_ROAST_FISH@2": "food",
    "T7_MEAL_ROAST_FISH@3": "food",
    "T4_BUTTER": "food",
    "T6_BUTTER": "food",
    "T8_BUTTER": "food",
    "T6_ALCOHOL": "food",
    "T7_ALCOHOL": "food",
    "T8_ALCOHOL": "food",
    "T4_BREAD": "food",
    "T3_FLOUR": "food",
    "T2_PLANKS": "wood",
    "T3_PLANKS": "wood",
    "T4_PLANKS": "wood",
    "T5_PLANKS": "wood",
    "T6_PLANKS": "wood",
    "T7_PLANKS": "wood",
    "T8_PLANKS": "wood",
    "T4_PLANKS_LEVEL1": "wood",
    "T5_PLANKS_LEVEL1": "wood",
    "T6_PLANKS_LEVEL1": "wood",
    "T7_PLANKS_LEVEL1": "wood",
    "T8_PLANKS_LEVEL1": "wood",
    "T4_PLANKS_LEVEL2": "wood",
    "T5_PLANKS_LEVEL2": "wood",
    "T6_PLANKS_LEVEL2": "wood",
    "T7_PLANKS_LEVEL2": "wood",
    "T8_PLANKS_LEVEL2": "wood",
    "T4_PLANKS_LEVEL3": "wood",
    "T5_PLANKS_LEVEL3": "wood",
    "T6_PLANKS_LEVEL3": "wood",
    "T7_PLANKS_LEVEL3": "wood",
    "T8_PLANKS_LEVEL3": "wood",
    "T2_STONEBLOCK": "rock",
    "T3_STONEBLOCK": "rock",
    "T4_STONEBLOCK": "rock",
    "T5_STONEBLOCK": "rock",
    "T6_STONEBLOCK": "rock",
    "T7_STONEBLOCK": "rock",
    "T8_STONEBLOCK": "rock",
    "T2_METALBAR": "ore",
    "T3_METALBAR": "ore",
    "T4_METALBAR": "ore",
    "T5_METALBAR": "ore",
    "T6_METALBAR": "ore",
    "T7_METALBAR": "ore",
    "T8_METALBAR": "ore",
    "T4_METALBAR_LEVEL1": "ore",
    "T5_METALBAR_LEVEL1": "ore",
    "T6_METALBAR_LEVEL1": "ore",
    "T7_METALBAR_LEVEL1": "ore",
    "T8_METALBAR_LEVEL1": "ore",
    "T4_METALBAR_LEVEL2": "ore",
    "T5_METALBAR_LEVEL2": "ore",
    "T6_METALBAR_LEVEL2": "ore",
    "T7_METALBAR_LEVEL2": "ore",
    "T8_METALBAR_LEVEL2": "ore",
    "T4_METALBAR_LEVEL3": "ore",
    "T5_METALBAR_LEVEL3": "ore",
    "T6_METALBAR_LEVEL3": "ore",
    "T7_METALBAR_LEVEL3": "ore",
    "T8_METALBAR_LEVEL3": "ore",
    "T2_LEATHER": "hide",
    "T3_LEATHER": "hide",
    "T4_LEATHER": "hide",
    "T5_LEATHER": "hide",
    "T6_LEATHER": "hide",
    "T7_LEATHER": "hide",
    "T8_LEATHER": "hide",
    "T4_LEATHER_LEVEL1": "hide",
    "T5_LEATHER_LEVEL1": "hide",
    "T6_LEATHER_LEVEL1": "hide",
    "T7_LEATHER_LEVEL1": "hide",
    "T8_LEATHER_LEVEL1": "hide",
    "T4_LEATHER_LEVEL2": "hide",
    "T5_LEATHER_LEVEL2": "hide",
    "T6_LEATHER_LEVEL2": "hide",
    "T7_LEATHER_LEVEL2": "hide",
    "T8_LEATHER_LEVEL2": "hide",
    "T4_LEATHER_LEVEL3": "hide",
    "T5_LEATHER_LEVEL3": "hide",
    "T6_LEATHER_LEVEL3": "hide",
    "T7_LEATHER_LEVEL3": "hide",
    "T8_LEATHER_LEVEL3": "hide",
    "T2_CLOTH": "fiber",
    "T3_CLOTH": "fiber",
    "T4_CLOTH": "fiber",
    "T5_CLOTH": "fiber",
    "T6_CLOTH": "fiber",
    "T7_CLOTH": "fiber",
    "T8_CLOTH": "fiber",
    "T4_CLOTH_LEVEL1": "fiber",
    "T5_CLOTH_LEVEL1": "fiber",
    "T6_CLOTH_LEVEL1": "fiber",
    "T7_CLOTH_LEVEL1": "fiber",
    "T8_CLOTH_LEVEL1": "fiber",
    "T4_CLOTH_LEVEL2": "fiber",
    "T5_CLOTH_LEVEL2": "fiber",
    "T6_CLOTH_LEVEL2": "fiber",
    "T7_CLOTH_LEVEL2": "fiber",
    "T8_CLOTH_LEVEL2": "fiber",
    "T4_CLOTH_LEVEL3": "fiber",
    "T5_CLOTH_LEVEL3": "fiber",
    "T6_CLOTH_LEVEL3": "fiber",
    "T7_CLOTH_LEVEL3": "fiber",
    "T8_CLOTH_LEVEL3": "fiber",
    "T2_OFF_SHIELD": "offhand",
    "T3_OFF_SHIELD": "offhand",
    "T4_OFF_SHIELD": "offhand",
    "T4_OFF_SHIELD@1": "offhand",
    "T4_OFF_SHIELD@2": "offhand",
    "T4_OFF_SHIELD@3": "offhand",
    "T5_OFF_SHIELD": "offhand",
    "T5_OFF_SHIELD@1": "offhand",
    "T5_OFF_SHIELD@2": "offhand",
    "T5_OFF_SHIELD@3": "offhand",
    "T6_OFF_SHIELD": "offhand",
    "T6_OFF_SHIELD@1": "offhand",
    "T6_OFF_SHIELD@2": "offhand",
    "T6_OFF_SHIELD@3": "offhand",
    "T7_OFF_SHIELD": "offhand",
    "T7_OFF_SHIELD@1": "offhand",
    "T7_OFF_SHIELD@2": "offhand",
    "T7_OFF_SHIELD@3": "offhand",
    "T8_OFF_SHIELD": "offhand",
    "T8_OFF_SHIELD@1": "offhand",
    "T8_OFF_SHIELD@2": "offhand",
    "T8_OFF_SHIELD@3": "offhand",
    "T4_OFF_TOWERSHIELD_UNDEAD": "offhand",
    "T4_OFF_TOWERSHIELD_UNDEAD@1": "offhand",
    "T4_OFF_TOWERSHIELD_UNDEAD@2": "offhand",
    "T4_OFF_TOWERSHIELD_UNDEAD@3": "offhand",
    "T5_OFF_TOWERSHIELD_UNDEAD": "offhand",
    "T5_OFF_TOWERSHIELD_UNDEAD@1": "offhand",
    "T5_OFF_TOWERSHIELD_UNDEAD@2": "offhand",
    "T5_OFF_TOWERSHIELD_UNDEAD@3": "offhand",
    "T6_OFF_TOWERSHIELD_UNDEAD": "offhand",
    "T6_OFF_TOWERSHIELD_UNDEAD@1": "offhand",
    "T6_OFF_TOWERSHIELD_UNDEAD@2": "offhand",
    "T6_OFF_TOWERSHIELD_UNDEAD@3": "offhand",
    "T7_OFF_TOWERSHIELD_UNDEAD": "offhand",
    "T7_OFF_TOWERSHIELD_UNDEAD@1": "offhand",
    "T7_OFF_TOWERSHIELD_UNDEAD@2": "offhand",
    "T7_OFF_TOWERSHIELD_UNDEAD@3": "offhand",
    "T8_OFF_TOWERSHIELD_UNDEAD": "offhand",
    "T8_OFF_TOWERSHIELD_UNDEAD@1": "offhand",
    "T8_OFF_TOWERSHIELD_UNDEAD@2": "offhand",
    "T8_OFF_TOWERSHIELD_UNDEAD@3": "offhand",
    "T4_OFF_SHIELD_HELL": "offhand",
    "T4_OFF_SHIELD_HELL@1": "offhand",
    "T4_OFF_SHIELD_HELL@2": "offhand",
    "T4_OFF_SHIELD_HELL@3": "offhand",
    "T5_OFF_SHIELD_HELL": "offhand",
    "T5_OFF_SHIELD_HELL@1": "offhand",
    "T5_OFF_SHIELD_HELL@2": "offhand",
    "T5_OFF_SHIELD_HELL@3": "offhand",
    "T6_OFF_SHIELD_HELL": "offhand",
    "T6_OFF_SHIELD_HELL@1": "offhand",
    "T6_OFF_SHIELD_HELL@2": "offhand",
    "T6_OFF_SHIELD_HELL@3": "offhand",
    "T7_OFF_SHIELD_HELL": "offhand",
    "T7_OFF_SHIELD_HELL@1": "offhand",
    "T7_OFF_SHIELD_HELL@2": "offhand",
    "T7_OFF_SHIELD_HELL@3": "offhand",
    "T8_OFF_SHIELD_HELL": "offhand",
    "T8_OFF_SHIELD_HELL@1": "offhand",
    "T8_OFF_SHIELD_HELL@2": "offhand",
    "T8_OFF_SHIELD_HELL@3": "offhand",
    "T4_OFF_SPIKEDSHIELD_MORGANA": "offhand",
    "T4_OFF_SPIKEDSHIELD_MORGANA@1": "offhand",
    "T4_OFF_SPIKEDSHIELD_MORGANA@2": "offhand",
    "T4_OFF_SPIKEDSHIELD_MORGANA@3": "offhand",
    "T5_OFF_SPIKEDSHIELD_MORGANA": "offhand",
    "T5_OFF_SPIKEDSHIELD_MORGANA@1": "offhand",
    "T5_OFF_SPIKEDSHIELD_MORGANA@2": "offhand",
    "T5_OFF_SPIKEDSHIELD_MORGANA@3": "offhand",
    "T6_OFF_SPIKEDSHIELD_MORGANA": "offhand",
    "T6_OFF_SPIKEDSHIELD_MORGANA@1": "offhand",
    "T6_OFF_SPIKEDSHIELD_MORGANA@2": "offhand",
    "T6_OFF_SPIKEDSHIELD_MORGANA@3": "offhand",
    "T7_OFF_SPIKEDSHIELD_MORGANA": "offhand",
    "T7_OFF_SPIKEDSHIELD_MORGANA@1": "offhand",
    "T7_OFF_SPIKEDSHIELD_MORGANA@2": "offhand",
    "T7_OFF_SPIKEDSHIELD_MORGANA@3": "offhand",
    "T8_OFF_SPIKEDSHIELD_MORGANA": "offhand",
    "T8_OFF_SPIKEDSHIELD_MORGANA@1": "offhand",
    "T8_OFF_SPIKEDSHIELD_MORGANA@2": "offhand",
    "T8_OFF_SPIKEDSHIELD_MORGANA@3": "offhand",
    "T4_OFF_SHIELD_AVALON": "offhand",
    "T4_OFF_SHIELD_AVALON@1": "offhand",
    "T4_OFF_SHIELD_AVALON@2": "offhand",
    "T4_OFF_SHIELD_AVALON@3": "offhand",
    "T5_OFF_SHIELD_AVALON": "offhand",
    "T5_OFF_SHIELD_AVALON@1": "offhand",
    "T5_OFF_SHIELD_AVALON@2": "offhand",
    "T5_OFF_SHIELD_AVALON@3": "offhand",
    "T6_OFF_SHIELD_AVALON": "offhand",
    "T6_OFF_SHIELD_AVALON@1": "offhand",
    "T6_OFF_SHIELD_AVALON@2": "offhand",
    "T6_OFF_SHIELD_AVALON@3": "offhand",
    "T7_OFF_SHIELD_AVALON": "offhand",
    "T7_OFF_SHIELD_AVALON@1": "offhand",
    "T7_OFF_SHIELD_AVALON@2": "offhand",
    "T7_OFF_SHIELD_AVALON@3": "offhand",
    "T8_OFF_SHIELD_AVALON": "offhand",
    "T8_OFF_SHIELD_AVALON@1": "offhand",
    "T8_OFF_SHIELD_AVALON@2": "offhand",
    "T8_OFF_SHIELD_AVALON@3": "offhand",
    "T2_OFF_BOOK": "offhand",
    "T3_OFF_BOOK": "offhand",
    "T4_OFF_BOOK": "offhand",
    "T4_OFF_BOOK@1": "offhand",
    "T4_OFF_BOOK@2": "offhand",
    "T4_OFF_BOOK@3": "offhand",
    "T5_OFF_BOOK": "offhand",
    "T5_OFF_BOOK@1": "offhand",
    "T5_OFF_BOOK@2": "offhand",
    "T5_OFF_BOOK@3": "offhand",
    "T6_OFF_BOOK": "offhand",
    "T6_OFF_BOOK@1": "offhand",
    "T6_OFF_BOOK@2": "offhand",
    "T6_OFF_BOOK@3": "offhand",
    "T7_OFF_BOOK": "offhand",
    "T7_OFF_BOOK@1": "offhand",
    "T7_OFF_BOOK@2": "offhand",
    "T7_OFF_BOOK@3": "offhand",
    "T8_OFF_BOOK": "offhand",
    "T8_OFF_BOOK@1": "offhand",
    "T8_OFF_BOOK@2": "offhand",
    "T8_OFF_BOOK@3": "offhand",
    "T4_OFF_ORB_MORGANA": "offhand",
    "T4_OFF_ORB_MORGANA@1": "offhand",
    "T4_OFF_ORB_MORGANA@2": "offhand",
    "T4_OFF_ORB_MORGANA@3": "offhand",
    "T5_OFF_ORB_MORGANA": "offhand",
    "T5_OFF_ORB_MORGANA@1": "offhand",
    "T5_OFF_ORB_MORGANA@2": "offhand",
    "T5_OFF_ORB_MORGANA@3": "offhand",
    "T6_OFF_ORB_MORGANA": "offhand",
    "T6_OFF_ORB_MORGANA@1": "offhand",
    "T6_OFF_ORB_MORGANA@2": "offhand",
    "T6_OFF_ORB_MORGANA@3": "offhand",
    "T7_OFF_ORB_MORGANA": "offhand",
    "T7_OFF_ORB_MORGANA@1": "offhand",
    "T7_OFF_ORB_MORGANA@2": "offhand",
    "T7_OFF_ORB_MORGANA@3": "offhand",
    "T8_OFF_ORB_MORGANA": "offhand",
    "T8_OFF_ORB_MORGANA@1": "offhand",
    "T8_OFF_ORB_MORGANA@2": "offhand",
    "T8_OFF_ORB_MORGANA@3": "offhand",
    "T4_OFF_DEMONSKULL_HELL": "offhand",
    "T4_OFF_DEMONSKULL_HELL@1": "offhand",
    "T4_OFF_DEMONSKULL_HELL@2": "offhand",
    "T4_OFF_DEMONSKULL_HELL@3": "offhand",
    "T5_OFF_DEMONSKULL_HELL": "offhand",
    "T5_OFF_DEMONSKULL_HELL@1": "offhand",
    "T5_OFF_DEMONSKULL_HELL@2": "offhand",
    "T5_OFF_DEMONSKULL_HELL@3": "offhand",
    "T6_OFF_DEMONSKULL_HELL": "offhand",
    "T6_OFF_DEMONSKULL_HELL@1": "offhand",
    "T6_OFF_DEMONSKULL_HELL@2": "offhand",
    "T6_OFF_DEMONSKULL_HELL@3": "offhand",
    "T7_OFF_DEMONSKULL_HELL": "offhand",
    "T7_OFF_DEMONSKULL_HELL@1": "offhand",
    "T7_OFF_DEMONSKULL_HELL@2": "offhand",
    "T7_OFF_DEMONSKULL_HELL@3": "offhand",
    "T8_OFF_DEMONSKULL_HELL": "offhand",
    "T8_OFF_DEMONSKULL_HELL@1": "offhand",
    "T8_OFF_DEMONSKULL_HELL@2": "offhand",
    "T8_OFF_DEMONSKULL_HELL@3": "offhand",
    "T4_OFF_TOTEM_KEEPER": "offhand",
    "T4_OFF_TOTEM_KEEPER@1": "offhand",
    "T4_OFF_TOTEM_KEEPER@2": "offhand",
    "T4_OFF_TOTEM_KEEPER@3": "offhand",
    "T5_OFF_TOTEM_KEEPER": "offhand",
    "T5_OFF_TOTEM_KEEPER@1": "offhand",
    "T5_OFF_TOTEM_KEEPER@2": "offhand",
    "T5_OFF_TOTEM_KEEPER@3": "offhand",
    "T6_OFF_TOTEM_KEEPER": "offhand",
    "T6_OFF_TOTEM_KEEPER@1": "offhand",
    "T6_OFF_TOTEM_KEEPER@2": "offhand",
    "T6_OFF_TOTEM_KEEPER@3": "offhand",
    "T7_OFF_TOTEM_KEEPER": "offhand",
    "T7_OFF_TOTEM_KEEPER@1": "offhand",
    "T7_OFF_TOTEM_KEEPER@2": "offhand",
    "T7_OFF_TOTEM_KEEPER@3": "offhand",
    "T8_OFF_TOTEM_KEEPER": "offhand",
    "T8_OFF_TOTEM_KEEPER@1": "offhand",
    "T8_OFF_TOTEM_KEEPER@2": "offhand",
    "T8_OFF_TOTEM_KEEPER@3": "offhand",
    "T4_OFF_CENSER_AVALON": "offhand",
    "T4_OFF_CENSER_AVALON@1": "offhand",
    "T4_OFF_CENSER_AVALON@2": "offhand",
    "T4_OFF_CENSER_AVALON@3": "offhand",
    "T5_OFF_CENSER_AVALON": "offhand",
    "T5_OFF_CENSER_AVALON@1": "offhand",
    "T5_OFF_CENSER_AVALON@2": "offhand",
    "T5_OFF_CENSER_AVALON@3": "offhand",
    "T6_OFF_CENSER_AVALON": "offhand",
    "T6_OFF_CENSER_AVALON@1": "offhand",
    "T6_OFF_CENSER_AVALON@2": "offhand",
    "T6_OFF_CENSER_AVALON@3": "offhand",
    "T7_OFF_CENSER_AVALON": "offhand",
    "T7_OFF_CENSER_AVALON@1": "offhand",
    "T7_OFF_CENSER_AVALON@2": "offhand",
    "T7_OFF_CENSER_AVALON@3": "offhand",
    "T8_OFF_CENSER_AVALON": "offhand",
    "T8_OFF_CENSER_AVALON@1": "offhand",
    "T8_OFF_CENSER_AVALON@2": "offhand",
    "T8_OFF_CENSER_AVALON@3": "offhand",
    "T3_OFF_TORCH": "offhand",
    "T4_OFF_TORCH": "offhand",
    "T4_OFF_TORCH@1": "offhand",
    "T4_OFF_TORCH@2": "offhand",
    "T4_OFF_TORCH@3": "offhand",
    "T5_OFF_TORCH": "offhand",
    "T5_OFF_TORCH@1": "offhand",
    "T5_OFF_TORCH@2": "offhand",
    "T5_OFF_TORCH@3": "offhand",
    "T6_OFF_TORCH": "offhand",
    "T6_OFF_TORCH@1": "offhand",
    "T6_OFF_TORCH@2": "offhand",
    "T6_OFF_TORCH@3": "offhand",
    "T7_OFF_TORCH": "offhand",
    "T7_OFF_TORCH@1": "offhand",
    "T7_OFF_TORCH@2": "offhand",
    "T7_OFF_TORCH@3": "offhand",
    "T8_OFF_TORCH": "offhand",
    "T8_OFF_TORCH@1": "offhand",
    "T8_OFF_TORCH@2": "offhand",
    "T8_OFF_TORCH@3": "offhand",
    "T4_OFF_HORN_KEEPER": "offhand",
    "T4_OFF_HORN_KEEPER@1": "offhand",
    "T4_OFF_HORN_KEEPER@2": "offhand",
    "T4_OFF_HORN_KEEPER@3": "offhand",
    "T5_OFF_HORN_KEEPER": "offhand",
    "T5_OFF_HORN_KEEPER@1": "offhand",
    "T5_OFF_HORN_KEEPER@2": "offhand",
    "T5_OFF_HORN_KEEPER@3": "offhand",
    "T6_OFF_HORN_KEEPER": "offhand",
    "T6_OFF_HORN_KEEPER@1": "offhand",
    "T6_OFF_HORN_KEEPER@2": "offhand",
    "T6_OFF_HORN_KEEPER@3": "offhand",
    "T7_OFF_HORN_KEEPER": "offhand",
    "T7_OFF_HORN_KEEPER@1": "offhand",
    "T7_OFF_HORN_KEEPER@2": "offhand",
    "T7_OFF_HORN_KEEPER@3": "offhand",
    "T8_OFF_HORN_KEEPER": "offhand",
    "T8_OFF_HORN_KEEPER@1": "offhand",
    "T8_OFF_HORN_KEEPER@2": "offhand",
    "T8_OFF_HORN_KEEPER@3": "offhand",
    "T4_OFF_TALISMAN_AVALON": "offhand",
    "T4_OFF_TALISMAN_AVALON@1": "offhand",
    "T4_OFF_TALISMAN_AVALON@2": "offhand",
    "T4_OFF_TALISMAN_AVALON@3": "offhand",
    "T5_OFF_TALISMAN_AVALON": "offhand",
    "T5_OFF_TALISMAN_AVALON@1": "offhand",
    "T5_OFF_TALISMAN_AVALON@2": "offhand",
    "T5_OFF_TALISMAN_AVALON@3": "offhand",
    "T6_OFF_TALISMAN_AVALON": "offhand",
    "T6_OFF_TALISMAN_AVALON@1": "offhand",
    "T6_OFF_TALISMAN_AVALON@2": "offhand",
    "T6_OFF_TALISMAN_AVALON@3": "offhand",
    "T7_OFF_TALISMAN_AVALON": "offhand",
    "T7_OFF_TALISMAN_AVALON@1": "offhand",
    "T7_OFF_TALISMAN_AVALON@2": "offhand",
    "T7_OFF_TALISMAN_AVALON@3": "offhand",
    "T8_OFF_TALISMAN_AVALON": "offhand",
    "T8_OFF_TALISMAN_AVALON@1": "offhand",
    "T8_OFF_TALISMAN_AVALON@2": "offhand",
    "T8_OFF_TALISMAN_AVALON@3": "offhand",
    "T4_OFF_LAMP_UNDEAD": "offhand",
    "T4_OFF_LAMP_UNDEAD@1": "offhand",
    "T4_OFF_LAMP_UNDEAD@2": "offhand",
    "T4_OFF_LAMP_UNDEAD@3": "offhand",
    "T5_OFF_LAMP_UNDEAD": "offhand",
    "T5_OFF_LAMP_UNDEAD@1": "offhand",
    "T5_OFF_LAMP_UNDEAD@2": "offhand",
    "T5_OFF_LAMP_UNDEAD@3": "offhand",
    "T6_OFF_LAMP_UNDEAD": "offhand",
    "T6_OFF_LAMP_UNDEAD@1": "offhand",
    "T6_OFF_LAMP_UNDEAD@2": "offhand",
    "T6_OFF_LAMP_UNDEAD@3": "offhand",
    "T7_OFF_LAMP_UNDEAD": "offhand",
    "T7_OFF_LAMP_UNDEAD@1": "offhand",
    "T7_OFF_LAMP_UNDEAD@2": "offhand",
    "T7_OFF_LAMP_UNDEAD@3": "offhand",
    "T8_OFF_LAMP_UNDEAD": "offhand",
    "T8_OFF_LAMP_UNDEAD@1": "offhand",
    "T8_OFF_LAMP_UNDEAD@2": "offhand",
    "T8_OFF_LAMP_UNDEAD@3": "offhand",
    "T4_OFF_JESTERCANE_HELL": "offhand",
    "T4_OFF_JESTERCANE_HELL@1": "offhand",
    "T4_OFF_JESTERCANE_HELL@2": "offhand",
    "T4_OFF_JESTERCANE_HELL@3": "offhand",
    "T5_OFF_JESTERCANE_HELL": "offhand",
    "T5_OFF_JESTERCANE_HELL@1": "offhand",
    "T5_OFF_JESTERCANE_HELL@2": "offhand",
    "T5_OFF_JESTERCANE_HELL@3": "offhand",
    "T6_OFF_JESTERCANE_HELL": "offhand",
    "T6_OFF_JESTERCANE_HELL@1": "offhand",
    "T6_OFF_JESTERCANE_HELL@2": "offhand",
    "T6_OFF_JESTERCANE_HELL@3": "offhand",
    "T7_OFF_JESTERCANE_HELL": "offhand",
    "T7_OFF_JESTERCANE_HELL@1": "offhand",
    "T7_OFF_JESTERCANE_HELL@2": "offhand",
    "T7_OFF_JESTERCANE_HELL@3": "offhand",
    "T8_OFF_JESTERCANE_HELL": "offhand",
    "T8_OFF_JESTERCANE_HELL@1": "offhand",
    "T8_OFF_JESTERCANE_HELL@2": "offhand",
    "T8_OFF_JESTERCANE_HELL@3": "offhand",
    "T2_2H_TOOL_PICK": "tools",
    "T3_2H_TOOL_PICK": "tools",
    "T4_2H_TOOL_PICK": "tools",
    "T5_2H_TOOL_PICK": "tools",
    "T6_2H_TOOL_PICK": "tools",
    "T7_2H_TOOL_PICK": "tools",
    "T8_2H_TOOL_PICK": "tools",
    "T4_2H_TOOL_PICK_AVALON": "tools",
    "T5_2H_TOOL_PICK_AVALON": "tools",
    "T6_2H_TOOL_PICK_AVALON": "tools",
    "T7_2H_TOOL_PICK_AVALON": "tools",
    "T8_2H_TOOL_PICK_AVALON": "tools",
    "T2_2H_TOOL_HAMMER": "tools",
    "T3_2H_TOOL_HAMMER": "tools",
    "T4_2H_TOOL_HAMMER": "tools",
    "T5_2H_TOOL_HAMMER": "tools",
    "T6_2H_TOOL_HAMMER": "tools",
    "T7_2H_TOOL_HAMMER": "tools",
    "T8_2H_TOOL_HAMMER": "tools",
    "T4_2H_TOOL_HAMMER_AVALON": "tools",
    "T5_2H_TOOL_HAMMER_AVALON": "tools",
    "T6_2H_TOOL_HAMMER_AVALON": "tools",
    "T7_2H_TOOL_HAMMER_AVALON": "tools",
    "T8_2H_TOOL_HAMMER_AVALON": "tools",
    "T2_2H_TOOL_AXE": "tools",
    "T3_2H_TOOL_AXE": "tools",
    "T4_2H_TOOL_AXE": "tools",
    "T5_2H_TOOL_AXE": "tools",
    "T6_2H_TOOL_AXE": "tools",
    "T7_2H_TOOL_AXE": "tools",
    "T8_2H_TOOL_AXE": "tools",
    "T4_2H_TOOL_AXE_AVALON": "tools",
    "T5_2H_TOOL_AXE_AVALON": "tools",
    "T6_2H_TOOL_AXE_AVALON": "tools",
    "T7_2H_TOOL_AXE_AVALON": "tools",
    "T8_2H_TOOL_AXE_AVALON": "tools",
    "T2_2H_TOOL_SICKLE": "tools",
    "T3_2H_TOOL_SICKLE": "tools",
    "T4_2H_TOOL_SICKLE": "tools",
    "T5_2H_TOOL_SICKLE": "tools",
    "T6_2H_TOOL_SICKLE": "tools",
    "T7_2H_TOOL_SICKLE": "tools",
    "T8_2H_TOOL_SICKLE": "tools",
    "T4_2H_TOOL_SICKLE_AVALON": "tools",
    "T5_2H_TOOL_SICKLE_AVALON": "tools",
    "T6_2H_TOOL_SICKLE_AVALON": "tools",
    "T7_2H_TOOL_SICKLE_AVALON": "tools",
    "T8_2H_TOOL_SICKLE_AVALON": "tools",
    "T2_2H_TOOL_KNIFE": "tools",
    "T3_2H_TOOL_KNIFE": "tools",
    "T4_2H_TOOL_KNIFE": "tools",
    "T5_2H_TOOL_KNIFE": "tools",
    "T6_2H_TOOL_KNIFE": "tools",
    "T7_2H_TOOL_KNIFE": "tools",
    "T8_2H_TOOL_KNIFE": "tools",
    "T4_2H_TOOL_KNIFE_AVALON": "tools",
    "T5_2H_TOOL_KNIFE_AVALON": "tools",
    "T6_2H_TOOL_KNIFE_AVALON": "tools",
    "T7_2H_TOOL_KNIFE_AVALON": "tools",
    "T8_2H_TOOL_KNIFE_AVALON": "tools",
    "T2_2H_TOOL_SIEGEHAMMER": "tools",
    "T3_2H_TOOL_SIEGEHAMMER": "tools",
    "T4_2H_TOOL_SIEGEHAMMER": "tools",
    "T5_2H_TOOL_SIEGEHAMMER": "tools",
    "T6_2H_TOOL_SIEGEHAMMER": "tools",
    "T7_2H_TOOL_SIEGEHAMMER": "tools",
    "T8_2H_TOOL_SIEGEHAMMER": "tools",
    "T4_2H_TOOL_SIEGEHAMMER_AVALON": "tools",
    "T5_2H_TOOL_SIEGEHAMMER_AVALON": "tools",
    "T6_2H_TOOL_SIEGEHAMMER_AVALON": "tools",
    "T7_2H_TOOL_SIEGEHAMMER_AVALON": "tools",
    "T8_2H_TOOL_SIEGEHAMMER_AVALON": "tools",
    "T3_2H_TOOL_FISHINGROD": "tools",
    "T4_2H_TOOL_FISHINGROD": "tools",
    "T5_2H_TOOL_FISHINGROD": "tools",
    "T6_2H_TOOL_FISHINGROD": "tools",
    "T7_2H_TOOL_FISHINGROD": "tools",
    "T8_2H_TOOL_FISHINGROD": "tools",
    "T4_2H_TOOL_FISHINGROD_AVALON": "tools",
    "T5_2H_TOOL_FISHINGROD_AVALON": "tools",
    "T6_2H_TOOL_FISHINGROD_AVALON": "tools",
    "T7_2H_TOOL_FISHINGROD_AVALON": "tools",
    "T8_2H_TOOL_FISHINGROD_AVALON": "tools",
    "T2_HEAD_PLATE_SET1": "plate_helmet",
    "T3_HEAD_PLATE_SET1": "plate_helmet",
    "T4_HEAD_PLATE_SET1": "plate_helmet",
    "T4_HEAD_PLATE_SET1@1": "plate_helmet",
    "T4_HEAD_PLATE_SET1@2": "plate_helmet",
    "T4_HEAD_PLATE_SET1@3": "plate_helmet",
    "T5_HEAD_PLATE_SET1": "plate_helmet",
    "T5_HEAD_PLATE_SET1@1": "plate_helmet",
    "T5_HEAD_PLATE_SET1@2": "plate_helmet",
    "T5_HEAD_PLATE_SET1@3": "plate_helmet",
    "T6_HEAD_PLATE_SET1": "plate_helmet",
    "T6_HEAD_PLATE_SET1@1": "plate_helmet",
    "T6_HEAD_PLATE_SET1@2": "plate_helmet",
    "T6_HEAD_PLATE_SET1@3": "plate_helmet",
    "T7_HEAD_PLATE_SET1": "plate_helmet",
    "T7_HEAD_PLATE_SET1@1": "plate_helmet",
    "T7_HEAD_PLATE_SET1@2": "plate_helmet",
    "T7_HEAD_PLATE_SET1@3": "plate_helmet",
    "T8_HEAD_PLATE_SET1": "plate_helmet",
    "T8_HEAD_PLATE_SET1@1": "plate_helmet",
    "T8_HEAD_PLATE_SET1@2": "plate_helmet",
    "T8_HEAD_PLATE_SET1@3": "plate_helmet",
    "T2_ARMOR_PLATE_SET1": "plate_armor",
    "T3_ARMOR_PLATE_SET1": "plate_armor",
    "T4_ARMOR_PLATE_SET1": "plate_armor",
    "T4_ARMOR_PLATE_SET1@1": "plate_armor",
    "T4_ARMOR_PLATE_SET1@2": "plate_armor",
    "T4_ARMOR_PLATE_SET1@3": "plate_armor",
    "T5_ARMOR_PLATE_SET1": "plate_armor",
    "T5_ARMOR_PLATE_SET1@1": "plate_armor",
    "T5_ARMOR_PLATE_SET1@2": "plate_armor",
    "T5_ARMOR_PLATE_SET1@3": "plate_armor",
    "T6_ARMOR_PLATE_SET1": "plate_armor",
    "T6_ARMOR_PLATE_SET1@1": "plate_armor",
    "T6_ARMOR_PLATE_SET1@2": "plate_armor",
    "T6_ARMOR_PLATE_SET1@3": "plate_armor",
    "T7_ARMOR_PLATE_SET1": "plate_armor",
    "T7_ARMOR_PLATE_SET1@1": "plate_armor",
    "T7_ARMOR_PLATE_SET1@2": "plate_armor",
    "T7_ARMOR_PLATE_SET1@3": "plate_armor",
    "T8_ARMOR_PLATE_SET1": "plate_armor",
    "T8_ARMOR_PLATE_SET1@1": "plate_armor",
    "T8_ARMOR_PLATE_SET1@2": "plate_armor",
    "T8_ARMOR_PLATE_SET1@3": "plate_armor",
    "T2_SHOES_PLATE_SET1": "plate_shoes",
    "T3_SHOES_PLATE_SET1": "plate_shoes",
    "T4_SHOES_PLATE_SET1": "plate_shoes",
    "T4_SHOES_PLATE_SET1@1": "plate_shoes",
    "T4_SHOES_PLATE_SET1@2": "plate_shoes",
    "T4_SHOES_PLATE_SET1@3": "plate_shoes",
    "T5_SHOES_PLATE_SET1": "plate_shoes",
    "T5_SHOES_PLATE_SET1@1": "plate_shoes",
    "T5_SHOES_PLATE_SET1@2": "plate_shoes",
    "T5_SHOES_PLATE_SET1@3": "plate_shoes",
    "T6_SHOES_PLATE_SET1": "plate_shoes",
    "T6_SHOES_PLATE_SET1@1": "plate_shoes",
    "T6_SHOES_PLATE_SET1@2": "plate_shoes",
    "T6_SHOES_PLATE_SET1@3": "plate_shoes",
    "T7_SHOES_PLATE_SET1": "plate_shoes",
    "T7_SHOES_PLATE_SET1@1": "plate_shoes",
    "T7_SHOES_PLATE_SET1@2": "plate_shoes",
    "T7_SHOES_PLATE_SET1@3": "plate_shoes",
    "T8_SHOES_PLATE_SET1": "plate_shoes",
    "T8_SHOES_PLATE_SET1@1": "plate_shoes",
    "T8_SHOES_PLATE_SET1@2": "plate_shoes",
    "T8_SHOES_PLATE_SET1@3": "plate_shoes",
    "T4_HEAD_PLATE_SET2": "plate_helmet",
    "T4_HEAD_PLATE_SET2@1": "plate_helmet",
    "T4_HEAD_PLATE_SET2@2": "plate_helmet",
    "T4_HEAD_PLATE_SET2@3": "plate_helmet",
    "T5_HEAD_PLATE_SET2": "plate_helmet",
    "T5_HEAD_PLATE_SET2@1": "plate_helmet",
    "T5_HEAD_PLATE_SET2@2": "plate_helmet",
    "T5_HEAD_PLATE_SET2@3": "plate_helmet",
    "T6_HEAD_PLATE_SET2": "plate_helmet",
    "T6_HEAD_PLATE_SET2@1": "plate_helmet",
    "T6_HEAD_PLATE_SET2@2": "plate_helmet",
    "T6_HEAD_PLATE_SET2@3": "plate_helmet",
    "T7_HEAD_PLATE_SET2": "plate_helmet",
    "T7_HEAD_PLATE_SET2@1": "plate_helmet",
    "T7_HEAD_PLATE_SET2@2": "plate_helmet",
    "T7_HEAD_PLATE_SET2@3": "plate_helmet",
    "T8_HEAD_PLATE_SET2": "plate_helmet",
    "T8_HEAD_PLATE_SET2@1": "plate_helmet",
    "T8_HEAD_PLATE_SET2@2": "plate_helmet",
    "T8_HEAD_PLATE_SET2@3": "plate_helmet",
    "T4_ARMOR_PLATE_SET2": "plate_armor",
    "T4_ARMOR_PLATE_SET2@1": "plate_armor",
    "T4_ARMOR_PLATE_SET2@2": "plate_armor",
    "T4_ARMOR_PLATE_SET2@3": "plate_armor",
    "T5_ARMOR_PLATE_SET2": "plate_armor",
    "T5_ARMOR_PLATE_SET2@1": "plate_armor",
    "T5_ARMOR_PLATE_SET2@2": "plate_armor",
    "T5_ARMOR_PLATE_SET2@3": "plate_armor",
    "T6_ARMOR_PLATE_SET2": "plate_armor",
    "T6_ARMOR_PLATE_SET2@1": "plate_armor",
    "T6_ARMOR_PLATE_SET2@2": "plate_armor",
    "T6_ARMOR_PLATE_SET2@3": "plate_armor",
    "T7_ARMOR_PLATE_SET2": "plate_armor",
    "T7_ARMOR_PLATE_SET2@1": "plate_armor",
    "T7_ARMOR_PLATE_SET2@2": "plate_armor",
    "T7_ARMOR_PLATE_SET2@3": "plate_armor",
    "T8_ARMOR_PLATE_SET2": "plate_armor",
    "T8_ARMOR_PLATE_SET2@1": "plate_armor",
    "T8_ARMOR_PLATE_SET2@2": "plate_armor",
    "T8_ARMOR_PLATE_SET2@3": "plate_armor",
    "T4_SHOES_PLATE_SET2": "plate_shoes",
    "T4_SHOES_PLATE_SET2@1": "plate_shoes",
    "T4_SHOES_PLATE_SET2@2": "plate_shoes",
    "T4_SHOES_PLATE_SET2@3": "plate_shoes",
    "T5_SHOES_PLATE_SET2": "plate_shoes",
    "T5_SHOES_PLATE_SET2@1": "plate_shoes",
    "T5_SHOES_PLATE_SET2@2": "plate_shoes",
    "T5_SHOES_PLATE_SET2@3": "plate_shoes",
    "T6_SHOES_PLATE_SET2": "plate_shoes",
    "T6_SHOES_PLATE_SET2@1": "plate_shoes",
    "T6_SHOES_PLATE_SET2@2": "plate_shoes",
    "T6_SHOES_PLATE_SET2@3": "plate_shoes",
    "T7_SHOES_PLATE_SET2": "plate_shoes",
    "T7_SHOES_PLATE_SET2@1": "plate_shoes",
    "T7_SHOES_PLATE_SET2@2": "plate_shoes",
    "T7_SHOES_PLATE_SET2@3": "plate_shoes",
    "T8_SHOES_PLATE_SET2": "plate_shoes",
    "T8_SHOES_PLATE_SET2@1": "plate_shoes",
    "T8_SHOES_PLATE_SET2@2": "plate_shoes",
    "T8_SHOES_PLATE_SET2@3": "plate_shoes",
    "T4_HEAD_PLATE_SET3": "plate_helmet",
    "T4_HEAD_PLATE_SET3@1": "plate_helmet",
    "T4_HEAD_PLATE_SET3@2": "plate_helmet",
    "T4_HEAD_PLATE_SET3@3": "plate_helmet",
    "T5_HEAD_PLATE_SET3": "plate_helmet",
    "T5_HEAD_PLATE_SET3@1": "plate_helmet",
    "T5_HEAD_PLATE_SET3@2": "plate_helmet",
    "T5_HEAD_PLATE_SET3@3": "plate_helmet",
    "T6_HEAD_PLATE_SET3": "plate_helmet",
    "T6_HEAD_PLATE_SET3@1": "plate_helmet",
    "T6_HEAD_PLATE_SET3@2": "plate_helmet",
    "T6_HEAD_PLATE_SET3@3": "plate_helmet",
    "T7_HEAD_PLATE_SET3": "plate_helmet",
    "T7_HEAD_PLATE_SET3@1": "plate_helmet",
    "T7_HEAD_PLATE_SET3@2": "plate_helmet",
    "T7_HEAD_PLATE_SET3@3": "plate_helmet",
    "T8_HEAD_PLATE_SET3": "plate_helmet",
    "T8_HEAD_PLATE_SET3@1": "plate_helmet",
    "T8_HEAD_PLATE_SET3@2": "plate_helmet",
    "T8_HEAD_PLATE_SET3@3": "plate_helmet",
    "T4_ARMOR_PLATE_SET3": "plate_armor",
    "T4_ARMOR_PLATE_SET3@1": "plate_armor",
    "T4_ARMOR_PLATE_SET3@2": "plate_armor",
    "T4_ARMOR_PLATE_SET3@3": "plate_armor",
    "T5_ARMOR_PLATE_SET3": "plate_armor",
    "T5_ARMOR_PLATE_SET3@1": "plate_armor",
    "T5_ARMOR_PLATE_SET3@2": "plate_armor",
    "T5_ARMOR_PLATE_SET3@3": "plate_armor",
    "T6_ARMOR_PLATE_SET3": "plate_armor",
    "T6_ARMOR_PLATE_SET3@1": "plate_armor",
    "T6_ARMOR_PLATE_SET3@2": "plate_armor",
    "T6_ARMOR_PLATE_SET3@3": "plate_armor",
    "T7_ARMOR_PLATE_SET3": "plate_armor",
    "T7_ARMOR_PLATE_SET3@1": "plate_armor",
    "T7_ARMOR_PLATE_SET3@2": "plate_armor",
    "T7_ARMOR_PLATE_SET3@3": "plate_armor",
    "T8_ARMOR_PLATE_SET3": "plate_armor",
    "T8_ARMOR_PLATE_SET3@1": "plate_armor",
    "T8_ARMOR_PLATE_SET3@2": "plate_armor",
    "T8_ARMOR_PLATE_SET3@3": "plate_armor",
    "T4_SHOES_PLATE_SET3": "plate_shoes",
    "T4_SHOES_PLATE_SET3@1": "plate_shoes",
    "T4_SHOES_PLATE_SET3@2": "plate_shoes",
    "T4_SHOES_PLATE_SET3@3": "plate_shoes",
    "T5_SHOES_PLATE_SET3": "plate_shoes",
    "T5_SHOES_PLATE_SET3@1": "plate_shoes",
    "T5_SHOES_PLATE_SET3@2": "plate_shoes",
    "T5_SHOES_PLATE_SET3@3": "plate_shoes",
    "T6_SHOES_PLATE_SET3": "plate_shoes",
    "T6_SHOES_PLATE_SET3@1": "plate_shoes",
    "T6_SHOES_PLATE_SET3@2": "plate_shoes",
    "T6_SHOES_PLATE_SET3@3": "plate_shoes",
    "T7_SHOES_PLATE_SET3": "plate_shoes",
    "T7_SHOES_PLATE_SET3@1": "plate_shoes",
    "T7_SHOES_PLATE_SET3@2": "plate_shoes",
    "T7_SHOES_PLATE_SET3@3": "plate_shoes",
    "T8_SHOES_PLATE_SET3": "plate_shoes",
    "T8_SHOES_PLATE_SET3@1": "plate_shoes",
    "T8_SHOES_PLATE_SET3@2": "plate_shoes",
    "T8_SHOES_PLATE_SET3@3": "plate_shoes",
    "T4_HEAD_PLATE_UNDEAD": "plate_helmet",
    "T4_HEAD_PLATE_UNDEAD@1": "plate_helmet",
    "T4_HEAD_PLATE_UNDEAD@2": "plate_helmet",
    "T4_HEAD_PLATE_UNDEAD@3": "plate_helmet",
    "T5_HEAD_PLATE_UNDEAD": "plate_helmet",
    "T5_HEAD_PLATE_UNDEAD@1": "plate_helmet",
    "T5_HEAD_PLATE_UNDEAD@2": "plate_helmet",
    "T5_HEAD_PLATE_UNDEAD@3": "plate_helmet",
    "T6_HEAD_PLATE_UNDEAD": "plate_helmet",
    "T6_HEAD_PLATE_UNDEAD@1": "plate_helmet",
    "T6_HEAD_PLATE_UNDEAD@2": "plate_helmet",
    "T6_HEAD_PLATE_UNDEAD@3": "plate_helmet",
    "T7_HEAD_PLATE_UNDEAD": "plate_helmet",
    "T7_HEAD_PLATE_UNDEAD@1": "plate_helmet",
    "T7_HEAD_PLATE_UNDEAD@2": "plate_helmet",
    "T7_HEAD_PLATE_UNDEAD@3": "plate_helmet",
    "T8_HEAD_PLATE_UNDEAD": "plate_helmet",
    "T8_HEAD_PLATE_UNDEAD@1": "plate_helmet",
    "T8_HEAD_PLATE_UNDEAD@2": "plate_helmet",
    "T8_HEAD_PLATE_UNDEAD@3": "plate_helmet",
    "T4_ARMOR_PLATE_UNDEAD": "plate_armor",
    "T4_ARMOR_PLATE_UNDEAD@1": "plate_armor",
    "T4_ARMOR_PLATE_UNDEAD@2": "plate_armor",
    "T4_ARMOR_PLATE_UNDEAD@3": "plate_armor",
    "T5_ARMOR_PLATE_UNDEAD": "plate_armor",
    "T5_ARMOR_PLATE_UNDEAD@1": "plate_armor",
    "T5_ARMOR_PLATE_UNDEAD@2": "plate_armor",
    "T5_ARMOR_PLATE_UNDEAD@3": "plate_armor",
    "T6_ARMOR_PLATE_UNDEAD": "plate_armor",
    "T6_ARMOR_PLATE_UNDEAD@1": "plate_armor",
    "T6_ARMOR_PLATE_UNDEAD@2": "plate_armor",
    "T6_ARMOR_PLATE_UNDEAD@3": "plate_armor",
    "T7_ARMOR_PLATE_UNDEAD": "plate_armor",
    "T7_ARMOR_PLATE_UNDEAD@1": "plate_armor",
    "T7_ARMOR_PLATE_UNDEAD@2": "plate_armor",
    "T7_ARMOR_PLATE_UNDEAD@3": "plate_armor",
    "T8_ARMOR_PLATE_UNDEAD": "plate_armor",
    "T8_ARMOR_PLATE_UNDEAD@1": "plate_armor",
    "T8_ARMOR_PLATE_UNDEAD@2": "plate_armor",
    "T8_ARMOR_PLATE_UNDEAD@3": "plate_armor",
    "T4_SHOES_PLATE_UNDEAD": "plate_shoes",
    "T4_SHOES_PLATE_UNDEAD@1": "plate_shoes",
    "T4_SHOES_PLATE_UNDEAD@2": "plate_shoes",
    "T4_SHOES_PLATE_UNDEAD@3": "plate_shoes",
    "T5_SHOES_PLATE_UNDEAD": "plate_shoes",
    "T5_SHOES_PLATE_UNDEAD@1": "plate_shoes",
    "T5_SHOES_PLATE_UNDEAD@2": "plate_shoes",
    "T5_SHOES_PLATE_UNDEAD@3": "plate_shoes",
    "T6_SHOES_PLATE_UNDEAD": "plate_shoes",
    "T6_SHOES_PLATE_UNDEAD@1": "plate_shoes",
    "T6_SHOES_PLATE_UNDEAD@2": "plate_shoes",
    "T6_SHOES_PLATE_UNDEAD@3": "plate_shoes",
    "T7_SHOES_PLATE_UNDEAD": "plate_shoes",
    "T7_SHOES_PLATE_UNDEAD@1": "plate_shoes",
    "T7_SHOES_PLATE_UNDEAD@2": "plate_shoes",
    "T7_SHOES_PLATE_UNDEAD@3": "plate_shoes",
    "T8_SHOES_PLATE_UNDEAD": "plate_shoes",
    "T8_SHOES_PLATE_UNDEAD@1": "plate_shoes",
    "T8_SHOES_PLATE_UNDEAD@2": "plate_shoes",
    "T8_SHOES_PLATE_UNDEAD@3": "plate_shoes",
    "T4_HEAD_PLATE_HELL": "plate_helmet",
    "T4_HEAD_PLATE_HELL@1": "plate_helmet",
    "T4_HEAD_PLATE_HELL@2": "plate_helmet",
    "T4_HEAD_PLATE_HELL@3": "plate_helmet",
    "T5_HEAD_PLATE_HELL": "plate_helmet",
    "T5_HEAD_PLATE_HELL@1": "plate_helmet",
    "T5_HEAD_PLATE_HELL@2": "plate_helmet",
    "T5_HEAD_PLATE_HELL@3": "plate_helmet",
    "T6_HEAD_PLATE_HELL": "plate_helmet",
    "T6_HEAD_PLATE_HELL@1": "plate_helmet",
    "T6_HEAD_PLATE_HELL@2": "plate_helmet",
    "T6_HEAD_PLATE_HELL@3": "plate_helmet",
    "T7_HEAD_PLATE_HELL": "plate_helmet",
    "T7_HEAD_PLATE_HELL@1": "plate_helmet",
    "T7_HEAD_PLATE_HELL@2": "plate_helmet",
    "T7_HEAD_PLATE_HELL@3": "plate_helmet",
    "T8_HEAD_PLATE_HELL": "plate_helmet",
    "T8_HEAD_PLATE_HELL@1": "plate_helmet",
    "T8_HEAD_PLATE_HELL@2": "plate_helmet",
    "T8_HEAD_PLATE_HELL@3": "plate_helmet",
    "T4_ARMOR_PLATE_HELL": "plate_armor",
    "T4_ARMOR_PLATE_HELL@1": "plate_armor",
    "T4_ARMOR_PLATE_HELL@2": "plate_armor",
    "T4_ARMOR_PLATE_HELL@3": "plate_armor",
    "T5_ARMOR_PLATE_HELL": "plate_armor",
    "T5_ARMOR_PLATE_HELL@1": "plate_armor",
    "T5_ARMOR_PLATE_HELL@2": "plate_armor",
    "T5_ARMOR_PLATE_HELL@3": "plate_armor",
    "T6_ARMOR_PLATE_HELL": "plate_armor",
    "T6_ARMOR_PLATE_HELL@1": "plate_armor",
    "T6_ARMOR_PLATE_HELL@2": "plate_armor",
    "T6_ARMOR_PLATE_HELL@3": "plate_armor",
    "T7_ARMOR_PLATE_HELL": "plate_armor",
    "T7_ARMOR_PLATE_HELL@1": "plate_armor",
    "T7_ARMOR_PLATE_HELL@2": "plate_armor",
    "T7_ARMOR_PLATE_HELL@3": "plate_armor",
    "T8_ARMOR_PLATE_HELL": "plate_armor",
    "T8_ARMOR_PLATE_HELL@1": "plate_armor",
    "T8_ARMOR_PLATE_HELL@2": "plate_armor",
    "T8_ARMOR_PLATE_HELL@3": "plate_armor",
    "T4_SHOES_PLATE_HELL": "plate_shoes",
    "T4_SHOES_PLATE_HELL@1": "plate_shoes",
    "T4_SHOES_PLATE_HELL@2": "plate_shoes",
    "T4_SHOES_PLATE_HELL@3": "plate_shoes",
    "T5_SHOES_PLATE_HELL": "plate_shoes",
    "T5_SHOES_PLATE_HELL@1": "plate_shoes",
    "T5_SHOES_PLATE_HELL@2": "plate_shoes",
    "T5_SHOES_PLATE_HELL@3": "plate_shoes",
    "T6_SHOES_PLATE_HELL": "plate_shoes",
    "T6_SHOES_PLATE_HELL@1": "plate_shoes",
    "T6_SHOES_PLATE_HELL@2": "plate_shoes",
    "T6_SHOES_PLATE_HELL@3": "plate_shoes",
    "T7_SHOES_PLATE_HELL": "plate_shoes",
    "T7_SHOES_PLATE_HELL@1": "plate_shoes",
    "T7_SHOES_PLATE_HELL@2": "plate_shoes",
    "T7_SHOES_PLATE_HELL@3": "plate_shoes",
    "T8_SHOES_PLATE_HELL": "plate_shoes",
    "T8_SHOES_PLATE_HELL@1": "plate_shoes",
    "T8_SHOES_PLATE_HELL@2": "plate_shoes",
    "T8_SHOES_PLATE_HELL@3": "plate_shoes",
    "T4_HEAD_PLATE_KEEPER": "plate_helmet",
    "T4_HEAD_PLATE_KEEPER@1": "plate_helmet",
    "T4_HEAD_PLATE_KEEPER@2": "plate_helmet",
    "T4_HEAD_PLATE_KEEPER@3": "plate_helmet",
    "T5_HEAD_PLATE_KEEPER": "plate_helmet",
    "T5_HEAD_PLATE_KEEPER@1": "plate_helmet",
    "T5_HEAD_PLATE_KEEPER@2": "plate_helmet",
    "T5_HEAD_PLATE_KEEPER@3": "plate_helmet",
    "T6_HEAD_PLATE_KEEPER": "plate_helmet",
    "T6_HEAD_PLATE_KEEPER@1": "plate_helmet",
    "T6_HEAD_PLATE_KEEPER@2": "plate_helmet",
    "T6_HEAD_PLATE_KEEPER@3": "plate_helmet",
    "T7_HEAD_PLATE_KEEPER": "plate_helmet",
    "T7_HEAD_PLATE_KEEPER@1": "plate_helmet",
    "T7_HEAD_PLATE_KEEPER@2": "plate_helmet",
    "T7_HEAD_PLATE_KEEPER@3": "plate_helmet",
    "T8_HEAD_PLATE_KEEPER": "plate_helmet",
    "T8_HEAD_PLATE_KEEPER@1": "plate_helmet",
    "T8_HEAD_PLATE_KEEPER@2": "plate_helmet",
    "T8_HEAD_PLATE_KEEPER@3": "plate_helmet",
    "T4_ARMOR_PLATE_KEEPER": "plate_armor",
    "T4_ARMOR_PLATE_KEEPER@1": "plate_armor",
    "T4_ARMOR_PLATE_KEEPER@2": "plate_armor",
    "T4_ARMOR_PLATE_KEEPER@3": "plate_armor",
    "T5_ARMOR_PLATE_KEEPER": "plate_armor",
    "T5_ARMOR_PLATE_KEEPER@1": "plate_armor",
    "T5_ARMOR_PLATE_KEEPER@2": "plate_armor",
    "T5_ARMOR_PLATE_KEEPER@3": "plate_armor",
    "T6_ARMOR_PLATE_KEEPER": "plate_armor",
    "T6_ARMOR_PLATE_KEEPER@1": "plate_armor",
    "T6_ARMOR_PLATE_KEEPER@2": "plate_armor",
    "T6_ARMOR_PLATE_KEEPER@3": "plate_armor",
    "T7_ARMOR_PLATE_KEEPER": "plate_armor",
    "T7_ARMOR_PLATE_KEEPER@1": "plate_armor",
    "T7_ARMOR_PLATE_KEEPER@2": "plate_armor",
    "T7_ARMOR_PLATE_KEEPER@3": "plate_armor",
    "T8_ARMOR_PLATE_KEEPER": "plate_armor",
    "T8_ARMOR_PLATE_KEEPER@1": "plate_armor",
    "T8_ARMOR_PLATE_KEEPER@2": "plate_armor",
    "T8_ARMOR_PLATE_KEEPER@3": "plate_armor",
    "T4_SHOES_PLATE_KEEPER": "plate_shoes",
    "T4_SHOES_PLATE_KEEPER@1": "plate_shoes",
    "T4_SHOES_PLATE_KEEPER@2": "plate_shoes",
    "T4_SHOES_PLATE_KEEPER@3": "plate_shoes",
    "T5_SHOES_PLATE_KEEPER": "plate_shoes",
    "T5_SHOES_PLATE_KEEPER@1": "plate_shoes",
    "T5_SHOES_PLATE_KEEPER@2": "plate_shoes",
    "T5_SHOES_PLATE_KEEPER@3": "plate_shoes",
    "T6_SHOES_PLATE_KEEPER": "plate_shoes",
    "T6_SHOES_PLATE_KEEPER@1": "plate_shoes",
    "T6_SHOES_PLATE_KEEPER@2": "plate_shoes",
    "T6_SHOES_PLATE_KEEPER@3": "plate_shoes",
    "T7_SHOES_PLATE_KEEPER": "plate_shoes",
    "T7_SHOES_PLATE_KEEPER@1": "plate_shoes",
    "T7_SHOES_PLATE_KEEPER@2": "plate_shoes",
    "T7_SHOES_PLATE_KEEPER@3": "plate_shoes",
    "T8_SHOES_PLATE_KEEPER": "plate_shoes",
    "T8_SHOES_PLATE_KEEPER@1": "plate_shoes",
    "T8_SHOES_PLATE_KEEPER@2": "plate_shoes",
    "T8_SHOES_PLATE_KEEPER@3": "plate_shoes",
    "T4_HEAD_PLATE_AVALON": "plate_helmet",
    "T4_HEAD_PLATE_AVALON@1": "plate_helmet",
    "T4_HEAD_PLATE_AVALON@2": "plate_helmet",
    "T4_HEAD_PLATE_AVALON@3": "plate_helmet",
    "T5_HEAD_PLATE_AVALON": "plate_helmet",
    "T5_HEAD_PLATE_AVALON@1": "plate_helmet",
    "T5_HEAD_PLATE_AVALON@2": "plate_helmet",
    "T5_HEAD_PLATE_AVALON@3": "plate_helmet",
    "T6_HEAD_PLATE_AVALON": "plate_helmet",
    "T6_HEAD_PLATE_AVALON@1": "plate_helmet",
    "T6_HEAD_PLATE_AVALON@2": "plate_helmet",
    "T6_HEAD_PLATE_AVALON@3": "plate_helmet",
    "T7_HEAD_PLATE_AVALON": "plate_helmet",
    "T7_HEAD_PLATE_AVALON@1": "plate_helmet",
    "T7_HEAD_PLATE_AVALON@2": "plate_helmet",
    "T7_HEAD_PLATE_AVALON@3": "plate_helmet",
    "T8_HEAD_PLATE_AVALON": "plate_helmet",
    "T8_HEAD_PLATE_AVALON@1": "plate_helmet",
    "T8_HEAD_PLATE_AVALON@2": "plate_helmet",
    "T8_HEAD_PLATE_AVALON@3": "plate_helmet",
    "T4_ARMOR_PLATE_AVALON": "plate_armor",
    "T4_ARMOR_PLATE_AVALON@1": "plate_armor",
    "T4_ARMOR_PLATE_AVALON@2": "plate_armor",
    "T4_ARMOR_PLATE_AVALON@3": "plate_armor",
    "T5_ARMOR_PLATE_AVALON": "plate_armor",
    "T5_ARMOR_PLATE_AVALON@1": "plate_armor",
    "T5_ARMOR_PLATE_AVALON@2": "plate_armor",
    "T5_ARMOR_PLATE_AVALON@3": "plate_armor",
    "T6_ARMOR_PLATE_AVALON": "plate_armor",
    "T6_ARMOR_PLATE_AVALON@1": "plate_armor",
    "T6_ARMOR_PLATE_AVALON@2": "plate_armor",
    "T6_ARMOR_PLATE_AVALON@3": "plate_armor",
    "T7_ARMOR_PLATE_AVALON": "plate_armor",
    "T7_ARMOR_PLATE_AVALON@1": "plate_armor",
    "T7_ARMOR_PLATE_AVALON@2": "plate_armor",
    "T7_ARMOR_PLATE_AVALON@3": "plate_armor",
    "T8_ARMOR_PLATE_AVALON": "plate_armor",
    "T8_ARMOR_PLATE_AVALON@1": "plate_armor",
    "T8_ARMOR_PLATE_AVALON@2": "plate_armor",
    "T8_ARMOR_PLATE_AVALON@3": "plate_armor",
    "T4_SHOES_PLATE_AVALON": "plate_shoes",
    "T4_SHOES_PLATE_AVALON@1": "plate_shoes",
    "T4_SHOES_PLATE_AVALON@2": "plate_shoes",
    "T4_SHOES_PLATE_AVALON@3": "plate_shoes",
    "T5_SHOES_PLATE_AVALON": "plate_shoes",
    "T5_SHOES_PLATE_AVALON@1": "plate_shoes",
    "T5_SHOES_PLATE_AVALON@2": "plate_shoes",
    "T5_SHOES_PLATE_AVALON@3": "plate_shoes",
    "T6_SHOES_PLATE_AVALON": "plate_shoes",
    "T6_SHOES_PLATE_AVALON@1": "plate_shoes",
    "T6_SHOES_PLATE_AVALON@2": "plate_shoes",
    "T6_SHOES_PLATE_AVALON@3": "plate_shoes",
    "T7_SHOES_PLATE_AVALON": "plate_shoes",
    "T7_SHOES_PLATE_AVALON@1": "plate_shoes",
    "T7_SHOES_PLATE_AVALON@2": "plate_shoes",
    "T7_SHOES_PLATE_AVALON@3": "plate_shoes",
    "T8_SHOES_PLATE_AVALON": "plate_shoes",
    "T8_SHOES_PLATE_AVALON@1": "plate_shoes",
    "T8_SHOES_PLATE_AVALON@2": "plate_shoes",
    "T8_SHOES_PLATE_AVALON@3": "plate_shoes",
    "T2_HEAD_LEATHER_SET1": "leather_helmet",
    "T3_HEAD_LEATHER_SET1": "leather_helmet",
    "T4_HEAD_LEATHER_SET1": "leather_helmet",
    "T4_HEAD_LEATHER_SET1@1": "leather_helmet",
    "T4_HEAD_LEATHER_SET1@2": "leather_helmet",
    "T4_HEAD_LEATHER_SET1@3": "leather_helmet",
    "T5_HEAD_LEATHER_SET1": "leather_helmet",
    "T5_HEAD_LEATHER_SET1@1": "leather_helmet",
    "T5_HEAD_LEATHER_SET1@2": "leather_helmet",
    "T5_HEAD_LEATHER_SET1@3": "leather_helmet",
    "T6_HEAD_LEATHER_SET1": "leather_helmet",
    "T6_HEAD_LEATHER_SET1@1": "leather_helmet",
    "T6_HEAD_LEATHER_SET1@2": "leather_helmet",
    "T6_HEAD_LEATHER_SET1@3": "leather_helmet",
    "T7_HEAD_LEATHER_SET1": "leather_helmet",
    "T7_HEAD_LEATHER_SET1@1": "leather_helmet",
    "T7_HEAD_LEATHER_SET1@2": "leather_helmet",
    "T7_HEAD_LEATHER_SET1@3": "leather_helmet",
    "T8_HEAD_LEATHER_SET1": "leather_helmet",
    "T8_HEAD_LEATHER_SET1@1": "leather_helmet",
    "T8_HEAD_LEATHER_SET1@2": "leather_helmet",
    "T8_HEAD_LEATHER_SET1@3": "leather_helmet",
    "T2_ARMOR_LEATHER_SET1": "leather_armor",
    "T3_ARMOR_LEATHER_SET1": "leather_armor",
    "T4_ARMOR_LEATHER_SET1": "leather_armor",
    "T4_ARMOR_LEATHER_SET1@1": "leather_armor",
    "T4_ARMOR_LEATHER_SET1@2": "leather_armor",
    "T4_ARMOR_LEATHER_SET1@3": "leather_armor",
    "T5_ARMOR_LEATHER_SET1": "leather_armor",
    "T5_ARMOR_LEATHER_SET1@1": "leather_armor",
    "T5_ARMOR_LEATHER_SET1@2": "leather_armor",
    "T5_ARMOR_LEATHER_SET1@3": "leather_armor",
    "T6_ARMOR_LEATHER_SET1": "leather_armor",
    "T6_ARMOR_LEATHER_SET1@1": "leather_armor",
    "T6_ARMOR_LEATHER_SET1@2": "leather_armor",
    "T6_ARMOR_LEATHER_SET1@3": "leather_armor",
    "T7_ARMOR_LEATHER_SET1": "leather_armor",
    "T7_ARMOR_LEATHER_SET1@1": "leather_armor",
    "T7_ARMOR_LEATHER_SET1@2": "leather_armor",
    "T7_ARMOR_LEATHER_SET1@3": "leather_armor",
    "T8_ARMOR_LEATHER_SET1": "leather_armor",
    "T8_ARMOR_LEATHER_SET1@1": "leather_armor",
    "T8_ARMOR_LEATHER_SET1@2": "leather_armor",
    "T8_ARMOR_LEATHER_SET1@3": "leather_armor",
    "T2_SHOES_LEATHER_SET1": "leather_shoes",
    "T3_SHOES_LEATHER_SET1": "leather_shoes",
    "T4_SHOES_LEATHER_SET1": "leather_shoes",
    "T4_SHOES_LEATHER_SET1@1": "leather_shoes",
    "T4_SHOES_LEATHER_SET1@2": "leather_shoes",
    "T4_SHOES_LEATHER_SET1@3": "leather_shoes",
    "T5_SHOES_LEATHER_SET1": "leather_shoes",
    "T5_SHOES_LEATHER_SET1@1": "leather_shoes",
    "T5_SHOES_LEATHER_SET1@2": "leather_shoes",
    "T5_SHOES_LEATHER_SET1@3": "leather_shoes",
    "T6_SHOES_LEATHER_SET1": "leather_shoes",
    "T6_SHOES_LEATHER_SET1@1": "leather_shoes",
    "T6_SHOES_LEATHER_SET1@2": "leather_shoes",
    "T6_SHOES_LEATHER_SET1@3": "leather_shoes",
    "T7_SHOES_LEATHER_SET1": "leather_shoes",
    "T7_SHOES_LEATHER_SET1@1": "leather_shoes",
    "T7_SHOES_LEATHER_SET1@2": "leather_shoes",
    "T7_SHOES_LEATHER_SET1@3": "leather_shoes",
    "T8_SHOES_LEATHER_SET1": "leather_shoes",
    "T8_SHOES_LEATHER_SET1@1": "leather_shoes",
    "T8_SHOES_LEATHER_SET1@2": "leather_shoes",
    "T8_SHOES_LEATHER_SET1@3": "leather_shoes",
    "T4_HEAD_LEATHER_SET2": "leather_helmet",
    "T4_HEAD_LEATHER_SET2@1": "leather_helmet",
    "T4_HEAD_LEATHER_SET2@2": "leather_helmet",
    "T4_HEAD_LEATHER_SET2@3": "leather_helmet",
    "T5_HEAD_LEATHER_SET2": "leather_helmet",
    "T5_HEAD_LEATHER_SET2@1": "leather_helmet",
    "T5_HEAD_LEATHER_SET2@2": "leather_helmet",
    "T5_HEAD_LEATHER_SET2@3": "leather_helmet",
    "T6_HEAD_LEATHER_SET2": "leather_helmet",
    "T6_HEAD_LEATHER_SET2@1": "leather_helmet",
    "T6_HEAD_LEATHER_SET2@2": "leather_helmet",
    "T6_HEAD_LEATHER_SET2@3": "leather_helmet",
    "T7_HEAD_LEATHER_SET2": "leather_helmet",
    "T7_HEAD_LEATHER_SET2@1": "leather_helmet",
    "T7_HEAD_LEATHER_SET2@2": "leather_helmet",
    "T7_HEAD_LEATHER_SET2@3": "leather_helmet",
    "T8_HEAD_LEATHER_SET2": "leather_helmet",
    "T8_HEAD_LEATHER_SET2@1": "leather_helmet",
    "T8_HEAD_LEATHER_SET2@2": "leather_helmet",
    "T8_HEAD_LEATHER_SET2@3": "leather_helmet",
    "T4_ARMOR_LEATHER_SET2": "leather_armor",
    "T4_ARMOR_LEATHER_SET2@1": "leather_armor",
    "T4_ARMOR_LEATHER_SET2@2": "leather_armor",
    "T4_ARMOR_LEATHER_SET2@3": "leather_armor",
    "T5_ARMOR_LEATHER_SET2": "leather_armor",
    "T5_ARMOR_LEATHER_SET2@1": "leather_armor",
    "T5_ARMOR_LEATHER_SET2@2": "leather_armor",
    "T5_ARMOR_LEATHER_SET2@3": "leather_armor",
    "T6_ARMOR_LEATHER_SET2": "leather_armor",
    "T6_ARMOR_LEATHER_SET2@1": "leather_armor",
    "T6_ARMOR_LEATHER_SET2@2": "leather_armor",
    "T6_ARMOR_LEATHER_SET2@3": "leather_armor",
    "T7_ARMOR_LEATHER_SET2": "leather_armor",
    "T7_ARMOR_LEATHER_SET2@1": "leather_armor",
    "T7_ARMOR_LEATHER_SET2@2": "leather_armor",
    "T7_ARMOR_LEATHER_SET2@3": "leather_armor",
    "T8_ARMOR_LEATHER_SET2": "leather_armor",
    "T8_ARMOR_LEATHER_SET2@1": "leather_armor",
    "T8_ARMOR_LEATHER_SET2@2": "leather_armor",
    "T8_ARMOR_LEATHER_SET2@3": "leather_armor",
    "T4_SHOES_LEATHER_SET2": "leather_shoes",
    "T4_SHOES_LEATHER_SET2@1": "leather_shoes",
    "T4_SHOES_LEATHER_SET2@2": "leather_shoes",
    "T4_SHOES_LEATHER_SET2@3": "leather_shoes",
    "T5_SHOES_LEATHER_SET2": "leather_shoes",
    "T5_SHOES_LEATHER_SET2@1": "leather_shoes",
    "T5_SHOES_LEATHER_SET2@2": "leather_shoes",
    "T5_SHOES_LEATHER_SET2@3": "leather_shoes",
    "T6_SHOES_LEATHER_SET2": "leather_shoes",
    "T6_SHOES_LEATHER_SET2@1": "leather_shoes",
    "T6_SHOES_LEATHER_SET2@2": "leather_shoes",
    "T6_SHOES_LEATHER_SET2@3": "leather_shoes",
    "T7_SHOES_LEATHER_SET2": "leather_shoes",
    "T7_SHOES_LEATHER_SET2@1": "leather_shoes",
    "T7_SHOES_LEATHER_SET2@2": "leather_shoes",
    "T7_SHOES_LEATHER_SET2@3": "leather_shoes",
    "T8_SHOES_LEATHER_SET2": "leather_shoes",
    "T8_SHOES_LEATHER_SET2@1": "leather_shoes",
    "T8_SHOES_LEATHER_SET2@2": "leather_shoes",
    "T8_SHOES_LEATHER_SET2@3": "leather_shoes",
    "T4_HEAD_LEATHER_SET3": "leather_helmet",
    "T4_HEAD_LEATHER_SET3@1": "leather_helmet",
    "T4_HEAD_LEATHER_SET3@2": "leather_helmet",
    "T4_HEAD_LEATHER_SET3@3": "leather_helmet",
    "T5_HEAD_LEATHER_SET3": "leather_helmet",
    "T5_HEAD_LEATHER_SET3@1": "leather_helmet",
    "T5_HEAD_LEATHER_SET3@2": "leather_helmet",
    "T5_HEAD_LEATHER_SET3@3": "leather_helmet",
    "T6_HEAD_LEATHER_SET3": "leather_helmet",
    "T6_HEAD_LEATHER_SET3@1": "leather_helmet",
    "T6_HEAD_LEATHER_SET3@2": "leather_helmet",
    "T6_HEAD_LEATHER_SET3@3": "leather_helmet",
    "T7_HEAD_LEATHER_SET3": "leather_helmet",
    "T7_HEAD_LEATHER_SET3@1": "leather_helmet",
    "T7_HEAD_LEATHER_SET3@2": "leather_helmet",
    "T7_HEAD_LEATHER_SET3@3": "leather_helmet",
    "T8_HEAD_LEATHER_SET3": "leather_helmet",
    "T8_HEAD_LEATHER_SET3@1": "leather_helmet",
    "T8_HEAD_LEATHER_SET3@2": "leather_helmet",
    "T8_HEAD_LEATHER_SET3@3": "leather_helmet",
    "T4_ARMOR_LEATHER_SET3": "leather_armor",
    "T4_ARMOR_LEATHER_SET3@1": "leather_armor",
    "T4_ARMOR_LEATHER_SET3@2": "leather_armor",
    "T4_ARMOR_LEATHER_SET3@3": "leather_armor",
    "T5_ARMOR_LEATHER_SET3": "leather_armor",
    "T5_ARMOR_LEATHER_SET3@1": "leather_armor",
    "T5_ARMOR_LEATHER_SET3@2": "leather_armor",
    "T5_ARMOR_LEATHER_SET3@3": "leather_armor",
    "T6_ARMOR_LEATHER_SET3": "leather_armor",
    "T6_ARMOR_LEATHER_SET3@1": "leather_armor",
    "T6_ARMOR_LEATHER_SET3@2": "leather_armor",
    "T6_ARMOR_LEATHER_SET3@3": "leather_armor",
    "T7_ARMOR_LEATHER_SET3": "leather_armor",
    "T7_ARMOR_LEATHER_SET3@1": "leather_armor",
    "T7_ARMOR_LEATHER_SET3@2": "leather_armor",
    "T7_ARMOR_LEATHER_SET3@3": "leather_armor",
    "T8_ARMOR_LEATHER_SET3": "leather_armor",
    "T8_ARMOR_LEATHER_SET3@1": "leather_armor",
    "T8_ARMOR_LEATHER_SET3@2": "leather_armor",
    "T8_ARMOR_LEATHER_SET3@3": "leather_armor",
    "T4_SHOES_LEATHER_SET3": "leather_shoes",
    "T4_SHOES_LEATHER_SET3@1": "leather_shoes",
    "T4_SHOES_LEATHER_SET3@2": "leather_shoes",
    "T4_SHOES_LEATHER_SET3@3": "leather_shoes",
    "T5_SHOES_LEATHER_SET3": "leather_shoes",
    "T5_SHOES_LEATHER_SET3@1": "leather_shoes",
    "T5_SHOES_LEATHER_SET3@2": "leather_shoes",
    "T5_SHOES_LEATHER_SET3@3": "leather_shoes",
    "T6_SHOES_LEATHER_SET3": "leather_shoes",
    "T6_SHOES_LEATHER_SET3@1": "leather_shoes",
    "T6_SHOES_LEATHER_SET3@2": "leather_shoes",
    "T6_SHOES_LEATHER_SET3@3": "leather_shoes",
    "T7_SHOES_LEATHER_SET3": "leather_shoes",
    "T7_SHOES_LEATHER_SET3@1": "leather_shoes",
    "T7_SHOES_LEATHER_SET3@2": "leather_shoes",
    "T7_SHOES_LEATHER_SET3@3": "leather_shoes",
    "T8_SHOES_LEATHER_SET3": "leather_shoes",
    "T8_SHOES_LEATHER_SET3@1": "leather_shoes",
    "T8_SHOES_LEATHER_SET3@2": "leather_shoes",
    "T8_SHOES_LEATHER_SET3@3": "leather_shoes",
    "T4_HEAD_LEATHER_MORGANA": "leather_helmet",
    "T4_HEAD_LEATHER_MORGANA@1": "leather_helmet",
    "T4_HEAD_LEATHER_MORGANA@2": "leather_helmet",
    "T4_HEAD_LEATHER_MORGANA@3": "leather_helmet",
    "T5_HEAD_LEATHER_MORGANA": "leather_helmet",
    "T5_HEAD_LEATHER_MORGANA@1": "leather_helmet",
    "T5_HEAD_LEATHER_MORGANA@2": "leather_helmet",
    "T5_HEAD_LEATHER_MORGANA@3": "leather_helmet",
    "T6_HEAD_LEATHER_MORGANA": "leather_helmet",
    "T6_HEAD_LEATHER_MORGANA@1": "leather_helmet",
    "T6_HEAD_LEATHER_MORGANA@2": "leather_helmet",
    "T6_HEAD_LEATHER_MORGANA@3": "leather_helmet",
    "T7_HEAD_LEATHER_MORGANA": "leather_helmet",
    "T7_HEAD_LEATHER_MORGANA@1": "leather_helmet",
    "T7_HEAD_LEATHER_MORGANA@2": "leather_helmet",
    "T7_HEAD_LEATHER_MORGANA@3": "leather_helmet",
    "T8_HEAD_LEATHER_MORGANA": "leather_helmet",
    "T8_HEAD_LEATHER_MORGANA@1": "leather_helmet",
    "T8_HEAD_LEATHER_MORGANA@2": "leather_helmet",
    "T8_HEAD_LEATHER_MORGANA@3": "leather_helmet",
    "T4_ARMOR_LEATHER_MORGANA": "leather_armor",
    "T4_ARMOR_LEATHER_MORGANA@1": "leather_armor",
    "T4_ARMOR_LEATHER_MORGANA@2": "leather_armor",
    "T4_ARMOR_LEATHER_MORGANA@3": "leather_armor",
    "T5_ARMOR_LEATHER_MORGANA": "leather_armor",
    "T5_ARMOR_LEATHER_MORGANA@1": "leather_armor",
    "T5_ARMOR_LEATHER_MORGANA@2": "leather_armor",
    "T5_ARMOR_LEATHER_MORGANA@3": "leather_armor",
    "T6_ARMOR_LEATHER_MORGANA": "leather_armor",
    "T6_ARMOR_LEATHER_MORGANA@1": "leather_armor",
    "T6_ARMOR_LEATHER_MORGANA@2": "leather_armor",
    "T6_ARMOR_LEATHER_MORGANA@3": "leather_armor",
    "T7_ARMOR_LEATHER_MORGANA": "leather_armor",
    "T7_ARMOR_LEATHER_MORGANA@1": "leather_armor",
    "T7_ARMOR_LEATHER_MORGANA@2": "leather_armor",
    "T7_ARMOR_LEATHER_MORGANA@3": "leather_armor",
    "T8_ARMOR_LEATHER_MORGANA": "leather_armor",
    "T8_ARMOR_LEATHER_MORGANA@1": "leather_armor",
    "T8_ARMOR_LEATHER_MORGANA@2": "leather_armor",
    "T8_ARMOR_LEATHER_MORGANA@3": "leather_armor",
    "T4_SHOES_LEATHER_MORGANA": "leather_shoes",
    "T4_SHOES_LEATHER_MORGANA@1": "leather_shoes",
    "T4_SHOES_LEATHER_MORGANA@2": "leather_shoes",
    "T4_SHOES_LEATHER_MORGANA@3": "leather_shoes",
    "T5_SHOES_LEATHER_MORGANA": "leather_shoes",
    "T5_SHOES_LEATHER_MORGANA@1": "leather_shoes",
    "T5_SHOES_LEATHER_MORGANA@2": "leather_shoes",
    "T5_SHOES_LEATHER_MORGANA@3": "leather_shoes",
    "T6_SHOES_LEATHER_MORGANA": "leather_shoes",
    "T6_SHOES_LEATHER_MORGANA@1": "leather_shoes",
    "T6_SHOES_LEATHER_MORGANA@2": "leather_shoes",
    "T6_SHOES_LEATHER_MORGANA@3": "leather_shoes",
    "T7_SHOES_LEATHER_MORGANA": "leather_shoes",
    "T7_SHOES_LEATHER_MORGANA@1": "leather_shoes",
    "T7_SHOES_LEATHER_MORGANA@2": "leather_shoes",
    "T7_SHOES_LEATHER_MORGANA@3": "leather_shoes",
    "T8_SHOES_LEATHER_MORGANA": "leather_shoes",
    "T8_SHOES_LEATHER_MORGANA@1": "leather_shoes",
    "T8_SHOES_LEATHER_MORGANA@2": "leather_shoes",
    "T8_SHOES_LEATHER_MORGANA@3": "leather_shoes",
    "T4_HEAD_LEATHER_HELL": "leather_helmet",
    "T4_HEAD_LEATHER_HELL@1": "leather_helmet",
    "T4_HEAD_LEATHER_HELL@2": "leather_helmet",
    "T4_HEAD_LEATHER_HELL@3": "leather_helmet",
    "T5_HEAD_LEATHER_HELL": "leather_helmet",
    "T5_HEAD_LEATHER_HELL@1": "leather_helmet",
    "T5_HEAD_LEATHER_HELL@2": "leather_helmet",
    "T5_HEAD_LEATHER_HELL@3": "leather_helmet",
    "T6_HEAD_LEATHER_HELL": "leather_helmet",
    "T6_HEAD_LEATHER_HELL@1": "leather_helmet",
    "T6_HEAD_LEATHER_HELL@2": "leather_helmet",
    "T6_HEAD_LEATHER_HELL@3": "leather_helmet",
    "T7_HEAD_LEATHER_HELL": "leather_helmet",
    "T7_HEAD_LEATHER_HELL@1": "leather_helmet",
    "T7_HEAD_LEATHER_HELL@2": "leather_helmet",
    "T7_HEAD_LEATHER_HELL@3": "leather_helmet",
    "T8_HEAD_LEATHER_HELL": "leather_helmet",
    "T8_HEAD_LEATHER_HELL@1": "leather_helmet",
    "T8_HEAD_LEATHER_HELL@2": "leather_helmet",
    "T8_HEAD_LEATHER_HELL@3": "leather_helmet",
    "T4_ARMOR_LEATHER_HELL": "leather_armor",
    "T4_ARMOR_LEATHER_HELL@1": "leather_armor",
    "T4_ARMOR_LEATHER_HELL@2": "leather_armor",
    "T4_ARMOR_LEATHER_HELL@3": "leather_armor",
    "T5_ARMOR_LEATHER_HELL": "leather_armor",
    "T5_ARMOR_LEATHER_HELL@1": "leather_armor",
    "T5_ARMOR_LEATHER_HELL@2": "leather_armor",
    "T5_ARMOR_LEATHER_HELL@3": "leather_armor",
    "T6_ARMOR_LEATHER_HELL": "leather_armor",
    "T6_ARMOR_LEATHER_HELL@1": "leather_armor",
    "T6_ARMOR_LEATHER_HELL@2": "leather_armor",
    "T6_ARMOR_LEATHER_HELL@3": "leather_armor",
    "T7_ARMOR_LEATHER_HELL": "leather_armor",
    "T7_ARMOR_LEATHER_HELL@1": "leather_armor",
    "T7_ARMOR_LEATHER_HELL@2": "leather_armor",
    "T7_ARMOR_LEATHER_HELL@3": "leather_armor",
    "T8_ARMOR_LEATHER_HELL": "leather_armor",
    "T8_ARMOR_LEATHER_HELL@1": "leather_armor",
    "T8_ARMOR_LEATHER_HELL@2": "leather_armor",
    "T8_ARMOR_LEATHER_HELL@3": "leather_armor",
    "T4_SHOES_LEATHER_HELL": "leather_shoes",
    "T4_SHOES_LEATHER_HELL@1": "leather_shoes",
    "T4_SHOES_LEATHER_HELL@2": "leather_shoes",
    "T4_SHOES_LEATHER_HELL@3": "leather_shoes",
    "T5_SHOES_LEATHER_HELL": "leather_shoes",
    "T5_SHOES_LEATHER_HELL@1": "leather_shoes",
    "T5_SHOES_LEATHER_HELL@2": "leather_shoes",
    "T5_SHOES_LEATHER_HELL@3": "leather_shoes",
    "T6_SHOES_LEATHER_HELL": "leather_shoes",
    "T6_SHOES_LEATHER_HELL@1": "leather_shoes",
    "T6_SHOES_LEATHER_HELL@2": "leather_shoes",
    "T6_SHOES_LEATHER_HELL@3": "leather_shoes",
    "T7_SHOES_LEATHER_HELL": "leather_shoes",
    "T7_SHOES_LEATHER_HELL@1": "leather_shoes",
    "T7_SHOES_LEATHER_HELL@2": "leather_shoes",
    "T7_SHOES_LEATHER_HELL@3": "leather_shoes",
    "T8_SHOES_LEATHER_HELL": "leather_shoes",
    "T8_SHOES_LEATHER_HELL@1": "leather_shoes",
    "T8_SHOES_LEATHER_HELL@2": "leather_shoes",
    "T8_SHOES_LEATHER_HELL@3": "leather_shoes",
    "T4_HEAD_LEATHER_UNDEAD": "leather_helmet",
    "T4_HEAD_LEATHER_UNDEAD@1": "leather_helmet",
    "T4_HEAD_LEATHER_UNDEAD@2": "leather_helmet",
    "T4_HEAD_LEATHER_UNDEAD@3": "leather_helmet",
    "T5_HEAD_LEATHER_UNDEAD": "leather_helmet",
    "T5_HEAD_LEATHER_UNDEAD@1": "leather_helmet",
    "T5_HEAD_LEATHER_UNDEAD@2": "leather_helmet",
    "T5_HEAD_LEATHER_UNDEAD@3": "leather_helmet",
    "T6_HEAD_LEATHER_UNDEAD": "leather_helmet",
    "T6_HEAD_LEATHER_UNDEAD@1": "leather_helmet",
    "T6_HEAD_LEATHER_UNDEAD@2": "leather_helmet",
    "T6_HEAD_LEATHER_UNDEAD@3": "leather_helmet",
    "T7_HEAD_LEATHER_UNDEAD": "leather_helmet",
    "T7_HEAD_LEATHER_UNDEAD@1": "leather_helmet",
    "T7_HEAD_LEATHER_UNDEAD@2": "leather_helmet",
    "T7_HEAD_LEATHER_UNDEAD@3": "leather_helmet",
    "T8_HEAD_LEATHER_UNDEAD": "leather_helmet",
    "T8_HEAD_LEATHER_UNDEAD@1": "leather_helmet",
    "T8_HEAD_LEATHER_UNDEAD@2": "leather_helmet",
    "T8_HEAD_LEATHER_UNDEAD@3": "leather_helmet",
    "T4_ARMOR_LEATHER_UNDEAD": "leather_armor",
    "T4_ARMOR_LEATHER_UNDEAD@1": "leather_armor",
    "T4_ARMOR_LEATHER_UNDEAD@2": "leather_armor",
    "T4_ARMOR_LEATHER_UNDEAD@3": "leather_armor",
    "T5_ARMOR_LEATHER_UNDEAD": "leather_armor",
    "T5_ARMOR_LEATHER_UNDEAD@1": "leather_armor",
    "T5_ARMOR_LEATHER_UNDEAD@2": "leather_armor",
    "T5_ARMOR_LEATHER_UNDEAD@3": "leather_armor",
    "T6_ARMOR_LEATHER_UNDEAD": "leather_armor",
    "T6_ARMOR_LEATHER_UNDEAD@1": "leather_armor",
    "T6_ARMOR_LEATHER_UNDEAD@2": "leather_armor",
    "T6_ARMOR_LEATHER_UNDEAD@3": "leather_armor",
    "T7_ARMOR_LEATHER_UNDEAD": "leather_armor",
    "T7_ARMOR_LEATHER_UNDEAD@1": "leather_armor",
    "T7_ARMOR_LEATHER_UNDEAD@2": "leather_armor",
    "T7_ARMOR_LEATHER_UNDEAD@3": "leather_armor",
    "T8_ARMOR_LEATHER_UNDEAD": "leather_armor",
    "T8_ARMOR_LEATHER_UNDEAD@1": "leather_armor",
    "T8_ARMOR_LEATHER_UNDEAD@2": "leather_armor",
    "T8_ARMOR_LEATHER_UNDEAD@3": "leather_armor",
    "T4_SHOES_LEATHER_UNDEAD": "leather_shoes",
    "T4_SHOES_LEATHER_UNDEAD@1": "leather_shoes",
    "T4_SHOES_LEATHER_UNDEAD@2": "leather_shoes",
    "T4_SHOES_LEATHER_UNDEAD@3": "leather_shoes",
    "T5_SHOES_LEATHER_UNDEAD": "leather_shoes",
    "T5_SHOES_LEATHER_UNDEAD@1": "leather_shoes",
    "T5_SHOES_LEATHER_UNDEAD@2": "leather_shoes",
    "T5_SHOES_LEATHER_UNDEAD@3": "leather_shoes",
    "T6_SHOES_LEATHER_UNDEAD": "leather_shoes",
    "T6_SHOES_LEATHER_UNDEAD@1": "leather_shoes",
    "T6_SHOES_LEATHER_UNDEAD@2": "leather_shoes",
    "T6_SHOES_LEATHER_UNDEAD@3": "leather_shoes",
    "T7_SHOES_LEATHER_UNDEAD": "leather_shoes",
    "T7_SHOES_LEATHER_UNDEAD@1": "leather_shoes",
    "T7_SHOES_LEATHER_UNDEAD@2": "leather_shoes",
    "T7_SHOES_LEATHER_UNDEAD@3": "leather_shoes",
    "T8_SHOES_LEATHER_UNDEAD": "leather_shoes",
    "T8_SHOES_LEATHER_UNDEAD@1": "leather_shoes",
    "T8_SHOES_LEATHER_UNDEAD@2": "leather_shoes",
    "T8_SHOES_LEATHER_UNDEAD@3": "leather_shoes",
    "T4_HEAD_LEATHER_AVALON": "leather_helmet",
    "T4_HEAD_LEATHER_AVALON@1": "leather_helmet",
    "T4_HEAD_LEATHER_AVALON@2": "leather_helmet",
    "T4_HEAD_LEATHER_AVALON@3": "leather_helmet",
    "T5_HEAD_LEATHER_AVALON": "leather_helmet",
    "T5_HEAD_LEATHER_AVALON@1": "leather_helmet",
    "T5_HEAD_LEATHER_AVALON@2": "leather_helmet",
    "T5_HEAD_LEATHER_AVALON@3": "leather_helmet",
    "T6_HEAD_LEATHER_AVALON": "leather_helmet",
    "T6_HEAD_LEATHER_AVALON@1": "leather_helmet",
    "T6_HEAD_LEATHER_AVALON@2": "leather_helmet",
    "T6_HEAD_LEATHER_AVALON@3": "leather_helmet",
    "T7_HEAD_LEATHER_AVALON": "leather_helmet",
    "T7_HEAD_LEATHER_AVALON@1": "leather_helmet",
    "T7_HEAD_LEATHER_AVALON@2": "leather_helmet",
    "T7_HEAD_LEATHER_AVALON@3": "leather_helmet",
    "T8_HEAD_LEATHER_AVALON": "leather_helmet",
    "T8_HEAD_LEATHER_AVALON@1": "leather_helmet",
    "T8_HEAD_LEATHER_AVALON@2": "leather_helmet",
    "T8_HEAD_LEATHER_AVALON@3": "leather_helmet",
    "T4_ARMOR_LEATHER_AVALON": "leather_armor",
    "T4_ARMOR_LEATHER_AVALON@1": "leather_armor",
    "T4_ARMOR_LEATHER_AVALON@2": "leather_armor",
    "T4_ARMOR_LEATHER_AVALON@3": "leather_armor",
    "T5_ARMOR_LEATHER_AVALON": "leather_armor",
    "T5_ARMOR_LEATHER_AVALON@1": "leather_armor",
    "T5_ARMOR_LEATHER_AVALON@2": "leather_armor",
    "T5_ARMOR_LEATHER_AVALON@3": "leather_armor",
    "T6_ARMOR_LEATHER_AVALON": "leather_armor",
    "T6_ARMOR_LEATHER_AVALON@1": "leather_armor",
    "T6_ARMOR_LEATHER_AVALON@2": "leather_armor",
    "T6_ARMOR_LEATHER_AVALON@3": "leather_armor",
    "T7_ARMOR_LEATHER_AVALON": "leather_armor",
    "T7_ARMOR_LEATHER_AVALON@1": "leather_armor",
    "T7_ARMOR_LEATHER_AVALON@2": "leather_armor",
    "T7_ARMOR_LEATHER_AVALON@3": "leather_armor",
    "T8_ARMOR_LEATHER_AVALON": "leather_armor",
    "T8_ARMOR_LEATHER_AVALON@1": "leather_armor",
    "T8_ARMOR_LEATHER_AVALON@2": "leather_armor",
    "T8_ARMOR_LEATHER_AVALON@3": "leather_armor",
    "T4_SHOES_LEATHER_AVALON": "leather_shoes",
    "T4_SHOES_LEATHER_AVALON@1": "leather_shoes",
    "T4_SHOES_LEATHER_AVALON@2": "leather_shoes",
    "T4_SHOES_LEATHER_AVALON@3": "leather_shoes",
    "T5_SHOES_LEATHER_AVALON": "leather_shoes",
    "T5_SHOES_LEATHER_AVALON@1": "leather_shoes",
    "T5_SHOES_LEATHER_AVALON@2": "leather_shoes",
    "T5_SHOES_LEATHER_AVALON@3": "leather_shoes",
    "T6_SHOES_LEATHER_AVALON": "leather_shoes",
    "T6_SHOES_LEATHER_AVALON@1": "leather_shoes",
    "T6_SHOES_LEATHER_AVALON@2": "leather_shoes",
    "T6_SHOES_LEATHER_AVALON@3": "leather_shoes",
    "T7_SHOES_LEATHER_AVALON": "leather_shoes",
    "T7_SHOES_LEATHER_AVALON@1": "leather_shoes",
    "T7_SHOES_LEATHER_AVALON@2": "leather_shoes",
    "T7_SHOES_LEATHER_AVALON@3": "leather_shoes",
    "T8_SHOES_LEATHER_AVALON": "leather_shoes",
    "T8_SHOES_LEATHER_AVALON@1": "leather_shoes",
    "T8_SHOES_LEATHER_AVALON@2": "leather_shoes",
    "T8_SHOES_LEATHER_AVALON@3": "leather_shoes",
    "T2_HEAD_CLOTH_SET1": "cloth_helmet",
    "T3_HEAD_CLOTH_SET1": "cloth_helmet",
    "T4_HEAD_CLOTH_SET1": "cloth_helmet",
    "T4_HEAD_CLOTH_SET1@1": "cloth_helmet",
    "T4_HEAD_CLOTH_SET1@2": "cloth_helmet",
    "T4_HEAD_CLOTH_SET1@3": "cloth_helmet",
    "T5_HEAD_CLOTH_SET1": "cloth_helmet",
    "T5_HEAD_CLOTH_SET1@1": "cloth_helmet",
    "T5_HEAD_CLOTH_SET1@2": "cloth_helmet",
    "T5_HEAD_CLOTH_SET1@3": "cloth_helmet",
    "T6_HEAD_CLOTH_SET1": "cloth_helmet",
    "T6_HEAD_CLOTH_SET1@1": "cloth_helmet",
    "T6_HEAD_CLOTH_SET1@2": "cloth_helmet",
    "T6_HEAD_CLOTH_SET1@3": "cloth_helmet",
    "T7_HEAD_CLOTH_SET1": "cloth_helmet",
    "T7_HEAD_CLOTH_SET1@1": "cloth_helmet",
    "T7_HEAD_CLOTH_SET1@2": "cloth_helmet",
    "T7_HEAD_CLOTH_SET1@3": "cloth_helmet",
    "T8_HEAD_CLOTH_SET1": "cloth_helmet",
    "T8_HEAD_CLOTH_SET1@1": "cloth_helmet",
    "T8_HEAD_CLOTH_SET1@2": "cloth_helmet",
    "T8_HEAD_CLOTH_SET1@3": "cloth_helmet",
    "T2_ARMOR_CLOTH_SET1": "cloth_armor",
    "T3_ARMOR_CLOTH_SET1": "cloth_armor",
    "T4_ARMOR_CLOTH_SET1": "cloth_armor",
    "T4_ARMOR_CLOTH_SET1@1": "cloth_armor",
    "T4_ARMOR_CLOTH_SET1@2": "cloth_armor",
    "T4_ARMOR_CLOTH_SET1@3": "cloth_armor",
    "T5_ARMOR_CLOTH_SET1": "cloth_armor",
    "T5_ARMOR_CLOTH_SET1@1": "cloth_armor",
    "T5_ARMOR_CLOTH_SET1@2": "cloth_armor",
    "T5_ARMOR_CLOTH_SET1@3": "cloth_armor",
    "T6_ARMOR_CLOTH_SET1": "cloth_armor",
    "T6_ARMOR_CLOTH_SET1@1": "cloth_armor",
    "T6_ARMOR_CLOTH_SET1@2": "cloth_armor",
    "T6_ARMOR_CLOTH_SET1@3": "cloth_armor",
    "T7_ARMOR_CLOTH_SET1": "cloth_armor",
    "T7_ARMOR_CLOTH_SET1@1": "cloth_armor",
    "T7_ARMOR_CLOTH_SET1@2": "cloth_armor",
    "T7_ARMOR_CLOTH_SET1@3": "cloth_armor",
    "T8_ARMOR_CLOTH_SET1": "cloth_armor",
    "T8_ARMOR_CLOTH_SET1@1": "cloth_armor",
    "T8_ARMOR_CLOTH_SET1@2": "cloth_armor",
    "T8_ARMOR_CLOTH_SET1@3": "cloth_armor",
    "T2_SHOES_CLOTH_SET1": "cloth_shoes",
    "T3_SHOES_CLOTH_SET1": "cloth_shoes",
    "T4_SHOES_CLOTH_SET1": "cloth_shoes",
    "T4_SHOES_CLOTH_SET1@1": "cloth_shoes",
    "T4_SHOES_CLOTH_SET1@2": "cloth_shoes",
    "T4_SHOES_CLOTH_SET1@3": "cloth_shoes",
    "T5_SHOES_CLOTH_SET1": "cloth_shoes",
    "T5_SHOES_CLOTH_SET1@1": "cloth_shoes",
    "T5_SHOES_CLOTH_SET1@2": "cloth_shoes",
    "T5_SHOES_CLOTH_SET1@3": "cloth_shoes",
    "T6_SHOES_CLOTH_SET1": "cloth_shoes",
    "T6_SHOES_CLOTH_SET1@1": "cloth_shoes",
    "T6_SHOES_CLOTH_SET1@2": "cloth_shoes",
    "T6_SHOES_CLOTH_SET1@3": "cloth_shoes",
    "T7_SHOES_CLOTH_SET1": "cloth_shoes",
    "T7_SHOES_CLOTH_SET1@1": "cloth_shoes",
    "T7_SHOES_CLOTH_SET1@2": "cloth_shoes",
    "T7_SHOES_CLOTH_SET1@3": "cloth_shoes",
    "T8_SHOES_CLOTH_SET1": "cloth_shoes",
    "T8_SHOES_CLOTH_SET1@1": "cloth_shoes",
    "T8_SHOES_CLOTH_SET1@2": "cloth_shoes",
    "T8_SHOES_CLOTH_SET1@3": "cloth_shoes",
    "T4_HEAD_CLOTH_SET2": "cloth_helmet",
    "T4_HEAD_CLOTH_SET2@1": "cloth_helmet",
    "T4_HEAD_CLOTH_SET2@2": "cloth_helmet",
    "T4_HEAD_CLOTH_SET2@3": "cloth_helmet",
    "T5_HEAD_CLOTH_SET2": "cloth_helmet",
    "T5_HEAD_CLOTH_SET2@1": "cloth_helmet",
    "T5_HEAD_CLOTH_SET2@2": "cloth_helmet",
    "T5_HEAD_CLOTH_SET2@3": "cloth_helmet",
    "T6_HEAD_CLOTH_SET2": "cloth_helmet",
    "T6_HEAD_CLOTH_SET2@1": "cloth_helmet",
    "T6_HEAD_CLOTH_SET2@2": "cloth_helmet",
    "T6_HEAD_CLOTH_SET2@3": "cloth_helmet",
    "T7_HEAD_CLOTH_SET2": "cloth_helmet",
    "T7_HEAD_CLOTH_SET2@1": "cloth_helmet",
    "T7_HEAD_CLOTH_SET2@2": "cloth_helmet",
    "T7_HEAD_CLOTH_SET2@3": "cloth_helmet",
    "T8_HEAD_CLOTH_SET2": "cloth_helmet",
    "T8_HEAD_CLOTH_SET2@1": "cloth_helmet",
    "T8_HEAD_CLOTH_SET2@2": "cloth_helmet",
    "T8_HEAD_CLOTH_SET2@3": "cloth_helmet",
    "T4_ARMOR_CLOTH_SET2": "cloth_armor",
    "T4_ARMOR_CLOTH_SET2@1": "cloth_armor",
    "T4_ARMOR_CLOTH_SET2@2": "cloth_armor",
    "T4_ARMOR_CLOTH_SET2@3": "cloth_armor",
    "T5_ARMOR_CLOTH_SET2": "cloth_armor",
    "T5_ARMOR_CLOTH_SET2@1": "cloth_armor",
    "T5_ARMOR_CLOTH_SET2@2": "cloth_armor",
    "T5_ARMOR_CLOTH_SET2@3": "cloth_armor",
    "T6_ARMOR_CLOTH_SET2": "cloth_armor",
    "T6_ARMOR_CLOTH_SET2@1": "cloth_armor",
    "T6_ARMOR_CLOTH_SET2@2": "cloth_armor",
    "T6_ARMOR_CLOTH_SET2@3": "cloth_armor",
    "T7_ARMOR_CLOTH_SET2": "cloth_armor",
    "T7_ARMOR_CLOTH_SET2@1": "cloth_armor",
    "T7_ARMOR_CLOTH_SET2@2": "cloth_armor",
    "T7_ARMOR_CLOTH_SET2@3": "cloth_armor",
    "T8_ARMOR_CLOTH_SET2": "cloth_armor",
    "T8_ARMOR_CLOTH_SET2@1": "cloth_armor",
    "T8_ARMOR_CLOTH_SET2@2": "cloth_armor",
    "T8_ARMOR_CLOTH_SET2@3": "cloth_armor",
    "T4_SHOES_CLOTH_SET2": "cloth_shoes",
    "T4_SHOES_CLOTH_SET2@1": "cloth_shoes",
    "T4_SHOES_CLOTH_SET2@2": "cloth_shoes",
    "T4_SHOES_CLOTH_SET2@3": "cloth_shoes",
    "T5_SHOES_CLOTH_SET2": "cloth_shoes",
    "T5_SHOES_CLOTH_SET2@1": "cloth_shoes",
    "T5_SHOES_CLOTH_SET2@2": "cloth_shoes",
    "T5_SHOES_CLOTH_SET2@3": "cloth_shoes",
    "T6_SHOES_CLOTH_SET2": "cloth_shoes",
    "T6_SHOES_CLOTH_SET2@1": "cloth_shoes",
    "T6_SHOES_CLOTH_SET2@2": "cloth_shoes",
    "T6_SHOES_CLOTH_SET2@3": "cloth_shoes",
    "T7_SHOES_CLOTH_SET2": "cloth_shoes",
    "T7_SHOES_CLOTH_SET2@1": "cloth_shoes",
    "T7_SHOES_CLOTH_SET2@2": "cloth_shoes",
    "T7_SHOES_CLOTH_SET2@3": "cloth_shoes",
    "T8_SHOES_CLOTH_SET2": "cloth_shoes",
    "T8_SHOES_CLOTH_SET2@1": "cloth_shoes",
    "T8_SHOES_CLOTH_SET2@2": "cloth_shoes",
    "T8_SHOES_CLOTH_SET2@3": "cloth_shoes",
    "T4_HEAD_CLOTH_SET3": "cloth_helmet",
    "T4_HEAD_CLOTH_SET3@1": "cloth_helmet",
    "T4_HEAD_CLOTH_SET3@2": "cloth_helmet",
    "T4_HEAD_CLOTH_SET3@3": "cloth_helmet",
    "T5_HEAD_CLOTH_SET3": "cloth_helmet",
    "T5_HEAD_CLOTH_SET3@1": "cloth_helmet",
    "T5_HEAD_CLOTH_SET3@2": "cloth_helmet",
    "T5_HEAD_CLOTH_SET3@3": "cloth_helmet",
    "T6_HEAD_CLOTH_SET3": "cloth_helmet",
    "T6_HEAD_CLOTH_SET3@1": "cloth_helmet",
    "T6_HEAD_CLOTH_SET3@2": "cloth_helmet",
    "T6_HEAD_CLOTH_SET3@3": "cloth_helmet",
    "T7_HEAD_CLOTH_SET3": "cloth_helmet",
    "T7_HEAD_CLOTH_SET3@1": "cloth_helmet",
    "T7_HEAD_CLOTH_SET3@2": "cloth_helmet",
    "T7_HEAD_CLOTH_SET3@3": "cloth_helmet",
    "T8_HEAD_CLOTH_SET3": "cloth_helmet",
    "T8_HEAD_CLOTH_SET3@1": "cloth_helmet",
    "T8_HEAD_CLOTH_SET3@2": "cloth_helmet",
    "T8_HEAD_CLOTH_SET3@3": "cloth_helmet",
    "T4_ARMOR_CLOTH_SET3": "cloth_armor",
    "T4_ARMOR_CLOTH_SET3@1": "cloth_armor",
    "T4_ARMOR_CLOTH_SET3@2": "cloth_armor",
    "T4_ARMOR_CLOTH_SET3@3": "cloth_armor",
    "T5_ARMOR_CLOTH_SET3": "cloth_armor",
    "T5_ARMOR_CLOTH_SET3@1": "cloth_armor",
    "T5_ARMOR_CLOTH_SET3@2": "cloth_armor",
    "T5_ARMOR_CLOTH_SET3@3": "cloth_armor",
    "T6_ARMOR_CLOTH_SET3": "cloth_armor",
    "T6_ARMOR_CLOTH_SET3@1": "cloth_armor",
    "T6_ARMOR_CLOTH_SET3@2": "cloth_armor",
    "T6_ARMOR_CLOTH_SET3@3": "cloth_armor",
    "T7_ARMOR_CLOTH_SET3": "cloth_armor",
    "T7_ARMOR_CLOTH_SET3@1": "cloth_armor",
    "T7_ARMOR_CLOTH_SET3@2": "cloth_armor",
    "T7_ARMOR_CLOTH_SET3@3": "cloth_armor",
    "T8_ARMOR_CLOTH_SET3": "cloth_armor",
    "T8_ARMOR_CLOTH_SET3@1": "cloth_armor",
    "T8_ARMOR_CLOTH_SET3@2": "cloth_armor",
    "T8_ARMOR_CLOTH_SET3@3": "cloth_armor",
    "T4_SHOES_CLOTH_SET3": "cloth_shoes",
    "T4_SHOES_CLOTH_SET3@1": "cloth_shoes",
    "T4_SHOES_CLOTH_SET3@2": "cloth_shoes",
    "T4_SHOES_CLOTH_SET3@3": "cloth_shoes",
    "T5_SHOES_CLOTH_SET3": "cloth_shoes",
    "T5_SHOES_CLOTH_SET3@1": "cloth_shoes",
    "T5_SHOES_CLOTH_SET3@2": "cloth_shoes",
    "T5_SHOES_CLOTH_SET3@3": "cloth_shoes",
    "T6_SHOES_CLOTH_SET3": "cloth_shoes",
    "T6_SHOES_CLOTH_SET3@1": "cloth_shoes",
    "T6_SHOES_CLOTH_SET3@2": "cloth_shoes",
    "T6_SHOES_CLOTH_SET3@3": "cloth_shoes",
    "T7_SHOES_CLOTH_SET3": "cloth_shoes",
    "T7_SHOES_CLOTH_SET3@1": "cloth_shoes",
    "T7_SHOES_CLOTH_SET3@2": "cloth_shoes",
    "T7_SHOES_CLOTH_SET3@3": "cloth_shoes",
    "T8_SHOES_CLOTH_SET3": "cloth_shoes",
    "T8_SHOES_CLOTH_SET3@1": "cloth_shoes",
    "T8_SHOES_CLOTH_SET3@2": "cloth_shoes",
    "T8_SHOES_CLOTH_SET3@3": "cloth_shoes",
    "T4_HEAD_CLOTH_KEEPER": "cloth_helmet",
    "T4_HEAD_CLOTH_KEEPER@1": "cloth_helmet",
    "T4_HEAD_CLOTH_KEEPER@2": "cloth_helmet",
    "T4_HEAD_CLOTH_KEEPER@3": "cloth_helmet",
    "T5_HEAD_CLOTH_KEEPER": "cloth_helmet",
    "T5_HEAD_CLOTH_KEEPER@1": "cloth_helmet",
    "T5_HEAD_CLOTH_KEEPER@2": "cloth_helmet",
    "T5_HEAD_CLOTH_KEEPER@3": "cloth_helmet",
    "T6_HEAD_CLOTH_KEEPER": "cloth_helmet",
    "T6_HEAD_CLOTH_KEEPER@1": "cloth_helmet",
    "T6_HEAD_CLOTH_KEEPER@2": "cloth_helmet",
    "T6_HEAD_CLOTH_KEEPER@3": "cloth_helmet",
    "T7_HEAD_CLOTH_KEEPER": "cloth_helmet",
    "T7_HEAD_CLOTH_KEEPER@1": "cloth_helmet",
    "T7_HEAD_CLOTH_KEEPER@2": "cloth_helmet",
    "T7_HEAD_CLOTH_KEEPER@3": "cloth_helmet",
    "T8_HEAD_CLOTH_KEEPER": "cloth_helmet",
    "T8_HEAD_CLOTH_KEEPER@1": "cloth_helmet",
    "T8_HEAD_CLOTH_KEEPER@2": "cloth_helmet",
    "T8_HEAD_CLOTH_KEEPER@3": "cloth_helmet",
    "T4_ARMOR_CLOTH_KEEPER": "cloth_armor",
    "T4_ARMOR_CLOTH_KEEPER@1": "cloth_armor",
    "T4_ARMOR_CLOTH_KEEPER@2": "cloth_armor",
    "T4_ARMOR_CLOTH_KEEPER@3": "cloth_armor",
    "T5_ARMOR_CLOTH_KEEPER": "cloth_armor",
    "T5_ARMOR_CLOTH_KEEPER@1": "cloth_armor",
    "T5_ARMOR_CLOTH_KEEPER@2": "cloth_armor",
    "T5_ARMOR_CLOTH_KEEPER@3": "cloth_armor",
    "T6_ARMOR_CLOTH_KEEPER": "cloth_armor",
    "T6_ARMOR_CLOTH_KEEPER@1": "cloth_armor",
    "T6_ARMOR_CLOTH_KEEPER@2": "cloth_armor",
    "T6_ARMOR_CLOTH_KEEPER@3": "cloth_armor",
    "T7_ARMOR_CLOTH_KEEPER": "cloth_armor",
    "T7_ARMOR_CLOTH_KEEPER@1": "cloth_armor",
    "T7_ARMOR_CLOTH_KEEPER@2": "cloth_armor",
    "T7_ARMOR_CLOTH_KEEPER@3": "cloth_armor",
    "T8_ARMOR_CLOTH_KEEPER": "cloth_armor",
    "T8_ARMOR_CLOTH_KEEPER@1": "cloth_armor",
    "T8_ARMOR_CLOTH_KEEPER@2": "cloth_armor",
    "T8_ARMOR_CLOTH_KEEPER@3": "cloth_armor",
    "T4_SHOES_CLOTH_KEEPER": "cloth_shoes",
    "T4_SHOES_CLOTH_KEEPER@1": "cloth_shoes",
    "T4_SHOES_CLOTH_KEEPER@2": "cloth_shoes",
    "T4_SHOES_CLOTH_KEEPER@3": "cloth_shoes",
    "T5_SHOES_CLOTH_KEEPER": "cloth_shoes",
    "T5_SHOES_CLOTH_KEEPER@1": "cloth_shoes",
    "T5_SHOES_CLOTH_KEEPER@2": "cloth_shoes",
    "T5_SHOES_CLOTH_KEEPER@3": "cloth_shoes",
    "T6_SHOES_CLOTH_KEEPER": "cloth_shoes",
    "T6_SHOES_CLOTH_KEEPER@1": "cloth_shoes",
    "T6_SHOES_CLOTH_KEEPER@2": "cloth_shoes",
    "T6_SHOES_CLOTH_KEEPER@3": "cloth_shoes",
    "T7_SHOES_CLOTH_KEEPER": "cloth_shoes",
    "T7_SHOES_CLOTH_KEEPER@1": "cloth_shoes",
    "T7_SHOES_CLOTH_KEEPER@2": "cloth_shoes",
    "T7_SHOES_CLOTH_KEEPER@3": "cloth_shoes",
    "T8_SHOES_CLOTH_KEEPER": "cloth_shoes",
    "T8_SHOES_CLOTH_KEEPER@1": "cloth_shoes",
    "T8_SHOES_CLOTH_KEEPER@2": "cloth_shoes",
    "T8_SHOES_CLOTH_KEEPER@3": "cloth_shoes",
    "T4_HEAD_CLOTH_HELL": "cloth_helmet",
    "T4_HEAD_CLOTH_HELL@1": "cloth_helmet",
    "T4_HEAD_CLOTH_HELL@2": "cloth_helmet",
    "T4_HEAD_CLOTH_HELL@3": "cloth_helmet",
    "T5_HEAD_CLOTH_HELL": "cloth_helmet",
    "T5_HEAD_CLOTH_HELL@1": "cloth_helmet",
    "T5_HEAD_CLOTH_HELL@2": "cloth_helmet",
    "T5_HEAD_CLOTH_HELL@3": "cloth_helmet",
    "T6_HEAD_CLOTH_HELL": "cloth_helmet",
    "T6_HEAD_CLOTH_HELL@1": "cloth_helmet",
    "T6_HEAD_CLOTH_HELL@2": "cloth_helmet",
    "T6_HEAD_CLOTH_HELL@3": "cloth_helmet",
    "T7_HEAD_CLOTH_HELL": "cloth_helmet",
    "T7_HEAD_CLOTH_HELL@1": "cloth_helmet",
    "T7_HEAD_CLOTH_HELL@2": "cloth_helmet",
    "T7_HEAD_CLOTH_HELL@3": "cloth_helmet",
    "T8_HEAD_CLOTH_HELL": "cloth_helmet",
    "T8_HEAD_CLOTH_HELL@1": "cloth_helmet",
    "T8_HEAD_CLOTH_HELL@2": "cloth_helmet",
    "T8_HEAD_CLOTH_HELL@3": "cloth_helmet",
    "T4_ARMOR_CLOTH_HELL": "cloth_armor",
    "T4_ARMOR_CLOTH_HELL@1": "cloth_armor",
    "T4_ARMOR_CLOTH_HELL@2": "cloth_armor",
    "T4_ARMOR_CLOTH_HELL@3": "cloth_armor",
    "T5_ARMOR_CLOTH_HELL": "cloth_armor",
    "T5_ARMOR_CLOTH_HELL@1": "cloth_armor",
    "T5_ARMOR_CLOTH_HELL@2": "cloth_armor",
    "T5_ARMOR_CLOTH_HELL@3": "cloth_armor",
    "T6_ARMOR_CLOTH_HELL": "cloth_armor",
    "T6_ARMOR_CLOTH_HELL@1": "cloth_armor",
    "T6_ARMOR_CLOTH_HELL@2": "cloth_armor",
    "T6_ARMOR_CLOTH_HELL@3": "cloth_armor",
    "T7_ARMOR_CLOTH_HELL": "cloth_armor",
    "T7_ARMOR_CLOTH_HELL@1": "cloth_armor",
    "T7_ARMOR_CLOTH_HELL@2": "cloth_armor",
    "T7_ARMOR_CLOTH_HELL@3": "cloth_armor",
    "T8_ARMOR_CLOTH_HELL": "cloth_armor",
    "T8_ARMOR_CLOTH_HELL@1": "cloth_armor",
    "T8_ARMOR_CLOTH_HELL@2": "cloth_armor",
    "T8_ARMOR_CLOTH_HELL@3": "cloth_armor",
    "T4_SHOES_CLOTH_HELL": "cloth_shoes",
    "T4_SHOES_CLOTH_HELL@1": "cloth_shoes",
    "T4_SHOES_CLOTH_HELL@2": "cloth_shoes",
    "T4_SHOES_CLOTH_HELL@3": "cloth_shoes",
    "T5_SHOES_CLOTH_HELL": "cloth_shoes",
    "T5_SHOES_CLOTH_HELL@1": "cloth_shoes",
    "T5_SHOES_CLOTH_HELL@2": "cloth_shoes",
    "T5_SHOES_CLOTH_HELL@3": "cloth_shoes",
    "T6_SHOES_CLOTH_HELL": "cloth_shoes",
    "T6_SHOES_CLOTH_HELL@1": "cloth_shoes",
    "T6_SHOES_CLOTH_HELL@2": "cloth_shoes",
    "T6_SHOES_CLOTH_HELL@3": "cloth_shoes",
    "T7_SHOES_CLOTH_HELL": "cloth_shoes",
    "T7_SHOES_CLOTH_HELL@1": "cloth_shoes",
    "T7_SHOES_CLOTH_HELL@2": "cloth_shoes",
    "T7_SHOES_CLOTH_HELL@3": "cloth_shoes",
    "T8_SHOES_CLOTH_HELL": "cloth_shoes",
    "T8_SHOES_CLOTH_HELL@1": "cloth_shoes",
    "T8_SHOES_CLOTH_HELL@2": "cloth_shoes",
    "T8_SHOES_CLOTH_HELL@3": "cloth_shoes",
    "T4_HEAD_CLOTH_MORGANA": "cloth_helmet",
    "T4_HEAD_CLOTH_MORGANA@1": "cloth_helmet",
    "T4_HEAD_CLOTH_MORGANA@2": "cloth_helmet",
    "T4_HEAD_CLOTH_MORGANA@3": "cloth_helmet",
    "T5_HEAD_CLOTH_MORGANA": "cloth_helmet",
    "T5_HEAD_CLOTH_MORGANA@1": "cloth_helmet",
    "T5_HEAD_CLOTH_MORGANA@2": "cloth_helmet",
    "T5_HEAD_CLOTH_MORGANA@3": "cloth_helmet",
    "T6_HEAD_CLOTH_MORGANA": "cloth_helmet",
    "T6_HEAD_CLOTH_MORGANA@1": "cloth_helmet",
    "T6_HEAD_CLOTH_MORGANA@2": "cloth_helmet",
    "T6_HEAD_CLOTH_MORGANA@3": "cloth_helmet",
    "T7_HEAD_CLOTH_MORGANA": "cloth_helmet",
    "T7_HEAD_CLOTH_MORGANA@1": "cloth_helmet",
    "T7_HEAD_CLOTH_MORGANA@2": "cloth_helmet",
    "T7_HEAD_CLOTH_MORGANA@3": "cloth_helmet",
    "T8_HEAD_CLOTH_MORGANA": "cloth_helmet",
    "T8_HEAD_CLOTH_MORGANA@1": "cloth_helmet",
    "T8_HEAD_CLOTH_MORGANA@2": "cloth_helmet",
    "T8_HEAD_CLOTH_MORGANA@3": "cloth_helmet",
    "T4_ARMOR_CLOTH_MORGANA": "cloth_armor",
    "T4_ARMOR_CLOTH_MORGANA@1": "cloth_armor",
    "T4_ARMOR_CLOTH_MORGANA@2": "cloth_armor",
    "T4_ARMOR_CLOTH_MORGANA@3": "cloth_armor",
    "T5_ARMOR_CLOTH_MORGANA": "cloth_armor",
    "T5_ARMOR_CLOTH_MORGANA@1": "cloth_armor",
    "T5_ARMOR_CLOTH_MORGANA@2": "cloth_armor",
    "T5_ARMOR_CLOTH_MORGANA@3": "cloth_armor",
    "T6_ARMOR_CLOTH_MORGANA": "cloth_armor",
    "T6_ARMOR_CLOTH_MORGANA@1": "cloth_armor",
    "T6_ARMOR_CLOTH_MORGANA@2": "cloth_armor",
    "T6_ARMOR_CLOTH_MORGANA@3": "cloth_armor",
    "T7_ARMOR_CLOTH_MORGANA": "cloth_armor",
    "T7_ARMOR_CLOTH_MORGANA@1": "cloth_armor",
    "T7_ARMOR_CLOTH_MORGANA@2": "cloth_armor",
    "T7_ARMOR_CLOTH_MORGANA@3": "cloth_armor",
    "T8_ARMOR_CLOTH_MORGANA": "cloth_armor",
    "T8_ARMOR_CLOTH_MORGANA@1": "cloth_armor",
    "T8_ARMOR_CLOTH_MORGANA@2": "cloth_armor",
    "T8_ARMOR_CLOTH_MORGANA@3": "cloth_armor",
    "T4_SHOES_CLOTH_MORGANA": "cloth_shoes",
    "T4_SHOES_CLOTH_MORGANA@1": "cloth_shoes",
    "T4_SHOES_CLOTH_MORGANA@2": "cloth_shoes",
    "T4_SHOES_CLOTH_MORGANA@3": "cloth_shoes",
    "T5_SHOES_CLOTH_MORGANA": "cloth_shoes",
    "T5_SHOES_CLOTH_MORGANA@1": "cloth_shoes",
    "T5_SHOES_CLOTH_MORGANA@2": "cloth_shoes",
    "T5_SHOES_CLOTH_MORGANA@3": "cloth_shoes",
    "T6_SHOES_CLOTH_MORGANA": "cloth_shoes",
    "T6_SHOES_CLOTH_MORGANA@1": "cloth_shoes",
    "T6_SHOES_CLOTH_MORGANA@2": "cloth_shoes",
    "T6_SHOES_CLOTH_MORGANA@3": "cloth_shoes",
    "T7_SHOES_CLOTH_MORGANA": "cloth_shoes",
    "T7_SHOES_CLOTH_MORGANA@1": "cloth_shoes",
    "T7_SHOES_CLOTH_MORGANA@2": "cloth_shoes",
    "T7_SHOES_CLOTH_MORGANA@3": "cloth_shoes",
    "T8_SHOES_CLOTH_MORGANA": "cloth_shoes",
    "T8_SHOES_CLOTH_MORGANA@1": "cloth_shoes",
    "T8_SHOES_CLOTH_MORGANA@2": "cloth_shoes",
    "T8_SHOES_CLOTH_MORGANA@3": "cloth_shoes",
    "T4_HEAD_CLOTH_AVALON": "cloth_helmet",
    "T4_HEAD_CLOTH_AVALON@1": "cloth_helmet",
    "T4_HEAD_CLOTH_AVALON@2": "cloth_helmet",
    "T4_HEAD_CLOTH_AVALON@3": "cloth_helmet",
    "T5_HEAD_CLOTH_AVALON": "cloth_helmet",
    "T5_HEAD_CLOTH_AVALON@1": "cloth_helmet",
    "T5_HEAD_CLOTH_AVALON@2": "cloth_helmet",
    "T5_HEAD_CLOTH_AVALON@3": "cloth_helmet",
    "T6_HEAD_CLOTH_AVALON": "cloth_helmet",
    "T6_HEAD_CLOTH_AVALON@1": "cloth_helmet",
    "T6_HEAD_CLOTH_AVALON@2": "cloth_helmet",
    "T6_HEAD_CLOTH_AVALON@3": "cloth_helmet",
    "T7_HEAD_CLOTH_AVALON": "cloth_helmet",
    "T7_HEAD_CLOTH_AVALON@1": "cloth_helmet",
    "T7_HEAD_CLOTH_AVALON@2": "cloth_helmet",
    "T7_HEAD_CLOTH_AVALON@3": "cloth_helmet",
    "T8_HEAD_CLOTH_AVALON": "cloth_helmet",
    "T8_HEAD_CLOTH_AVALON@1": "cloth_helmet",
    "T8_HEAD_CLOTH_AVALON@2": "cloth_helmet",
    "T8_HEAD_CLOTH_AVALON@3": "cloth_helmet",
    "T4_ARMOR_CLOTH_AVALON": "cloth_armor",
    "T4_ARMOR_CLOTH_AVALON@1": "cloth_armor",
    "T4_ARMOR_CLOTH_AVALON@2": "cloth_armor",
    "T4_ARMOR_CLOTH_AVALON@3": "cloth_armor",
    "T5_ARMOR_CLOTH_AVALON": "cloth_armor",
    "T5_ARMOR_CLOTH_AVALON@1": "cloth_armor",
    "T5_ARMOR_CLOTH_AVALON@2": "cloth_armor",
    "T5_ARMOR_CLOTH_AVALON@3": "cloth_armor",
    "T6_ARMOR_CLOTH_AVALON": "cloth_armor",
    "T6_ARMOR_CLOTH_AVALON@1": "cloth_armor",
    "T6_ARMOR_CLOTH_AVALON@2": "cloth_armor",
    "T6_ARMOR_CLOTH_AVALON@3": "cloth_armor",
    "T7_ARMOR_CLOTH_AVALON": "cloth_armor",
    "T7_ARMOR_CLOTH_AVALON@1": "cloth_armor",
    "T7_ARMOR_CLOTH_AVALON@2": "cloth_armor",
    "T7_ARMOR_CLOTH_AVALON@3": "cloth_armor",
    "T8_ARMOR_CLOTH_AVALON": "cloth_armor",
    "T8_ARMOR_CLOTH_AVALON@1": "cloth_armor",
    "T8_ARMOR_CLOTH_AVALON@2": "cloth_armor",
    "T8_ARMOR_CLOTH_AVALON@3": "cloth_armor",
    "T4_SHOES_CLOTH_AVALON": "cloth_shoes",
    "T4_SHOES_CLOTH_AVALON@1": "cloth_shoes",
    "T4_SHOES_CLOTH_AVALON@2": "cloth_shoes",
    "T4_SHOES_CLOTH_AVALON@3": "cloth_shoes",
    "T5_SHOES_CLOTH_AVALON": "cloth_shoes",
    "T5_SHOES_CLOTH_AVALON@1": "cloth_shoes",
    "T5_SHOES_CLOTH_AVALON@2": "cloth_shoes",
    "T5_SHOES_CLOTH_AVALON@3": "cloth_shoes",
    "T6_SHOES_CLOTH_AVALON": "cloth_shoes",
    "T6_SHOES_CLOTH_AVALON@1": "cloth_shoes",
    "T6_SHOES_CLOTH_AVALON@2": "cloth_shoes",
    "T6_SHOES_CLOTH_AVALON@3": "cloth_shoes",
    "T7_SHOES_CLOTH_AVALON": "cloth_shoes",
    "T7_SHOES_CLOTH_AVALON@1": "cloth_shoes",
    "T7_SHOES_CLOTH_AVALON@2": "cloth_shoes",
    "T7_SHOES_CLOTH_AVALON@3": "cloth_shoes",
    "T8_SHOES_CLOTH_AVALON": "cloth_shoes",
    "T8_SHOES_CLOTH_AVALON@1": "cloth_shoes",
    "T8_SHOES_CLOTH_AVALON@2": "cloth_shoes",
    "T8_SHOES_CLOTH_AVALON@3": "cloth_shoes",
    "T4_HEAD_GATHERER_FIBER": "gatherergear",
    "T4_HEAD_GATHERER_FIBER@1": "gatherergear",
    "T4_HEAD_GATHERER_FIBER@2": "gatherergear",
    "T4_HEAD_GATHERER_FIBER@3": "gatherergear",
    "T5_HEAD_GATHERER_FIBER": "gatherergear",
    "T5_HEAD_GATHERER_FIBER@1": "gatherergear",
    "T5_HEAD_GATHERER_FIBER@2": "gatherergear",
    "T5_HEAD_GATHERER_FIBER@3": "gatherergear",
    "T6_HEAD_GATHERER_FIBER": "gatherergear",
    "T6_HEAD_GATHERER_FIBER@1": "gatherergear",
    "T6_HEAD_GATHERER_FIBER@2": "gatherergear",
    "T6_HEAD_GATHERER_FIBER@3": "gatherergear",
    "T7_HEAD_GATHERER_FIBER": "gatherergear",
    "T7_HEAD_GATHERER_FIBER@1": "gatherergear",
    "T7_HEAD_GATHERER_FIBER@2": "gatherergear",
    "T7_HEAD_GATHERER_FIBER@3": "gatherergear",
    "T8_HEAD_GATHERER_FIBER": "gatherergear",
    "T8_HEAD_GATHERER_FIBER@1": "gatherergear",
    "T8_HEAD_GATHERER_FIBER@2": "gatherergear",
    "T8_HEAD_GATHERER_FIBER@3": "gatherergear",
    "T4_ARMOR_GATHERER_FIBER": "gatherergear",
    "T4_ARMOR_GATHERER_FIBER@1": "gatherergear",
    "T4_ARMOR_GATHERER_FIBER@2": "gatherergear",
    "T4_ARMOR_GATHERER_FIBER@3": "gatherergear",
    "T5_ARMOR_GATHERER_FIBER": "gatherergear",
    "T5_ARMOR_GATHERER_FIBER@1": "gatherergear",
    "T5_ARMOR_GATHERER_FIBER@2": "gatherergear",
    "T5_ARMOR_GATHERER_FIBER@3": "gatherergear",
    "T6_ARMOR_GATHERER_FIBER": "gatherergear",
    "T6_ARMOR_GATHERER_FIBER@1": "gatherergear",
    "T6_ARMOR_GATHERER_FIBER@2": "gatherergear",
    "T6_ARMOR_GATHERER_FIBER@3": "gatherergear",
    "T7_ARMOR_GATHERER_FIBER": "gatherergear",
    "T7_ARMOR_GATHERER_FIBER@1": "gatherergear",
    "T7_ARMOR_GATHERER_FIBER@2": "gatherergear",
    "T7_ARMOR_GATHERER_FIBER@3": "gatherergear",
    "T8_ARMOR_GATHERER_FIBER": "gatherergear",
    "T8_ARMOR_GATHERER_FIBER@1": "gatherergear",
    "T8_ARMOR_GATHERER_FIBER@2": "gatherergear",
    "T8_ARMOR_GATHERER_FIBER@3": "gatherergear",
    "T4_SHOES_GATHERER_FIBER": "gatherergear",
    "T4_SHOES_GATHERER_FIBER@1": "gatherergear",
    "T4_SHOES_GATHERER_FIBER@2": "gatherergear",
    "T4_SHOES_GATHERER_FIBER@3": "gatherergear",
    "T5_SHOES_GATHERER_FIBER": "gatherergear",
    "T5_SHOES_GATHERER_FIBER@1": "gatherergear",
    "T5_SHOES_GATHERER_FIBER@2": "gatherergear",
    "T5_SHOES_GATHERER_FIBER@3": "gatherergear",
    "T6_SHOES_GATHERER_FIBER": "gatherergear",
    "T6_SHOES_GATHERER_FIBER@1": "gatherergear",
    "T6_SHOES_GATHERER_FIBER@2": "gatherergear",
    "T6_SHOES_GATHERER_FIBER@3": "gatherergear",
    "T7_SHOES_GATHERER_FIBER": "gatherergear",
    "T7_SHOES_GATHERER_FIBER@1": "gatherergear",
    "T7_SHOES_GATHERER_FIBER@2": "gatherergear",
    "T7_SHOES_GATHERER_FIBER@3": "gatherergear",
    "T8_SHOES_GATHERER_FIBER": "gatherergear",
    "T8_SHOES_GATHERER_FIBER@1": "gatherergear",
    "T8_SHOES_GATHERER_FIBER@2": "gatherergear",
    "T8_SHOES_GATHERER_FIBER@3": "gatherergear",
    "T4_BACKPACK_GATHERER_FIBER": "gatherergear",
    "T4_BACKPACK_GATHERER_FIBER@1": "gatherergear",
    "T4_BACKPACK_GATHERER_FIBER@2": "gatherergear",
    "T4_BACKPACK_GATHERER_FIBER@3": "gatherergear",
    "T5_BACKPACK_GATHERER_FIBER": "gatherergear",
    "T5_BACKPACK_GATHERER_FIBER@1": "gatherergear",
    "T5_BACKPACK_GATHERER_FIBER@2": "gatherergear",
    "T5_BACKPACK_GATHERER_FIBER@3": "gatherergear",
    "T6_BACKPACK_GATHERER_FIBER": "gatherergear",
    "T6_BACKPACK_GATHERER_FIBER@1": "gatherergear",
    "T6_BACKPACK_GATHERER_FIBER@2": "gatherergear",
    "T6_BACKPACK_GATHERER_FIBER@3": "gatherergear",
    "T7_BACKPACK_GATHERER_FIBER": "gatherergear",
    "T7_BACKPACK_GATHERER_FIBER@1": "gatherergear",
    "T7_BACKPACK_GATHERER_FIBER@2": "gatherergear",
    "T7_BACKPACK_GATHERER_FIBER@3": "gatherergear",
    "T8_BACKPACK_GATHERER_FIBER": "gatherergear",
    "T8_BACKPACK_GATHERER_FIBER@1": "gatherergear",
    "T8_BACKPACK_GATHERER_FIBER@2": "gatherergear",
    "T8_BACKPACK_GATHERER_FIBER@3": "gatherergear",
    "T4_HEAD_GATHERER_HIDE": "gatherergear",
    "T4_HEAD_GATHERER_HIDE@1": "gatherergear",
    "T4_HEAD_GATHERER_HIDE@2": "gatherergear",
    "T4_HEAD_GATHERER_HIDE@3": "gatherergear",
    "T5_HEAD_GATHERER_HIDE": "gatherergear",
    "T5_HEAD_GATHERER_HIDE@1": "gatherergear",
    "T5_HEAD_GATHERER_HIDE@2": "gatherergear",
    "T5_HEAD_GATHERER_HIDE@3": "gatherergear",
    "T6_HEAD_GATHERER_HIDE": "gatherergear",
    "T6_HEAD_GATHERER_HIDE@1": "gatherergear",
    "T6_HEAD_GATHERER_HIDE@2": "gatherergear",
    "T6_HEAD_GATHERER_HIDE@3": "gatherergear",
    "T7_HEAD_GATHERER_HIDE": "gatherergear",
    "T7_HEAD_GATHERER_HIDE@1": "gatherergear",
    "T7_HEAD_GATHERER_HIDE@2": "gatherergear",
    "T7_HEAD_GATHERER_HIDE@3": "gatherergear",
    "T8_HEAD_GATHERER_HIDE": "gatherergear",
    "T8_HEAD_GATHERER_HIDE@1": "gatherergear",
    "T8_HEAD_GATHERER_HIDE@2": "gatherergear",
    "T8_HEAD_GATHERER_HIDE@3": "gatherergear",
    "T4_ARMOR_GATHERER_HIDE": "gatherergear",
    "T4_ARMOR_GATHERER_HIDE@1": "gatherergear",
    "T4_ARMOR_GATHERER_HIDE@2": "gatherergear",
    "T4_ARMOR_GATHERER_HIDE@3": "gatherergear",
    "T5_ARMOR_GATHERER_HIDE": "gatherergear",
    "T5_ARMOR_GATHERER_HIDE@1": "gatherergear",
    "T5_ARMOR_GATHERER_HIDE@2": "gatherergear",
    "T5_ARMOR_GATHERER_HIDE@3": "gatherergear",
    "T6_ARMOR_GATHERER_HIDE": "gatherergear",
    "T6_ARMOR_GATHERER_HIDE@1": "gatherergear",
    "T6_ARMOR_GATHERER_HIDE@2": "gatherergear",
    "T6_ARMOR_GATHERER_HIDE@3": "gatherergear",
    "T7_ARMOR_GATHERER_HIDE": "gatherergear",
    "T7_ARMOR_GATHERER_HIDE@1": "gatherergear",
    "T7_ARMOR_GATHERER_HIDE@2": "gatherergear",
    "T7_ARMOR_GATHERER_HIDE@3": "gatherergear",
    "T8_ARMOR_GATHERER_HIDE": "gatherergear",
    "T8_ARMOR_GATHERER_HIDE@1": "gatherergear",
    "T8_ARMOR_GATHERER_HIDE@2": "gatherergear",
    "T8_ARMOR_GATHERER_HIDE@3": "gatherergear",
    "T4_SHOES_GATHERER_HIDE": "gatherergear",
    "T4_SHOES_GATHERER_HIDE@1": "gatherergear",
    "T4_SHOES_GATHERER_HIDE@2": "gatherergear",
    "T4_SHOES_GATHERER_HIDE@3": "gatherergear",
    "T5_SHOES_GATHERER_HIDE": "gatherergear",
    "T5_SHOES_GATHERER_HIDE@1": "gatherergear",
    "T5_SHOES_GATHERER_HIDE@2": "gatherergear",
    "T5_SHOES_GATHERER_HIDE@3": "gatherergear",
    "T6_SHOES_GATHERER_HIDE": "gatherergear",
    "T6_SHOES_GATHERER_HIDE@1": "gatherergear",
    "T6_SHOES_GATHERER_HIDE@2": "gatherergear",
    "T6_SHOES_GATHERER_HIDE@3": "gatherergear",
    "T7_SHOES_GATHERER_HIDE": "gatherergear",
    "T7_SHOES_GATHERER_HIDE@1": "gatherergear",
    "T7_SHOES_GATHERER_HIDE@2": "gatherergear",
    "T7_SHOES_GATHERER_HIDE@3": "gatherergear",
    "T8_SHOES_GATHERER_HIDE": "gatherergear",
    "T8_SHOES_GATHERER_HIDE@1": "gatherergear",
    "T8_SHOES_GATHERER_HIDE@2": "gatherergear",
    "T8_SHOES_GATHERER_HIDE@3": "gatherergear",
    "T4_BACKPACK_GATHERER_HIDE": "gatherergear",
    "T4_BACKPACK_GATHERER_HIDE@1": "gatherergear",
    "T4_BACKPACK_GATHERER_HIDE@2": "gatherergear",
    "T4_BACKPACK_GATHERER_HIDE@3": "gatherergear",
    "T5_BACKPACK_GATHERER_HIDE": "gatherergear",
    "T5_BACKPACK_GATHERER_HIDE@1": "gatherergear",
    "T5_BACKPACK_GATHERER_HIDE@2": "gatherergear",
    "T5_BACKPACK_GATHERER_HIDE@3": "gatherergear",
    "T6_BACKPACK_GATHERER_HIDE": "gatherergear",
    "T6_BACKPACK_GATHERER_HIDE@1": "gatherergear",
    "T6_BACKPACK_GATHERER_HIDE@2": "gatherergear",
    "T6_BACKPACK_GATHERER_HIDE@3": "gatherergear",
    "T7_BACKPACK_GATHERER_HIDE": "gatherergear",
    "T7_BACKPACK_GATHERER_HIDE@1": "gatherergear",
    "T7_BACKPACK_GATHERER_HIDE@2": "gatherergear",
    "T7_BACKPACK_GATHERER_HIDE@3": "gatherergear",
    "T8_BACKPACK_GATHERER_HIDE": "gatherergear",
    "T8_BACKPACK_GATHERER_HIDE@1": "gatherergear",
    "T8_BACKPACK_GATHERER_HIDE@2": "gatherergear",
    "T8_BACKPACK_GATHERER_HIDE@3": "gatherergear",
    "T4_HEAD_GATHERER_ORE": "gatherergear",
    "T4_HEAD_GATHERER_ORE@1": "gatherergear",
    "T4_HEAD_GATHERER_ORE@2": "gatherergear",
    "T4_HEAD_GATHERER_ORE@3": "gatherergear",
    "T5_HEAD_GATHERER_ORE": "gatherergear",
    "T5_HEAD_GATHERER_ORE@1": "gatherergear",
    "T5_HEAD_GATHERER_ORE@2": "gatherergear",
    "T5_HEAD_GATHERER_ORE@3": "gatherergear",
    "T6_HEAD_GATHERER_ORE": "gatherergear",
    "T6_HEAD_GATHERER_ORE@1": "gatherergear",
    "T6_HEAD_GATHERER_ORE@2": "gatherergear",
    "T6_HEAD_GATHERER_ORE@3": "gatherergear",
    "T7_HEAD_GATHERER_ORE": "gatherergear",
    "T7_HEAD_GATHERER_ORE@1": "gatherergear",
    "T7_HEAD_GATHERER_ORE@2": "gatherergear",
    "T7_HEAD_GATHERER_ORE@3": "gatherergear",
    "T8_HEAD_GATHERER_ORE": "gatherergear",
    "T8_HEAD_GATHERER_ORE@1": "gatherergear",
    "T8_HEAD_GATHERER_ORE@2": "gatherergear",
    "T8_HEAD_GATHERER_ORE@3": "gatherergear",
    "T4_ARMOR_GATHERER_ORE": "gatherergear",
    "T4_ARMOR_GATHERER_ORE@1": "gatherergear",
    "T4_ARMOR_GATHERER_ORE@2": "gatherergear",
    "T4_ARMOR_GATHERER_ORE@3": "gatherergear",
    "T5_ARMOR_GATHERER_ORE": "gatherergear",
    "T5_ARMOR_GATHERER_ORE@1": "gatherergear",
    "T5_ARMOR_GATHERER_ORE@2": "gatherergear",
    "T5_ARMOR_GATHERER_ORE@3": "gatherergear",
    "T6_ARMOR_GATHERER_ORE": "gatherergear",
    "T6_ARMOR_GATHERER_ORE@1": "gatherergear",
    "T6_ARMOR_GATHERER_ORE@2": "gatherergear",
    "T6_ARMOR_GATHERER_ORE@3": "gatherergear",
    "T7_ARMOR_GATHERER_ORE": "gatherergear",
    "T7_ARMOR_GATHERER_ORE@1": "gatherergear",
    "T7_ARMOR_GATHERER_ORE@2": "gatherergear",
    "T7_ARMOR_GATHERER_ORE@3": "gatherergear",
    "T8_ARMOR_GATHERER_ORE": "gatherergear",
    "T8_ARMOR_GATHERER_ORE@1": "gatherergear",
    "T8_ARMOR_GATHERER_ORE@2": "gatherergear",
    "T8_ARMOR_GATHERER_ORE@3": "gatherergear",
    "T4_SHOES_GATHERER_ORE": "gatherergear",
    "T4_SHOES_GATHERER_ORE@1": "gatherergear",
    "T4_SHOES_GATHERER_ORE@2": "gatherergear",
    "T4_SHOES_GATHERER_ORE@3": "gatherergear",
    "T5_SHOES_GATHERER_ORE": "gatherergear",
    "T5_SHOES_GATHERER_ORE@1": "gatherergear",
    "T5_SHOES_GATHERER_ORE@2": "gatherergear",
    "T5_SHOES_GATHERER_ORE@3": "gatherergear",
    "T6_SHOES_GATHERER_ORE": "gatherergear",
    "T6_SHOES_GATHERER_ORE@1": "gatherergear",
    "T6_SHOES_GATHERER_ORE@2": "gatherergear",
    "T6_SHOES_GATHERER_ORE@3": "gatherergear",
    "T7_SHOES_GATHERER_ORE": "gatherergear",
    "T7_SHOES_GATHERER_ORE@1": "gatherergear",
    "T7_SHOES_GATHERER_ORE@2": "gatherergear",
    "T7_SHOES_GATHERER_ORE@3": "gatherergear",
    "T8_SHOES_GATHERER_ORE": "gatherergear",
    "T8_SHOES_GATHERER_ORE@1": "gatherergear",
    "T8_SHOES_GATHERER_ORE@2": "gatherergear",
    "T8_SHOES_GATHERER_ORE@3": "gatherergear",
    "T4_BACKPACK_GATHERER_ORE": "gatherergear",
    "T4_BACKPACK_GATHERER_ORE@1": "gatherergear",
    "T4_BACKPACK_GATHERER_ORE@2": "gatherergear",
    "T4_BACKPACK_GATHERER_ORE@3": "gatherergear",
    "T5_BACKPACK_GATHERER_ORE": "gatherergear",
    "T5_BACKPACK_GATHERER_ORE@1": "gatherergear",
    "T5_BACKPACK_GATHERER_ORE@2": "gatherergear",
    "T5_BACKPACK_GATHERER_ORE@3": "gatherergear",
    "T6_BACKPACK_GATHERER_ORE": "gatherergear",
    "T6_BACKPACK_GATHERER_ORE@1": "gatherergear",
    "T6_BACKPACK_GATHERER_ORE@2": "gatherergear",
    "T6_BACKPACK_GATHERER_ORE@3": "gatherergear",
    "T7_BACKPACK_GATHERER_ORE": "gatherergear",
    "T7_BACKPACK_GATHERER_ORE@1": "gatherergear",
    "T7_BACKPACK_GATHERER_ORE@2": "gatherergear",
    "T7_BACKPACK_GATHERER_ORE@3": "gatherergear",
    "T8_BACKPACK_GATHERER_ORE": "gatherergear",
    "T8_BACKPACK_GATHERER_ORE@1": "gatherergear",
    "T8_BACKPACK_GATHERER_ORE@2": "gatherergear",
    "T8_BACKPACK_GATHERER_ORE@3": "gatherergear",
    "T4_HEAD_GATHERER_ROCK": "gatherergear",
    "T4_HEAD_GATHERER_ROCK@1": "gatherergear",
    "T4_HEAD_GATHERER_ROCK@2": "gatherergear",
    "T4_HEAD_GATHERER_ROCK@3": "gatherergear",
    "T5_HEAD_GATHERER_ROCK": "gatherergear",
    "T5_HEAD_GATHERER_ROCK@1": "gatherergear",
    "T5_HEAD_GATHERER_ROCK@2": "gatherergear",
    "T5_HEAD_GATHERER_ROCK@3": "gatherergear",
    "T6_HEAD_GATHERER_ROCK": "gatherergear",
    "T6_HEAD_GATHERER_ROCK@1": "gatherergear",
    "T6_HEAD_GATHERER_ROCK@2": "gatherergear",
    "T6_HEAD_GATHERER_ROCK@3": "gatherergear",
    "T7_HEAD_GATHERER_ROCK": "gatherergear",
    "T7_HEAD_GATHERER_ROCK@1": "gatherergear",
    "T7_HEAD_GATHERER_ROCK@2": "gatherergear",
    "T7_HEAD_GATHERER_ROCK@3": "gatherergear",
    "T8_HEAD_GATHERER_ROCK": "gatherergear",
    "T8_HEAD_GATHERER_ROCK@1": "gatherergear",
    "T8_HEAD_GATHERER_ROCK@2": "gatherergear",
    "T8_HEAD_GATHERER_ROCK@3": "gatherergear",
    "T4_ARMOR_GATHERER_ROCK": "gatherergear",
    "T4_ARMOR_GATHERER_ROCK@1": "gatherergear",
    "T4_ARMOR_GATHERER_ROCK@2": "gatherergear",
    "T4_ARMOR_GATHERER_ROCK@3": "gatherergear",
    "T5_ARMOR_GATHERER_ROCK": "gatherergear",
    "T5_ARMOR_GATHERER_ROCK@1": "gatherergear",
    "T5_ARMOR_GATHERER_ROCK@2": "gatherergear",
    "T5_ARMOR_GATHERER_ROCK@3": "gatherergear",
    "T6_ARMOR_GATHERER_ROCK": "gatherergear",
    "T6_ARMOR_GATHERER_ROCK@1": "gatherergear",
    "T6_ARMOR_GATHERER_ROCK@2": "gatherergear",
    "T6_ARMOR_GATHERER_ROCK@3": "gatherergear",
    "T7_ARMOR_GATHERER_ROCK": "gatherergear",
    "T7_ARMOR_GATHERER_ROCK@1": "gatherergear",
    "T7_ARMOR_GATHERER_ROCK@2": "gatherergear",
    "T7_ARMOR_GATHERER_ROCK@3": "gatherergear",
    "T8_ARMOR_GATHERER_ROCK": "gatherergear",
    "T8_ARMOR_GATHERER_ROCK@1": "gatherergear",
    "T8_ARMOR_GATHERER_ROCK@2": "gatherergear",
    "T8_ARMOR_GATHERER_ROCK@3": "gatherergear",
    "T4_SHOES_GATHERER_ROCK": "gatherergear",
    "T4_SHOES_GATHERER_ROCK@1": "gatherergear",
    "T4_SHOES_GATHERER_ROCK@2": "gatherergear",
    "T4_SHOES_GATHERER_ROCK@3": "gatherergear",
    "T5_SHOES_GATHERER_ROCK": "gatherergear",
    "T5_SHOES_GATHERER_ROCK@1": "gatherergear",
    "T5_SHOES_GATHERER_ROCK@2": "gatherergear",
    "T5_SHOES_GATHERER_ROCK@3": "gatherergear",
    "T6_SHOES_GATHERER_ROCK": "gatherergear",
    "T6_SHOES_GATHERER_ROCK@1": "gatherergear",
    "T6_SHOES_GATHERER_ROCK@2": "gatherergear",
    "T6_SHOES_GATHERER_ROCK@3": "gatherergear",
    "T7_SHOES_GATHERER_ROCK": "gatherergear",
    "T7_SHOES_GATHERER_ROCK@1": "gatherergear",
    "T7_SHOES_GATHERER_ROCK@2": "gatherergear",
    "T7_SHOES_GATHERER_ROCK@3": "gatherergear",
    "T8_SHOES_GATHERER_ROCK": "gatherergear",
    "T8_SHOES_GATHERER_ROCK@1": "gatherergear",
    "T8_SHOES_GATHERER_ROCK@2": "gatherergear",
    "T8_SHOES_GATHERER_ROCK@3": "gatherergear",
    "T4_BACKPACK_GATHERER_ROCK": "gatherergear",
    "T4_BACKPACK_GATHERER_ROCK@1": "gatherergear",
    "T4_BACKPACK_GATHERER_ROCK@2": "gatherergear",
    "T4_BACKPACK_GATHERER_ROCK@3": "gatherergear",
    "T5_BACKPACK_GATHERER_ROCK": "gatherergear",
    "T5_BACKPACK_GATHERER_ROCK@1": "gatherergear",
    "T5_BACKPACK_GATHERER_ROCK@2": "gatherergear",
    "T5_BACKPACK_GATHERER_ROCK@3": "gatherergear",
    "T6_BACKPACK_GATHERER_ROCK": "gatherergear",
    "T6_BACKPACK_GATHERER_ROCK@1": "gatherergear",
    "T6_BACKPACK_GATHERER_ROCK@2": "gatherergear",
    "T6_BACKPACK_GATHERER_ROCK@3": "gatherergear",
    "T7_BACKPACK_GATHERER_ROCK": "gatherergear",
    "T7_BACKPACK_GATHERER_ROCK@1": "gatherergear",
    "T7_BACKPACK_GATHERER_ROCK@2": "gatherergear",
    "T7_BACKPACK_GATHERER_ROCK@3": "gatherergear",
    "T8_BACKPACK_GATHERER_ROCK": "gatherergear",
    "T8_BACKPACK_GATHERER_ROCK@1": "gatherergear",
    "T8_BACKPACK_GATHERER_ROCK@2": "gatherergear",
    "T8_BACKPACK_GATHERER_ROCK@3": "gatherergear",
    "T4_HEAD_GATHERER_WOOD": "gatherergear",
    "T4_HEAD_GATHERER_WOOD@1": "gatherergear",
    "T4_HEAD_GATHERER_WOOD@2": "gatherergear",
    "T4_HEAD_GATHERER_WOOD@3": "gatherergear",
    "T5_HEAD_GATHERER_WOOD": "gatherergear",
    "T5_HEAD_GATHERER_WOOD@1": "gatherergear",
    "T5_HEAD_GATHERER_WOOD@2": "gatherergear",
    "T5_HEAD_GATHERER_WOOD@3": "gatherergear",
    "T6_HEAD_GATHERER_WOOD": "gatherergear",
    "T6_HEAD_GATHERER_WOOD@1": "gatherergear",
    "T6_HEAD_GATHERER_WOOD@2": "gatherergear",
    "T6_HEAD_GATHERER_WOOD@3": "gatherergear",
    "T7_HEAD_GATHERER_WOOD": "gatherergear",
    "T7_HEAD_GATHERER_WOOD@1": "gatherergear",
    "T7_HEAD_GATHERER_WOOD@2": "gatherergear",
    "T7_HEAD_GATHERER_WOOD@3": "gatherergear",
    "T8_HEAD_GATHERER_WOOD": "gatherergear",
    "T8_HEAD_GATHERER_WOOD@1": "gatherergear",
    "T8_HEAD_GATHERER_WOOD@2": "gatherergear",
    "T8_HEAD_GATHERER_WOOD@3": "gatherergear",
    "T4_ARMOR_GATHERER_WOOD": "gatherergear",
    "T4_ARMOR_GATHERER_WOOD@1": "gatherergear",
    "T4_ARMOR_GATHERER_WOOD@2": "gatherergear",
    "T4_ARMOR_GATHERER_WOOD@3": "gatherergear",
    "T5_ARMOR_GATHERER_WOOD": "gatherergear",
    "T5_ARMOR_GATHERER_WOOD@1": "gatherergear",
    "T5_ARMOR_GATHERER_WOOD@2": "gatherergear",
    "T5_ARMOR_GATHERER_WOOD@3": "gatherergear",
    "T6_ARMOR_GATHERER_WOOD": "gatherergear",
    "T6_ARMOR_GATHERER_WOOD@1": "gatherergear",
    "T6_ARMOR_GATHERER_WOOD@2": "gatherergear",
    "T6_ARMOR_GATHERER_WOOD@3": "gatherergear",
    "T7_ARMOR_GATHERER_WOOD": "gatherergear",
    "T7_ARMOR_GATHERER_WOOD@1": "gatherergear",
    "T7_ARMOR_GATHERER_WOOD@2": "gatherergear",
    "T7_ARMOR_GATHERER_WOOD@3": "gatherergear",
    "T8_ARMOR_GATHERER_WOOD": "gatherergear",
    "T8_ARMOR_GATHERER_WOOD@1": "gatherergear",
    "T8_ARMOR_GATHERER_WOOD@2": "gatherergear",
    "T8_ARMOR_GATHERER_WOOD@3": "gatherergear",
    "T4_SHOES_GATHERER_WOOD": "gatherergear",
    "T4_SHOES_GATHERER_WOOD@1": "gatherergear",
    "T4_SHOES_GATHERER_WOOD@2": "gatherergear",
    "T4_SHOES_GATHERER_WOOD@3": "gatherergear",
    "T5_SHOES_GATHERER_WOOD": "gatherergear",
    "T5_SHOES_GATHERER_WOOD@1": "gatherergear",
    "T5_SHOES_GATHERER_WOOD@2": "gatherergear",
    "T5_SHOES_GATHERER_WOOD@3": "gatherergear",
    "T6_SHOES_GATHERER_WOOD": "gatherergear",
    "T6_SHOES_GATHERER_WOOD@1": "gatherergear",
    "T6_SHOES_GATHERER_WOOD@2": "gatherergear",
    "T6_SHOES_GATHERER_WOOD@3": "gatherergear",
    "T7_SHOES_GATHERER_WOOD": "gatherergear",
    "T7_SHOES_GATHERER_WOOD@1": "gatherergear",
    "T7_SHOES_GATHERER_WOOD@2": "gatherergear",
    "T7_SHOES_GATHERER_WOOD@3": "gatherergear",
    "T8_SHOES_GATHERER_WOOD": "gatherergear",
    "T8_SHOES_GATHERER_WOOD@1": "gatherergear",
    "T8_SHOES_GATHERER_WOOD@2": "gatherergear",
    "T8_SHOES_GATHERER_WOOD@3": "gatherergear",
    "T4_BACKPACK_GATHERER_WOOD": "gatherergear",
    "T4_BACKPACK_GATHERER_WOOD@1": "gatherergear",
    "T4_BACKPACK_GATHERER_WOOD@2": "gatherergear",
    "T4_BACKPACK_GATHERER_WOOD@3": "gatherergear",
    "T5_BACKPACK_GATHERER_WOOD": "gatherergear",
    "T5_BACKPACK_GATHERER_WOOD@1": "gatherergear",
    "T5_BACKPACK_GATHERER_WOOD@2": "gatherergear",
    "T5_BACKPACK_GATHERER_WOOD@3": "gatherergear",
    "T6_BACKPACK_GATHERER_WOOD": "gatherergear",
    "T6_BACKPACK_GATHERER_WOOD@1": "gatherergear",
    "T6_BACKPACK_GATHERER_WOOD@2": "gatherergear",
    "T6_BACKPACK_GATHERER_WOOD@3": "gatherergear",
    "T7_BACKPACK_GATHERER_WOOD": "gatherergear",
    "T7_BACKPACK_GATHERER_WOOD@1": "gatherergear",
    "T7_BACKPACK_GATHERER_WOOD@2": "gatherergear",
    "T7_BACKPACK_GATHERER_WOOD@3": "gatherergear",
    "T8_BACKPACK_GATHERER_WOOD": "gatherergear",
    "T8_BACKPACK_GATHERER_WOOD@1": "gatherergear",
    "T8_BACKPACK_GATHERER_WOOD@2": "gatherergear",
    "T8_BACKPACK_GATHERER_WOOD@3": "gatherergear",
    "T4_HEAD_GATHERER_FISH": "gatherergear",
    "T4_HEAD_GATHERER_FISH@1": "gatherergear",
    "T4_HEAD_GATHERER_FISH@2": "gatherergear",
    "T4_HEAD_GATHERER_FISH@3": "gatherergear",
    "T5_HEAD_GATHERER_FISH": "gatherergear",
    "T5_HEAD_GATHERER_FISH@1": "gatherergear",
    "T5_HEAD_GATHERER_FISH@2": "gatherergear",
    "T5_HEAD_GATHERER_FISH@3": "gatherergear",
    "T6_HEAD_GATHERER_FISH": "gatherergear",
    "T6_HEAD_GATHERER_FISH@1": "gatherergear",
    "T6_HEAD_GATHERER_FISH@2": "gatherergear",
    "T6_HEAD_GATHERER_FISH@3": "gatherergear",
    "T7_HEAD_GATHERER_FISH": "gatherergear",
    "T7_HEAD_GATHERER_FISH@1": "gatherergear",
    "T7_HEAD_GATHERER_FISH@2": "gatherergear",
    "T7_HEAD_GATHERER_FISH@3": "gatherergear",
    "T8_HEAD_GATHERER_FISH": "gatherergear",
    "T8_HEAD_GATHERER_FISH@1": "gatherergear",
    "T8_HEAD_GATHERER_FISH@2": "gatherergear",
    "T8_HEAD_GATHERER_FISH@3": "gatherergear",
    "T4_ARMOR_GATHERER_FISH": "gatherergear",
    "T4_ARMOR_GATHERER_FISH@1": "gatherergear",
    "T4_ARMOR_GATHERER_FISH@2": "gatherergear",
    "T4_ARMOR_GATHERER_FISH@3": "gatherergear",
    "T5_ARMOR_GATHERER_FISH": "gatherergear",
    "T5_ARMOR_GATHERER_FISH@1": "gatherergear",
    "T5_ARMOR_GATHERER_FISH@2": "gatherergear",
    "T5_ARMOR_GATHERER_FISH@3": "gatherergear",
    "T6_ARMOR_GATHERER_FISH": "gatherergear",
    "T6_ARMOR_GATHERER_FISH@1": "gatherergear",
    "T6_ARMOR_GATHERER_FISH@2": "gatherergear",
    "T6_ARMOR_GATHERER_FISH@3": "gatherergear",
    "T7_ARMOR_GATHERER_FISH": "gatherergear",
    "T7_ARMOR_GATHERER_FISH@1": "gatherergear",
    "T7_ARMOR_GATHERER_FISH@2": "gatherergear",
    "T7_ARMOR_GATHERER_FISH@3": "gatherergear",
    "T8_ARMOR_GATHERER_FISH": "gatherergear",
    "T8_ARMOR_GATHERER_FISH@1": "gatherergear",
    "T8_ARMOR_GATHERER_FISH@2": "gatherergear",
    "T8_ARMOR_GATHERER_FISH@3": "gatherergear",
    "T4_SHOES_GATHERER_FISH": "gatherergear",
    "T4_SHOES_GATHERER_FISH@1": "gatherergear",
    "T4_SHOES_GATHERER_FISH@2": "gatherergear",
    "T4_SHOES_GATHERER_FISH@3": "gatherergear",
    "T5_SHOES_GATHERER_FISH": "gatherergear",
    "T5_SHOES_GATHERER_FISH@1": "gatherergear",
    "T5_SHOES_GATHERER_FISH@2": "gatherergear",
    "T5_SHOES_GATHERER_FISH@3": "gatherergear",
    "T6_SHOES_GATHERER_FISH": "gatherergear",
    "T6_SHOES_GATHERER_FISH@1": "gatherergear",
    "T6_SHOES_GATHERER_FISH@2": "gatherergear",
    "T6_SHOES_GATHERER_FISH@3": "gatherergear",
    "T7_SHOES_GATHERER_FISH": "gatherergear",
    "T7_SHOES_GATHERER_FISH@1": "gatherergear",
    "T7_SHOES_GATHERER_FISH@2": "gatherergear",
    "T7_SHOES_GATHERER_FISH@3": "gatherergear",
    "T8_SHOES_GATHERER_FISH": "gatherergear",
    "T8_SHOES_GATHERER_FISH@1": "gatherergear",
    "T8_SHOES_GATHERER_FISH@2": "gatherergear",
    "T8_SHOES_GATHERER_FISH@3": "gatherergear",
    "T4_BACKPACK_GATHERER_FISH": "gatherergear",
    "T4_BACKPACK_GATHERER_FISH@1": "gatherergear",
    "T4_BACKPACK_GATHERER_FISH@2": "gatherergear",
    "T4_BACKPACK_GATHERER_FISH@3": "gatherergear",
    "T5_BACKPACK_GATHERER_FISH": "gatherergear",
    "T5_BACKPACK_GATHERER_FISH@1": "gatherergear",
    "T5_BACKPACK_GATHERER_FISH@2": "gatherergear",
    "T5_BACKPACK_GATHERER_FISH@3": "gatherergear",
    "T6_BACKPACK_GATHERER_FISH": "gatherergear",
    "T6_BACKPACK_GATHERER_FISH@1": "gatherergear",
    "T6_BACKPACK_GATHERER_FISH@2": "gatherergear",
    "T6_BACKPACK_GATHERER_FISH@3": "gatherergear",
    "T7_BACKPACK_GATHERER_FISH": "gatherergear",
    "T7_BACKPACK_GATHERER_FISH@1": "gatherergear",
    "T7_BACKPACK_GATHERER_FISH@2": "gatherergear",
    "T7_BACKPACK_GATHERER_FISH@3": "gatherergear",
    "T8_BACKPACK_GATHERER_FISH": "gatherergear",
    "T8_BACKPACK_GATHERER_FISH@1": "gatherergear",
    "T8_BACKPACK_GATHERER_FISH@2": "gatherergear",
    "T8_BACKPACK_GATHERER_FISH@3": "gatherergear",
    "T2_2H_BOW": "bow",
    "T3_2H_BOW": "bow",
    "T4_2H_BOW": "bow",
    "T4_2H_BOW@1": "bow",
    "T4_2H_BOW@2": "bow",
    "T4_2H_BOW@3": "bow",
    "T5_2H_BOW": "bow",
    "T5_2H_BOW@1": "bow",
    "T5_2H_BOW@2": "bow",
    "T5_2H_BOW@3": "bow",
    "T6_2H_BOW": "bow",
    "T6_2H_BOW@1": "bow",
    "T6_2H_BOW@2": "bow",
    "T6_2H_BOW@3": "bow",
    "T7_2H_BOW": "bow",
    "T7_2H_BOW@1": "bow",
    "T7_2H_BOW@2": "bow",
    "T7_2H_BOW@3": "bow",
    "T8_2H_BOW": "bow",
    "T8_2H_BOW@1": "bow",
    "T8_2H_BOW@2": "bow",
    "T8_2H_BOW@3": "bow",
    "T4_2H_WARBOW": "bow",
    "T4_2H_WARBOW@1": "bow",
    "T4_2H_WARBOW@2": "bow",
    "T4_2H_WARBOW@3": "bow",
    "T5_2H_WARBOW": "bow",
    "T5_2H_WARBOW@1": "bow",
    "T5_2H_WARBOW@2": "bow",
    "T5_2H_WARBOW@3": "bow",
    "T6_2H_WARBOW": "bow",
    "T6_2H_WARBOW@1": "bow",
    "T6_2H_WARBOW@2": "bow",
    "T6_2H_WARBOW@3": "bow",
    "T7_2H_WARBOW": "bow",
    "T7_2H_WARBOW@1": "bow",
    "T7_2H_WARBOW@2": "bow",
    "T7_2H_WARBOW@3": "bow",
    "T8_2H_WARBOW": "bow",
    "T8_2H_WARBOW@1": "bow",
    "T8_2H_WARBOW@2": "bow",
    "T8_2H_WARBOW@3": "bow",
    "T4_2H_LONGBOW": "bow",
    "T4_2H_LONGBOW@1": "bow",
    "T4_2H_LONGBOW@2": "bow",
    "T4_2H_LONGBOW@3": "bow",
    "T5_2H_LONGBOW": "bow",
    "T5_2H_LONGBOW@1": "bow",
    "T5_2H_LONGBOW@2": "bow",
    "T5_2H_LONGBOW@3": "bow",
    "T6_2H_LONGBOW": "bow",
    "T6_2H_LONGBOW@1": "bow",
    "T6_2H_LONGBOW@2": "bow",
    "T6_2H_LONGBOW@3": "bow",
    "T7_2H_LONGBOW": "bow",
    "T7_2H_LONGBOW@1": "bow",
    "T7_2H_LONGBOW@2": "bow",
    "T7_2H_LONGBOW@3": "bow",
    "T8_2H_LONGBOW": "bow",
    "T8_2H_LONGBOW@1": "bow",
    "T8_2H_LONGBOW@2": "bow",
    "T8_2H_LONGBOW@3": "bow",
    "T4_2H_LONGBOW_UNDEAD": "bow",
    "T4_2H_LONGBOW_UNDEAD@1": "bow",
    "T4_2H_LONGBOW_UNDEAD@2": "bow",
    "T4_2H_LONGBOW_UNDEAD@3": "bow",
    "T5_2H_LONGBOW_UNDEAD": "bow",
    "T5_2H_LONGBOW_UNDEAD@1": "bow",
    "T5_2H_LONGBOW_UNDEAD@2": "bow",
    "T5_2H_LONGBOW_UNDEAD@3": "bow",
    "T6_2H_LONGBOW_UNDEAD": "bow",
    "T6_2H_LONGBOW_UNDEAD@1": "bow",
    "T6_2H_LONGBOW_UNDEAD@2": "bow",
    "T6_2H_LONGBOW_UNDEAD@3": "bow",
    "T7_2H_LONGBOW_UNDEAD": "bow",
    "T7_2H_LONGBOW_UNDEAD@1": "bow",
    "T7_2H_LONGBOW_UNDEAD@2": "bow",
    "T7_2H_LONGBOW_UNDEAD@3": "bow",
    "T8_2H_LONGBOW_UNDEAD": "bow",
    "T8_2H_LONGBOW_UNDEAD@1": "bow",
    "T8_2H_LONGBOW_UNDEAD@2": "bow",
    "T8_2H_LONGBOW_UNDEAD@3": "bow",
    "T4_2H_BOW_HELL": "bow",
    "T4_2H_BOW_HELL@1": "bow",
    "T4_2H_BOW_HELL@2": "bow",
    "T4_2H_BOW_HELL@3": "bow",
    "T5_2H_BOW_HELL": "bow",
    "T5_2H_BOW_HELL@1": "bow",
    "T5_2H_BOW_HELL@2": "bow",
    "T5_2H_BOW_HELL@3": "bow",
    "T6_2H_BOW_HELL": "bow",
    "T6_2H_BOW_HELL@1": "bow",
    "T6_2H_BOW_HELL@2": "bow",
    "T6_2H_BOW_HELL@3": "bow",
    "T7_2H_BOW_HELL": "bow",
    "T7_2H_BOW_HELL@1": "bow",
    "T7_2H_BOW_HELL@2": "bow",
    "T7_2H_BOW_HELL@3": "bow",
    "T8_2H_BOW_HELL": "bow",
    "T8_2H_BOW_HELL@1": "bow",
    "T8_2H_BOW_HELL@2": "bow",
    "T8_2H_BOW_HELL@3": "bow",
    "T4_2H_BOW_KEEPER": "bow",
    "T4_2H_BOW_KEEPER@1": "bow",
    "T4_2H_BOW_KEEPER@2": "bow",
    "T4_2H_BOW_KEEPER@3": "bow",
    "T5_2H_BOW_KEEPER": "bow",
    "T5_2H_BOW_KEEPER@1": "bow",
    "T5_2H_BOW_KEEPER@2": "bow",
    "T5_2H_BOW_KEEPER@3": "bow",
    "T6_2H_BOW_KEEPER": "bow",
    "T6_2H_BOW_KEEPER@1": "bow",
    "T6_2H_BOW_KEEPER@2": "bow",
    "T6_2H_BOW_KEEPER@3": "bow",
    "T7_2H_BOW_KEEPER": "bow",
    "T7_2H_BOW_KEEPER@1": "bow",
    "T7_2H_BOW_KEEPER@2": "bow",
    "T7_2H_BOW_KEEPER@3": "bow",
    "T8_2H_BOW_KEEPER": "bow",
    "T8_2H_BOW_KEEPER@1": "bow",
    "T8_2H_BOW_KEEPER@2": "bow",
    "T8_2H_BOW_KEEPER@3": "bow",
    "T4_2H_BOW_AVALON": "bow",
    "T4_2H_BOW_AVALON@1": "bow",
    "T4_2H_BOW_AVALON@2": "bow",
    "T4_2H_BOW_AVALON@3": "bow",
    "T5_2H_BOW_AVALON": "bow",
    "T5_2H_BOW_AVALON@1": "bow",
    "T5_2H_BOW_AVALON@2": "bow",
    "T5_2H_BOW_AVALON@3": "bow",
    "T6_2H_BOW_AVALON": "bow",
    "T6_2H_BOW_AVALON@1": "bow",
    "T6_2H_BOW_AVALON@2": "bow",
    "T6_2H_BOW_AVALON@3": "bow",
    "T7_2H_BOW_AVALON": "bow",
    "T7_2H_BOW_AVALON@1": "bow",
    "T7_2H_BOW_AVALON@2": "bow",
    "T7_2H_BOW_AVALON@3": "bow",
    "T8_2H_BOW_AVALON": "bow",
    "T8_2H_BOW_AVALON@1": "bow",
    "T8_2H_BOW_AVALON@2": "bow",
    "T8_2H_BOW_AVALON@3": "bow",
    "T3_2H_CROSSBOW": "crossbow",
    "T4_2H_CROSSBOW": "crossbow",
    "T4_2H_CROSSBOW@1": "crossbow",
    "T4_2H_CROSSBOW@2": "crossbow",
    "T4_2H_CROSSBOW@3": "crossbow",
    "T5_2H_CROSSBOW": "crossbow",
    "T5_2H_CROSSBOW@1": "crossbow",
    "T5_2H_CROSSBOW@2": "crossbow",
    "T5_2H_CROSSBOW@3": "crossbow",
    "T6_2H_CROSSBOW": "crossbow",
    "T6_2H_CROSSBOW@1": "crossbow",
    "T6_2H_CROSSBOW@2": "crossbow",
    "T6_2H_CROSSBOW@3": "crossbow",
    "T7_2H_CROSSBOW": "crossbow",
    "T7_2H_CROSSBOW@1": "crossbow",
    "T7_2H_CROSSBOW@2": "crossbow",
    "T7_2H_CROSSBOW@3": "crossbow",
    "T8_2H_CROSSBOW": "crossbow",
    "T8_2H_CROSSBOW@1": "crossbow",
    "T8_2H_CROSSBOW@2": "crossbow",
    "T8_2H_CROSSBOW@3": "crossbow",
    "T4_2H_CROSSBOWLARGE": "crossbow",
    "T4_2H_CROSSBOWLARGE@1": "crossbow",
    "T4_2H_CROSSBOWLARGE@2": "crossbow",
    "T4_2H_CROSSBOWLARGE@3": "crossbow",
    "T5_2H_CROSSBOWLARGE": "crossbow",
    "T5_2H_CROSSBOWLARGE@1": "crossbow",
    "T5_2H_CROSSBOWLARGE@2": "crossbow",
    "T5_2H_CROSSBOWLARGE@3": "crossbow",
    "T6_2H_CROSSBOWLARGE": "crossbow",
    "T6_2H_CROSSBOWLARGE@1": "crossbow",
    "T6_2H_CROSSBOWLARGE@2": "crossbow",
    "T6_2H_CROSSBOWLARGE@3": "crossbow",
    "T7_2H_CROSSBOWLARGE": "crossbow",
    "T7_2H_CROSSBOWLARGE@1": "crossbow",
    "T7_2H_CROSSBOWLARGE@2": "crossbow",
    "T7_2H_CROSSBOWLARGE@3": "crossbow",
    "T8_2H_CROSSBOWLARGE": "crossbow",
    "T8_2H_CROSSBOWLARGE@1": "crossbow",
    "T8_2H_CROSSBOWLARGE@2": "crossbow",
    "T8_2H_CROSSBOWLARGE@3": "crossbow",
    "T4_MAIN_1HCROSSBOW": "crossbow",
    "T4_MAIN_1HCROSSBOW@1": "crossbow",
    "T4_MAIN_1HCROSSBOW@2": "crossbow",
    "T4_MAIN_1HCROSSBOW@3": "crossbow",
    "T5_MAIN_1HCROSSBOW": "crossbow",
    "T5_MAIN_1HCROSSBOW@1": "crossbow",
    "T5_MAIN_1HCROSSBOW@2": "crossbow",
    "T5_MAIN_1HCROSSBOW@3": "crossbow",
    "T6_MAIN_1HCROSSBOW": "crossbow",
    "T6_MAIN_1HCROSSBOW@1": "crossbow",
    "T6_MAIN_1HCROSSBOW@2": "crossbow",
    "T6_MAIN_1HCROSSBOW@3": "crossbow",
    "T7_MAIN_1HCROSSBOW": "crossbow",
    "T7_MAIN_1HCROSSBOW@1": "crossbow",
    "T7_MAIN_1HCROSSBOW@2": "crossbow",
    "T7_MAIN_1HCROSSBOW@3": "crossbow",
    "T8_MAIN_1HCROSSBOW": "crossbow",
    "T8_MAIN_1HCROSSBOW@1": "crossbow",
    "T8_MAIN_1HCROSSBOW@2": "crossbow",
    "T8_MAIN_1HCROSSBOW@3": "crossbow",
    "T4_2H_REPEATINGCROSSBOW_UNDEAD": "crossbow",
    "T4_2H_REPEATINGCROSSBOW_UNDEAD@1": "crossbow",
    "T4_2H_REPEATINGCROSSBOW_UNDEAD@2": "crossbow",
    "T4_2H_REPEATINGCROSSBOW_UNDEAD@3": "crossbow",
    "T5_2H_REPEATINGCROSSBOW_UNDEAD": "crossbow",
    "T5_2H_REPEATINGCROSSBOW_UNDEAD@1": "crossbow",
    "T5_2H_REPEATINGCROSSBOW_UNDEAD@2": "crossbow",
    "T5_2H_REPEATINGCROSSBOW_UNDEAD@3": "crossbow",
    "T6_2H_REPEATINGCROSSBOW_UNDEAD": "crossbow",
    "T6_2H_REPEATINGCROSSBOW_UNDEAD@1": "crossbow",
    "T6_2H_REPEATINGCROSSBOW_UNDEAD@2": "crossbow",
    "T6_2H_REPEATINGCROSSBOW_UNDEAD@3": "crossbow",
    "T7_2H_REPEATINGCROSSBOW_UNDEAD": "crossbow",
    "T7_2H_REPEATINGCROSSBOW_UNDEAD@1": "crossbow",
    "T7_2H_REPEATINGCROSSBOW_UNDEAD@2": "crossbow",
    "T7_2H_REPEATINGCROSSBOW_UNDEAD@3": "crossbow",
    "T8_2H_REPEATINGCROSSBOW_UNDEAD": "crossbow",
    "T8_2H_REPEATINGCROSSBOW_UNDEAD@1": "crossbow",
    "T8_2H_REPEATINGCROSSBOW_UNDEAD@2": "crossbow",
    "T8_2H_REPEATINGCROSSBOW_UNDEAD@3": "crossbow",
    "T4_2H_DUALCROSSBOW_HELL": "crossbow",
    "T4_2H_DUALCROSSBOW_HELL@1": "crossbow",
    "T4_2H_DUALCROSSBOW_HELL@2": "crossbow",
    "T4_2H_DUALCROSSBOW_HELL@3": "crossbow",
    "T5_2H_DUALCROSSBOW_HELL": "crossbow",
    "T5_2H_DUALCROSSBOW_HELL@1": "crossbow",
    "T5_2H_DUALCROSSBOW_HELL@2": "crossbow",
    "T5_2H_DUALCROSSBOW_HELL@3": "crossbow",
    "T6_2H_DUALCROSSBOW_HELL": "crossbow",
    "T6_2H_DUALCROSSBOW_HELL@1": "crossbow",
    "T6_2H_DUALCROSSBOW_HELL@2": "crossbow",
    "T6_2H_DUALCROSSBOW_HELL@3": "crossbow",
    "T7_2H_DUALCROSSBOW_HELL": "crossbow",
    "T7_2H_DUALCROSSBOW_HELL@1": "crossbow",
    "T7_2H_DUALCROSSBOW_HELL@2": "crossbow",
    "T7_2H_DUALCROSSBOW_HELL@3": "crossbow",
    "T8_2H_DUALCROSSBOW_HELL": "crossbow",
    "T8_2H_DUALCROSSBOW_HELL@1": "crossbow",
    "T8_2H_DUALCROSSBOW_HELL@2": "crossbow",
    "T8_2H_DUALCROSSBOW_HELL@3": "crossbow",
    "T4_2H_CROSSBOWLARGE_MORGANA": "crossbow",
    "T4_2H_CROSSBOWLARGE_MORGANA@1": "crossbow",
    "T4_2H_CROSSBOWLARGE_MORGANA@2": "crossbow",
    "T4_2H_CROSSBOWLARGE_MORGANA@3": "crossbow",
    "T5_2H_CROSSBOWLARGE_MORGANA": "crossbow",
    "T5_2H_CROSSBOWLARGE_MORGANA@1": "crossbow",
    "T5_2H_CROSSBOWLARGE_MORGANA@2": "crossbow",
    "T5_2H_CROSSBOWLARGE_MORGANA@3": "crossbow",
    "T6_2H_CROSSBOWLARGE_MORGANA": "crossbow",
    "T6_2H_CROSSBOWLARGE_MORGANA@1": "crossbow",
    "T6_2H_CROSSBOWLARGE_MORGANA@2": "crossbow",
    "T6_2H_CROSSBOWLARGE_MORGANA@3": "crossbow",
    "T7_2H_CROSSBOWLARGE_MORGANA": "crossbow",
    "T7_2H_CROSSBOWLARGE_MORGANA@1": "crossbow",
    "T7_2H_CROSSBOWLARGE_MORGANA@2": "crossbow",
    "T7_2H_CROSSBOWLARGE_MORGANA@3": "crossbow",
    "T8_2H_CROSSBOWLARGE_MORGANA": "crossbow",
    "T8_2H_CROSSBOWLARGE_MORGANA@1": "crossbow",
    "T8_2H_CROSSBOWLARGE_MORGANA@2": "crossbow",
    "T8_2H_CROSSBOWLARGE_MORGANA@3": "crossbow",
    "T4_2H_CROSSBOW_CANNON_AVALON": "crossbow",
    "T4_2H_CROSSBOW_CANNON_AVALON@1": "crossbow",
    "T4_2H_CROSSBOW_CANNON_AVALON@2": "crossbow",
    "T4_2H_CROSSBOW_CANNON_AVALON@3": "crossbow",
    "T5_2H_CROSSBOW_CANNON_AVALON": "crossbow",
    "T5_2H_CROSSBOW_CANNON_AVALON@1": "crossbow",
    "T5_2H_CROSSBOW_CANNON_AVALON@2": "crossbow",
    "T5_2H_CROSSBOW_CANNON_AVALON@3": "crossbow",
    "T6_2H_CROSSBOW_CANNON_AVALON": "crossbow",
    "T6_2H_CROSSBOW_CANNON_AVALON@1": "crossbow",
    "T6_2H_CROSSBOW_CANNON_AVALON@2": "crossbow",
    "T6_2H_CROSSBOW_CANNON_AVALON@3": "crossbow",
    "T7_2H_CROSSBOW_CANNON_AVALON": "crossbow",
    "T7_2H_CROSSBOW_CANNON_AVALON@1": "crossbow",
    "T7_2H_CROSSBOW_CANNON_AVALON@2": "crossbow",
    "T7_2H_CROSSBOW_CANNON_AVALON@3": "crossbow",
    "T8_2H_CROSSBOW_CANNON_AVALON": "crossbow",
    "T8_2H_CROSSBOW_CANNON_AVALON@1": "crossbow",
    "T8_2H_CROSSBOW_CANNON_AVALON@2": "crossbow",
    "T8_2H_CROSSBOW_CANNON_AVALON@3": "crossbow",
    "T3_MAIN_CURSEDSTAFF": "cursestaff",
    "T4_MAIN_CURSEDSTAFF": "cursestaff",
    "T4_MAIN_CURSEDSTAFF@1": "cursestaff",
    "T4_MAIN_CURSEDSTAFF@2": "cursestaff",
    "T4_MAIN_CURSEDSTAFF@3": "cursestaff",
    "T5_MAIN_CURSEDSTAFF": "cursestaff",
    "T5_MAIN_CURSEDSTAFF@1": "cursestaff",
    "T5_MAIN_CURSEDSTAFF@2": "cursestaff",
    "T5_MAIN_CURSEDSTAFF@3": "cursestaff",
    "T6_MAIN_CURSEDSTAFF": "cursestaff",
    "T6_MAIN_CURSEDSTAFF@1": "cursestaff",
    "T6_MAIN_CURSEDSTAFF@2": "cursestaff",
    "T6_MAIN_CURSEDSTAFF@3": "cursestaff",
    "T7_MAIN_CURSEDSTAFF": "cursestaff",
    "T7_MAIN_CURSEDSTAFF@1": "cursestaff",
    "T7_MAIN_CURSEDSTAFF@2": "cursestaff",
    "T7_MAIN_CURSEDSTAFF@3": "cursestaff",
    "T8_MAIN_CURSEDSTAFF": "cursestaff",
    "T8_MAIN_CURSEDSTAFF@1": "cursestaff",
    "T8_MAIN_CURSEDSTAFF@2": "cursestaff",
    "T8_MAIN_CURSEDSTAFF@3": "cursestaff",
    "T4_2H_CURSEDSTAFF": "cursestaff",
    "T4_2H_CURSEDSTAFF@1": "cursestaff",
    "T4_2H_CURSEDSTAFF@2": "cursestaff",
    "T4_2H_CURSEDSTAFF@3": "cursestaff",
    "T5_2H_CURSEDSTAFF": "cursestaff",
    "T5_2H_CURSEDSTAFF@1": "cursestaff",
    "T5_2H_CURSEDSTAFF@2": "cursestaff",
    "T5_2H_CURSEDSTAFF@3": "cursestaff",
    "T6_2H_CURSEDSTAFF": "cursestaff",
    "T6_2H_CURSEDSTAFF@1": "cursestaff",
    "T6_2H_CURSEDSTAFF@2": "cursestaff",
    "T6_2H_CURSEDSTAFF@3": "cursestaff",
    "T7_2H_CURSEDSTAFF": "cursestaff",
    "T7_2H_CURSEDSTAFF@1": "cursestaff",
    "T7_2H_CURSEDSTAFF@2": "cursestaff",
    "T7_2H_CURSEDSTAFF@3": "cursestaff",
    "T8_2H_CURSEDSTAFF": "cursestaff",
    "T8_2H_CURSEDSTAFF@1": "cursestaff",
    "T8_2H_CURSEDSTAFF@2": "cursestaff",
    "T8_2H_CURSEDSTAFF@3": "cursestaff",
    "T4_2H_DEMONICSTAFF": "cursestaff",
    "T4_2H_DEMONICSTAFF@1": "cursestaff",
    "T4_2H_DEMONICSTAFF@2": "cursestaff",
    "T4_2H_DEMONICSTAFF@3": "cursestaff",
    "T5_2H_DEMONICSTAFF": "cursestaff",
    "T5_2H_DEMONICSTAFF@1": "cursestaff",
    "T5_2H_DEMONICSTAFF@2": "cursestaff",
    "T5_2H_DEMONICSTAFF@3": "cursestaff",
    "T6_2H_DEMONICSTAFF": "cursestaff",
    "T6_2H_DEMONICSTAFF@1": "cursestaff",
    "T6_2H_DEMONICSTAFF@2": "cursestaff",
    "T6_2H_DEMONICSTAFF@3": "cursestaff",
    "T7_2H_DEMONICSTAFF": "cursestaff",
    "T7_2H_DEMONICSTAFF@1": "cursestaff",
    "T7_2H_DEMONICSTAFF@2": "cursestaff",
    "T7_2H_DEMONICSTAFF@3": "cursestaff",
    "T8_2H_DEMONICSTAFF": "cursestaff",
    "T8_2H_DEMONICSTAFF@1": "cursestaff",
    "T8_2H_DEMONICSTAFF@2": "cursestaff",
    "T8_2H_DEMONICSTAFF@3": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_UNDEAD": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_UNDEAD@1": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_UNDEAD@2": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_UNDEAD@3": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_UNDEAD": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_UNDEAD@1": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_UNDEAD@2": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_UNDEAD@3": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_UNDEAD": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_UNDEAD@1": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_UNDEAD@2": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_UNDEAD@3": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_UNDEAD": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_UNDEAD@1": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_UNDEAD@2": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_UNDEAD@3": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_UNDEAD": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_UNDEAD@1": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_UNDEAD@2": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_UNDEAD@3": "cursestaff",
    "T4_2H_SKULLORB_HELL": "cursestaff",
    "T4_2H_SKULLORB_HELL@1": "cursestaff",
    "T4_2H_SKULLORB_HELL@2": "cursestaff",
    "T4_2H_SKULLORB_HELL@3": "cursestaff",
    "T5_2H_SKULLORB_HELL": "cursestaff",
    "T5_2H_SKULLORB_HELL@1": "cursestaff",
    "T5_2H_SKULLORB_HELL@2": "cursestaff",
    "T5_2H_SKULLORB_HELL@3": "cursestaff",
    "T6_2H_SKULLORB_HELL": "cursestaff",
    "T6_2H_SKULLORB_HELL@1": "cursestaff",
    "T6_2H_SKULLORB_HELL@2": "cursestaff",
    "T6_2H_SKULLORB_HELL@3": "cursestaff",
    "T7_2H_SKULLORB_HELL": "cursestaff",
    "T7_2H_SKULLORB_HELL@1": "cursestaff",
    "T7_2H_SKULLORB_HELL@2": "cursestaff",
    "T7_2H_SKULLORB_HELL@3": "cursestaff",
    "T8_2H_SKULLORB_HELL": "cursestaff",
    "T8_2H_SKULLORB_HELL@1": "cursestaff",
    "T8_2H_SKULLORB_HELL@2": "cursestaff",
    "T8_2H_SKULLORB_HELL@3": "cursestaff",
    "T4_2H_CURSEDSTAFF_MORGANA": "cursestaff",
    "T4_2H_CURSEDSTAFF_MORGANA@1": "cursestaff",
    "T4_2H_CURSEDSTAFF_MORGANA@2": "cursestaff",
    "T4_2H_CURSEDSTAFF_MORGANA@3": "cursestaff",
    "T5_2H_CURSEDSTAFF_MORGANA": "cursestaff",
    "T5_2H_CURSEDSTAFF_MORGANA@1": "cursestaff",
    "T5_2H_CURSEDSTAFF_MORGANA@2": "cursestaff",
    "T5_2H_CURSEDSTAFF_MORGANA@3": "cursestaff",
    "T6_2H_CURSEDSTAFF_MORGANA": "cursestaff",
    "T6_2H_CURSEDSTAFF_MORGANA@1": "cursestaff",
    "T6_2H_CURSEDSTAFF_MORGANA@2": "cursestaff",
    "T6_2H_CURSEDSTAFF_MORGANA@3": "cursestaff",
    "T7_2H_CURSEDSTAFF_MORGANA": "cursestaff",
    "T7_2H_CURSEDSTAFF_MORGANA@1": "cursestaff",
    "T7_2H_CURSEDSTAFF_MORGANA@2": "cursestaff",
    "T7_2H_CURSEDSTAFF_MORGANA@3": "cursestaff",
    "T8_2H_CURSEDSTAFF_MORGANA": "cursestaff",
    "T8_2H_CURSEDSTAFF_MORGANA@1": "cursestaff",
    "T8_2H_CURSEDSTAFF_MORGANA@2": "cursestaff",
    "T8_2H_CURSEDSTAFF_MORGANA@3": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_AVALON": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_AVALON@1": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_AVALON@2": "cursestaff",
    "T4_MAIN_CURSEDSTAFF_AVALON@3": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_AVALON": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_AVALON@1": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_AVALON@2": "cursestaff",
    "T5_MAIN_CURSEDSTAFF_AVALON@3": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_AVALON": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_AVALON@1": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_AVALON@2": "cursestaff",
    "T6_MAIN_CURSEDSTAFF_AVALON@3": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_AVALON": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_AVALON@1": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_AVALON@2": "cursestaff",
    "T7_MAIN_CURSEDSTAFF_AVALON@3": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_AVALON": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_AVALON@1": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_AVALON@2": "cursestaff",
    "T8_MAIN_CURSEDSTAFF_AVALON@3": "cursestaff",
    "T2_MAIN_FIRESTAFF": "firestaff",
    "T3_MAIN_FIRESTAFF": "firestaff",
    "T4_MAIN_FIRESTAFF": "firestaff",
    "T4_MAIN_FIRESTAFF@1": "firestaff",
    "T4_MAIN_FIRESTAFF@2": "firestaff",
    "T4_MAIN_FIRESTAFF@3": "firestaff",
    "T5_MAIN_FIRESTAFF": "firestaff",
    "T5_MAIN_FIRESTAFF@1": "firestaff",
    "T5_MAIN_FIRESTAFF@2": "firestaff",
    "T5_MAIN_FIRESTAFF@3": "firestaff",
    "T6_MAIN_FIRESTAFF": "firestaff",
    "T6_MAIN_FIRESTAFF@1": "firestaff",
    "T6_MAIN_FIRESTAFF@2": "firestaff",
    "T6_MAIN_FIRESTAFF@3": "firestaff",
    "T7_MAIN_FIRESTAFF": "firestaff",
    "T7_MAIN_FIRESTAFF@1": "firestaff",
    "T7_MAIN_FIRESTAFF@2": "firestaff",
    "T7_MAIN_FIRESTAFF@3": "firestaff",
    "T8_MAIN_FIRESTAFF": "firestaff",
    "T8_MAIN_FIRESTAFF@1": "firestaff",
    "T8_MAIN_FIRESTAFF@2": "firestaff",
    "T8_MAIN_FIRESTAFF@3": "firestaff",
    "T4_2H_FIRESTAFF": "firestaff",
    "T4_2H_FIRESTAFF@1": "firestaff",
    "T4_2H_FIRESTAFF@2": "firestaff",
    "T4_2H_FIRESTAFF@3": "firestaff",
    "T5_2H_FIRESTAFF": "firestaff",
    "T5_2H_FIRESTAFF@1": "firestaff",
    "T5_2H_FIRESTAFF@2": "firestaff",
    "T5_2H_FIRESTAFF@3": "firestaff",
    "T6_2H_FIRESTAFF": "firestaff",
    "T6_2H_FIRESTAFF@1": "firestaff",
    "T6_2H_FIRESTAFF@2": "firestaff",
    "T6_2H_FIRESTAFF@3": "firestaff",
    "T7_2H_FIRESTAFF": "firestaff",
    "T7_2H_FIRESTAFF@1": "firestaff",
    "T7_2H_FIRESTAFF@2": "firestaff",
    "T7_2H_FIRESTAFF@3": "firestaff",
    "T8_2H_FIRESTAFF": "firestaff",
    "T8_2H_FIRESTAFF@1": "firestaff",
    "T8_2H_FIRESTAFF@2": "firestaff",
    "T8_2H_FIRESTAFF@3": "firestaff",
    "T4_2H_INFERNOSTAFF": "firestaff",
    "T4_2H_INFERNOSTAFF@1": "firestaff",
    "T4_2H_INFERNOSTAFF@2": "firestaff",
    "T4_2H_INFERNOSTAFF@3": "firestaff",
    "T5_2H_INFERNOSTAFF": "firestaff",
    "T5_2H_INFERNOSTAFF@1": "firestaff",
    "T5_2H_INFERNOSTAFF@2": "firestaff",
    "T5_2H_INFERNOSTAFF@3": "firestaff",
    "T6_2H_INFERNOSTAFF": "firestaff",
    "T6_2H_INFERNOSTAFF@1": "firestaff",
    "T6_2H_INFERNOSTAFF@2": "firestaff",
    "T6_2H_INFERNOSTAFF@3": "firestaff",
    "T7_2H_INFERNOSTAFF": "firestaff",
    "T7_2H_INFERNOSTAFF@1": "firestaff",
    "T7_2H_INFERNOSTAFF@2": "firestaff",
    "T7_2H_INFERNOSTAFF@3": "firestaff",
    "T8_2H_INFERNOSTAFF": "firestaff",
    "T8_2H_INFERNOSTAFF@1": "firestaff",
    "T8_2H_INFERNOSTAFF@2": "firestaff",
    "T8_2H_INFERNOSTAFF@3": "firestaff",
    "T4_MAIN_FIRESTAFF_KEEPER": "firestaff",
    "T4_MAIN_FIRESTAFF_KEEPER@1": "firestaff",
    "T4_MAIN_FIRESTAFF_KEEPER@2": "firestaff",
    "T4_MAIN_FIRESTAFF_KEEPER@3": "firestaff",
    "T5_MAIN_FIRESTAFF_KEEPER": "firestaff",
    "T5_MAIN_FIRESTAFF_KEEPER@1": "firestaff",
    "T5_MAIN_FIRESTAFF_KEEPER@2": "firestaff",
    "T5_MAIN_FIRESTAFF_KEEPER@3": "firestaff",
    "T6_MAIN_FIRESTAFF_KEEPER": "firestaff",
    "T6_MAIN_FIRESTAFF_KEEPER@1": "firestaff",
    "T6_MAIN_FIRESTAFF_KEEPER@2": "firestaff",
    "T6_MAIN_FIRESTAFF_KEEPER@3": "firestaff",
    "T7_MAIN_FIRESTAFF_KEEPER": "firestaff",
    "T7_MAIN_FIRESTAFF_KEEPER@1": "firestaff",
    "T7_MAIN_FIRESTAFF_KEEPER@2": "firestaff",
    "T7_MAIN_FIRESTAFF_KEEPER@3": "firestaff",
    "T8_MAIN_FIRESTAFF_KEEPER": "firestaff",
    "T8_MAIN_FIRESTAFF_KEEPER@1": "firestaff",
    "T8_MAIN_FIRESTAFF_KEEPER@2": "firestaff",
    "T8_MAIN_FIRESTAFF_KEEPER@3": "firestaff",
    "T4_2H_FIRESTAFF_HELL": "firestaff",
    "T4_2H_FIRESTAFF_HELL@1": "firestaff",
    "T4_2H_FIRESTAFF_HELL@2": "firestaff",
    "T4_2H_FIRESTAFF_HELL@3": "firestaff",
    "T5_2H_FIRESTAFF_HELL": "firestaff",
    "T5_2H_FIRESTAFF_HELL@1": "firestaff",
    "T5_2H_FIRESTAFF_HELL@2": "firestaff",
    "T5_2H_FIRESTAFF_HELL@3": "firestaff",
    "T6_2H_FIRESTAFF_HELL": "firestaff",
    "T6_2H_FIRESTAFF_HELL@1": "firestaff",
    "T6_2H_FIRESTAFF_HELL@2": "firestaff",
    "T6_2H_FIRESTAFF_HELL@3": "firestaff",
    "T7_2H_FIRESTAFF_HELL": "firestaff",
    "T7_2H_FIRESTAFF_HELL@1": "firestaff",
    "T7_2H_FIRESTAFF_HELL@2": "firestaff",
    "T7_2H_FIRESTAFF_HELL@3": "firestaff",
    "T8_2H_FIRESTAFF_HELL": "firestaff",
    "T8_2H_FIRESTAFF_HELL@1": "firestaff",
    "T8_2H_FIRESTAFF_HELL@2": "firestaff",
    "T8_2H_FIRESTAFF_HELL@3": "firestaff",
    "T4_2H_INFERNOSTAFF_MORGANA": "firestaff",
    "T4_2H_INFERNOSTAFF_MORGANA@1": "firestaff",
    "T4_2H_INFERNOSTAFF_MORGANA@2": "firestaff",
    "T4_2H_INFERNOSTAFF_MORGANA@3": "firestaff",
    "T5_2H_INFERNOSTAFF_MORGANA": "firestaff",
    "T5_2H_INFERNOSTAFF_MORGANA@1": "firestaff",
    "T5_2H_INFERNOSTAFF_MORGANA@2": "firestaff",
    "T5_2H_INFERNOSTAFF_MORGANA@3": "firestaff",
    "T6_2H_INFERNOSTAFF_MORGANA": "firestaff",
    "T6_2H_INFERNOSTAFF_MORGANA@1": "firestaff",
    "T6_2H_INFERNOSTAFF_MORGANA@2": "firestaff",
    "T6_2H_INFERNOSTAFF_MORGANA@3": "firestaff",
    "T7_2H_INFERNOSTAFF_MORGANA": "firestaff",
    "T7_2H_INFERNOSTAFF_MORGANA@1": "firestaff",
    "T7_2H_INFERNOSTAFF_MORGANA@2": "firestaff",
    "T7_2H_INFERNOSTAFF_MORGANA@3": "firestaff",
    "T8_2H_INFERNOSTAFF_MORGANA": "firestaff",
    "T8_2H_INFERNOSTAFF_MORGANA@1": "firestaff",
    "T8_2H_INFERNOSTAFF_MORGANA@2": "firestaff",
    "T8_2H_INFERNOSTAFF_MORGANA@3": "firestaff",
    "T4_2H_FIRE_RINGPAIR_AVALON": "firestaff",
    "T4_2H_FIRE_RINGPAIR_AVALON@1": "firestaff",
    "T4_2H_FIRE_RINGPAIR_AVALON@2": "firestaff",
    "T4_2H_FIRE_RINGPAIR_AVALON@3": "firestaff",
    "T5_2H_FIRE_RINGPAIR_AVALON": "firestaff",
    "T5_2H_FIRE_RINGPAIR_AVALON@1": "firestaff",
    "T5_2H_FIRE_RINGPAIR_AVALON@2": "firestaff",
    "T5_2H_FIRE_RINGPAIR_AVALON@3": "firestaff",
    "T6_2H_FIRE_RINGPAIR_AVALON": "firestaff",
    "T6_2H_FIRE_RINGPAIR_AVALON@1": "firestaff",
    "T6_2H_FIRE_RINGPAIR_AVALON@2": "firestaff",
    "T6_2H_FIRE_RINGPAIR_AVALON@3": "firestaff",
    "T7_2H_FIRE_RINGPAIR_AVALON": "firestaff",
    "T7_2H_FIRE_RINGPAIR_AVALON@1": "firestaff",
    "T7_2H_FIRE_RINGPAIR_AVALON@2": "firestaff",
    "T7_2H_FIRE_RINGPAIR_AVALON@3": "firestaff",
    "T8_2H_FIRE_RINGPAIR_AVALON": "firestaff",
    "T8_2H_FIRE_RINGPAIR_AVALON@1": "firestaff",
    "T8_2H_FIRE_RINGPAIR_AVALON@2": "firestaff",
    "T8_2H_FIRE_RINGPAIR_AVALON@3": "firestaff",
    "T3_MAIN_FROSTSTAFF": "froststaff",
    "T4_MAIN_FROSTSTAFF": "froststaff",
    "T4_MAIN_FROSTSTAFF@1": "froststaff",
    "T4_MAIN_FROSTSTAFF@2": "froststaff",
    "T4_MAIN_FROSTSTAFF@3": "froststaff",
    "T5_MAIN_FROSTSTAFF": "froststaff",
    "T5_MAIN_FROSTSTAFF@1": "froststaff",
    "T5_MAIN_FROSTSTAFF@2": "froststaff",
    "T5_MAIN_FROSTSTAFF@3": "froststaff",
    "T6_MAIN_FROSTSTAFF": "froststaff",
    "T6_MAIN_FROSTSTAFF@1": "froststaff",
    "T6_MAIN_FROSTSTAFF@2": "froststaff",
    "T6_MAIN_FROSTSTAFF@3": "froststaff",
    "T7_MAIN_FROSTSTAFF": "froststaff",
    "T7_MAIN_FROSTSTAFF@1": "froststaff",
    "T7_MAIN_FROSTSTAFF@2": "froststaff",
    "T7_MAIN_FROSTSTAFF@3": "froststaff",
    "T8_MAIN_FROSTSTAFF": "froststaff",
    "T8_MAIN_FROSTSTAFF@1": "froststaff",
    "T8_MAIN_FROSTSTAFF@2": "froststaff",
    "T8_MAIN_FROSTSTAFF@3": "froststaff",
    "T4_2H_FROSTSTAFF": "froststaff",
    "T4_2H_FROSTSTAFF@1": "froststaff",
    "T4_2H_FROSTSTAFF@2": "froststaff",
    "T4_2H_FROSTSTAFF@3": "froststaff",
    "T5_2H_FROSTSTAFF": "froststaff",
    "T5_2H_FROSTSTAFF@1": "froststaff",
    "T5_2H_FROSTSTAFF@2": "froststaff",
    "T5_2H_FROSTSTAFF@3": "froststaff",
    "T6_2H_FROSTSTAFF": "froststaff",
    "T6_2H_FROSTSTAFF@1": "froststaff",
    "T6_2H_FROSTSTAFF@2": "froststaff",
    "T6_2H_FROSTSTAFF@3": "froststaff",
    "T7_2H_FROSTSTAFF": "froststaff",
    "T7_2H_FROSTSTAFF@1": "froststaff",
    "T7_2H_FROSTSTAFF@2": "froststaff",
    "T7_2H_FROSTSTAFF@3": "froststaff",
    "T8_2H_FROSTSTAFF": "froststaff",
    "T8_2H_FROSTSTAFF@1": "froststaff",
    "T8_2H_FROSTSTAFF@2": "froststaff",
    "T8_2H_FROSTSTAFF@3": "froststaff",
    "T4_2H_GLACIALSTAFF": "froststaff",
    "T4_2H_GLACIALSTAFF@1": "froststaff",
    "T4_2H_GLACIALSTAFF@2": "froststaff",
    "T4_2H_GLACIALSTAFF@3": "froststaff",
    "T5_2H_GLACIALSTAFF": "froststaff",
    "T5_2H_GLACIALSTAFF@1": "froststaff",
    "T5_2H_GLACIALSTAFF@2": "froststaff",
    "T5_2H_GLACIALSTAFF@3": "froststaff",
    "T6_2H_GLACIALSTAFF": "froststaff",
    "T6_2H_GLACIALSTAFF@1": "froststaff",
    "T6_2H_GLACIALSTAFF@2": "froststaff",
    "T6_2H_GLACIALSTAFF@3": "froststaff",
    "T7_2H_GLACIALSTAFF": "froststaff",
    "T7_2H_GLACIALSTAFF@1": "froststaff",
    "T7_2H_GLACIALSTAFF@2": "froststaff",
    "T7_2H_GLACIALSTAFF@3": "froststaff",
    "T8_2H_GLACIALSTAFF": "froststaff",
    "T8_2H_GLACIALSTAFF@1": "froststaff",
    "T8_2H_GLACIALSTAFF@2": "froststaff",
    "T8_2H_GLACIALSTAFF@3": "froststaff",
    "T4_MAIN_FROSTSTAFF_KEEPER": "froststaff",
    "T4_MAIN_FROSTSTAFF_KEEPER@1": "froststaff",
    "T4_MAIN_FROSTSTAFF_KEEPER@2": "froststaff",
    "T4_MAIN_FROSTSTAFF_KEEPER@3": "froststaff",
    "T5_MAIN_FROSTSTAFF_KEEPER": "froststaff",
    "T5_MAIN_FROSTSTAFF_KEEPER@1": "froststaff",
    "T5_MAIN_FROSTSTAFF_KEEPER@2": "froststaff",
    "T5_MAIN_FROSTSTAFF_KEEPER@3": "froststaff",
    "T6_MAIN_FROSTSTAFF_KEEPER": "froststaff",
    "T6_MAIN_FROSTSTAFF_KEEPER@1": "froststaff",
    "T6_MAIN_FROSTSTAFF_KEEPER@2": "froststaff",
    "T6_MAIN_FROSTSTAFF_KEEPER@3": "froststaff",
    "T7_MAIN_FROSTSTAFF_KEEPER": "froststaff",
    "T7_MAIN_FROSTSTAFF_KEEPER@1": "froststaff",
    "T7_MAIN_FROSTSTAFF_KEEPER@2": "froststaff",
    "T7_MAIN_FROSTSTAFF_KEEPER@3": "froststaff",
    "T8_MAIN_FROSTSTAFF_KEEPER": "froststaff",
    "T8_MAIN_FROSTSTAFF_KEEPER@1": "froststaff",
    "T8_MAIN_FROSTSTAFF_KEEPER@2": "froststaff",
    "T8_MAIN_FROSTSTAFF_KEEPER@3": "froststaff",
    "T4_2H_ICEGAUNTLETS_HELL": "froststaff",
    "T4_2H_ICEGAUNTLETS_HELL@1": "froststaff",
    "T4_2H_ICEGAUNTLETS_HELL@2": "froststaff",
    "T4_2H_ICEGAUNTLETS_HELL@3": "froststaff",
    "T5_2H_ICEGAUNTLETS_HELL": "froststaff",
    "T5_2H_ICEGAUNTLETS_HELL@1": "froststaff",
    "T5_2H_ICEGAUNTLETS_HELL@2": "froststaff",
    "T5_2H_ICEGAUNTLETS_HELL@3": "froststaff",
    "T6_2H_ICEGAUNTLETS_HELL": "froststaff",
    "T6_2H_ICEGAUNTLETS_HELL@1": "froststaff",
    "T6_2H_ICEGAUNTLETS_HELL@2": "froststaff",
    "T6_2H_ICEGAUNTLETS_HELL@3": "froststaff",
    "T7_2H_ICEGAUNTLETS_HELL": "froststaff",
    "T7_2H_ICEGAUNTLETS_HELL@1": "froststaff",
    "T7_2H_ICEGAUNTLETS_HELL@2": "froststaff",
    "T7_2H_ICEGAUNTLETS_HELL@3": "froststaff",
    "T8_2H_ICEGAUNTLETS_HELL": "froststaff",
    "T8_2H_ICEGAUNTLETS_HELL@1": "froststaff",
    "T8_2H_ICEGAUNTLETS_HELL@2": "froststaff",
    "T8_2H_ICEGAUNTLETS_HELL@3": "froststaff",
    "T4_2H_ICECRYSTAL_UNDEAD": "froststaff",
    "T4_2H_ICECRYSTAL_UNDEAD@1": "froststaff",
    "T4_2H_ICECRYSTAL_UNDEAD@2": "froststaff",
    "T4_2H_ICECRYSTAL_UNDEAD@3": "froststaff",
    "T5_2H_ICECRYSTAL_UNDEAD": "froststaff",
    "T5_2H_ICECRYSTAL_UNDEAD@1": "froststaff",
    "T5_2H_ICECRYSTAL_UNDEAD@2": "froststaff",
    "T5_2H_ICECRYSTAL_UNDEAD@3": "froststaff",
    "T6_2H_ICECRYSTAL_UNDEAD": "froststaff",
    "T6_2H_ICECRYSTAL_UNDEAD@1": "froststaff",
    "T6_2H_ICECRYSTAL_UNDEAD@2": "froststaff",
    "T6_2H_ICECRYSTAL_UNDEAD@3": "froststaff",
    "T7_2H_ICECRYSTAL_UNDEAD": "froststaff",
    "T7_2H_ICECRYSTAL_UNDEAD@1": "froststaff",
    "T7_2H_ICECRYSTAL_UNDEAD@2": "froststaff",
    "T7_2H_ICECRYSTAL_UNDEAD@3": "froststaff",
    "T8_2H_ICECRYSTAL_UNDEAD": "froststaff",
    "T8_2H_ICECRYSTAL_UNDEAD@1": "froststaff",
    "T8_2H_ICECRYSTAL_UNDEAD@2": "froststaff",
    "T8_2H_ICECRYSTAL_UNDEAD@3": "froststaff",
    "T4_MAIN_FROSTSTAFF_AVALON": "froststaff",
    "T4_MAIN_FROSTSTAFF_AVALON@1": "froststaff",
    "T4_MAIN_FROSTSTAFF_AVALON@2": "froststaff",
    "T4_MAIN_FROSTSTAFF_AVALON@3": "froststaff",
    "T5_MAIN_FROSTSTAFF_AVALON": "froststaff",
    "T5_MAIN_FROSTSTAFF_AVALON@1": "froststaff",
    "T5_MAIN_FROSTSTAFF_AVALON@2": "froststaff",
    "T5_MAIN_FROSTSTAFF_AVALON@3": "froststaff",
    "T6_MAIN_FROSTSTAFF_AVALON": "froststaff",
    "T6_MAIN_FROSTSTAFF_AVALON@1": "froststaff",
    "T6_MAIN_FROSTSTAFF_AVALON@2": "froststaff",
    "T6_MAIN_FROSTSTAFF_AVALON@3": "froststaff",
    "T7_MAIN_FROSTSTAFF_AVALON": "froststaff",
    "T7_MAIN_FROSTSTAFF_AVALON@1": "froststaff",
    "T7_MAIN_FROSTSTAFF_AVALON@2": "froststaff",
    "T7_MAIN_FROSTSTAFF_AVALON@3": "froststaff",
    "T8_MAIN_FROSTSTAFF_AVALON": "froststaff",
    "T8_MAIN_FROSTSTAFF_AVALON@1": "froststaff",
    "T8_MAIN_FROSTSTAFF_AVALON@2": "froststaff",
    "T8_MAIN_FROSTSTAFF_AVALON@3": "froststaff",
    "T3_MAIN_ARCANESTAFF": "arcanestaff",
    "T4_MAIN_ARCANESTAFF": "arcanestaff",
    "T4_MAIN_ARCANESTAFF@1": "arcanestaff",
    "T4_MAIN_ARCANESTAFF@2": "arcanestaff",
    "T4_MAIN_ARCANESTAFF@3": "arcanestaff",
    "T5_MAIN_ARCANESTAFF": "arcanestaff",
    "T5_MAIN_ARCANESTAFF@1": "arcanestaff",
    "T5_MAIN_ARCANESTAFF@2": "arcanestaff",
    "T5_MAIN_ARCANESTAFF@3": "arcanestaff",
    "T6_MAIN_ARCANESTAFF": "arcanestaff",
    "T6_MAIN_ARCANESTAFF@1": "arcanestaff",
    "T6_MAIN_ARCANESTAFF@2": "arcanestaff",
    "T6_MAIN_ARCANESTAFF@3": "arcanestaff",
    "T7_MAIN_ARCANESTAFF": "arcanestaff",
    "T7_MAIN_ARCANESTAFF@1": "arcanestaff",
    "T7_MAIN_ARCANESTAFF@2": "arcanestaff",
    "T7_MAIN_ARCANESTAFF@3": "arcanestaff",
    "T8_MAIN_ARCANESTAFF": "arcanestaff",
    "T8_MAIN_ARCANESTAFF@1": "arcanestaff",
    "T8_MAIN_ARCANESTAFF@2": "arcanestaff",
    "T8_MAIN_ARCANESTAFF@3": "arcanestaff",
    "T4_2H_ARCANESTAFF": "arcanestaff",
    "T4_2H_ARCANESTAFF@1": "arcanestaff",
    "T4_2H_ARCANESTAFF@2": "arcanestaff",
    "T4_2H_ARCANESTAFF@3": "arcanestaff",
    "T5_2H_ARCANESTAFF": "arcanestaff",
    "T5_2H_ARCANESTAFF@1": "arcanestaff",
    "T5_2H_ARCANESTAFF@2": "arcanestaff",
    "T5_2H_ARCANESTAFF@3": "arcanestaff",
    "T6_2H_ARCANESTAFF": "arcanestaff",
    "T6_2H_ARCANESTAFF@1": "arcanestaff",
    "T6_2H_ARCANESTAFF@2": "arcanestaff",
    "T6_2H_ARCANESTAFF@3": "arcanestaff",
    "T7_2H_ARCANESTAFF": "arcanestaff",
    "T7_2H_ARCANESTAFF@1": "arcanestaff",
    "T7_2H_ARCANESTAFF@2": "arcanestaff",
    "T7_2H_ARCANESTAFF@3": "arcanestaff",
    "T8_2H_ARCANESTAFF": "arcanestaff",
    "T8_2H_ARCANESTAFF@1": "arcanestaff",
    "T8_2H_ARCANESTAFF@2": "arcanestaff",
    "T8_2H_ARCANESTAFF@3": "arcanestaff",
    "T4_2H_ENIGMATICSTAFF": "arcanestaff",
    "T4_2H_ENIGMATICSTAFF@1": "arcanestaff",
    "T4_2H_ENIGMATICSTAFF@2": "arcanestaff",
    "T4_2H_ENIGMATICSTAFF@3": "arcanestaff",
    "T5_2H_ENIGMATICSTAFF": "arcanestaff",
    "T5_2H_ENIGMATICSTAFF@1": "arcanestaff",
    "T5_2H_ENIGMATICSTAFF@2": "arcanestaff",
    "T5_2H_ENIGMATICSTAFF@3": "arcanestaff",
    "T6_2H_ENIGMATICSTAFF": "arcanestaff",
    "T6_2H_ENIGMATICSTAFF@1": "arcanestaff",
    "T6_2H_ENIGMATICSTAFF@2": "arcanestaff",
    "T6_2H_ENIGMATICSTAFF@3": "arcanestaff",
    "T7_2H_ENIGMATICSTAFF": "arcanestaff",
    "T7_2H_ENIGMATICSTAFF@1": "arcanestaff",
    "T7_2H_ENIGMATICSTAFF@2": "arcanestaff",
    "T7_2H_ENIGMATICSTAFF@3": "arcanestaff",
    "T8_2H_ENIGMATICSTAFF": "arcanestaff",
    "T8_2H_ENIGMATICSTAFF@1": "arcanestaff",
    "T8_2H_ENIGMATICSTAFF@2": "arcanestaff",
    "T8_2H_ENIGMATICSTAFF@3": "arcanestaff",
    "T4_MAIN_ARCANESTAFF_UNDEAD": "arcanestaff",
    "T4_MAIN_ARCANESTAFF_UNDEAD@1": "arcanestaff",
    "T4_MAIN_ARCANESTAFF_UNDEAD@2": "arcanestaff",
    "T4_MAIN_ARCANESTAFF_UNDEAD@3": "arcanestaff",
    "T5_MAIN_ARCANESTAFF_UNDEAD": "arcanestaff",
    "T5_MAIN_ARCANESTAFF_UNDEAD@1": "arcanestaff",
    "T5_MAIN_ARCANESTAFF_UNDEAD@2": "arcanestaff",
    "T5_MAIN_ARCANESTAFF_UNDEAD@3": "arcanestaff",
    "T6_MAIN_ARCANESTAFF_UNDEAD": "arcanestaff",
    "T6_MAIN_ARCANESTAFF_UNDEAD@1": "arcanestaff",
    "T6_MAIN_ARCANESTAFF_UNDEAD@2": "arcanestaff",
    "T6_MAIN_ARCANESTAFF_UNDEAD@3": "arcanestaff",
    "T7_MAIN_ARCANESTAFF_UNDEAD": "arcanestaff",
    "T7_MAIN_ARCANESTAFF_UNDEAD@1": "arcanestaff",
    "T7_MAIN_ARCANESTAFF_UNDEAD@2": "arcanestaff",
    "T7_MAIN_ARCANESTAFF_UNDEAD@3": "arcanestaff",
    "T8_MAIN_ARCANESTAFF_UNDEAD": "arcanestaff",
    "T8_MAIN_ARCANESTAFF_UNDEAD@1": "arcanestaff",
    "T8_MAIN_ARCANESTAFF_UNDEAD@2": "arcanestaff",
    "T8_MAIN_ARCANESTAFF_UNDEAD@3": "arcanestaff",
    "T4_2H_ARCANESTAFF_HELL": "arcanestaff",
    "T4_2H_ARCANESTAFF_HELL@1": "arcanestaff",
    "T4_2H_ARCANESTAFF_HELL@2": "arcanestaff",
    "T4_2H_ARCANESTAFF_HELL@3": "arcanestaff",
    "T5_2H_ARCANESTAFF_HELL": "arcanestaff",
    "T5_2H_ARCANESTAFF_HELL@1": "arcanestaff",
    "T5_2H_ARCANESTAFF_HELL@2": "arcanestaff",
    "T5_2H_ARCANESTAFF_HELL@3": "arcanestaff",
    "T6_2H_ARCANESTAFF_HELL": "arcanestaff",
    "T6_2H_ARCANESTAFF_HELL@1": "arcanestaff",
    "T6_2H_ARCANESTAFF_HELL@2": "arcanestaff",
    "T6_2H_ARCANESTAFF_HELL@3": "arcanestaff",
    "T7_2H_ARCANESTAFF_HELL": "arcanestaff",
    "T7_2H_ARCANESTAFF_HELL@1": "arcanestaff",
    "T7_2H_ARCANESTAFF_HELL@2": "arcanestaff",
    "T7_2H_ARCANESTAFF_HELL@3": "arcanestaff",
    "T8_2H_ARCANESTAFF_HELL": "arcanestaff",
    "T8_2H_ARCANESTAFF_HELL@1": "arcanestaff",
    "T8_2H_ARCANESTAFF_HELL@2": "arcanestaff",
    "T8_2H_ARCANESTAFF_HELL@3": "arcanestaff",
    "T4_2H_ENIGMATICORB_MORGANA": "arcanestaff",
    "T4_2H_ENIGMATICORB_MORGANA@1": "arcanestaff",
    "T4_2H_ENIGMATICORB_MORGANA@2": "arcanestaff",
    "T4_2H_ENIGMATICORB_MORGANA@3": "arcanestaff",
    "T5_2H_ENIGMATICORB_MORGANA": "arcanestaff",
    "T5_2H_ENIGMATICORB_MORGANA@1": "arcanestaff",
    "T5_2H_ENIGMATICORB_MORGANA@2": "arcanestaff",
    "T5_2H_ENIGMATICORB_MORGANA@3": "arcanestaff",
    "T6_2H_ENIGMATICORB_MORGANA": "arcanestaff",
    "T6_2H_ENIGMATICORB_MORGANA@1": "arcanestaff",
    "T6_2H_ENIGMATICORB_MORGANA@2": "arcanestaff",
    "T6_2H_ENIGMATICORB_MORGANA@3": "arcanestaff",
    "T7_2H_ENIGMATICORB_MORGANA": "arcanestaff",
    "T7_2H_ENIGMATICORB_MORGANA@1": "arcanestaff",
    "T7_2H_ENIGMATICORB_MORGANA@2": "arcanestaff",
    "T7_2H_ENIGMATICORB_MORGANA@3": "arcanestaff",
    "T8_2H_ENIGMATICORB_MORGANA": "arcanestaff",
    "T8_2H_ENIGMATICORB_MORGANA@1": "arcanestaff",
    "T8_2H_ENIGMATICORB_MORGANA@2": "arcanestaff",
    "T8_2H_ENIGMATICORB_MORGANA@3": "arcanestaff",
    "T4_2H_ARCANE_RINGPAIR_AVALON": "arcanestaff",
    "T4_2H_ARCANE_RINGPAIR_AVALON@1": "arcanestaff",
    "T4_2H_ARCANE_RINGPAIR_AVALON@2": "arcanestaff",
    "T4_2H_ARCANE_RINGPAIR_AVALON@3": "arcanestaff",
    "T5_2H_ARCANE_RINGPAIR_AVALON": "arcanestaff",
    "T5_2H_ARCANE_RINGPAIR_AVALON@1": "arcanestaff",
    "T5_2H_ARCANE_RINGPAIR_AVALON@2": "arcanestaff",
    "T5_2H_ARCANE_RINGPAIR_AVALON@3": "arcanestaff",
    "T6_2H_ARCANE_RINGPAIR_AVALON": "arcanestaff",
    "T6_2H_ARCANE_RINGPAIR_AVALON@1": "arcanestaff",
    "T6_2H_ARCANE_RINGPAIR_AVALON@2": "arcanestaff",
    "T6_2H_ARCANE_RINGPAIR_AVALON@3": "arcanestaff",
    "T7_2H_ARCANE_RINGPAIR_AVALON": "arcanestaff",
    "T7_2H_ARCANE_RINGPAIR_AVALON@1": "arcanestaff",
    "T7_2H_ARCANE_RINGPAIR_AVALON@2": "arcanestaff",
    "T7_2H_ARCANE_RINGPAIR_AVALON@3": "arcanestaff",
    "T8_2H_ARCANE_RINGPAIR_AVALON": "arcanestaff",
    "T8_2H_ARCANE_RINGPAIR_AVALON@1": "arcanestaff",
    "T8_2H_ARCANE_RINGPAIR_AVALON@2": "arcanestaff",
    "T8_2H_ARCANE_RINGPAIR_AVALON@3": "arcanestaff",
    "T3_MAIN_HOLYSTAFF": "holystaff",
    "T4_MAIN_HOLYSTAFF": "holystaff",
    "T4_MAIN_HOLYSTAFF@1": "holystaff",
    "T4_MAIN_HOLYSTAFF@2": "holystaff",
    "T4_MAIN_HOLYSTAFF@3": "holystaff",
    "T5_MAIN_HOLYSTAFF": "holystaff",
    "T5_MAIN_HOLYSTAFF@1": "holystaff",
    "T5_MAIN_HOLYSTAFF@2": "holystaff",
    "T5_MAIN_HOLYSTAFF@3": "holystaff",
    "T6_MAIN_HOLYSTAFF": "holystaff",
    "T6_MAIN_HOLYSTAFF@1": "holystaff",
    "T6_MAIN_HOLYSTAFF@2": "holystaff",
    "T6_MAIN_HOLYSTAFF@3": "holystaff",
    "T7_MAIN_HOLYSTAFF": "holystaff",
    "T7_MAIN_HOLYSTAFF@1": "holystaff",
    "T7_MAIN_HOLYSTAFF@2": "holystaff",
    "T7_MAIN_HOLYSTAFF@3": "holystaff",
    "T8_MAIN_HOLYSTAFF": "holystaff",
    "T8_MAIN_HOLYSTAFF@1": "holystaff",
    "T8_MAIN_HOLYSTAFF@2": "holystaff",
    "T8_MAIN_HOLYSTAFF@3": "holystaff",
    "T4_2H_HOLYSTAFF": "holystaff",
    "T4_2H_HOLYSTAFF@1": "holystaff",
    "T4_2H_HOLYSTAFF@2": "holystaff",
    "T4_2H_HOLYSTAFF@3": "holystaff",
    "T5_2H_HOLYSTAFF": "holystaff",
    "T5_2H_HOLYSTAFF@1": "holystaff",
    "T5_2H_HOLYSTAFF@2": "holystaff",
    "T5_2H_HOLYSTAFF@3": "holystaff",
    "T6_2H_HOLYSTAFF": "holystaff",
    "T6_2H_HOLYSTAFF@1": "holystaff",
    "T6_2H_HOLYSTAFF@2": "holystaff",
    "T6_2H_HOLYSTAFF@3": "holystaff",
    "T7_2H_HOLYSTAFF": "holystaff",
    "T7_2H_HOLYSTAFF@1": "holystaff",
    "T7_2H_HOLYSTAFF@2": "holystaff",
    "T7_2H_HOLYSTAFF@3": "holystaff",
    "T8_2H_HOLYSTAFF": "holystaff",
    "T8_2H_HOLYSTAFF@1": "holystaff",
    "T8_2H_HOLYSTAFF@2": "holystaff",
    "T8_2H_HOLYSTAFF@3": "holystaff",
    "T4_2H_DIVINESTAFF": "holystaff",
    "T4_2H_DIVINESTAFF@1": "holystaff",
    "T4_2H_DIVINESTAFF@2": "holystaff",
    "T4_2H_DIVINESTAFF@3": "holystaff",
    "T5_2H_DIVINESTAFF": "holystaff",
    "T5_2H_DIVINESTAFF@1": "holystaff",
    "T5_2H_DIVINESTAFF@2": "holystaff",
    "T5_2H_DIVINESTAFF@3": "holystaff",
    "T6_2H_DIVINESTAFF": "holystaff",
    "T6_2H_DIVINESTAFF@1": "holystaff",
    "T6_2H_DIVINESTAFF@2": "holystaff",
    "T6_2H_DIVINESTAFF@3": "holystaff",
    "T7_2H_DIVINESTAFF": "holystaff",
    "T7_2H_DIVINESTAFF@1": "holystaff",
    "T7_2H_DIVINESTAFF@2": "holystaff",
    "T7_2H_DIVINESTAFF@3": "holystaff",
    "T8_2H_DIVINESTAFF": "holystaff",
    "T8_2H_DIVINESTAFF@1": "holystaff",
    "T8_2H_DIVINESTAFF@2": "holystaff",
    "T8_2H_DIVINESTAFF@3": "holystaff",
    "T4_MAIN_HOLYSTAFF_MORGANA": "holystaff",
    "T4_MAIN_HOLYSTAFF_MORGANA@1": "holystaff",
    "T4_MAIN_HOLYSTAFF_MORGANA@2": "holystaff",
    "T4_MAIN_HOLYSTAFF_MORGANA@3": "holystaff",
    "T5_MAIN_HOLYSTAFF_MORGANA": "holystaff",
    "T5_MAIN_HOLYSTAFF_MORGANA@1": "holystaff",
    "T5_MAIN_HOLYSTAFF_MORGANA@2": "holystaff",
    "T5_MAIN_HOLYSTAFF_MORGANA@3": "holystaff",
    "T6_MAIN_HOLYSTAFF_MORGANA": "holystaff",
    "T6_MAIN_HOLYSTAFF_MORGANA@1": "holystaff",
    "T6_MAIN_HOLYSTAFF_MORGANA@2": "holystaff",
    "T6_MAIN_HOLYSTAFF_MORGANA@3": "holystaff",
    "T7_MAIN_HOLYSTAFF_MORGANA": "holystaff",
    "T7_MAIN_HOLYSTAFF_MORGANA@1": "holystaff",
    "T7_MAIN_HOLYSTAFF_MORGANA@2": "holystaff",
    "T7_MAIN_HOLYSTAFF_MORGANA@3": "holystaff",
    "T8_MAIN_HOLYSTAFF_MORGANA": "holystaff",
    "T8_MAIN_HOLYSTAFF_MORGANA@1": "holystaff",
    "T8_MAIN_HOLYSTAFF_MORGANA@2": "holystaff",
    "T8_MAIN_HOLYSTAFF_MORGANA@3": "holystaff",
    "T4_2H_HOLYSTAFF_HELL": "holystaff",
    "T4_2H_HOLYSTAFF_HELL@1": "holystaff",
    "T4_2H_HOLYSTAFF_HELL@2": "holystaff",
    "T4_2H_HOLYSTAFF_HELL@3": "holystaff",
    "T5_2H_HOLYSTAFF_HELL": "holystaff",
    "T5_2H_HOLYSTAFF_HELL@1": "holystaff",
    "T5_2H_HOLYSTAFF_HELL@2": "holystaff",
    "T5_2H_HOLYSTAFF_HELL@3": "holystaff",
    "T6_2H_HOLYSTAFF_HELL": "holystaff",
    "T6_2H_HOLYSTAFF_HELL@1": "holystaff",
    "T6_2H_HOLYSTAFF_HELL@2": "holystaff",
    "T6_2H_HOLYSTAFF_HELL@3": "holystaff",
    "T7_2H_HOLYSTAFF_HELL": "holystaff",
    "T7_2H_HOLYSTAFF_HELL@1": "holystaff",
    "T7_2H_HOLYSTAFF_HELL@2": "holystaff",
    "T7_2H_HOLYSTAFF_HELL@3": "holystaff",
    "T8_2H_HOLYSTAFF_HELL": "holystaff",
    "T8_2H_HOLYSTAFF_HELL@1": "holystaff",
    "T8_2H_HOLYSTAFF_HELL@2": "holystaff",
    "T8_2H_HOLYSTAFF_HELL@3": "holystaff",
    "T4_2H_HOLYSTAFF_UNDEAD": "holystaff",
    "T4_2H_HOLYSTAFF_UNDEAD@1": "holystaff",
    "T4_2H_HOLYSTAFF_UNDEAD@2": "holystaff",
    "T4_2H_HOLYSTAFF_UNDEAD@3": "holystaff",
    "T5_2H_HOLYSTAFF_UNDEAD": "holystaff",
    "T5_2H_HOLYSTAFF_UNDEAD@1": "holystaff",
    "T5_2H_HOLYSTAFF_UNDEAD@2": "holystaff",
    "T5_2H_HOLYSTAFF_UNDEAD@3": "holystaff",
    "T6_2H_HOLYSTAFF_UNDEAD": "holystaff",
    "T6_2H_HOLYSTAFF_UNDEAD@1": "holystaff",
    "T6_2H_HOLYSTAFF_UNDEAD@2": "holystaff",
    "T6_2H_HOLYSTAFF_UNDEAD@3": "holystaff",
    "T7_2H_HOLYSTAFF_UNDEAD": "holystaff",
    "T7_2H_HOLYSTAFF_UNDEAD@1": "holystaff",
    "T7_2H_HOLYSTAFF_UNDEAD@2": "holystaff",
    "T7_2H_HOLYSTAFF_UNDEAD@3": "holystaff",
    "T8_2H_HOLYSTAFF_UNDEAD": "holystaff",
    "T8_2H_HOLYSTAFF_UNDEAD@1": "holystaff",
    "T8_2H_HOLYSTAFF_UNDEAD@2": "holystaff",
    "T8_2H_HOLYSTAFF_UNDEAD@3": "holystaff",
    "T4_MAIN_HOLYSTAFF_AVALON": "holystaff",
    "T4_MAIN_HOLYSTAFF_AVALON@1": "holystaff",
    "T4_MAIN_HOLYSTAFF_AVALON@2": "holystaff",
    "T4_MAIN_HOLYSTAFF_AVALON@3": "holystaff",
    "T5_MAIN_HOLYSTAFF_AVALON": "holystaff",
    "T5_MAIN_HOLYSTAFF_AVALON@1": "holystaff",
    "T5_MAIN_HOLYSTAFF_AVALON@2": "holystaff",
    "T5_MAIN_HOLYSTAFF_AVALON@3": "holystaff",
    "T6_MAIN_HOLYSTAFF_AVALON": "holystaff",
    "T6_MAIN_HOLYSTAFF_AVALON@1": "holystaff",
    "T6_MAIN_HOLYSTAFF_AVALON@2": "holystaff",
    "T6_MAIN_HOLYSTAFF_AVALON@3": "holystaff",
    "T7_MAIN_HOLYSTAFF_AVALON": "holystaff",
    "T7_MAIN_HOLYSTAFF_AVALON@1": "holystaff",
    "T7_MAIN_HOLYSTAFF_AVALON@2": "holystaff",
    "T7_MAIN_HOLYSTAFF_AVALON@3": "holystaff",
    "T8_MAIN_HOLYSTAFF_AVALON": "holystaff",
    "T8_MAIN_HOLYSTAFF_AVALON@1": "holystaff",
    "T8_MAIN_HOLYSTAFF_AVALON@2": "holystaff",
    "T8_MAIN_HOLYSTAFF_AVALON@3": "holystaff",
    "T3_MAIN_NATURESTAFF": "naturestaff",
    "T4_MAIN_NATURESTAFF": "naturestaff",
    "T4_MAIN_NATURESTAFF@1": "naturestaff",
    "T4_MAIN_NATURESTAFF@2": "naturestaff",
    "T4_MAIN_NATURESTAFF@3": "naturestaff",
    "T5_MAIN_NATURESTAFF": "naturestaff",
    "T5_MAIN_NATURESTAFF@1": "naturestaff",
    "T5_MAIN_NATURESTAFF@2": "naturestaff",
    "T5_MAIN_NATURESTAFF@3": "naturestaff",
    "T6_MAIN_NATURESTAFF": "naturestaff",
    "T6_MAIN_NATURESTAFF@1": "naturestaff",
    "T6_MAIN_NATURESTAFF@2": "naturestaff",
    "T6_MAIN_NATURESTAFF@3": "naturestaff",
    "T7_MAIN_NATURESTAFF": "naturestaff",
    "T7_MAIN_NATURESTAFF@1": "naturestaff",
    "T7_MAIN_NATURESTAFF@2": "naturestaff",
    "T7_MAIN_NATURESTAFF@3": "naturestaff",
    "T8_MAIN_NATURESTAFF": "naturestaff",
    "T8_MAIN_NATURESTAFF@1": "naturestaff",
    "T8_MAIN_NATURESTAFF@2": "naturestaff",
    "T8_MAIN_NATURESTAFF@3": "naturestaff",
    "T4_2H_NATURESTAFF": "naturestaff",
    "T4_2H_NATURESTAFF@1": "naturestaff",
    "T4_2H_NATURESTAFF@2": "naturestaff",
    "T4_2H_NATURESTAFF@3": "naturestaff",
    "T5_2H_NATURESTAFF": "naturestaff",
    "T5_2H_NATURESTAFF@1": "naturestaff",
    "T5_2H_NATURESTAFF@2": "naturestaff",
    "T5_2H_NATURESTAFF@3": "naturestaff",
    "T6_2H_NATURESTAFF": "naturestaff",
    "T6_2H_NATURESTAFF@1": "naturestaff",
    "T6_2H_NATURESTAFF@2": "naturestaff",
    "T6_2H_NATURESTAFF@3": "naturestaff",
    "T7_2H_NATURESTAFF": "naturestaff",
    "T7_2H_NATURESTAFF@1": "naturestaff",
    "T7_2H_NATURESTAFF@2": "naturestaff",
    "T7_2H_NATURESTAFF@3": "naturestaff",
    "T8_2H_NATURESTAFF": "naturestaff",
    "T8_2H_NATURESTAFF@1": "naturestaff",
    "T8_2H_NATURESTAFF@2": "naturestaff",
    "T8_2H_NATURESTAFF@3": "naturestaff",
    "T4_2H_WILDSTAFF": "naturestaff",
    "T4_2H_WILDSTAFF@1": "naturestaff",
    "T4_2H_WILDSTAFF@2": "naturestaff",
    "T4_2H_WILDSTAFF@3": "naturestaff",
    "T5_2H_WILDSTAFF": "naturestaff",
    "T5_2H_WILDSTAFF@1": "naturestaff",
    "T5_2H_WILDSTAFF@2": "naturestaff",
    "T5_2H_WILDSTAFF@3": "naturestaff",
    "T6_2H_WILDSTAFF": "naturestaff",
    "T6_2H_WILDSTAFF@1": "naturestaff",
    "T6_2H_WILDSTAFF@2": "naturestaff",
    "T6_2H_WILDSTAFF@3": "naturestaff",
    "T7_2H_WILDSTAFF": "naturestaff",
    "T7_2H_WILDSTAFF@1": "naturestaff",
    "T7_2H_WILDSTAFF@2": "naturestaff",
    "T7_2H_WILDSTAFF@3": "naturestaff",
    "T8_2H_WILDSTAFF": "naturestaff",
    "T8_2H_WILDSTAFF@1": "naturestaff",
    "T8_2H_WILDSTAFF@2": "naturestaff",
    "T8_2H_WILDSTAFF@3": "naturestaff",
    "T4_MAIN_NATURESTAFF_KEEPER": "naturestaff",
    "T4_MAIN_NATURESTAFF_KEEPER@1": "naturestaff",
    "T4_MAIN_NATURESTAFF_KEEPER@2": "naturestaff",
    "T4_MAIN_NATURESTAFF_KEEPER@3": "naturestaff",
    "T5_MAIN_NATURESTAFF_KEEPER": "naturestaff",
    "T5_MAIN_NATURESTAFF_KEEPER@1": "naturestaff",
    "T5_MAIN_NATURESTAFF_KEEPER@2": "naturestaff",
    "T5_MAIN_NATURESTAFF_KEEPER@3": "naturestaff",
    "T6_MAIN_NATURESTAFF_KEEPER": "naturestaff",
    "T6_MAIN_NATURESTAFF_KEEPER@1": "naturestaff",
    "T6_MAIN_NATURESTAFF_KEEPER@2": "naturestaff",
    "T6_MAIN_NATURESTAFF_KEEPER@3": "naturestaff",
    "T7_MAIN_NATURESTAFF_KEEPER": "naturestaff",
    "T7_MAIN_NATURESTAFF_KEEPER@1": "naturestaff",
    "T7_MAIN_NATURESTAFF_KEEPER@2": "naturestaff",
    "T7_MAIN_NATURESTAFF_KEEPER@3": "naturestaff",
    "T8_MAIN_NATURESTAFF_KEEPER": "naturestaff",
    "T8_MAIN_NATURESTAFF_KEEPER@1": "naturestaff",
    "T8_MAIN_NATURESTAFF_KEEPER@2": "naturestaff",
    "T8_MAIN_NATURESTAFF_KEEPER@3": "naturestaff",
    "T4_2H_NATURESTAFF_HELL": "naturestaff",
    "T4_2H_NATURESTAFF_HELL@1": "naturestaff",
    "T4_2H_NATURESTAFF_HELL@2": "naturestaff",
    "T4_2H_NATURESTAFF_HELL@3": "naturestaff",
    "T5_2H_NATURESTAFF_HELL": "naturestaff",
    "T5_2H_NATURESTAFF_HELL@1": "naturestaff",
    "T5_2H_NATURESTAFF_HELL@2": "naturestaff",
    "T5_2H_NATURESTAFF_HELL@3": "naturestaff",
    "T6_2H_NATURESTAFF_HELL": "naturestaff",
    "T6_2H_NATURESTAFF_HELL@1": "naturestaff",
    "T6_2H_NATURESTAFF_HELL@2": "naturestaff",
    "T6_2H_NATURESTAFF_HELL@3": "naturestaff",
    "T7_2H_NATURESTAFF_HELL": "naturestaff",
    "T7_2H_NATURESTAFF_HELL@1": "naturestaff",
    "T7_2H_NATURESTAFF_HELL@2": "naturestaff",
    "T7_2H_NATURESTAFF_HELL@3": "naturestaff",
    "T8_2H_NATURESTAFF_HELL": "naturestaff",
    "T8_2H_NATURESTAFF_HELL@1": "naturestaff",
    "T8_2H_NATURESTAFF_HELL@2": "naturestaff",
    "T8_2H_NATURESTAFF_HELL@3": "naturestaff",
    "T4_2H_NATURESTAFF_KEEPER": "naturestaff",
    "T4_2H_NATURESTAFF_KEEPER@1": "naturestaff",
    "T4_2H_NATURESTAFF_KEEPER@2": "naturestaff",
    "T4_2H_NATURESTAFF_KEEPER@3": "naturestaff",
    "T5_2H_NATURESTAFF_KEEPER": "naturestaff",
    "T5_2H_NATURESTAFF_KEEPER@1": "naturestaff",
    "T5_2H_NATURESTAFF_KEEPER@2": "naturestaff",
    "T5_2H_NATURESTAFF_KEEPER@3": "naturestaff",
    "T6_2H_NATURESTAFF_KEEPER": "naturestaff",
    "T6_2H_NATURESTAFF_KEEPER@1": "naturestaff",
    "T6_2H_NATURESTAFF_KEEPER@2": "naturestaff",
    "T6_2H_NATURESTAFF_KEEPER@3": "naturestaff",
    "T7_2H_NATURESTAFF_KEEPER": "naturestaff",
    "T7_2H_NATURESTAFF_KEEPER@1": "naturestaff",
    "T7_2H_NATURESTAFF_KEEPER@2": "naturestaff",
    "T7_2H_NATURESTAFF_KEEPER@3": "naturestaff",
    "T8_2H_NATURESTAFF_KEEPER": "naturestaff",
    "T8_2H_NATURESTAFF_KEEPER@1": "naturestaff",
    "T8_2H_NATURESTAFF_KEEPER@2": "naturestaff",
    "T8_2H_NATURESTAFF_KEEPER@3": "naturestaff",
    "T4_MAIN_NATURESTAFF_AVALON": "naturestaff",
    "T4_MAIN_NATURESTAFF_AVALON@1": "naturestaff",
    "T4_MAIN_NATURESTAFF_AVALON@2": "naturestaff",
    "T4_MAIN_NATURESTAFF_AVALON@3": "naturestaff",
    "T5_MAIN_NATURESTAFF_AVALON": "naturestaff",
    "T5_MAIN_NATURESTAFF_AVALON@1": "naturestaff",
    "T5_MAIN_NATURESTAFF_AVALON@2": "naturestaff",
    "T5_MAIN_NATURESTAFF_AVALON@3": "naturestaff",
    "T6_MAIN_NATURESTAFF_AVALON": "naturestaff",
    "T6_MAIN_NATURESTAFF_AVALON@1": "naturestaff",
    "T6_MAIN_NATURESTAFF_AVALON@2": "naturestaff",
    "T6_MAIN_NATURESTAFF_AVALON@3": "naturestaff",
    "T7_MAIN_NATURESTAFF_AVALON": "naturestaff",
    "T7_MAIN_NATURESTAFF_AVALON@1": "naturestaff",
    "T7_MAIN_NATURESTAFF_AVALON@2": "naturestaff",
    "T7_MAIN_NATURESTAFF_AVALON@3": "naturestaff",
    "T8_MAIN_NATURESTAFF_AVALON": "naturestaff",
    "T8_MAIN_NATURESTAFF_AVALON@1": "naturestaff",
    "T8_MAIN_NATURESTAFF_AVALON@2": "naturestaff",
    "T8_MAIN_NATURESTAFF_AVALON@3": "naturestaff",
    "T3_MAIN_DAGGER": "dagger",
    "T4_MAIN_DAGGER": "dagger",
    "T4_MAIN_DAGGER@1": "dagger",
    "T4_MAIN_DAGGER@2": "dagger",
    "T4_MAIN_DAGGER@3": "dagger",
    "T5_MAIN_DAGGER": "dagger",
    "T5_MAIN_DAGGER@1": "dagger",
    "T5_MAIN_DAGGER@2": "dagger",
    "T5_MAIN_DAGGER@3": "dagger",
    "T6_MAIN_DAGGER": "dagger",
    "T6_MAIN_DAGGER@1": "dagger",
    "T6_MAIN_DAGGER@2": "dagger",
    "T6_MAIN_DAGGER@3": "dagger",
    "T7_MAIN_DAGGER": "dagger",
    "T7_MAIN_DAGGER@1": "dagger",
    "T7_MAIN_DAGGER@2": "dagger",
    "T7_MAIN_DAGGER@3": "dagger",
    "T8_MAIN_DAGGER": "dagger",
    "T8_MAIN_DAGGER@1": "dagger",
    "T8_MAIN_DAGGER@2": "dagger",
    "T8_MAIN_DAGGER@3": "dagger",
    "T4_2H_DAGGERPAIR": "dagger",
    "T4_2H_DAGGERPAIR@1": "dagger",
    "T4_2H_DAGGERPAIR@2": "dagger",
    "T4_2H_DAGGERPAIR@3": "dagger",
    "T5_2H_DAGGERPAIR": "dagger",
    "T5_2H_DAGGERPAIR@1": "dagger",
    "T5_2H_DAGGERPAIR@2": "dagger",
    "T5_2H_DAGGERPAIR@3": "dagger",
    "T6_2H_DAGGERPAIR": "dagger",
    "T6_2H_DAGGERPAIR@1": "dagger",
    "T6_2H_DAGGERPAIR@2": "dagger",
    "T6_2H_DAGGERPAIR@3": "dagger",
    "T7_2H_DAGGERPAIR": "dagger",
    "T7_2H_DAGGERPAIR@1": "dagger",
    "T7_2H_DAGGERPAIR@2": "dagger",
    "T7_2H_DAGGERPAIR@3": "dagger",
    "T8_2H_DAGGERPAIR": "dagger",
    "T8_2H_DAGGERPAIR@1": "dagger",
    "T8_2H_DAGGERPAIR@2": "dagger",
    "T8_2H_DAGGERPAIR@3": "dagger",
    "T4_2H_CLAWPAIR": "dagger",
    "T4_2H_CLAWPAIR@1": "dagger",
    "T4_2H_CLAWPAIR@2": "dagger",
    "T4_2H_CLAWPAIR@3": "dagger",
    "T5_2H_CLAWPAIR": "dagger",
    "T5_2H_CLAWPAIR@1": "dagger",
    "T5_2H_CLAWPAIR@2": "dagger",
    "T5_2H_CLAWPAIR@3": "dagger",
    "T6_2H_CLAWPAIR": "dagger",
    "T6_2H_CLAWPAIR@1": "dagger",
    "T6_2H_CLAWPAIR@2": "dagger",
    "T6_2H_CLAWPAIR@3": "dagger",
    "T7_2H_CLAWPAIR": "dagger",
    "T7_2H_CLAWPAIR@1": "dagger",
    "T7_2H_CLAWPAIR@2": "dagger",
    "T7_2H_CLAWPAIR@3": "dagger",
    "T8_2H_CLAWPAIR": "dagger",
    "T8_2H_CLAWPAIR@1": "dagger",
    "T8_2H_CLAWPAIR@2": "dagger",
    "T8_2H_CLAWPAIR@3": "dagger",
    "T4_MAIN_RAPIER_MORGANA": "dagger",
    "T4_MAIN_RAPIER_MORGANA@1": "dagger",
    "T4_MAIN_RAPIER_MORGANA@2": "dagger",
    "T4_MAIN_RAPIER_MORGANA@3": "dagger",
    "T5_MAIN_RAPIER_MORGANA": "dagger",
    "T5_MAIN_RAPIER_MORGANA@1": "dagger",
    "T5_MAIN_RAPIER_MORGANA@2": "dagger",
    "T5_MAIN_RAPIER_MORGANA@3": "dagger",
    "T6_MAIN_RAPIER_MORGANA": "dagger",
    "T6_MAIN_RAPIER_MORGANA@1": "dagger",
    "T6_MAIN_RAPIER_MORGANA@2": "dagger",
    "T6_MAIN_RAPIER_MORGANA@3": "dagger",
    "T7_MAIN_RAPIER_MORGANA": "dagger",
    "T7_MAIN_RAPIER_MORGANA@1": "dagger",
    "T7_MAIN_RAPIER_MORGANA@2": "dagger",
    "T7_MAIN_RAPIER_MORGANA@3": "dagger",
    "T8_MAIN_RAPIER_MORGANA": "dagger",
    "T8_MAIN_RAPIER_MORGANA@1": "dagger",
    "T8_MAIN_RAPIER_MORGANA@2": "dagger",
    "T8_MAIN_RAPIER_MORGANA@3": "dagger",
    "T4_2H_IRONGAUNTLETS_HELL": "dagger",
    "T4_2H_IRONGAUNTLETS_HELL@1": "dagger",
    "T4_2H_IRONGAUNTLETS_HELL@2": "dagger",
    "T4_2H_IRONGAUNTLETS_HELL@3": "dagger",
    "T5_2H_IRONGAUNTLETS_HELL": "dagger",
    "T5_2H_IRONGAUNTLETS_HELL@1": "dagger",
    "T5_2H_IRONGAUNTLETS_HELL@2": "dagger",
    "T5_2H_IRONGAUNTLETS_HELL@3": "dagger",
    "T6_2H_IRONGAUNTLETS_HELL": "dagger",
    "T6_2H_IRONGAUNTLETS_HELL@1": "dagger",
    "T6_2H_IRONGAUNTLETS_HELL@2": "dagger",
    "T6_2H_IRONGAUNTLETS_HELL@3": "dagger",
    "T7_2H_IRONGAUNTLETS_HELL": "dagger",
    "T7_2H_IRONGAUNTLETS_HELL@1": "dagger",
    "T7_2H_IRONGAUNTLETS_HELL@2": "dagger",
    "T7_2H_IRONGAUNTLETS_HELL@3": "dagger",
    "T8_2H_IRONGAUNTLETS_HELL": "dagger",
    "T8_2H_IRONGAUNTLETS_HELL@1": "dagger",
    "T8_2H_IRONGAUNTLETS_HELL@2": "dagger",
    "T8_2H_IRONGAUNTLETS_HELL@3": "dagger",
    "T4_2H_DUALSICKLE_UNDEAD": "dagger",
    "T4_2H_DUALSICKLE_UNDEAD@1": "dagger",
    "T4_2H_DUALSICKLE_UNDEAD@2": "dagger",
    "T4_2H_DUALSICKLE_UNDEAD@3": "dagger",
    "T5_2H_DUALSICKLE_UNDEAD": "dagger",
    "T5_2H_DUALSICKLE_UNDEAD@1": "dagger",
    "T5_2H_DUALSICKLE_UNDEAD@2": "dagger",
    "T5_2H_DUALSICKLE_UNDEAD@3": "dagger",
    "T6_2H_DUALSICKLE_UNDEAD": "dagger",
    "T6_2H_DUALSICKLE_UNDEAD@1": "dagger",
    "T6_2H_DUALSICKLE_UNDEAD@2": "dagger",
    "T6_2H_DUALSICKLE_UNDEAD@3": "dagger",
    "T7_2H_DUALSICKLE_UNDEAD": "dagger",
    "T7_2H_DUALSICKLE_UNDEAD@1": "dagger",
    "T7_2H_DUALSICKLE_UNDEAD@2": "dagger",
    "T7_2H_DUALSICKLE_UNDEAD@3": "dagger",
    "T8_2H_DUALSICKLE_UNDEAD": "dagger",
    "T8_2H_DUALSICKLE_UNDEAD@1": "dagger",
    "T8_2H_DUALSICKLE_UNDEAD@2": "dagger",
    "T8_2H_DUALSICKLE_UNDEAD@3": "dagger",
    "T4_2H_DAGGER_KATAR_AVALON": "dagger",
    "T4_2H_DAGGER_KATAR_AVALON@1": "dagger",
    "T4_2H_DAGGER_KATAR_AVALON@2": "dagger",
    "T4_2H_DAGGER_KATAR_AVALON@3": "dagger",
    "T5_2H_DAGGER_KATAR_AVALON": "dagger",
    "T5_2H_DAGGER_KATAR_AVALON@1": "dagger",
    "T5_2H_DAGGER_KATAR_AVALON@2": "dagger",
    "T5_2H_DAGGER_KATAR_AVALON@3": "dagger",
    "T6_2H_DAGGER_KATAR_AVALON": "dagger",
    "T6_2H_DAGGER_KATAR_AVALON@1": "dagger",
    "T6_2H_DAGGER_KATAR_AVALON@2": "dagger",
    "T6_2H_DAGGER_KATAR_AVALON@3": "dagger",
    "T7_2H_DAGGER_KATAR_AVALON": "dagger",
    "T7_2H_DAGGER_KATAR_AVALON@1": "dagger",
    "T7_2H_DAGGER_KATAR_AVALON@2": "dagger",
    "T7_2H_DAGGER_KATAR_AVALON@3": "dagger",
    "T8_2H_DAGGER_KATAR_AVALON": "dagger",
    "T8_2H_DAGGER_KATAR_AVALON@1": "dagger",
    "T8_2H_DAGGER_KATAR_AVALON@2": "dagger",
    "T8_2H_DAGGER_KATAR_AVALON@3": "dagger",
    "T3_MAIN_SPEAR": "spear",
    "T4_MAIN_SPEAR": "spear",
    "T4_MAIN_SPEAR@1": "spear",
    "T4_MAIN_SPEAR@2": "spear",
    "T4_MAIN_SPEAR@3": "spear",
    "T5_MAIN_SPEAR": "spear",
    "T5_MAIN_SPEAR@1": "spear",
    "T5_MAIN_SPEAR@2": "spear",
    "T5_MAIN_SPEAR@3": "spear",
    "T6_MAIN_SPEAR": "spear",
    "T6_MAIN_SPEAR@1": "spear",
    "T6_MAIN_SPEAR@2": "spear",
    "T6_MAIN_SPEAR@3": "spear",
    "T7_MAIN_SPEAR": "spear",
    "T7_MAIN_SPEAR@1": "spear",
    "T7_MAIN_SPEAR@2": "spear",
    "T7_MAIN_SPEAR@3": "spear",
    "T8_MAIN_SPEAR": "spear",
    "T8_MAIN_SPEAR@1": "spear",
    "T8_MAIN_SPEAR@2": "spear",
    "T8_MAIN_SPEAR@3": "spear",
    "T4_2H_SPEAR": "spear",
    "T4_2H_SPEAR@1": "spear",
    "T4_2H_SPEAR@2": "spear",
    "T4_2H_SPEAR@3": "spear",
    "T5_2H_SPEAR": "spear",
    "T5_2H_SPEAR@1": "spear",
    "T5_2H_SPEAR@2": "spear",
    "T5_2H_SPEAR@3": "spear",
    "T6_2H_SPEAR": "spear",
    "T6_2H_SPEAR@1": "spear",
    "T6_2H_SPEAR@2": "spear",
    "T6_2H_SPEAR@3": "spear",
    "T7_2H_SPEAR": "spear",
    "T7_2H_SPEAR@1": "spear",
    "T7_2H_SPEAR@2": "spear",
    "T7_2H_SPEAR@3": "spear",
    "T8_2H_SPEAR": "spear",
    "T8_2H_SPEAR@1": "spear",
    "T8_2H_SPEAR@2": "spear",
    "T8_2H_SPEAR@3": "spear",
    "T4_2H_GLAIVE": "spear",
    "T4_2H_GLAIVE@1": "spear",
    "T4_2H_GLAIVE@2": "spear",
    "T4_2H_GLAIVE@3": "spear",
    "T5_2H_GLAIVE": "spear",
    "T5_2H_GLAIVE@1": "spear",
    "T5_2H_GLAIVE@2": "spear",
    "T5_2H_GLAIVE@3": "spear",
    "T6_2H_GLAIVE": "spear",
    "T6_2H_GLAIVE@1": "spear",
    "T6_2H_GLAIVE@2": "spear",
    "T6_2H_GLAIVE@3": "spear",
    "T7_2H_GLAIVE": "spear",
    "T7_2H_GLAIVE@1": "spear",
    "T7_2H_GLAIVE@2": "spear",
    "T7_2H_GLAIVE@3": "spear",
    "T8_2H_GLAIVE": "spear",
    "T8_2H_GLAIVE@1": "spear",
    "T8_2H_GLAIVE@2": "spear",
    "T8_2H_GLAIVE@3": "spear",
    "T4_MAIN_SPEAR_KEEPER": "spear",
    "T4_MAIN_SPEAR_KEEPER@1": "spear",
    "T4_MAIN_SPEAR_KEEPER@2": "spear",
    "T4_MAIN_SPEAR_KEEPER@3": "spear",
    "T5_MAIN_SPEAR_KEEPER": "spear",
    "T5_MAIN_SPEAR_KEEPER@1": "spear",
    "T5_MAIN_SPEAR_KEEPER@2": "spear",
    "T5_MAIN_SPEAR_KEEPER@3": "spear",
    "T6_MAIN_SPEAR_KEEPER": "spear",
    "T6_MAIN_SPEAR_KEEPER@1": "spear",
    "T6_MAIN_SPEAR_KEEPER@2": "spear",
    "T6_MAIN_SPEAR_KEEPER@3": "spear",
    "T7_MAIN_SPEAR_KEEPER": "spear",
    "T7_MAIN_SPEAR_KEEPER@1": "spear",
    "T7_MAIN_SPEAR_KEEPER@2": "spear",
    "T7_MAIN_SPEAR_KEEPER@3": "spear",
    "T8_MAIN_SPEAR_KEEPER": "spear",
    "T8_MAIN_SPEAR_KEEPER@1": "spear",
    "T8_MAIN_SPEAR_KEEPER@2": "spear",
    "T8_MAIN_SPEAR_KEEPER@3": "spear",
    "T4_2H_HARPOON_HELL": "spear",
    "T4_2H_HARPOON_HELL@1": "spear",
    "T4_2H_HARPOON_HELL@2": "spear",
    "T4_2H_HARPOON_HELL@3": "spear",
    "T5_2H_HARPOON_HELL": "spear",
    "T5_2H_HARPOON_HELL@1": "spear",
    "T5_2H_HARPOON_HELL@2": "spear",
    "T5_2H_HARPOON_HELL@3": "spear",
    "T6_2H_HARPOON_HELL": "spear",
    "T6_2H_HARPOON_HELL@1": "spear",
    "T6_2H_HARPOON_HELL@2": "spear",
    "T6_2H_HARPOON_HELL@3": "spear",
    "T7_2H_HARPOON_HELL": "spear",
    "T7_2H_HARPOON_HELL@1": "spear",
    "T7_2H_HARPOON_HELL@2": "spear",
    "T7_2H_HARPOON_HELL@3": "spear",
    "T8_2H_HARPOON_HELL": "spear",
    "T8_2H_HARPOON_HELL@1": "spear",
    "T8_2H_HARPOON_HELL@2": "spear",
    "T8_2H_HARPOON_HELL@3": "spear",
    "T4_2H_TRIDENT_UNDEAD": "spear",
    "T4_2H_TRIDENT_UNDEAD@1": "spear",
    "T4_2H_TRIDENT_UNDEAD@2": "spear",
    "T4_2H_TRIDENT_UNDEAD@3": "spear",
    "T5_2H_TRIDENT_UNDEAD": "spear",
    "T5_2H_TRIDENT_UNDEAD@1": "spear",
    "T5_2H_TRIDENT_UNDEAD@2": "spear",
    "T5_2H_TRIDENT_UNDEAD@3": "spear",
    "T6_2H_TRIDENT_UNDEAD": "spear",
    "T6_2H_TRIDENT_UNDEAD@1": "spear",
    "T6_2H_TRIDENT_UNDEAD@2": "spear",
    "T6_2H_TRIDENT_UNDEAD@3": "spear",
    "T7_2H_TRIDENT_UNDEAD": "spear",
    "T7_2H_TRIDENT_UNDEAD@1": "spear",
    "T7_2H_TRIDENT_UNDEAD@2": "spear",
    "T7_2H_TRIDENT_UNDEAD@3": "spear",
    "T8_2H_TRIDENT_UNDEAD": "spear",
    "T8_2H_TRIDENT_UNDEAD@1": "spear",
    "T8_2H_TRIDENT_UNDEAD@2": "spear",
    "T8_2H_TRIDENT_UNDEAD@3": "spear",
    "T4_MAIN_SPEAR_LANCE_AVALON": "spear",
    "T4_MAIN_SPEAR_LANCE_AVALON@1": "spear",
    "T4_MAIN_SPEAR_LANCE_AVALON@2": "spear",
    "T4_MAIN_SPEAR_LANCE_AVALON@3": "spear",
    "T5_MAIN_SPEAR_LANCE_AVALON": "spear",
    "T5_MAIN_SPEAR_LANCE_AVALON@1": "spear",
    "T5_MAIN_SPEAR_LANCE_AVALON@2": "spear",
    "T5_MAIN_SPEAR_LANCE_AVALON@3": "spear",
    "T6_MAIN_SPEAR_LANCE_AVALON": "spear",
    "T6_MAIN_SPEAR_LANCE_AVALON@1": "spear",
    "T6_MAIN_SPEAR_LANCE_AVALON@2": "spear",
    "T6_MAIN_SPEAR_LANCE_AVALON@3": "spear",
    "T7_MAIN_SPEAR_LANCE_AVALON": "spear",
    "T7_MAIN_SPEAR_LANCE_AVALON@1": "spear",
    "T7_MAIN_SPEAR_LANCE_AVALON@2": "spear",
    "T7_MAIN_SPEAR_LANCE_AVALON@3": "spear",
    "T8_MAIN_SPEAR_LANCE_AVALON": "spear",
    "T8_MAIN_SPEAR_LANCE_AVALON@1": "spear",
    "T8_MAIN_SPEAR_LANCE_AVALON@2": "spear",
    "T8_MAIN_SPEAR_LANCE_AVALON@3": "spear",
    "T3_MAIN_AXE": "axe",
    "T4_MAIN_AXE": "axe",
    "T4_MAIN_AXE@1": "axe",
    "T4_MAIN_AXE@2": "axe",
    "T4_MAIN_AXE@3": "axe",
    "T5_MAIN_AXE": "axe",
    "T5_MAIN_AXE@1": "axe",
    "T5_MAIN_AXE@2": "axe",
    "T5_MAIN_AXE@3": "axe",
    "T6_MAIN_AXE": "axe",
    "T6_MAIN_AXE@1": "axe",
    "T6_MAIN_AXE@2": "axe",
    "T6_MAIN_AXE@3": "axe",
    "T7_MAIN_AXE": "axe",
    "T7_MAIN_AXE@1": "axe",
    "T7_MAIN_AXE@2": "axe",
    "T7_MAIN_AXE@3": "axe",
    "T8_MAIN_AXE": "axe",
    "T8_MAIN_AXE@1": "axe",
    "T8_MAIN_AXE@2": "axe",
    "T8_MAIN_AXE@3": "axe",
    "T4_2H_AXE": "axe",
    "T4_2H_AXE@1": "axe",
    "T4_2H_AXE@2": "axe",
    "T4_2H_AXE@3": "axe",
    "T5_2H_AXE": "axe",
    "T5_2H_AXE@1": "axe",
    "T5_2H_AXE@2": "axe",
    "T5_2H_AXE@3": "axe",
    "T6_2H_AXE": "axe",
    "T6_2H_AXE@1": "axe",
    "T6_2H_AXE@2": "axe",
    "T6_2H_AXE@3": "axe",
    "T7_2H_AXE": "axe",
    "T7_2H_AXE@1": "axe",
    "T7_2H_AXE@2": "axe",
    "T7_2H_AXE@3": "axe",
    "T8_2H_AXE": "axe",
    "T8_2H_AXE@1": "axe",
    "T8_2H_AXE@2": "axe",
    "T8_2H_AXE@3": "axe",
    "T4_2H_HALBERD": "axe",
    "T4_2H_HALBERD@1": "axe",
    "T4_2H_HALBERD@2": "axe",
    "T4_2H_HALBERD@3": "axe",
    "T5_2H_HALBERD": "axe",
    "T5_2H_HALBERD@1": "axe",
    "T5_2H_HALBERD@2": "axe",
    "T5_2H_HALBERD@3": "axe",
    "T6_2H_HALBERD": "axe",
    "T6_2H_HALBERD@1": "axe",
    "T6_2H_HALBERD@2": "axe",
    "T6_2H_HALBERD@3": "axe",
    "T7_2H_HALBERD": "axe",
    "T7_2H_HALBERD@1": "axe",
    "T7_2H_HALBERD@2": "axe",
    "T7_2H_HALBERD@3": "axe",
    "T8_2H_HALBERD": "axe",
    "T8_2H_HALBERD@1": "axe",
    "T8_2H_HALBERD@2": "axe",
    "T8_2H_HALBERD@3": "axe",
    "T4_2H_HALBERD_MORGANA": "axe",
    "T4_2H_HALBERD_MORGANA@1": "axe",
    "T4_2H_HALBERD_MORGANA@2": "axe",
    "T4_2H_HALBERD_MORGANA@3": "axe",
    "T5_2H_HALBERD_MORGANA": "axe",
    "T5_2H_HALBERD_MORGANA@1": "axe",
    "T5_2H_HALBERD_MORGANA@2": "axe",
    "T5_2H_HALBERD_MORGANA@3": "axe",
    "T6_2H_HALBERD_MORGANA": "axe",
    "T6_2H_HALBERD_MORGANA@1": "axe",
    "T6_2H_HALBERD_MORGANA@2": "axe",
    "T6_2H_HALBERD_MORGANA@3": "axe",
    "T7_2H_HALBERD_MORGANA": "axe",
    "T7_2H_HALBERD_MORGANA@1": "axe",
    "T7_2H_HALBERD_MORGANA@2": "axe",
    "T7_2H_HALBERD_MORGANA@3": "axe",
    "T8_2H_HALBERD_MORGANA": "axe",
    "T8_2H_HALBERD_MORGANA@1": "axe",
    "T8_2H_HALBERD_MORGANA@2": "axe",
    "T8_2H_HALBERD_MORGANA@3": "axe",
    "T4_2H_SCYTHE_HELL": "axe",
    "T4_2H_SCYTHE_HELL@1": "axe",
    "T4_2H_SCYTHE_HELL@2": "axe",
    "T4_2H_SCYTHE_HELL@3": "axe",
    "T5_2H_SCYTHE_HELL": "axe",
    "T5_2H_SCYTHE_HELL@1": "axe",
    "T5_2H_SCYTHE_HELL@2": "axe",
    "T5_2H_SCYTHE_HELL@3": "axe",
    "T6_2H_SCYTHE_HELL": "axe",
    "T6_2H_SCYTHE_HELL@1": "axe",
    "T6_2H_SCYTHE_HELL@2": "axe",
    "T6_2H_SCYTHE_HELL@3": "axe",
    "T7_2H_SCYTHE_HELL": "axe",
    "T7_2H_SCYTHE_HELL@1": "axe",
    "T7_2H_SCYTHE_HELL@2": "axe",
    "T7_2H_SCYTHE_HELL@3": "axe",
    "T8_2H_SCYTHE_HELL": "axe",
    "T8_2H_SCYTHE_HELL@1": "axe",
    "T8_2H_SCYTHE_HELL@2": "axe",
    "T8_2H_SCYTHE_HELL@3": "axe",
    "T4_2H_DUALAXE_KEEPER": "axe",
    "T4_2H_DUALAXE_KEEPER@1": "axe",
    "T4_2H_DUALAXE_KEEPER@2": "axe",
    "T4_2H_DUALAXE_KEEPER@3": "axe",
    "T5_2H_DUALAXE_KEEPER": "axe",
    "T5_2H_DUALAXE_KEEPER@1": "axe",
    "T5_2H_DUALAXE_KEEPER@2": "axe",
    "T5_2H_DUALAXE_KEEPER@3": "axe",
    "T6_2H_DUALAXE_KEEPER": "axe",
    "T6_2H_DUALAXE_KEEPER@1": "axe",
    "T6_2H_DUALAXE_KEEPER@2": "axe",
    "T6_2H_DUALAXE_KEEPER@3": "axe",
    "T7_2H_DUALAXE_KEEPER": "axe",
    "T7_2H_DUALAXE_KEEPER@1": "axe",
    "T7_2H_DUALAXE_KEEPER@2": "axe",
    "T7_2H_DUALAXE_KEEPER@3": "axe",
    "T8_2H_DUALAXE_KEEPER": "axe",
    "T8_2H_DUALAXE_KEEPER@1": "axe",
    "T8_2H_DUALAXE_KEEPER@2": "axe",
    "T8_2H_DUALAXE_KEEPER@3": "axe",
    "T4_2H_AXE_AVALON": "axe",
    "T4_2H_AXE_AVALON@1": "axe",
    "T4_2H_AXE_AVALON@2": "axe",
    "T4_2H_AXE_AVALON@3": "axe",
    "T5_2H_AXE_AVALON": "axe",
    "T5_2H_AXE_AVALON@1": "axe",
    "T5_2H_AXE_AVALON@2": "axe",
    "T5_2H_AXE_AVALON@3": "axe",
    "T6_2H_AXE_AVALON": "axe",
    "T6_2H_AXE_AVALON@1": "axe",
    "T6_2H_AXE_AVALON@2": "axe",
    "T6_2H_AXE_AVALON@3": "axe",
    "T7_2H_AXE_AVALON": "axe",
    "T7_2H_AXE_AVALON@1": "axe",
    "T7_2H_AXE_AVALON@2": "axe",
    "T7_2H_AXE_AVALON@3": "axe",
    "T8_2H_AXE_AVALON": "axe",
    "T8_2H_AXE_AVALON@1": "axe",
    "T8_2H_AXE_AVALON@2": "axe",
    "T8_2H_AXE_AVALON@3": "axe",
    "T2_MAIN_SWORD": "sword",
    "T3_MAIN_SWORD": "sword",
    "T4_MAIN_SWORD": "sword",
    "T4_MAIN_SWORD@1": "sword",
    "T4_MAIN_SWORD@2": "sword",
    "T4_MAIN_SWORD@3": "sword",
    "T5_MAIN_SWORD": "sword",
    "T5_MAIN_SWORD@1": "sword",
    "T5_MAIN_SWORD@2": "sword",
    "T5_MAIN_SWORD@3": "sword",
    "T6_MAIN_SWORD": "sword",
    "T6_MAIN_SWORD@1": "sword",
    "T6_MAIN_SWORD@2": "sword",
    "T6_MAIN_SWORD@3": "sword",
    "T7_MAIN_SWORD": "sword",
    "T7_MAIN_SWORD@1": "sword",
    "T7_MAIN_SWORD@2": "sword",
    "T7_MAIN_SWORD@3": "sword",
    "T8_MAIN_SWORD": "sword",
    "T8_MAIN_SWORD@1": "sword",
    "T8_MAIN_SWORD@2": "sword",
    "T8_MAIN_SWORD@3": "sword",
    "T4_2H_CLAYMORE": "sword",
    "T4_2H_CLAYMORE@1": "sword",
    "T4_2H_CLAYMORE@2": "sword",
    "T4_2H_CLAYMORE@3": "sword",
    "T5_2H_CLAYMORE": "sword",
    "T5_2H_CLAYMORE@1": "sword",
    "T5_2H_CLAYMORE@2": "sword",
    "T5_2H_CLAYMORE@3": "sword",
    "T6_2H_CLAYMORE": "sword",
    "T6_2H_CLAYMORE@1": "sword",
    "T6_2H_CLAYMORE@2": "sword",
    "T6_2H_CLAYMORE@3": "sword",
    "T7_2H_CLAYMORE": "sword",
    "T7_2H_CLAYMORE@1": "sword",
    "T7_2H_CLAYMORE@2": "sword",
    "T7_2H_CLAYMORE@3": "sword",
    "T8_2H_CLAYMORE": "sword",
    "T8_2H_CLAYMORE@1": "sword",
    "T8_2H_CLAYMORE@2": "sword",
    "T8_2H_CLAYMORE@3": "sword",
    "T4_2H_DUALSWORD": "sword",
    "T4_2H_DUALSWORD@1": "sword",
    "T4_2H_DUALSWORD@2": "sword",
    "T4_2H_DUALSWORD@3": "sword",
    "T5_2H_DUALSWORD": "sword",
    "T5_2H_DUALSWORD@1": "sword",
    "T5_2H_DUALSWORD@2": "sword",
    "T5_2H_DUALSWORD@3": "sword",
    "T6_2H_DUALSWORD": "sword",
    "T6_2H_DUALSWORD@1": "sword",
    "T6_2H_DUALSWORD@2": "sword",
    "T6_2H_DUALSWORD@3": "sword",
    "T7_2H_DUALSWORD": "sword",
    "T7_2H_DUALSWORD@1": "sword",
    "T7_2H_DUALSWORD@2": "sword",
    "T7_2H_DUALSWORD@3": "sword",
    "T8_2H_DUALSWORD": "sword",
    "T8_2H_DUALSWORD@1": "sword",
    "T8_2H_DUALSWORD@2": "sword",
    "T8_2H_DUALSWORD@3": "sword",
    "T4_MAIN_SCIMITAR_MORGANA": "sword",
    "T4_MAIN_SCIMITAR_MORGANA@1": "sword",
    "T4_MAIN_SCIMITAR_MORGANA@2": "sword",
    "T4_MAIN_SCIMITAR_MORGANA@3": "sword",
    "T5_MAIN_SCIMITAR_MORGANA": "sword",
    "T5_MAIN_SCIMITAR_MORGANA@1": "sword",
    "T5_MAIN_SCIMITAR_MORGANA@2": "sword",
    "T5_MAIN_SCIMITAR_MORGANA@3": "sword",
    "T6_MAIN_SCIMITAR_MORGANA": "sword",
    "T6_MAIN_SCIMITAR_MORGANA@1": "sword",
    "T6_MAIN_SCIMITAR_MORGANA@2": "sword",
    "T6_MAIN_SCIMITAR_MORGANA@3": "sword",
    "T7_MAIN_SCIMITAR_MORGANA": "sword",
    "T7_MAIN_SCIMITAR_MORGANA@1": "sword",
    "T7_MAIN_SCIMITAR_MORGANA@2": "sword",
    "T7_MAIN_SCIMITAR_MORGANA@3": "sword",
    "T8_MAIN_SCIMITAR_MORGANA": "sword",
    "T8_MAIN_SCIMITAR_MORGANA@1": "sword",
    "T8_MAIN_SCIMITAR_MORGANA@2": "sword",
    "T8_MAIN_SCIMITAR_MORGANA@3": "sword",
    "T4_2H_CLEAVER_HELL": "sword",
    "T4_2H_CLEAVER_HELL@1": "sword",
    "T4_2H_CLEAVER_HELL@2": "sword",
    "T4_2H_CLEAVER_HELL@3": "sword",
    "T5_2H_CLEAVER_HELL": "sword",
    "T5_2H_CLEAVER_HELL@1": "sword",
    "T5_2H_CLEAVER_HELL@2": "sword",
    "T5_2H_CLEAVER_HELL@3": "sword",
    "T6_2H_CLEAVER_HELL": "sword",
    "T6_2H_CLEAVER_HELL@1": "sword",
    "T6_2H_CLEAVER_HELL@2": "sword",
    "T6_2H_CLEAVER_HELL@3": "sword",
    "T7_2H_CLEAVER_HELL": "sword",
    "T7_2H_CLEAVER_HELL@1": "sword",
    "T7_2H_CLEAVER_HELL@2": "sword",
    "T7_2H_CLEAVER_HELL@3": "sword",
    "T8_2H_CLEAVER_HELL": "sword",
    "T8_2H_CLEAVER_HELL@1": "sword",
    "T8_2H_CLEAVER_HELL@2": "sword",
    "T8_2H_CLEAVER_HELL@3": "sword",
    "T4_2H_DUALSCIMITAR_UNDEAD": "sword",
    "T4_2H_DUALSCIMITAR_UNDEAD@1": "sword",
    "T4_2H_DUALSCIMITAR_UNDEAD@2": "sword",
    "T4_2H_DUALSCIMITAR_UNDEAD@3": "sword",
    "T5_2H_DUALSCIMITAR_UNDEAD": "sword",
    "T5_2H_DUALSCIMITAR_UNDEAD@1": "sword",
    "T5_2H_DUALSCIMITAR_UNDEAD@2": "sword",
    "T5_2H_DUALSCIMITAR_UNDEAD@3": "sword",
    "T6_2H_DUALSCIMITAR_UNDEAD": "sword",
    "T6_2H_DUALSCIMITAR_UNDEAD@1": "sword",
    "T6_2H_DUALSCIMITAR_UNDEAD@2": "sword",
    "T6_2H_DUALSCIMITAR_UNDEAD@3": "sword",
    "T7_2H_DUALSCIMITAR_UNDEAD": "sword",
    "T7_2H_DUALSCIMITAR_UNDEAD@1": "sword",
    "T7_2H_DUALSCIMITAR_UNDEAD@2": "sword",
    "T7_2H_DUALSCIMITAR_UNDEAD@3": "sword",
    "T8_2H_DUALSCIMITAR_UNDEAD": "sword",
    "T8_2H_DUALSCIMITAR_UNDEAD@1": "sword",
    "T8_2H_DUALSCIMITAR_UNDEAD@2": "sword",
    "T8_2H_DUALSCIMITAR_UNDEAD@3": "sword",
    "T4_2H_CLAYMORE_AVALON": "sword",
    "T4_2H_CLAYMORE_AVALON@1": "sword",
    "T4_2H_CLAYMORE_AVALON@2": "sword",
    "T4_2H_CLAYMORE_AVALON@3": "sword",
    "T5_2H_CLAYMORE_AVALON": "sword",
    "T5_2H_CLAYMORE_AVALON@1": "sword",
    "T5_2H_CLAYMORE_AVALON@2": "sword",
    "T5_2H_CLAYMORE_AVALON@3": "sword",
    "T6_2H_CLAYMORE_AVALON": "sword",
    "T6_2H_CLAYMORE_AVALON@1": "sword",
    "T6_2H_CLAYMORE_AVALON@2": "sword",
    "T6_2H_CLAYMORE_AVALON@3": "sword",
    "T7_2H_CLAYMORE_AVALON": "sword",
    "T7_2H_CLAYMORE_AVALON@1": "sword",
    "T7_2H_CLAYMORE_AVALON@2": "sword",
    "T7_2H_CLAYMORE_AVALON@3": "sword",
    "T8_2H_CLAYMORE_AVALON": "sword",
    "T8_2H_CLAYMORE_AVALON@1": "sword",
    "T8_2H_CLAYMORE_AVALON@2": "sword",
    "T8_2H_CLAYMORE_AVALON@3": "sword",
    "T3_2H_QUARTERSTAFF": "quarterstaff",
    "T4_2H_QUARTERSTAFF": "quarterstaff",
    "T4_2H_QUARTERSTAFF@1": "quarterstaff",
    "T4_2H_QUARTERSTAFF@2": "quarterstaff",
    "T4_2H_QUARTERSTAFF@3": "quarterstaff",
    "T5_2H_QUARTERSTAFF": "quarterstaff",
    "T5_2H_QUARTERSTAFF@1": "quarterstaff",
    "T5_2H_QUARTERSTAFF@2": "quarterstaff",
    "T5_2H_QUARTERSTAFF@3": "quarterstaff",
    "T6_2H_QUARTERSTAFF": "quarterstaff",
    "T6_2H_QUARTERSTAFF@1": "quarterstaff",
    "T6_2H_QUARTERSTAFF@2": "quarterstaff",
    "T6_2H_QUARTERSTAFF@3": "quarterstaff",
    "T7_2H_QUARTERSTAFF": "quarterstaff",
    "T7_2H_QUARTERSTAFF@1": "quarterstaff",
    "T7_2H_QUARTERSTAFF@2": "quarterstaff",
    "T7_2H_QUARTERSTAFF@3": "quarterstaff",
    "T8_2H_QUARTERSTAFF": "quarterstaff",
    "T8_2H_QUARTERSTAFF@1": "quarterstaff",
    "T8_2H_QUARTERSTAFF@2": "quarterstaff",
    "T8_2H_QUARTERSTAFF@3": "quarterstaff",
    "T4_2H_IRONCLADEDSTAFF": "quarterstaff",
    "T4_2H_IRONCLADEDSTAFF@1": "quarterstaff",
    "T4_2H_IRONCLADEDSTAFF@2": "quarterstaff",
    "T4_2H_IRONCLADEDSTAFF@3": "quarterstaff",
    "T5_2H_IRONCLADEDSTAFF": "quarterstaff",
    "T5_2H_IRONCLADEDSTAFF@1": "quarterstaff",
    "T5_2H_IRONCLADEDSTAFF@2": "quarterstaff",
    "T5_2H_IRONCLADEDSTAFF@3": "quarterstaff",
    "T6_2H_IRONCLADEDSTAFF": "quarterstaff",
    "T6_2H_IRONCLADEDSTAFF@1": "quarterstaff",
    "T6_2H_IRONCLADEDSTAFF@2": "quarterstaff",
    "T6_2H_IRONCLADEDSTAFF@3": "quarterstaff",
    "T7_2H_IRONCLADEDSTAFF": "quarterstaff",
    "T7_2H_IRONCLADEDSTAFF@1": "quarterstaff",
    "T7_2H_IRONCLADEDSTAFF@2": "quarterstaff",
    "T7_2H_IRONCLADEDSTAFF@3": "quarterstaff",
    "T8_2H_IRONCLADEDSTAFF": "quarterstaff",
    "T8_2H_IRONCLADEDSTAFF@1": "quarterstaff",
    "T8_2H_IRONCLADEDSTAFF@2": "quarterstaff",
    "T8_2H_IRONCLADEDSTAFF@3": "quarterstaff",
    "T4_2H_DOUBLEBLADEDSTAFF": "quarterstaff",
    "T4_2H_DOUBLEBLADEDSTAFF@1": "quarterstaff",
    "T4_2H_DOUBLEBLADEDSTAFF@2": "quarterstaff",
    "T4_2H_DOUBLEBLADEDSTAFF@3": "quarterstaff",
    "T5_2H_DOUBLEBLADEDSTAFF": "quarterstaff",
    "T5_2H_DOUBLEBLADEDSTAFF@1": "quarterstaff",
    "T5_2H_DOUBLEBLADEDSTAFF@2": "quarterstaff",
    "T5_2H_DOUBLEBLADEDSTAFF@3": "quarterstaff",
    "T6_2H_DOUBLEBLADEDSTAFF": "quarterstaff",
    "T6_2H_DOUBLEBLADEDSTAFF@1": "quarterstaff",
    "T6_2H_DOUBLEBLADEDSTAFF@2": "quarterstaff",
    "T6_2H_DOUBLEBLADEDSTAFF@3": "quarterstaff",
    "T7_2H_DOUBLEBLADEDSTAFF": "quarterstaff",
    "T7_2H_DOUBLEBLADEDSTAFF@1": "quarterstaff",
    "T7_2H_DOUBLEBLADEDSTAFF@2": "quarterstaff",
    "T7_2H_DOUBLEBLADEDSTAFF@3": "quarterstaff",
    "T8_2H_DOUBLEBLADEDSTAFF": "quarterstaff",
    "T8_2H_DOUBLEBLADEDSTAFF@1": "quarterstaff",
    "T8_2H_DOUBLEBLADEDSTAFF@2": "quarterstaff",
    "T8_2H_DOUBLEBLADEDSTAFF@3": "quarterstaff",
    "T4_2H_COMBATSTAFF_MORGANA": "quarterstaff",
    "T4_2H_COMBATSTAFF_MORGANA@1": "quarterstaff",
    "T4_2H_COMBATSTAFF_MORGANA@2": "quarterstaff",
    "T4_2H_COMBATSTAFF_MORGANA@3": "quarterstaff",
    "T5_2H_COMBATSTAFF_MORGANA": "quarterstaff",
    "T5_2H_COMBATSTAFF_MORGANA@1": "quarterstaff",
    "T5_2H_COMBATSTAFF_MORGANA@2": "quarterstaff",
    "T5_2H_COMBATSTAFF_MORGANA@3": "quarterstaff",
    "T6_2H_COMBATSTAFF_MORGANA": "quarterstaff",
    "T6_2H_COMBATSTAFF_MORGANA@1": "quarterstaff",
    "T6_2H_COMBATSTAFF_MORGANA@2": "quarterstaff",
    "T6_2H_COMBATSTAFF_MORGANA@3": "quarterstaff",
    "T7_2H_COMBATSTAFF_MORGANA": "quarterstaff",
    "T7_2H_COMBATSTAFF_MORGANA@1": "quarterstaff",
    "T7_2H_COMBATSTAFF_MORGANA@2": "quarterstaff",
    "T7_2H_COMBATSTAFF_MORGANA@3": "quarterstaff",
    "T8_2H_COMBATSTAFF_MORGANA": "quarterstaff",
    "T8_2H_COMBATSTAFF_MORGANA@1": "quarterstaff",
    "T8_2H_COMBATSTAFF_MORGANA@2": "quarterstaff",
    "T8_2H_COMBATSTAFF_MORGANA@3": "quarterstaff",
    "T4_2H_TWINSCYTHE_HELL": "quarterstaff",
    "T4_2H_TWINSCYTHE_HELL@1": "quarterstaff",
    "T4_2H_TWINSCYTHE_HELL@2": "quarterstaff",
    "T4_2H_TWINSCYTHE_HELL@3": "quarterstaff",
    "T5_2H_TWINSCYTHE_HELL": "quarterstaff",
    "T5_2H_TWINSCYTHE_HELL@1": "quarterstaff",
    "T5_2H_TWINSCYTHE_HELL@2": "quarterstaff",
    "T5_2H_TWINSCYTHE_HELL@3": "quarterstaff",
    "T6_2H_TWINSCYTHE_HELL": "quarterstaff",
    "T6_2H_TWINSCYTHE_HELL@1": "quarterstaff",
    "T6_2H_TWINSCYTHE_HELL@2": "quarterstaff",
    "T6_2H_TWINSCYTHE_HELL@3": "quarterstaff",
    "T7_2H_TWINSCYTHE_HELL": "quarterstaff",
    "T7_2H_TWINSCYTHE_HELL@1": "quarterstaff",
    "T7_2H_TWINSCYTHE_HELL@2": "quarterstaff",
    "T7_2H_TWINSCYTHE_HELL@3": "quarterstaff",
    "T8_2H_TWINSCYTHE_HELL": "quarterstaff",
    "T8_2H_TWINSCYTHE_HELL@1": "quarterstaff",
    "T8_2H_TWINSCYTHE_HELL@2": "quarterstaff",
    "T8_2H_TWINSCYTHE_HELL@3": "quarterstaff",
    "T4_2H_ROCKSTAFF_KEEPER": "quarterstaff",
    "T4_2H_ROCKSTAFF_KEEPER@1": "quarterstaff",
    "T4_2H_ROCKSTAFF_KEEPER@2": "quarterstaff",
    "T4_2H_ROCKSTAFF_KEEPER@3": "quarterstaff",
    "T5_2H_ROCKSTAFF_KEEPER": "quarterstaff",
    "T5_2H_ROCKSTAFF_KEEPER@1": "quarterstaff",
    "T5_2H_ROCKSTAFF_KEEPER@2": "quarterstaff",
    "T5_2H_ROCKSTAFF_KEEPER@3": "quarterstaff",
    "T6_2H_ROCKSTAFF_KEEPER": "quarterstaff",
    "T6_2H_ROCKSTAFF_KEEPER@1": "quarterstaff",
    "T6_2H_ROCKSTAFF_KEEPER@2": "quarterstaff",
    "T6_2H_ROCKSTAFF_KEEPER@3": "quarterstaff",
    "T7_2H_ROCKSTAFF_KEEPER": "quarterstaff",
    "T7_2H_ROCKSTAFF_KEEPER@1": "quarterstaff",
    "T7_2H_ROCKSTAFF_KEEPER@2": "quarterstaff",
    "T7_2H_ROCKSTAFF_KEEPER@3": "quarterstaff",
    "T8_2H_ROCKSTAFF_KEEPER": "quarterstaff",
    "T8_2H_ROCKSTAFF_KEEPER@1": "quarterstaff",
    "T8_2H_ROCKSTAFF_KEEPER@2": "quarterstaff",
    "T8_2H_ROCKSTAFF_KEEPER@3": "quarterstaff",
    "T4_2H_QUARTERSTAFF_AVALON": "quarterstaff",
    "T4_2H_QUARTERSTAFF_AVALON@1": "quarterstaff",
    "T4_2H_QUARTERSTAFF_AVALON@2": "quarterstaff",
    "T4_2H_QUARTERSTAFF_AVALON@3": "quarterstaff",
    "T5_2H_QUARTERSTAFF_AVALON": "quarterstaff",
    "T5_2H_QUARTERSTAFF_AVALON@1": "quarterstaff",
    "T5_2H_QUARTERSTAFF_AVALON@2": "quarterstaff",
    "T5_2H_QUARTERSTAFF_AVALON@3": "quarterstaff",
    "T6_2H_QUARTERSTAFF_AVALON": "quarterstaff",
    "T6_2H_QUARTERSTAFF_AVALON@1": "quarterstaff",
    "T6_2H_QUARTERSTAFF_AVALON@2": "quarterstaff",
    "T6_2H_QUARTERSTAFF_AVALON@3": "quarterstaff",
    "T7_2H_QUARTERSTAFF_AVALON": "quarterstaff",
    "T7_2H_QUARTERSTAFF_AVALON@1": "quarterstaff",
    "T7_2H_QUARTERSTAFF_AVALON@2": "quarterstaff",
    "T7_2H_QUARTERSTAFF_AVALON@3": "quarterstaff",
    "T8_2H_QUARTERSTAFF_AVALON": "quarterstaff",
    "T8_2H_QUARTERSTAFF_AVALON@1": "quarterstaff",
    "T8_2H_QUARTERSTAFF_AVALON@2": "quarterstaff",
    "T8_2H_QUARTERSTAFF_AVALON@3": "quarterstaff",
    "T3_MAIN_HAMMER": "hammer",
    "T4_MAIN_HAMMER": "hammer",
    "T4_MAIN_HAMMER@1": "hammer",
    "T4_MAIN_HAMMER@2": "hammer",
    "T4_MAIN_HAMMER@3": "hammer",
    "T5_MAIN_HAMMER": "hammer",
    "T5_MAIN_HAMMER@1": "hammer",
    "T5_MAIN_HAMMER@2": "hammer",
    "T5_MAIN_HAMMER@3": "hammer",
    "T6_MAIN_HAMMER": "hammer",
    "T6_MAIN_HAMMER@1": "hammer",
    "T6_MAIN_HAMMER@2": "hammer",
    "T6_MAIN_HAMMER@3": "hammer",
    "T7_MAIN_HAMMER": "hammer",
    "T7_MAIN_HAMMER@1": "hammer",
    "T7_MAIN_HAMMER@2": "hammer",
    "T7_MAIN_HAMMER@3": "hammer",
    "T8_MAIN_HAMMER": "hammer",
    "T8_MAIN_HAMMER@1": "hammer",
    "T8_MAIN_HAMMER@2": "hammer",
    "T8_MAIN_HAMMER@3": "hammer",
    "T4_2H_POLEHAMMER": "hammer",
    "T4_2H_POLEHAMMER@1": "hammer",
    "T4_2H_POLEHAMMER@2": "hammer",
    "T4_2H_POLEHAMMER@3": "hammer",
    "T5_2H_POLEHAMMER": "hammer",
    "T5_2H_POLEHAMMER@1": "hammer",
    "T5_2H_POLEHAMMER@2": "hammer",
    "T5_2H_POLEHAMMER@3": "hammer",
    "T6_2H_POLEHAMMER": "hammer",
    "T6_2H_POLEHAMMER@1": "hammer",
    "T6_2H_POLEHAMMER@2": "hammer",
    "T6_2H_POLEHAMMER@3": "hammer",
    "T7_2H_POLEHAMMER": "hammer",
    "T7_2H_POLEHAMMER@1": "hammer",
    "T7_2H_POLEHAMMER@2": "hammer",
    "T7_2H_POLEHAMMER@3": "hammer",
    "T8_2H_POLEHAMMER": "hammer",
    "T8_2H_POLEHAMMER@1": "hammer",
    "T8_2H_POLEHAMMER@2": "hammer",
    "T8_2H_POLEHAMMER@3": "hammer",
    "T4_2H_HAMMER": "hammer",
    "T4_2H_HAMMER@1": "hammer",
    "T4_2H_HAMMER@2": "hammer",
    "T4_2H_HAMMER@3": "hammer",
    "T5_2H_HAMMER": "hammer",
    "T5_2H_HAMMER@1": "hammer",
    "T5_2H_HAMMER@2": "hammer",
    "T5_2H_HAMMER@3": "hammer",
    "T6_2H_HAMMER": "hammer",
    "T6_2H_HAMMER@1": "hammer",
    "T6_2H_HAMMER@2": "hammer",
    "T6_2H_HAMMER@3": "hammer",
    "T7_2H_HAMMER": "hammer",
    "T7_2H_HAMMER@1": "hammer",
    "T7_2H_HAMMER@2": "hammer",
    "T7_2H_HAMMER@3": "hammer",
    "T8_2H_HAMMER": "hammer",
    "T8_2H_HAMMER@1": "hammer",
    "T8_2H_HAMMER@2": "hammer",
    "T8_2H_HAMMER@3": "hammer",
    "T4_2H_HAMMER_UNDEAD": "hammer",
    "T4_2H_HAMMER_UNDEAD@1": "hammer",
    "T4_2H_HAMMER_UNDEAD@2": "hammer",
    "T4_2H_HAMMER_UNDEAD@3": "hammer",
    "T5_2H_HAMMER_UNDEAD": "hammer",
    "T5_2H_HAMMER_UNDEAD@1": "hammer",
    "T5_2H_HAMMER_UNDEAD@2": "hammer",
    "T5_2H_HAMMER_UNDEAD@3": "hammer",
    "T6_2H_HAMMER_UNDEAD": "hammer",
    "T6_2H_HAMMER_UNDEAD@1": "hammer",
    "T6_2H_HAMMER_UNDEAD@2": "hammer",
    "T6_2H_HAMMER_UNDEAD@3": "hammer",
    "T7_2H_HAMMER_UNDEAD": "hammer",
    "T7_2H_HAMMER_UNDEAD@1": "hammer",
    "T7_2H_HAMMER_UNDEAD@2": "hammer",
    "T7_2H_HAMMER_UNDEAD@3": "hammer",
    "T8_2H_HAMMER_UNDEAD": "hammer",
    "T8_2H_HAMMER_UNDEAD@1": "hammer",
    "T8_2H_HAMMER_UNDEAD@2": "hammer",
    "T8_2H_HAMMER_UNDEAD@3": "hammer",
    "T4_2H_DUALHAMMER_HELL": "hammer",
    "T4_2H_DUALHAMMER_HELL@1": "hammer",
    "T4_2H_DUALHAMMER_HELL@2": "hammer",
    "T4_2H_DUALHAMMER_HELL@3": "hammer",
    "T5_2H_DUALHAMMER_HELL": "hammer",
    "T5_2H_DUALHAMMER_HELL@1": "hammer",
    "T5_2H_DUALHAMMER_HELL@2": "hammer",
    "T5_2H_DUALHAMMER_HELL@3": "hammer",
    "T6_2H_DUALHAMMER_HELL": "hammer",
    "T6_2H_DUALHAMMER_HELL@1": "hammer",
    "T6_2H_DUALHAMMER_HELL@2": "hammer",
    "T6_2H_DUALHAMMER_HELL@3": "hammer",
    "T7_2H_DUALHAMMER_HELL": "hammer",
    "T7_2H_DUALHAMMER_HELL@1": "hammer",
    "T7_2H_DUALHAMMER_HELL@2": "hammer",
    "T7_2H_DUALHAMMER_HELL@3": "hammer",
    "T8_2H_DUALHAMMER_HELL": "hammer",
    "T8_2H_DUALHAMMER_HELL@1": "hammer",
    "T8_2H_DUALHAMMER_HELL@2": "hammer",
    "T8_2H_DUALHAMMER_HELL@3": "hammer",
    "T4_2H_RAM_KEEPER": "hammer",
    "T4_2H_RAM_KEEPER@1": "hammer",
    "T4_2H_RAM_KEEPER@2": "hammer",
    "T4_2H_RAM_KEEPER@3": "hammer",
    "T5_2H_RAM_KEEPER": "hammer",
    "T5_2H_RAM_KEEPER@1": "hammer",
    "T5_2H_RAM_KEEPER@2": "hammer",
    "T5_2H_RAM_KEEPER@3": "hammer",
    "T6_2H_RAM_KEEPER": "hammer",
    "T6_2H_RAM_KEEPER@1": "hammer",
    "T6_2H_RAM_KEEPER@2": "hammer",
    "T6_2H_RAM_KEEPER@3": "hammer",
    "T7_2H_RAM_KEEPER": "hammer",
    "T7_2H_RAM_KEEPER@1": "hammer",
    "T7_2H_RAM_KEEPER@2": "hammer",
    "T7_2H_RAM_KEEPER@3": "hammer",
    "T8_2H_RAM_KEEPER": "hammer",
    "T8_2H_RAM_KEEPER@1": "hammer",
    "T8_2H_RAM_KEEPER@2": "hammer",
    "T8_2H_RAM_KEEPER@3": "hammer",
    "T4_2H_HAMMER_AVALON": "hammer",
    "T4_2H_HAMMER_AVALON@1": "hammer",
    "T4_2H_HAMMER_AVALON@2": "hammer",
    "T4_2H_HAMMER_AVALON@3": "hammer",
    "T5_2H_HAMMER_AVALON": "hammer",
    "T5_2H_HAMMER_AVALON@1": "hammer",
    "T5_2H_HAMMER_AVALON@2": "hammer",
    "T5_2H_HAMMER_AVALON@3": "hammer",
    "T6_2H_HAMMER_AVALON": "hammer",
    "T6_2H_HAMMER_AVALON@1": "hammer",
    "T6_2H_HAMMER_AVALON@2": "hammer",
    "T6_2H_HAMMER_AVALON@3": "hammer",
    "T7_2H_HAMMER_AVALON": "hammer",
    "T7_2H_HAMMER_AVALON@1": "hammer",
    "T7_2H_HAMMER_AVALON@2": "hammer",
    "T7_2H_HAMMER_AVALON@3": "hammer",
    "T8_2H_HAMMER_AVALON": "hammer",
    "T8_2H_HAMMER_AVALON@1": "hammer",
    "T8_2H_HAMMER_AVALON@2": "hammer",
    "T8_2H_HAMMER_AVALON@3": "hammer",
    "T3_MAIN_MACE": "mace",
    "T4_MAIN_MACE": "mace",
    "T4_MAIN_MACE@1": "mace",
    "T4_MAIN_MACE@2": "mace",
    "T4_MAIN_MACE@3": "mace",
    "T5_MAIN_MACE": "mace",
    "T5_MAIN_MACE@1": "mace",
    "T5_MAIN_MACE@2": "mace",
    "T5_MAIN_MACE@3": "mace",
    "T6_MAIN_MACE": "mace",
    "T6_MAIN_MACE@1": "mace",
    "T6_MAIN_MACE@2": "mace",
    "T6_MAIN_MACE@3": "mace",
    "T7_MAIN_MACE": "mace",
    "T7_MAIN_MACE@1": "mace",
    "T7_MAIN_MACE@2": "mace",
    "T7_MAIN_MACE@3": "mace",
    "T8_MAIN_MACE": "mace",
    "T8_MAIN_MACE@1": "mace",
    "T8_MAIN_MACE@2": "mace",
    "T8_MAIN_MACE@3": "mace",
    "T4_2H_MACE": "mace",
    "T4_2H_MACE@1": "mace",
    "T4_2H_MACE@2": "mace",
    "T4_2H_MACE@3": "mace",
    "T5_2H_MACE": "mace",
    "T5_2H_MACE@1": "mace",
    "T5_2H_MACE@2": "mace",
    "T5_2H_MACE@3": "mace",
    "T6_2H_MACE": "mace",
    "T6_2H_MACE@1": "mace",
    "T6_2H_MACE@2": "mace",
    "T6_2H_MACE@3": "mace",
    "T7_2H_MACE": "mace",
    "T7_2H_MACE@1": "mace",
    "T7_2H_MACE@2": "mace",
    "T7_2H_MACE@3": "mace",
    "T8_2H_MACE": "mace",
    "T8_2H_MACE@1": "mace",
    "T8_2H_MACE@2": "mace",
    "T8_2H_MACE@3": "mace",
    "T4_2H_FLAIL": "mace",
    "T4_2H_FLAIL@1": "mace",
    "T4_2H_FLAIL@2": "mace",
    "T4_2H_FLAIL@3": "mace",
    "T5_2H_FLAIL": "mace",
    "T5_2H_FLAIL@1": "mace",
    "T5_2H_FLAIL@2": "mace",
    "T5_2H_FLAIL@3": "mace",
    "T6_2H_FLAIL": "mace",
    "T6_2H_FLAIL@1": "mace",
    "T6_2H_FLAIL@2": "mace",
    "T6_2H_FLAIL@3": "mace",
    "T7_2H_FLAIL": "mace",
    "T7_2H_FLAIL@1": "mace",
    "T7_2H_FLAIL@2": "mace",
    "T7_2H_FLAIL@3": "mace",
    "T8_2H_FLAIL": "mace",
    "T8_2H_FLAIL@1": "mace",
    "T8_2H_FLAIL@2": "mace",
    "T8_2H_FLAIL@3": "mace",
    "T4_MAIN_ROCKMACE_KEEPER": "mace",
    "T4_MAIN_ROCKMACE_KEEPER@1": "mace",
    "T4_MAIN_ROCKMACE_KEEPER@2": "mace",
    "T4_MAIN_ROCKMACE_KEEPER@3": "mace",
    "T5_MAIN_ROCKMACE_KEEPER": "mace",
    "T5_MAIN_ROCKMACE_KEEPER@1": "mace",
    "T5_MAIN_ROCKMACE_KEEPER@2": "mace",
    "T5_MAIN_ROCKMACE_KEEPER@3": "mace",
    "T6_MAIN_ROCKMACE_KEEPER": "mace",
    "T6_MAIN_ROCKMACE_KEEPER@1": "mace",
    "T6_MAIN_ROCKMACE_KEEPER@2": "mace",
    "T6_MAIN_ROCKMACE_KEEPER@3": "mace",
    "T7_MAIN_ROCKMACE_KEEPER": "mace",
    "T7_MAIN_ROCKMACE_KEEPER@1": "mace",
    "T7_MAIN_ROCKMACE_KEEPER@2": "mace",
    "T7_MAIN_ROCKMACE_KEEPER@3": "mace",
    "T8_MAIN_ROCKMACE_KEEPER": "mace",
    "T8_MAIN_ROCKMACE_KEEPER@1": "mace",
    "T8_MAIN_ROCKMACE_KEEPER@2": "mace",
    "T8_MAIN_ROCKMACE_KEEPER@3": "mace",
    "T4_MAIN_MACE_HELL": "mace",
    "T4_MAIN_MACE_HELL@1": "mace",
    "T4_MAIN_MACE_HELL@2": "mace",
    "T4_MAIN_MACE_HELL@3": "mace",
    "T5_MAIN_MACE_HELL": "mace",
    "T5_MAIN_MACE_HELL@1": "mace",
    "T5_MAIN_MACE_HELL@2": "mace",
    "T5_MAIN_MACE_HELL@3": "mace",
    "T6_MAIN_MACE_HELL": "mace",
    "T6_MAIN_MACE_HELL@1": "mace",
    "T6_MAIN_MACE_HELL@2": "mace",
    "T6_MAIN_MACE_HELL@3": "mace",
    "T7_MAIN_MACE_HELL": "mace",
    "T7_MAIN_MACE_HELL@1": "mace",
    "T7_MAIN_MACE_HELL@2": "mace",
    "T7_MAIN_MACE_HELL@3": "mace",
    "T8_MAIN_MACE_HELL": "mace",
    "T8_MAIN_MACE_HELL@1": "mace",
    "T8_MAIN_MACE_HELL@2": "mace",
    "T8_MAIN_MACE_HELL@3": "mace",
    "T4_2H_MACE_MORGANA": "mace",
    "T4_2H_MACE_MORGANA@1": "mace",
    "T4_2H_MACE_MORGANA@2": "mace",
    "T4_2H_MACE_MORGANA@3": "mace",
    "T5_2H_MACE_MORGANA": "mace",
    "T5_2H_MACE_MORGANA@1": "mace",
    "T5_2H_MACE_MORGANA@2": "mace",
    "T5_2H_MACE_MORGANA@3": "mace",
    "T6_2H_MACE_MORGANA": "mace",
    "T6_2H_MACE_MORGANA@1": "mace",
    "T6_2H_MACE_MORGANA@2": "mace",
    "T6_2H_MACE_MORGANA@3": "mace",
    "T7_2H_MACE_MORGANA": "mace",
    "T7_2H_MACE_MORGANA@1": "mace",
    "T7_2H_MACE_MORGANA@2": "mace",
    "T7_2H_MACE_MORGANA@3": "mace",
    "T8_2H_MACE_MORGANA": "mace",
    "T8_2H_MACE_MORGANA@1": "mace",
    "T8_2H_MACE_MORGANA@2": "mace",
    "T8_2H_MACE_MORGANA@3": "mace",
    "T4_2H_DUALMACE_AVALON": "mace",
    "T4_2H_DUALMACE_AVALON@1": "mace",
    "T4_2H_DUALMACE_AVALON@2": "mace",
    "T4_2H_DUALMACE_AVALON@3": "mace",
    "T5_2H_DUALMACE_AVALON": "mace",
    "T5_2H_DUALMACE_AVALON@1": "mace",
    "T5_2H_DUALMACE_AVALON@2": "mace",
    "T5_2H_DUALMACE_AVALON@3": "mace",
    "T6_2H_DUALMACE_AVALON": "mace",
    "T6_2H_DUALMACE_AVALON@1": "mace",
    "T6_2H_DUALMACE_AVALON@2": "mace",
    "T6_2H_DUALMACE_AVALON@3": "mace",
    "T7_2H_DUALMACE_AVALON": "mace",
    "T7_2H_DUALMACE_AVALON@1": "mace",
    "T7_2H_DUALMACE_AVALON@2": "mace",
    "T7_2H_DUALMACE_AVALON@3": "mace",
    "T8_2H_DUALMACE_AVALON": "mace",
    "T8_2H_DUALMACE_AVALON@1": "mace",
    "T8_2H_DUALMACE_AVALON@2": "mace",
    "T8_2H_DUALMACE_AVALON@3": "mace",
    "UNIQUE_WEAPONMASTER_POTION_PROTOTYPE": "potion",
    "UNIQUE_WEAPONMASTER_IDLE_PROTOTYPE": "potion",
    "UNIQUE_FOCUSPOTION_ADC_GENERAL_01": "potion",
    "UNIQUE_FOCUSPOTION_ADC_NONTRADABLE_01": "potion",
    "UNIQUE_FOCUSPOTION_TUTORIAL_01": "potion",
    "T7_MAIN_SUMMONERSTAFF_PROTOTYPE": "cursestaff",
    "T7_MAIN_SUMMONERSTAFF_PROTOTYPE@1": "cursestaff",
    "T7_MAIN_SUMMONERSTAFF_PROTOTYPE@2": "cursestaff",
    "T7_MAIN_SUMMONERSTAFF_PROTOTYPE@3": "cursestaff",
    "T8_SHOES_PLATE_VANITY_PERFTEST_HIGH": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_HIGH@1": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_HIGH@2": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_HIGH@3": "plate_shoes",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_HIGH": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_HIGH@1": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_HIGH@2": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_HIGH@3": "plate_armor",
    "T8_HEAD_PLATE_VANITY_PERFTEST_HIGH": "plate_helmet",
    "T8_HEAD_PLATE_VANITY_PERFTEST_HIGH@1": "plate_helmet",
    "T8_HEAD_PLATE_VANITY_PERFTEST_HIGH@2": "plate_helmet",
    "T8_HEAD_PLATE_VANITY_PERFTEST_HIGH@3": "plate_helmet",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_VERYHIGH": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_VERYHIGH@1": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_VERYHIGH@2": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_VERYHIGH@3": "plate_armor",
    "T8_SHOES_PLATE_VANITY_PERFTEST_NO_FX": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_NO_FX@1": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_NO_FX@2": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_NO_FX@3": "plate_shoes",
    "T8_HEAD_PLATE_VANITY_PERFTEST_NO_FX": "plate_helmet",
    "T8_HEAD_PLATE_VANITY_PERFTEST_NO_FX@1": "plate_helmet",
    "T8_HEAD_PLATE_VANITY_PERFTEST_NO_FX@2": "plate_helmet",
    "T8_HEAD_PLATE_VANITY_PERFTEST_NO_FX@3": "plate_helmet",
    "T8_SHOES_PLATE_VANITY_PERFTEST_MESHONLY": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_MESHONLY@1": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_MESHONLY@2": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_MESHONLY@3": "plate_shoes",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_MESHONLY": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_MESHONLY@1": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_MESHONLY@2": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_MESHONLY@3": "plate_armor",
    "T8_SHOES_PLATE_VANITY_PERFTEST_PARTICLEONLY": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_PARTICLEONLY@1": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_PARTICLEONLY@2": "plate_shoes",
    "T8_SHOES_PLATE_VANITY_PERFTEST_PARTICLEONLY@3": "plate_shoes",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_PARTICLEONLY": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_PARTICLEONLY@1": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_PARTICLEONLY@2": "plate_armor",
    "T8_ARMOR_PLATE_VANITY_PERFTEST_PARTICLEONLY@3": "plate_armor"
}
